OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Navedena adresa e-pošte je preduga",
    "User-Session unexpectedly expired" : "Korisnička sesija neočekivano je istekla",
    "Provided email-address is not valid" : "Unesena adresa e-pošte nije važeća",
    "%s has published the calendar »%s«" : "%s je objavio kalendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Došlo je do pogreške pri slanju poruke e-pošte. Obratite se svom administratoru.",
    "Successfully sent email to %1$s" : "Poruka e-pošte uspješno je poslana na %1$s",
    "Hello," : "Pozdrav,",
    "We wanted to inform you that %s has published the calendar »%s«." : "htjeli bismo vas obavijestiti da je %s objavio kalendar »%s«.",
    "Open »%s«" : "Otvori »%s«",
    "Cheers!" : "Bok!",
    "Upcoming events" : "Nadolazeći događaji",
    "No more events today" : "Danas više nema događaja",
    "No upcoming events" : "Nema nadolazećih događaja",
    "More events" : "Više događaja",
    "%1$s with %2$s" : "%1$s sa %2$s",
    "Calendar" : "Kalendar",
    "New booking {booking}" : "Nova rezervacija {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) rezervirao/la je termin \"{config_display_name}\" za {date_time}.",
    "Appointments" : "Termini",
    "Schedule appointment \"%s\"" : "Zakaži termin \"%s\"",
    "Schedule an appointment" : "Zakaži termin",
    "Requestor Comments:" : "Komentari podnositelja zahtjeva:",
    "Appointment Description:" : "Opis termina:",
    "Prepare for %s" : "Pripremi za %s",
    "Follow up for %s" : "Praćenje za %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Vaš termin \"%s\" s %s treba potvrdu",
    "Dear %s, please confirm your booking" : "Poštovani %s, molimo potvrdite svoju rezervaciju",
    "Confirm" : "Potvrdi",
    "Appointment with:" : "Termin s:",
    "Description:" : "Opis:",
    "This confirmation link expires in %s hours." : "Ova poveznica za potvrdu istječe za %s sati.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ako ipak želite otkazati termin, obratite se organizatoru odgovorom na ovu e-poruku ili posjetom njegovoj/njezinoj stranici profila.",
    "Your appointment \"%s\" with %s has been accepted" : "Vaš termin \"%s\" s %s je prihvaćen",
    "Dear %s, your booking has been accepted." : "Poštovani %s, vaša je rezervacija prihvaćena.",
    "Appointment for:" : "Termin za:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Poveznicu ćete dobiti u e-poruci s potvrdom",
    "Where:" : "Gdje:",
    "Comment:" : "Komentar:",
    "You have a new appointment booking \"%s\" from %s" : "Imate novu rezervaciju termina \"%s\" od %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Poštovani %s, %s (%s) rezervirao/la je termin s vama.",
    "%s has proposed a meeting" : "%s je predložio/la sastanak",
    "%s has updated a proposed meeting" : "%s je ažurirao/la predloženi sastanak",
    "%s has canceled a proposed meeting" : "%s je otkazao/la predloženi sastanak",
    "Dear %s, a new meeting has been proposed" : "Poštovani %s, predložen je novi sastanak",
    "Dear %s, a proposed meeting has been updated" : "Poštovani %s, predloženi sastanak je ažuriran",
    "Dear %s, a proposed meeting has been cancelled" : "Poštovani %s, predloženi sastanak je otkazan",
    "Respond" : "Odgovori",
    "Location:" : "Lokacija:",
    "%1$s minutes" : "%1$s min",
    "Duration:" : "Trajanje:",
    "%1$s from %2$s to %3$s" : "%1$s od %2$s do %3$s",
    "Dates:" : "Datumi:",
    "[Proposed] %1$s" : "[Predloženo] %1$s",
    "Calendar App" : "Aplikacija Kalendar",
    "Calendars App settings including proposals and appointments schedule configurations." : "Postavke aplikacije Kalendar, uključujući prijedloge sastanaka i konfiguracije rasporeda termina.",
    "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikacija Kalendar za Nextcloud. Jednostavno sinkronizirajte događaje s raznih uređaja s vašim Nextcloudom i uređujte ih na mreži.\n\n* 🚀 **Integracija s drugim Nextcloud aplikacijama!** Poput Kontakata, Talka, Zadataka, Decka i Krugova\n* 🌐 **WebCal podrška!** Želite vidjeti raspored utakmica omiljenog tima u kalendaru? Nema problema!\n* 🙋 **Sudionici!** Pozovite osobe na svoje događaje\n* ⌚ **Slobodno/Zauzeto!** Pogledajte kada su sudionici dostupni za sastanak\n* ⏰ **Podsjetnici!** Primajte obavijesti o događajima u pregledniku i e-poštom\n* 🔍 **Pretraživanje!** Jednostavno pronađite svoje događaje\n* ☑️ **Zadaci!** Prikazujte zadatke ili Deck kartice s rokom izravno u kalendaru\n* 🔈 **Talk sobe!** Stvorite povezanu Talk sobu pri zakazivanju sastanka jednim klikom\n* 📆 **Rezervacija termina** Pošaljite ljudima poveznicu kako bi mogli rezervirati termin s vama [pomoću ove aplikacije](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Privitci!** Dodajte, prenesite i pregledajte privitke događaja\n* 🙈 **Ne izmišljamo toplu vodu!** Temeljeno na odličnim bibliotekama [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) i [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Prethodni dan",
    "Previous week" : "Prethodni tjedan",
    "Previous year" : "Prethodna godina",
    "Previous month" : "Prethodni mjesec",
    "Next day" : "Sljedeći dan",
    "Next week" : "Sljedeći tjedan",
    "Next year" : "Sljedeće godine",
    "Next month" : "Sljedeći mjesec",
    "Create new event" : "Stvori novi događaj",
    "Event" : "Događaj",
    "Today" : "Danas",
    "Day" : "Dan",
    "Week" : "Tjedan",
    "Month" : "Mjesec",
    "Year" : "Godina",
    "List" : "Popis",
    "Appointment link was copied to clipboard" : "Poveznica termina kopirana je u međuspremnik",
    "Appointment link could not be copied to clipboard" : "Poveznicu termina nije moguće kopirati u međuspremnik",
    "Preview" : "Pretpregled",
    "Copy link" : "Kopiraj poveznicu",
    "Duplicate" : "Dupliciraj",
    "Edit" : "Uredi",
    "Delete" : "Izbriši",
    "Appointment schedules" : "Rasporedi termina",
    "Create new" : "Stvori novi",
    "Disable calendar \"{calendar}\"" : "Onemogući kalendar \"{calendar}\"",
    "Disable untitled calendar" : "Onemogući kalendar bez naslova",
    "Enable calendar \"{calendar}\"" : "Omogući kalendar \"{calendar}\"",
    "Enable untitled calendar" : "Omogući kalendar bez naslova",
    "An error occurred, unable to change visibility of the calendar." : "Došlo je do pogreške, nije moguće promijeniti vidljivost kalendara.",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "Untitled calendar" : "Kalendar bez naslova",
    "Shared with you by" : "S vama podijelio",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "Edit and share calendar" : "Uredi i dijeli kalendar",
    "Edit calendar" : "Uredi kalendar",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
    "Calendar name can not be blank" : "Naziv kalendara ne može biti prazan",
    "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Unesite valjanu poveznicu (mora početi s http://, https://, webcal:// ili webcals://)",
    "My calendars" : "Moji kalendari",
    "Add new" : "Dodaj novo",
    "New calendar" : "Novi kalendar",
    "Name for new calendar" : "Naziv novog kalendara",
    "Creating calendar …" : "Stvaranje kalendara...",
    "New calendar with task list" : "Novi kalendar s popisom zadataka",
    "New subscription from link (read-only)" : "Nova pretplata putem poveznice (samo za čitanje)",
    "Creating subscription …" : "Stvaranje pretplate...",
    "Add public holiday calendar" : "Dodaj kalendar državnih praznika",
    "Add custom public calendar" : "Dodaj prilagođeni javni kalendar",
    "Copy subscription link" : "Kopiraj poveznicu pretplate",
    "Copying link …" : "Kopiranje poveznice...",
    "Copied link" : "Poveznica je kopirana",
    "Could not copy link" : "Kopiranje poveznice nije uspjelo",
    "Export" : "Izvoz",
    "Untitled item" : "Stavka bez naslova",
    "Unknown calendar" : "Nepoznati kalendar",
    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
    "Could not delete calendar or event" : "Nije moguće izbrisati kalendar ili događaj",
    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "Trash bin" : "Kanta za smeće",
    "Loading deleted items." : "Učitavanje obrisanih stavki.",
    "You do not have any deleted items." : "Nemate obrisanih stavki.",
    "Name" : "Naziv",
    "Deleted" : "Izbrisano",
    "Restore" : "Vrati",
    "Delete permanently" : "Trajno izbrišite",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Stavke u košu za smeće brišu se nakon {numDays} dana.","Stavke u košu za smeće brišu se nakon {numDays} dana.","Stavke u košu za smeće brišu se nakon {numDays} dana."],
    "Could not update calendar order." : "Ažuriranje redoslijeda kalendara nije uspjelo.",
    "Shared calendars" : "Dijeljeni kalendari",
    "Deck" : "Deck",
    "Tasks" : "Zadaci",
    "Internal link" : "Interna poveznica",
    "A private link that can be used with external clients" : "Privatna poveznica koja se može koristiti s vanjskim klijentima",
    "Copy internal link" : "Kopiraj internu poveznicu",
    "An error occurred, unable to publish calendar." : "Došlo je do pogreške, nije moguće objaviti kalendar.",
    "An error occurred, unable to send email." : "Došlo je do pogreške, nije moguće poslati poruku e-pošte.",
    "Embed code copied to clipboard." : "Šifra za ugradnju kopirana je u međuspremnik.",
    "Embed code could not be copied to clipboard." : "Šifru za ugradnju nije moguće kopirati u međuspremnik.",
    "Unpublishing calendar failed" : "Neuspješan prekid objave kalendara",
    "Share link" : "Dijeli poveznicu",
    "Send link to calendar via email" : "Pošalji poveznicu na kalendar putem e-pošte",
    "Enter one address" : "Unesi jednu adresu",
    "Sending email …" : "Slanje e-pošte u tijeku...",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Copying code …" : "Kopiranje šifre...",
    "Copied code" : "Šifra je kopirana",
    "Could not copy code" : "Kopiranje šifre nije uspjelo",
    "Delete share link" : "Izbriši poveznicu dijeljenja",
    "Deleting share link …" : "Brisanje poveznice dijeljenja...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Tim)",
    "An error occurred while unsharing the calendar." : "Došlo je do pogreške pri uklanjanju dijeljenja kalendara.",
    "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
    "can edit and see confidential events" : "može uređivati i vidjeti povjerljive događaje",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "events" : "događaji",
    "tasks" : "zadaci",
    "journal entries" : "zapisi dnevnika",
    "This calendar supports neither events, tasks nor journal entries." : "Ovaj kalendar ne podržava ni događaje, ni zadatke, ni zapise dnevnika.",
    "_This calendar supports only {types}._::_This calendar supports {types}._" : ["Ovaj kalendar podržava samo {types}.","Ovaj kalendar podržava {types}.","Ovaj kalendar podržava {types}."],
    "None" : "Nema",
    "Failed to save calendar name and color" : "Nije uspjelo spremiti naziv i boju kalendara",
    "Calendar name" : "Naziv kalendara",
    "Never show me as busy (set this calendar to transparent)" : "Nikad me ne prikazuj zauzetim (postavi ovaj kalendar kao proziran)",
    "Select default reminder" : "Odaberi zadani podsjetnik",
    "Share calendar" : "Dijeli kalendar",
    "Unshare from me" : "Prekid dijeljenja sa mnom",
    "Save" : "Spremi",
    "No title" : "Bez naslova",
    "Are you sure you want to delete \"{title}\"?" : "Jeste li sigurni da želite izbrisati \"{title}\"?",
    "Cancel" : "Odustani",
    "Deleting proposal \"{title}\"" : "Brisanje prijedloga \"{title}\"",
    "Successfully deleted proposal" : "Prijedlog je uspješno izbrisan",
    "Failed to delete proposal" : "Nije uspjelo izbrisati prijedlog",
    "Failed to retrieve proposals" : "Nije uspjelo dohvatiti prijedloge",
    "Meeting proposals" : "Prijedlozi sastanaka",
    "A configured email address is required to use meeting proposals" : "Za korištenje prijedloga sastanaka potrebna je konfigurirana adresa e-pošte",
    "No active meeting proposals" : "Nema aktivnih prijedloga sastanaka",
    "View" : "Pregledaj",
    "Delete proposal" : "Izbriši prijedlog",
    "Busy" : "Zauzeto",
    "Free" : "Dostupno",
    "Accepted" : "Prihvaćeno",
    "Tentative" : "Uvjetno",
    "Invited" : "Pozvan",
    "Icons" : "Ikone",
    "Attendees" : "Sudionici",
    "Import destination selection" : "Odabir odredišta uvoza",
    "Import calendars" : "Uvezi kalendare",
    "Please select a calendar to import into …" : "Odaberite kalendar za uvoz...",
    "Filename" : "Naziv datoteke",
    "Calendar to import into" : "Kalendar za uvoz",
    "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
    "Select the default location for attachments" : "Odaberite zadanu lokaciju za privitke",
    "Pick" : "Odaberi",
    "Invalid location selected" : "Odabrana je neispravna lokacija",
    "Attachments folder successfully saved." : "Mapa privitaka je uspješno spremljena.",
    "Error on saving attachments folder." : "Pogreška pri spremanju mape privitaka.",
    "Attachments folder" : "Mapa s privicima",
    "Revoke" : "Opozovi",
    "Viewer" : "Preglednik",
    "Editor" : "Uređivač",
    "No users found" : "Nije pronađen nijedan korisnik",
    "{filename} could not be parsed" : "Nije moguće parsirati {filename}",
    "No valid files found, aborting import" : "Nisu pronađene važeće datoteke, uvoz je otkazan",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspješno uvezen %n događaj","Uspješno uvezena %n događaja","Uspješno uvezeno %n događaja"],
    "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
    "Automatic" : "Automatsko",
    "Automatic ({timezone})" : "Automatski ({timezone})",
    "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
    "Timezone" : "Vremenska zona",
    "Navigation" : "Navigacija",
    "Previous period" : "Prethodno razdoblje",
    "Next period" : "Sljedeće razdoblje",
    "Views" : "Prikazi",
    "Day view" : "Dnevni prikaz",
    "Week view" : "Tjedni prikaz",
    "Month view" : "Mjesečni prikaz",
    "Year view" : "Godišnji prikaz",
    "List view" : "Prikaz popisa",
    "Actions" : "Radnje",
    "Create event" : "Stvori događaj",
    "Show shortcuts" : "Prikaži prečace",
    "Close editor" : "Zatvori uređivač",
    "Save edited event" : "Spremi uređeni događaj",
    "Delete edited event" : "Izbriši uređeni događaj",
    "Duplicate event" : "Dupliciraj događaj",
    "or" : "ili",
    "Calendar settings" : "Postavke kalendara",
    "No reminder" : "Nema podsjetnika",
    "At event start" : "Na početku događaja",
    "Failed to save default calendar" : "Spremanje zadanog kalendara nije uspjelo",
    "General" : "Općenito",
    "Default calendar for incoming invitations" : "Zadani kalendar za dolazne pozivnice",
    "Availability settings" : "Postavke dostupnosti",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Pristupite Nextcloud kalendarima iz drugih aplikacija i uređaja",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "Adresa poslužitelja za iOS i macOS",
    "Appearance" : "Izgled",
    "Birthday calendar" : "Rođendanski kalendar",
    "Tasks in calendar" : "Zadaci u kalendaru",
    "Weekends" : "Vikendi",
    "Week numbers" : "Brojevi tjedana",
    "Limit number of events shown in Month view" : "Ograniči broj događaja prikazanih u mjesečnom prikazu",
    "Density in Day and Week View" : "Gustoća u dnevnom i tjednom prikazu",
    "Editing" : "Uređivanje",
    "Simple event editor" : "Jednostavan uređivač događaja",
    "\"More details\" opens the detailed editor" : "\"Više detalja\" otvara detaljni uređivač",
    "Files" : "Datoteke",
    "Appointment schedule successfully created" : "Raspored termina uspješno je stvoren",
    "Appointment schedule successfully updated" : "Raspored termina uspješno je ažuriran",
    "0 minutes" : "0 minuta",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minute","{duration} minuta"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} sat","{duration} sata","{duration} sati"],
    "_{duration} day_::_{duration} days_" : ["{duration} dan","{duration} dana","{duration} dana"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} tjedan","{duration} tjedna","{duration} tjedana"],
    "_{duration} month_::_{duration} months_" : ["{duration} mjesec","{duration} mjeseca","{duration} mjeseci"],
    "_{duration} year_::_{duration} years_" : ["{duration} godina","{duration} godine","{duration} godina"],
    "To configure appointments, add your email address in personal settings." : "Za konfiguriranje termina dodajte svoju adresu e-pošte u osobnim postavkama.",
    "Appointment schedule saved" : "Raspored termina je spremljen",
    "Create appointment schedule" : "Stvori raspored termina",
    "Edit appointment schedule" : "Uredi raspored termina",
    "Update" : "Ažuriraj",
    "(copy)" : "(kopiraj)",
    "Appointment name" : "Naziv termina",
    "Location" : "Lokacija",
    "Create a Talk room" : "Stvori Talk sobu",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Za svaki rezervirani termin generirat će se jedinstvena poveznica i poslati u e-poruci s potvrdom",
    "Description" : "Opis",
    "Increments" : "Koraci",
    "Visibility" : "Vidljivost",
    "to" : "do",
    "Delete slot" : "Izbriši mjesto",
    "No times set" : "Nije postavljeno vrijeme",
    "Add" : "Dodaj",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "Weekdays" : "Dani u tjednu",
    "Planning restrictions" : "Ograničenja planiranja",
    "Max slots per day" : "Maksimalan broj termina dnevno",
    "Limit how far in the future appointments can be booked" : "Ograniči koliko daleko u budućnost se termini mogu rezervirati",
    "It seems a rate limit has been reached. Please try again later." : "Čini se da je dosegnuto ograničenje učestalosti. Pokušajte ponovno kasnije.",
    "Please confirm your reservation" : "Molimo potvrdite svoju rezervaciju",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Poslali smo vam e-poruku s detaljima. Potvrdite termin putem poveznice u e-poruci. Ovu stranicu sada možete zatvoriti.",
    "Your name" : "Vaše ime",
    "Your email address" : "Vaša adresa e-pošte",
    "Please share anything that will help prepare for our meeting" : "Podijelite sve što će pomoći u pripremi našeg sastanka",
    "Could not book the appointment. Please try again later or contact the organizer." : "Nije moguće rezervirati termin. Pokušajte ponovno kasnije ili kontaktirajte organizatora.",
    "Back" : "Natrag",
    "Book appointment" : "Rezerviraj termin",
    "Error fetching Talk conversations." : "Pogreška pri dohvaćanju Talk razgovora.",
    "Conversation does not have a valid URL." : "Razgovor nema valjani URL.",
    "Successfully added Talk conversation link to location." : "Poveznica na Talk razgovor uspješno je dodana u lokaciju.",
    "Successfully added Talk conversation link to description." : "Poveznica na Talk razgovor uspješno je dodana u opis.",
    "Failed to apply Talk room." : "Nije uspjelo primijeniti Talk sobu.",
    "Talk conversation for event" : "Talk razgovor za događaj",
    "Error creating Talk conversation" : "Pogreška pri stvaranju Talk razgovora",
    "Select a Talk Room" : "Odaberite Talk sobu",
    "Fetching Talk rooms…" : "Dohvaćanje Talk soba…",
    "No Talk room available" : "Nema dostupne Talk sobe",
    "Select existing conversation" : "Odaberite postojeći razgovor",
    "Select conversation" : "Odaberi razgovor",
    "Or create a new conversation" : "Ili stvorite novi razgovor",
    "Create public conversation" : "Stvori javni razgovor",
    "Create private conversation" : "Stvori privatni razgovor",
    "on" : "na",
    "at" : "u",
    "Default reminder of calendar" : "Zadani podsjetnik za kalendar",
    "Amount" : "Iznos",
    "before at" : "prije u",
    "Notification" : "Obavijest",
    "Email" : "E-pošta",
    "Audio notification" : "Zvučna obavijest",
    "Other notification" : "Druga obavijest",
    "Relative to event" : "Povezano s događajem",
    "On date" : "Na datum",
    "Edit time" : "Uredi vrijeme",
    "Save time" : "Spremi vrijeme",
    "Remove reminder" : "Ukloni podsjetnik",
    "Add reminder" : "Dodaj podsjetnik",
    "seconds" : "sekunda",
    "minutes" : "minuta",
    "hours" : "sati",
    "days" : "dani",
    "weeks" : "tjedana",
    "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
    "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
    "Attachment {name} already exist!" : "Privitak {name} već postoji!",
    "Could not upload attachment(s)" : "Nije moguće prenijeti privitak/privitke",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Upravo ćete otvoriti {link}. Jeste li sigurni da želite nastaviti?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Upravo ćete otvoriti {host}. Jeste li sigurni da želite nastaviti? Poveznica: {link}",
    "Proceed" : "Nastavi",
    "No attachments" : "Nema privitaka",
    "Add from Files" : "Dodaj iz aplikacije Datoteke",
    "Upload from device" : "Prenesi s uređaja",
    "Delete file" : "Izbriši datoteku",
    "Confirmation" : "Potvrda",
    "_{count} attachment_::_{count} attachments_" : ["{count} privitak","{count} privitka","{count} privitaka"],
    "Suggested" : "Predloženo",
    "Available" : "Dostupno",
    "Invitation accepted" : "Pozivnica prihvaćena",
    "Accepted {organizerName}'s invitation" : "Prihvaćena je pozivnica organizatora {organizerName}",
    "Participation marked as tentative" : "Sudjelovanje je označeno kao neizvjesno",
    "Invitation is delegated" : "Pozivnica je delegirana",
    "Not available" : "Nije dostupno",
    "Invitation declined" : "Pozivnica odbijena",
    "Declined {organizerName}'s invitation" : "Odbijena je pozivnica organizatora {organizerName}",
    "Availability will be checked" : "Dostupnost će se provjeriti",
    "Invitation will be sent" : "Pozivnica će biti poslana",
    "Failed to check availability" : "Provjera dostupnosti nije uspjela",
    "Failed to deliver invitation" : "Slanje pozivnice nije uspjelo",
    "Awaiting response" : "Čeka se odgovor",
    "Checking availability" : "Provjera dostupnosti",
    "Has not responded to {organizerName}'s invitation yet" : "Još nije odgovorio/la na pozivnicu organizatora {organizerName}",
    "Duration" : "Trajanje",
    "15 minutes" : "15 minuta",
    "30 minutes" : "30 minuta",
    "45 minutes" : "45 minuta",
    "1 hour" : "1 sat",
    "2 hours" : "2 sata",
    "Custom" : "Prilagođeno",
    "Hours" : "Sati",
    "Minutes" : "Minute",
    "Suggested times" : "Predložena vremena",
    "chairperson" : "predsjedatelj",
    "required participant" : "obvezni sudionik",
    "non-participant" : "nesudionik",
    "optional participant" : "neobavezni sudionik",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Odabrani termin",
    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
    "Suggestion accepted" : "Prijedlog prihvaćen",
    "Previous date" : "Prethodni datum",
    "Next date" : "Sljedeći datum",
    "Legend" : "Legenda",
    "Out of office" : "Izvan ureda",
    "Attendees:" : "Polaznici:",
    "local time" : "lokalno vrijeme",
    "Done" : "Gotovo",
    "Search room" : "Pretraži sobu",
    "Room name" : "Naziv sobe",
    "Check room availability" : "Provjeri dostupnost sobe",
    "Busy (tentative)" : "Zauzeto (uvjetno)",
    "Unknown" : "Nepoznato",
    "Find a time" : "Pronađi termin",
    "The invitation has been accepted successfully." : "Pozivnica je uspješno prihvaćena.",
    "Failed to accept the invitation." : "Prihvaćanje pozivnice nije uspjelo.",
    "The invitation has been declined successfully." : "Pozivnica je uspješno odbijena.",
    "Failed to decline the invitation." : "Odbijanje pozivnice nije uspjelo.",
    "Your participation has been marked as tentative." : "Vaše je sudjelovanje označeno kao neizvjesno.",
    "Failed to set the participation status to tentative." : "Postavljanje statusa sudjelovanja na neizvjesno nije uspjelo.",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Copied to clipboard" : "Kopirano u međuspremnik",
    "Failed to copy" : "Kopiranje nije uspjelo",
    "Copy name and email address" : "Kopiraj ime i adresu e-pošte",
    "Send email to {email}" : "Pošalji poruku e-pošte {email}",
    "No attendees yet" : "Još nema sudionika",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} potvrđeno, {waitingCount} čeka odgovor",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Dodajte barem jednog sudionika kako biste koristili značajku \"Pronađi termin\".",
    "Status" : "Status",
    "Role" : "Uloga",
    "Chairperson" : "Predsjednik",
    "Required participant" : "Obavezan sudionik",
    "Optional participant" : "Neobavezan sudionik",
    "Non-participant" : "Nije sudionik",
    "_%n more attendee_::_%n more attendees_" : ["još %n sudionik","još %n sudionika","još %n sudionika"],
    "Remove group" : "Ukloni grupu",
    "Remove attendee" : "Ukloni sudionika",
    "Request reply" : "Zatraži odgovor",
    "_%n member_::_%n members_" : ["%n član","%n člana","%n članova"],
    "Search for emails, users, contacts, contact groups or teams" : "Pretražite e-adrese, korisnike, kontakte, grupe kontakata ili timove",
    "No match found" : "Nema podudaranja",
    "Note that members of circles get invited but are not synced yet." : "Imajte na umu da se članovi krugova pozivaju, ali se još ne sinkroniziraju.",
    "Note that members of contact groups get invited but are not synced yet." : "Imajte na umu da se članovi grupa kontakata pozivaju, ali se još ne sinkroniziraju.",
    "(organizer)" : "(organizator)",
    "Make {label} the organizer" : "Postavi {label} kao organizatora",
    "Make {label} the organizer and attend" : "Postavi {label} kao organizatora i sudjeluj",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Dodajte svoju adresu e-pošte u osobne postavke[linkclose] za slanje pozivnica i upravljanje odgovorima.",
    "Remove color" : "Ukloni boju",
    "Title" : "Naslov",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
    "From" : "Od",
    "To" : "Za",
    "Your Time" : "Vaše vrijeme",
    "Repeat" : "Ponovi",
    "Repeat event" : "Ponovi događaj",
    "never" : "nikad",
    "on date" : "na datum",
    "after" : "nakon",
    "End repeat" : "Završi ponavljanje",
    "Occurrences" : "Pojavljivanja",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ovaj događaj je iznimka ponavljanja skupa ponavljanja. Ne možete mu dodati pravilo ponavljanja.",
    "first" : "prvi",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Promjene pravila ponavljanja primjenjuju se na ovo i sva buduća ponavljanja.",
    "Repeat every" : "Ponovi svakih",
    "By day of the month" : "Do dana u mjesecu",
    "On the" : "Na",
    "_day_::_days_" : ["dan","dana","dana"],
    "_week_::_weeks_" : ["tjedan","tjedana","tjedana"],
    "_month_::_months_" : ["mjesec","mjeseci","mjeseci"],
    "_year_::_years_" : ["godinu","godina","godina"],
    "On specific day" : "Na određeni dan",
    "weekday" : "dan u tjednu",
    "weekend day" : "dan vikendom",
    "Does not repeat" : "Ne ponavlja se",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud ne podržava u potpunosti definiciju ponavljanja za ovaj događaj. Ako uredite mogućnosti ponavljanja, može doći do gubitka određenih ponavljanja.",
    "No rooms or resources yet" : "Još nema soba ili resursa",
    "Resources" : "Resursi",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sjedalo","{seatingCapacity} sjedala","{seatingCapacity} sjedala"],
    "Add resource" : "Dodaj resurs",
    "Has a projector" : "Ima projektor",
    "Has a whiteboard" : "Ima ploču za pisanje",
    "Wheelchair accessible" : "Pristupačno za invalidska kolica",
    "Remove resource" : "Ukloni resurs",
    "Search for resources or rooms" : "Potražite resurse ili sobe",
    "available" : "dostupno",
    "unavailable" : "nedostupno",
    "Show all rooms" : "Prikaži sve sobe",
    "Projector" : "Projektor",
    "Whiteboard" : "Ploča za pisanje",
    "Room type" : "Vrsta sobe",
    "Any" : "Bilo koji",
    "Minimum seating capacity" : "Minimalni broj sjedala",
    "More details" : "Više detalja",
    "Update this and all future" : "Ažuriraj ovo i sva buduća ponavljanja",
    "Update this occurrence" : "Ažuriraj ovo ponavljanje",
    "Public calendar does not exist" : "Javni kalendar ne postoji",
    "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
    "Remove date" : "Ukloni datum",
    "Attendance required" : "Prisustvo obavezno",
    "Attendance optional" : "Prisustvo neobavezno",
    "Remove participant" : "Ukloni sudionika",
    "Yes" : "Da",
    "No" : "Ne",
    "Maybe" : "Možda",
    "Select your meeting availability" : "Odaberite svoju dostupnost za sastanak",
    "Create a meeting for this date and time" : "Stvori sastanak za ovaj datum i vrijeme",
    "Create" : "Stvori",
    "No participants or dates available" : "Nema dostupnih sudionika ili datuma",
    "Type to search time zone" : "Upišite za pretraživanje vremenskih zona",
    "Global" : "Globalno",
    "Holidays in {region}" : "Praznici u regiji {region}",
    "An error occurred, unable to read public calendars." : "Došlo je do pogreške, nije moguće pročitati javne kalendare.",
    "An error occurred, unable to subscribe to calendar." : "Došlo je do pogreške, nije moguće pretplatiti se na kalendar.",
    "Public calendar subscriptions selection" : "Odabir pretplata na javne kalendare",
    "Public holiday calendars" : "Kalendari državnih praznika",
    "Public calendars" : "Javni kalendari",
    "No valid public calendars configured" : "Nema konfiguriranih valjanih javnih kalendara",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalendare državnih praznika pruža Thunderbird. Podaci kalendara preuzet će se s {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Ove javne kalendare predlaže administrator poslužitelja. Podaci kalendara preuzet će se s odgovarajućih web-stranica.",
    "By {authors}" : "Od {authors}",
    "Subscribed" : "Pretplaćen",
    "Subscribe" : "Pretplata",
    "Could not fetch slots" : "Nije moguće dohvatiti termine",
    "Select a date" : "Odaberi datum",
    "Select slot" : "Odaberite termin",
    "No slots available" : "Nema dostupnih termina",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Hvala. Vaša rezervacija od {startDate} do {endDate} je potvrđena.",
    "Book another appointment:" : "Rezervirajte drugi termin:",
    "See all available slots" : "Prikaži sve dostupne termine",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Termin za vaš termin od {startDate} do {endDate} više nije dostupan.",
    "Please book a different slot:" : "Molimo rezervirajte drugi termin:",
    "Book an appointment with {name}" : "Rezervirajte termin s {name}",
    "No public appointments found for {name}" : "Nema javno dostupnih termina za {name}",
    "Personal" : "Osobno",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nije pronađena vaša konfigurirana vremenska zona ({timezoneId}). Postavka vremenske zone vraćena je na UTC.\nPromijenite vremensku zonu u postavkama i prijavite ovu poteškoću.",
    "Show unscheduled tasks" : "Prikaži nezakazane zadatke",
    "Unscheduled tasks" : "Nezakazani zadaci",
    "Availability of {displayName}" : "Dostupnost korisnika {displayName}",
    "Discard changes" : "Odbaci promjene",
    "Edit event" : "Uredi događaj",
    "Event does not exist" : "Događaj ne postoji",
    "Delete this occurrence" : "Izbriši ovo ponavljanje",
    "Delete this and all future" : "Izbriši ovo i sva buduća ponavljanja",
    "All day" : "Cijeli dan",
    "Modifications wont get propagated to the organizer and other attendees" : "Izmjene se neće proslijediti organizatoru i ostalim sudionicima",
    "Add Talk conversation" : "Dodaj Talk razgovor",
    "Managing shared access" : "Upravljanje dijeljenim pristupom",
    "Deny access" : "Odbij pristup",
    "Invite" : "Poziv",
    "Discard changes?" : "Odbaciti promjene?",
    "Are you sure you want to discard the changes made to this event?" : "Jeste li sigurni da želite odbaciti promjene napravljene na ovom događaju?",
    "_User requires access to your file_::_Users require access to your file_" : ["Korisnik treba pristup vašoj datoteci","Korisnici trebaju pristup vašoj datoteci","Korisnici trebaju pristup vašoj datoteci"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Privitak zahtijeva dijeljeni pristup","Privitci zahtijevaju dijeljeni pristup","Privitci zahtijevaju dijeljeni pristup"],
    "Untitled event" : "Događaj bez naslova",
    "Close" : "Zatvori",
    "Modifications will not get propagated to the organizer and other attendees" : "Izmjene se neće proslijediti organizatoru i ostalim sudionicima",
    "This event was cancelled" : "Ovaj je događaj otkazan",
    "Meeting proposals overview" : "Pregled prijedloga sastanaka",
    "Edit meeting proposal" : "Uredi prijedlog sastanka",
    "Create meeting proposal" : "Stvori prijedlog sastanka",
    "Update meeting proposal" : "Ažuriraj prijedlog sastanka",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Stvoriti sastanak za \"{date}\"? Time će se stvoriti događaj u kalendaru sa svim sudionicima.",
    "Create meeting" : "Stvori sastanak",
    "Saving proposal \"{title}\"" : "Spremanje prijedloga \"{title}\"",
    "Successfully saved proposal" : "Prijedlog je uspješno spremljen",
    "Failed to save proposal" : "Spremanje prijedloga nije uspjelo",
    "Please enter a valid duration in minutes." : "Unesite valjano trajanje u minutama.",
    "Failed to fetch proposals" : "Dohvaćanje prijedloga nije uspjelo",
    "Creating meeting for {date}" : "Stvaranje sastanka za {date}",
    "Successfully created meeting for {date}" : "Sastanak za {date} uspješno je stvoren",
    "Failed to create a meeting for {date}" : "Stvaranje sastanka za {date} nije uspjelo",
    "Failed to fetch free/busy data" : "Dohvaćanje podataka slobodno/zauzeto nije uspjelo",
    "Selected" : "Odabrano",
    "No Description" : "Nema opisa",
    "No Location" : "Nema lokacije",
    "Edit this meeting proposal" : "Uredi ovaj prijedlog sastanka",
    "Delete this meeting proposal" : "Izbriši ovaj prijedlog sastanka",
    "Participants" : "Sudionici",
    "Selected times" : "Odabrana vremena",
    "Previous span" : "Prethodni raspon",
    "Next span" : "Sljedeći raspon",
    "Less days" : "Manje dana",
    "More days" : "Više dana",
    "Loading meeting proposal" : "Učitavanje prijedloga sastanka",
    "No meeting proposal found" : "Nije pronađen nijedan prijedlog sastanka",
    "Please wait while we load the meeting proposal." : "Pričekajte dok učitavamo prijedlog sastanka.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Poveznica koju ste otvorili možda je neispravna ili prijedlog sastanka više ne postoji.",
    "Thank you for your response!" : "Hvala na odgovoru!",
    "Your vote has been recorded. Thank you for participating!" : "Vaš je glas zabilježen. Hvala na sudjelovanju!",
    "Unknown User" : "Nepoznat korisnik",
    "No Title" : "Bez naslova",
    "No Duration" : "Nema trajanja",
    "Select a different time zone" : "Odaberite drugu vremensku zonu",
    "Submit" : "Šalji",
    "Subscribe to {name}" : "Pretplati se na {name}",
    "Export {name}" : "Izvezi {name}",
    "Show availability" : "Prikaži dostupnost",
    "Anniversary" : "Godišnjica",
    "Appointment" : "Dogovor",
    "Business" : "Poslovno",
    "Education" : "Obrazovno",
    "Holiday" : "Blagdan/praznik",
    "Meeting" : "Sastanak",
    "Miscellaneous" : "Razno",
    "Non-working hours" : "Neradni sati",
    "Not in office" : "Nije u uredu",
    "Phone call" : "Telefonski poziv",
    "Sick day" : "Bolovanje",
    "Special occasion" : "Poseban događaj",
    "Travel" : "Putovanje",
    "Vacation" : "Odmor",
    "Midnight on the day the event starts" : "Ponoć na dan početka događaja",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dan prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tjedan prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "na dan događaja u {formattedHourMinute}",
    "at the event's start" : "na početku događaja",
    "at the event's end" : "na završetku događaja",
    "{time} before the event starts" : "{time} prije početka događaja",
    "{time} before the event ends" : "{time} prije završetka događaja",
    "{time} after the event starts" : "{time} nakon početka događaja",
    "{time} after the event ends" : "{time} nakon završetka događaja",
    "on {time}" : "u {time}",
    "on {time} ({timezoneId})" : "u {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} tjedan {year}",
    "Daily" : "Svaki dan",
    "Weekly" : "Svaki tjedan",
    "Monthly" : "Svaki mjesec",
    "Yearly" : "Svake godine",
    "_Every %n day_::_Every %n days_" : ["Svaki %n dan","Svakih %n dana","Svakih %n dana"],
    "_Every %n week_::_Every %n weeks_" : ["Svaki %n tjedan","Svakih %n tjedana","Svakih %n tjedana"],
    "_Every %n month_::_Every %n months_" : ["Svaki %n mjesec","Svakih %n mjeseci","Svakih %n mjeseci"],
    "_Every %n year_::_Every %n years_" : ["Svake %n godine","Svakih %n godina","Svakih %n godina"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["na dan {dayOfMonthList}","na dane {dayOfMonthList}","na dane {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "u {monthNames} na {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "u {monthNames} {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n put","%n puta","%n puta"],
    "second" : "drugi",
    "third" : "treći",
    "fourth" : "četvrti",
    "fifth" : "peti",
    "second to last" : "predzadnji",
    "last" : "zadnji",
    "Untitled task" : "Zadatak bez naslova",
    "Please ask your administrator to enable the Tasks App." : "Zatražite od administratora da omogući aplikaciju Tasks.",
    "You are not allowed to edit this event as an attendee." : "Kao sudionik ne smijete uređivati ovaj događaj.",
    "W" : "W",
    "%n more" : "još %n",
    "No events to display" : "Nema događaja za prikaz",
    "All participants declined" : "Svi sudionici su odbili",
    "Please confirm your participation" : "Molimo potvrdite svoje sudjelovanje",
    "You declined this event" : "Odbili ste ovaj događaj",
    "Your participation is tentative" : "Vaše je sudjelovanje neizvjesno",
    "_+%n more_::_+%n more_" : ["+%n više","+%n više","+%n više"],
    "No events" : "Nema događaja",
    "Create a new event or change the visible time-range" : "Stvorite novi događaj ili promijenite vidljivi vremenski raspon",
    "It might have been deleted, or there was a typo in a link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "Failed to save event" : "Spremanje događaja nije uspjelo",
    "It might have been deleted, or there was a typo in the link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "Meeting room" : "Soba za sastanke",
    "Lecture hall" : "Predavaonica",
    "Seminar room" : "Soba za seminare",
    "Other" : "Drugo",
    "When shared show" : "Kada se dijeli, prikaži",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "The visibility of this event in read-only shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima samo za čitanje.",
    "Add a location" : "Dodaj lokaciju",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Dodajte opis\n\n- O čemu je ovaj sastanak\n- Točke dnevnog reda\n- Sve što se sudionici trebaju pripremiti",
    "Confirmed" : "Potvrđeno",
    "Canceled" : "Otkazano",
    "Confirmation about the overall status of the event." : "Potvrda cjelokupnog statusa događaja.",
    "Show as" : "Prikaži kao",
    "Take this event into account when calculating free-busy information." : "Uzmite ovaj događaj u obzir pri izračunu informacija o dostupnosti i zauzeću.",
    "Categories" : "Kategorije",
    "Categories help you to structure and organize your events." : "Kategorije vam pomažu odrediti strukturu i organizirati događaj.",
    "Search or add categories" : "Pretraži ili dodaj kategorije",
    "Add this as a new category" : "Dodaj kao novu kategoriju",
    "Custom color" : "Prilagođena boja",
    "Special color of this event. Overrides the calendar-color." : "Posebna boja ovog događaja. Primjenjuje se umjesto boje kalendara.",
    "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
    "Error while sharing file with user" : "Pogreška pri dijeljenju datoteke s korisnikom",
    "Error creating a folder {folder}" : "Pogreška pri stvaranju mape {folder}",
    "Attachment {fileName} already exists!" : "Privitak {fileName} već postoji!",
    "Attachment {fileName} added!" : "Privitak {fileName} je dodan!",
    "An error occurred during uploading file {fileName}" : "Došlo je do pogreške pri prijenosu datoteke {fileName}",
    "An error occurred during getting file information" : "Došlo je do pogreške pri dohvaćanju informacija o datoteci",
    "Talk conversation for proposal" : "Talk razgovor za prijedlog",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "Imported {filename}" : "Uvezena datoteka {filename}",
    "This is an event reminder." : "Ovo je podsjetnik za događaj.",
    "Error while parsing a PROPFIND error" : "Pogreška pri obradi PROPFIND pogreške",
    "Appointment not found" : "Termin nije pronađen",
    "User not found" : "Korisnik nije pronađen",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendars" : "Kalendari",
    "Hidden" : "Skriveno",
    "Calendar name …" : "Naziv kalendara …",
    "Default attachments location" : "Zadana lokacija privitaka",
    "Automatic ({detected})" : "Automatsko ({detected})",
    "Shortcut overview" : "Pregled prečaca",
    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
    "Enable birthday calendar" : "Omogući kalendar rođendana",
    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
    "Enable simplified editor" : "Omogući jednostavan uređivač",
    "Limit the number of events displayed in the monthly view" : "Ograniči broj događaja prikazanih u mjesečnom prikazu",
    "Show weekends" : "Prikaži vikende",
    "Show week numbers" : "Prikaži brojeve tjedana",
    "Time increments" : "Vremenski prirasti",
    "Default reminder" : "Zadani podsjetnik",
    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
    "Personal availability settings" : "Osobne postavke dostupnosti",
    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
    "Public – shown on the profile page" : "Javno – prikazano na stranici profila",
    "Private – only accessible via secret link" : "Privatno – dostupno samo putem tajne poveznice",
    "Additional calendars to check for conflicts" : "Dodatni kalendari za provjeru sukoba",
    "Pick time ranges where appointments are allowed" : "Odaberite vremenske raspone u kojima su termini dopušteni",
    "Add time before and after the event" : "Dodaj vrijeme prije i nakon događaja",
    "Before the event" : "Prije događaja",
    "After the event" : "Nakon događaja",
    "Minimum time before next available slot" : "Minimalno vrijeme prije sljedećeg dostupnog termina",
    "Create a new public conversation" : "Stvori novi javni razgovor",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} pozvano, {confirmedCount} potvrđeno",
    "Successfully appended link to talk room to location." : "Poveznica na Talk sobu uspješno je dodana u lokaciju.",
    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
    "_%n more guest_::_%n more guests_" : ["još %n gost","još %n gosta","još %n gostiju"],
    "Event title" : "Naslov događaja",
    "_time_::_times_" : ["put","puta","puta"],
    "Select to end repeat" : "Odaberi za završetak ponavljanja",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} u {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} u {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "dana {formattedDate} u {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} u {formattedTime}",
    "Please enter a valid date" : "Unesite važeći datum",
    "Please enter a valid date and time" : "Unesite važeći datum i vrijeme",
    "Select a time zone" : "Odaberite vremensku zonu",
    "Please select a time zone:" : "Odaberite vremensku zonu:",
    "Pick a time" : "Odaberi vrijeme",
    "Pick a date" : "Odaberi datum",
    "Speak to the server administrator to resolve this issue." : "Obratite se administratoru poslužitelja kako bi riješio ovaj problem.",
    "The slot for your appointment has been confirmed" : "Termin za vaš termin je potvrđen",
    "Appointment Details:" : "Detalji termina:",
    "Time:" : "Vrijeme:",
    "Booked for:" : "Rezervirano za:",
    "Duration suggestions" : "Prijedlozi trajanja",
    "{duration} min" : "{duration}min"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
