<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'v6.5.0',
        'version' => '6.5.0.0',
        'reference' => '9defe0e372974e5fdd43bd51897bd5890908099a',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'v6.5.0',
            'version' => '6.5.0.0',
            'reference' => '9defe0e372974e5fdd43bd51897bd5890908099a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => '641d0663f5ac270b1aeec4337b7856f76204df47',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
