(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcTextField_vue_vue_type_script_setup_t-715f22"],{95113(e,i,t){"use strict";t.r(i);var n=t(71354),a=t.n(n),r=t(76314),o=t.n(r)()(a());o.push([e.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-8e16cbb5] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}

/*!
 * SPDX-FileCopyrightText: 2025 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * Similar as inputBorder but without active styles.
 */
/**
 * Create a consistent border for an input element.
 * With Nextcloud 32+ there is no real border anymore but we use a box-shadow.
 */
.input-field[data-v-8e16cbb5] {
  --input-border-color: var(--color-border-maxcontrast);
  --input-border-radius: var(--border-radius-element);
  --input-padding-start: var(--border-radius-element);
  --input-padding-end: var(--border-radius-element);
  position: relative;
  width: 100%;
  margin-block-start: 6px;
}
.input-field--disabled[data-v-8e16cbb5] {
  opacity: 0.4;
  filter: saturate(0.4);
}
.input-field--label-outside[data-v-8e16cbb5] {
  margin-block-start: 0;
}
.input-field--leading-icon[data-v-8e16cbb5] {
  --input-padding-start: calc(var(--default-clickable-area) - var(--default-grid-baseline));
}
.input-field--trailing-icon[data-v-8e16cbb5] {
  --input-padding-end: calc(var(--default-clickable-area) - var(--default-grid-baseline));
}
.input-field--pill[data-v-8e16cbb5] {
  --input-border-radius: var(--border-radius-pill);
}
.input-field__main-wrapper[data-v-8e16cbb5] {
  height: var(--default-clickable-area);
  padding: var(--border-width-input-focused, 2px);
  position: relative;
}
.input-field__input[data-v-8e16cbb5] {
  --input-border-box-shadow-light: 0 -1px var(--input-border-color),
  	0 0 0 1px color-mix(in srgb, var(--input-border-color), 65% transparent);
  --input-border-box-shadow-dark: 0 1px var(--input-border-color),
  	0 0 0 1px color-mix(in srgb, var(--input-border-color), 65% transparent);
  --input-border-box-shadow: var(--input-border-box-shadow-light);
  border: none;
  border-radius: var(--border-radius-element);
  box-shadow: var(--input-border-box-shadow);
}
.input-field__input[data-v-8e16cbb5]:hover:not([disabled]) {
  box-shadow: 0 0 0 1px var(--input-border-color);
}
@media (prefers-color-scheme: dark) {
.input-field__input .input-field__input[data-v-8e16cbb5] {
    --input-border-box-shadow: var(--input-border-box-shadow-dark);
}
}
[data-theme-dark] .input-field__input[data-v-8e16cbb5] {
  --input-border-box-shadow: var(--input-border-box-shadow-dark);
}
[data-theme-light] .input-field__input[data-v-8e16cbb5] {
  --input-border-box-shadow: var(--input-border-box-shadow-light);
}
.input-field--legacy .input-field__input[data-v-8e16cbb5] {
  box-shadow: 0 0 0 1px var(--input-border-color);
}
.input-field--legacy .input-field__input[data-v-8e16cbb5]:hover:not([disabled]) {
  box-shadow: 0 0 0 2px var(--input-border-color);
}
.input-field__input[data-v-8e16cbb5]:focus-within:not([disabled]), .input-field__input[data-v-8e16cbb5]:active:not([disabled]) {
  box-shadow: 0 0 0 2px var(--input-border-color), 0 0 0 4px var(--color-main-background) !important;
}
.input-field__input[data-v-8e16cbb5] {
  background-color: var(--color-main-background);
  color: var(--color-main-text);
  border-radius: var(--input-border-radius);
  cursor: pointer;
  -webkit-appearance: textfield !important;
  -moz-appearance: textfield !important;
  appearance: textfield !important;
  font-size: var(--default-font-size);
  text-overflow: ellipsis;
  padding-block: 0;
  padding-inline: var(--input-padding-start) var(--input-padding-end);
  height: 100% !important;
  min-height: unset;
  width: 100%;
}
.input-field__input[data-v-8e16cbb5]::placeholder {
  color: var(--color-text-maxcontrast);
}
.input-field__input[data-v-8e16cbb5]::-webkit-search-cancel-button {
  display: none;
}
.input-field__input[data-v-8e16cbb5]::-webkit-search-decoration, .input-field__input[data-v-8e16cbb5]::-webkit-search-results-button, .input-field__input[data-v-8e16cbb5]::-webkit-search-results-decoration, .input-field__input[data-v-8e16cbb5]::-ms-clear {
  display: none;
}
.input-field__input[data-v-8e16cbb5]:active:not([disabled]), .input-field__input[data-v-8e16cbb5]:focus:not([disabled]) {
  --input-border-color: var(--color-main-text);
}
.input-field__input:focus + .input-field__label[data-v-8e16cbb5], .input-field__input:hover:not(:placeholder-shown) + .input-field__label[data-v-8e16cbb5] {
  color: var(--color-main-text);
}
.input-field__input[data-v-8e16cbb5]:focus {
  cursor: text;
}
.input-field__input[data-v-8e16cbb5]:disabled {
  cursor: default;
}
.input-field__input[data-v-8e16cbb5]:focus-visible {
  box-shadow: unset !important;
}
.input-field:not(.input-field--label-outside) .input-field__input[data-v-8e16cbb5]:not(:focus)::placeholder {
  opacity: 0;
}
.input-field__label[data-v-8e16cbb5] {
  --input-label-font-size: var(--default-font-size);
  font-size: var(--input-label-font-size);
  position: absolute;
  margin-inline: var(--input-padding-start) var(--input-padding-end);
  max-width: fit-content;
  inset-block-start: calc((var(--default-clickable-area) - 1lh) / 2);
  inset-inline: var(--border-width-input-focused, 2px);
  color: var(--color-text-maxcontrast);
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  pointer-events: none;
  transition: height var(--animation-quick), inset-block-start var(--animation-quick), font-size var(--animation-quick), color var(--animation-quick), background-color var(--animation-quick) var(--animation-slow);
}
.input-field__input:focus + .input-field__label[data-v-8e16cbb5], .input-field__input:not(:placeholder-shown) + .input-field__label[data-v-8e16cbb5] {
  --input-label-font-size: 13px;
  line-height: 1.5;
  inset-block-start: calc(-1.5 * var(--input-label-font-size) / 2);
  font-weight: var(--font-weight-element, 500);
  border-radius: var(--default-grid-baseline) var(--default-grid-baseline) 0 0;
  background-color: var(--color-main-background);
  padding-inline: var(--default-grid-baseline);
  margin-inline: calc(var(--input-padding-start) - var(--default-grid-baseline)) calc(var(--input-padding-end) - var(--default-grid-baseline));
  transition: height var(--animation-quick), inset-block-start var(--animation-quick), font-size var(--animation-quick), color var(--animation-quick);
}
.input-field__icon[data-v-8e16cbb5] {
  position: absolute;
  height: var(--default-clickable-area);
  width: var(--default-clickable-area);
  display: flex;
  align-items: center;
  justify-content: center;
  opacity: 0.7;
  inset-block-end: 0;
}
.input-field__icon--leading[data-v-8e16cbb5] {
  inset-inline-start: 0px;
}
.input-field__icon--trailing[data-v-8e16cbb5] {
  inset-inline-end: 0px;
}
.input-field__trailing-button[data-v-8e16cbb5] {
  --button-size: calc(var(--default-clickable-area) - 2 * var(--border-width-input-focused, 2px)) !important;
  --button-radius: calc(var(--input-border-radius) - var(--border-width-input-focused, 2px));
}
.input-field__trailing-button.button-vue[data-v-8e16cbb5] {
  position: absolute;
  top: var(--border-width-input-focused, 2px);
  inset-inline-end: var(--border-width-input-focused, 2px);
}
.input-field__trailing-button.button-vue[data-v-8e16cbb5]:focus-visible {
  box-shadow: none !important;
}
.input-field__helper-text-message[data-v-8e16cbb5] {
  padding-block: 4px;
  padding-inline: var(--border-radius-element);
  display: flex;
  align-items: center;
  color: var(--color-text-maxcontrast);
  overflow-wrap: anywhere;
}
.input-field__helper-text-message__icon[data-v-8e16cbb5] {
  margin-inline-end: 8px;
}
.input-field--error .input-field__helper-text-message[data-v-8e16cbb5],
.input-field--error .input-field__icon--trailing[data-v-8e16cbb5] {
  color: var(--color-text-error, var(--color-error));
}
.input-field--error .input-field__input[data-v-8e16cbb5], .input-field__input[data-v-8e16cbb5]:user-invalid {
  --input-border-color: var(--color-border-error, var(--color-error)) !important;
}
.input-field--error .input-field__input[data-v-8e16cbb5]:focus-visible, .input-field__input[data-v-8e16cbb5]:user-invalid:focus-visible {
  box-shadow: rgb(248, 250, 252) 0px 0px 0px 2px, var(--color-primary-element) 0px 0px 0px 4px, rgba(0, 0, 0, 0.05) 0px 1px 2px 0px;
}
.input-field--success .input-field__input[data-v-8e16cbb5] {
  --input-border-color: var(--color-border-success, var(--color-success)) !important;
}
.input-field--success .input-field__input[data-v-8e16cbb5]:focus-visible {
  box-shadow: rgb(248, 250, 252) 0px 0px 0px 2px, var(--color-primary-element) 0px 0px 0px 4px, rgba(0, 0, 0, 0.05) 0px 1px 2px 0px;
}
.input-field--success .input-field__helper-text-message__icon[data-v-8e16cbb5] {
  color: var(--color-border-success, var(--color-success));
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcInputField-DpyFJ1xw.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;;AAEA;;;EAGE;AACF;;EAEE;AACF;;;EAGE;AACF;EACE,qDAAqD;EACrD,mDAAmD;EACnD,mDAAmD;EACnD,iDAAiD;EACjD,kBAAkB;EAClB,WAAW;EACX,uBAAuB;AACzB;AACA;EACE,YAAY;EACZ,qBAAqB;AACvB;AACA;EACE,qBAAqB;AACvB;AACA;EACE,yFAAyF;AAC3F;AACA;EACE,uFAAuF;AACzF;AACA;EACE,gDAAgD;AAClD;AACA;EACE,qCAAqC;EACrC,+CAA+C;EAC/C,kBAAkB;AACpB;AACA;EACE;2EACyE;EACzE;2EACyE;EACzE,+DAA+D;EAC/D,YAAY;EACZ,2CAA2C;EAC3C,0CAA0C;AAC5C;AACA;EACE,+CAA+C;AACjD;AACA;AACA;IACI,8DAA8D;AAClE;AACA;AACA;EACE,8DAA8D;AAChE;AACA;EACE,+DAA+D;AACjE;AACA;EACE,+CAA+C;AACjD;AACA;EACE,+CAA+C;AACjD;AACA;EACE,kGAAkG;AACpG;AACA;EACE,8CAA8C;EAC9C,6BAA6B;EAC7B,yCAAyC;EACzC,eAAe;EACf,wCAAwC;EACxC,qCAAqC;EACrC,gCAAgC;EAChC,mCAAmC;EACnC,uBAAuB;EACvB,gBAAgB;EAChB,mEAAmE;EACnE,uBAAuB;EACvB,iBAAiB;EACjB,WAAW;AACb;AACA;EACE,oCAAoC;AACtC;AACA;EACE,aAAa;AACf;AACA;EACE,aAAa;AACf;AACA;EACE,4CAA4C;AAC9C;AACA;EACE,6BAA6B;AAC/B;AACA;EACE,YAAY;AACd;AACA;EACE,eAAe;AACjB;AACA;EACE,4BAA4B;AAC9B;AACA;EACE,UAAU;AACZ;AACA;EACE,iDAAiD;EACjD,uCAAuC;EACvC,kBAAkB;EAClB,kEAAkE;EAClE,sBAAsB;EACtB,kEAAkE;EAClE,oDAAoD;EACpD,oCAAoC;EACpC,mBAAmB;EACnB,gBAAgB;EAChB,uBAAuB;EACvB,oBAAoB;EACpB,kNAAkN;AACpN;AACA;EACE,6BAA6B;EAC7B,gBAAgB;EAChB,gEAAgE;EAChE,4CAA4C;EAC5C,4EAA4E;EAC5E,8CAA8C;EAC9C,4CAA4C;EAC5C,4IAA4I;EAC5I,mJAAmJ;AACrJ;AACA;EACE,kBAAkB;EAClB,qCAAqC;EACrC,oCAAoC;EACpC,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,YAAY;EACZ,kBAAkB;AACpB;AACA;EACE,uBAAuB;AACzB;AACA;EACE,qBAAqB;AACvB;AACA;EACE,0GAA0G;EAC1G,0FAA0F;AAC5F;AACA;EACE,kBAAkB;EAClB,2CAA2C;EAC3C,wDAAwD;AAC1D;AACA;EACE,2BAA2B;AAC7B;AACA;EACE,kBAAkB;EAClB,4CAA4C;EAC5C,aAAa;EACb,mBAAmB;EACnB,oCAAoC;EACpC,uBAAuB;AACzB;AACA;EACE,sBAAsB;AACxB;AACA;;EAEE,kDAAkD;AACpD;AACA;EACE,8EAA8E;AAChF;AACA;EACE,iIAAiI;AACnI;AACA;EACE,kFAAkF;AACpF;AACA;EACE,iIAAiI;AACnI;AACA;EACE,wDAAwD;AAC1D",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-8e16cbb5] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n\n/*!\n * SPDX-FileCopyrightText: 2025 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * Similar as inputBorder but without active styles.\n */\n/**\n * Create a consistent border for an input element.\n * With Nextcloud 32+ there is no real border anymore but we use a box-shadow.\n */\n.input-field[data-v-8e16cbb5] {\n  --input-border-color: var(--color-border-maxcontrast);\n  --input-border-radius: var(--border-radius-element);\n  --input-padding-start: var(--border-radius-element);\n  --input-padding-end: var(--border-radius-element);\n  position: relative;\n  width: 100%;\n  margin-block-start: 6px;\n}\n.input-field--disabled[data-v-8e16cbb5] {\n  opacity: 0.4;\n  filter: saturate(0.4);\n}\n.input-field--label-outside[data-v-8e16cbb5] {\n  margin-block-start: 0;\n}\n.input-field--leading-icon[data-v-8e16cbb5] {\n  --input-padding-start: calc(var(--default-clickable-area) - var(--default-grid-baseline));\n}\n.input-field--trailing-icon[data-v-8e16cbb5] {\n  --input-padding-end: calc(var(--default-clickable-area) - var(--default-grid-baseline));\n}\n.input-field--pill[data-v-8e16cbb5] {\n  --input-border-radius: var(--border-radius-pill);\n}\n.input-field__main-wrapper[data-v-8e16cbb5] {\n  height: var(--default-clickable-area);\n  padding: var(--border-width-input-focused, 2px);\n  position: relative;\n}\n.input-field__input[data-v-8e16cbb5] {\n  --input-border-box-shadow-light: 0 -1px var(--input-border-color),\n  	0 0 0 1px color-mix(in srgb, var(--input-border-color), 65% transparent);\n  --input-border-box-shadow-dark: 0 1px var(--input-border-color),\n  	0 0 0 1px color-mix(in srgb, var(--input-border-color), 65% transparent);\n  --input-border-box-shadow: var(--input-border-box-shadow-light);\n  border: none;\n  border-radius: var(--border-radius-element);\n  box-shadow: var(--input-border-box-shadow);\n}\n.input-field__input[data-v-8e16cbb5]:hover:not([disabled]) {\n  box-shadow: 0 0 0 1px var(--input-border-color);\n}\n@media (prefers-color-scheme: dark) {\n.input-field__input .input-field__input[data-v-8e16cbb5] {\n    --input-border-box-shadow: var(--input-border-box-shadow-dark);\n}\n}\n[data-theme-dark] .input-field__input[data-v-8e16cbb5] {\n  --input-border-box-shadow: var(--input-border-box-shadow-dark);\n}\n[data-theme-light] .input-field__input[data-v-8e16cbb5] {\n  --input-border-box-shadow: var(--input-border-box-shadow-light);\n}\n.input-field--legacy .input-field__input[data-v-8e16cbb5] {\n  box-shadow: 0 0 0 1px var(--input-border-color);\n}\n.input-field--legacy .input-field__input[data-v-8e16cbb5]:hover:not([disabled]) {\n  box-shadow: 0 0 0 2px var(--input-border-color);\n}\n.input-field__input[data-v-8e16cbb5]:focus-within:not([disabled]), .input-field__input[data-v-8e16cbb5]:active:not([disabled]) {\n  box-shadow: 0 0 0 2px var(--input-border-color), 0 0 0 4px var(--color-main-background) !important;\n}\n.input-field__input[data-v-8e16cbb5] {\n  background-color: var(--color-main-background);\n  color: var(--color-main-text);\n  border-radius: var(--input-border-radius);\n  cursor: pointer;\n  -webkit-appearance: textfield !important;\n  -moz-appearance: textfield !important;\n  appearance: textfield !important;\n  font-size: var(--default-font-size);\n  text-overflow: ellipsis;\n  padding-block: 0;\n  padding-inline: var(--input-padding-start) var(--input-padding-end);\n  height: 100% !important;\n  min-height: unset;\n  width: 100%;\n}\n.input-field__input[data-v-8e16cbb5]::placeholder {\n  color: var(--color-text-maxcontrast);\n}\n.input-field__input[data-v-8e16cbb5]::-webkit-search-cancel-button {\n  display: none;\n}\n.input-field__input[data-v-8e16cbb5]::-webkit-search-decoration, .input-field__input[data-v-8e16cbb5]::-webkit-search-results-button, .input-field__input[data-v-8e16cbb5]::-webkit-search-results-decoration, .input-field__input[data-v-8e16cbb5]::-ms-clear {\n  display: none;\n}\n.input-field__input[data-v-8e16cbb5]:active:not([disabled]), .input-field__input[data-v-8e16cbb5]:focus:not([disabled]) {\n  --input-border-color: var(--color-main-text);\n}\n.input-field__input:focus + .input-field__label[data-v-8e16cbb5], .input-field__input:hover:not(:placeholder-shown) + .input-field__label[data-v-8e16cbb5] {\n  color: var(--color-main-text);\n}\n.input-field__input[data-v-8e16cbb5]:focus {\n  cursor: text;\n}\n.input-field__input[data-v-8e16cbb5]:disabled {\n  cursor: default;\n}\n.input-field__input[data-v-8e16cbb5]:focus-visible {\n  box-shadow: unset !important;\n}\n.input-field:not(.input-field--label-outside) .input-field__input[data-v-8e16cbb5]:not(:focus)::placeholder {\n  opacity: 0;\n}\n.input-field__label[data-v-8e16cbb5] {\n  --input-label-font-size: var(--default-font-size);\n  font-size: var(--input-label-font-size);\n  position: absolute;\n  margin-inline: var(--input-padding-start) var(--input-padding-end);\n  max-width: fit-content;\n  inset-block-start: calc((var(--default-clickable-area) - 1lh) / 2);\n  inset-inline: var(--border-width-input-focused, 2px);\n  color: var(--color-text-maxcontrast);\n  white-space: nowrap;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  pointer-events: none;\n  transition: height var(--animation-quick), inset-block-start var(--animation-quick), font-size var(--animation-quick), color var(--animation-quick), background-color var(--animation-quick) var(--animation-slow);\n}\n.input-field__input:focus + .input-field__label[data-v-8e16cbb5], .input-field__input:not(:placeholder-shown) + .input-field__label[data-v-8e16cbb5] {\n  --input-label-font-size: 13px;\n  line-height: 1.5;\n  inset-block-start: calc(-1.5 * var(--input-label-font-size) / 2);\n  font-weight: var(--font-weight-element, 500);\n  border-radius: var(--default-grid-baseline) var(--default-grid-baseline) 0 0;\n  background-color: var(--color-main-background);\n  padding-inline: var(--default-grid-baseline);\n  margin-inline: calc(var(--input-padding-start) - var(--default-grid-baseline)) calc(var(--input-padding-end) - var(--default-grid-baseline));\n  transition: height var(--animation-quick), inset-block-start var(--animation-quick), font-size var(--animation-quick), color var(--animation-quick);\n}\n.input-field__icon[data-v-8e16cbb5] {\n  position: absolute;\n  height: var(--default-clickable-area);\n  width: var(--default-clickable-area);\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  opacity: 0.7;\n  inset-block-end: 0;\n}\n.input-field__icon--leading[data-v-8e16cbb5] {\n  inset-inline-start: 0px;\n}\n.input-field__icon--trailing[data-v-8e16cbb5] {\n  inset-inline-end: 0px;\n}\n.input-field__trailing-button[data-v-8e16cbb5] {\n  --button-size: calc(var(--default-clickable-area) - 2 * var(--border-width-input-focused, 2px)) !important;\n  --button-radius: calc(var(--input-border-radius) - var(--border-width-input-focused, 2px));\n}\n.input-field__trailing-button.button-vue[data-v-8e16cbb5] {\n  position: absolute;\n  top: var(--border-width-input-focused, 2px);\n  inset-inline-end: var(--border-width-input-focused, 2px);\n}\n.input-field__trailing-button.button-vue[data-v-8e16cbb5]:focus-visible {\n  box-shadow: none !important;\n}\n.input-field__helper-text-message[data-v-8e16cbb5] {\n  padding-block: 4px;\n  padding-inline: var(--border-radius-element);\n  display: flex;\n  align-items: center;\n  color: var(--color-text-maxcontrast);\n  overflow-wrap: anywhere;\n}\n.input-field__helper-text-message__icon[data-v-8e16cbb5] {\n  margin-inline-end: 8px;\n}\n.input-field--error .input-field__helper-text-message[data-v-8e16cbb5],\n.input-field--error .input-field__icon--trailing[data-v-8e16cbb5] {\n  color: var(--color-text-error, var(--color-error));\n}\n.input-field--error .input-field__input[data-v-8e16cbb5], .input-field__input[data-v-8e16cbb5]:user-invalid {\n  --input-border-color: var(--color-border-error, var(--color-error)) !important;\n}\n.input-field--error .input-field__input[data-v-8e16cbb5]:focus-visible, .input-field__input[data-v-8e16cbb5]:user-invalid:focus-visible {\n  box-shadow: rgb(248, 250, 252) 0px 0px 0px 2px, var(--color-primary-element) 0px 0px 0px 4px, rgba(0, 0, 0, 0.05) 0px 1px 2px 0px;\n}\n.input-field--success .input-field__input[data-v-8e16cbb5] {\n  --input-border-color: var(--color-border-success, var(--color-success)) !important;\n}\n.input-field--success .input-field__input[data-v-8e16cbb5]:focus-visible {\n  box-shadow: rgb(248, 250, 252) 0px 0px 0px 2px, var(--color-primary-element) 0px 0px 0px 4px, rgba(0, 0, 0, 0.05) 0px 1px 2px 0px;\n}\n.input-field--success .input-field__helper-text-message__icon[data-v-8e16cbb5] {\n  color: var(--color-border-success, var(--color-success));\n}"],sourceRoot:""}]),t.d(i,{},{default:o})},10258(e,i,t){var n=t(95113);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[e.id,n,""]]),n.locals&&(e.exports=n.locals),(0,t(15739).A)("6a6e5758",n,!0,{})},26089(e,i,t){"use strict";t(10258);var n=t(20641),a=t(90033),r=t(50953),o=t(53751),l=t(98190),d=t(42221),u=t(51012),p=t(34163),c=t(26096),s=t(52697);let b={class:"input-field__main-wrapper"},A=["id","aria-describedby","disabled","placeholder","type","value"],v=["for"],f={class:"input-field__icon input-field__icon--leading"},C={key:2,class:"input-field__icon input-field__icon--trailing"},_=["id"],x=(0,n.pM)({...{inheritAttrs:!1},__name:"NcInputField",props:(0,n.zz)({class:{default:""},inputClass:{default:""},id:{default:()=>(0,p.c)()},label:{default:void 0},labelOutside:{type:Boolean},type:{default:"text"},placeholder:{default:void 0},showTrailingButton:{type:Boolean},trailingButtonLabel:{default:void 0},success:{type:Boolean},error:{type:Boolean},helperText:{default:""},disabled:{type:Boolean},pill:{type:Boolean}},{modelValue:{required:!0},modelModifiers:{}}),emits:(0,n.zz)(["trailingButtonClick"],["update:modelValue"]),setup(e,{expose:i,emit:t}){let p=(0,n.fn)(e,"modelValue");i({focus:function(e){x.value.focus(e)},select:function(){x.value.select()}});let s=(0,n.OA)(),x=(0,n.rk)("input"),h=(0,n.EW)(()=>e.showTrailingButton||e.success),E=(0,n.EW)(()=>e.placeholder?e.placeholder:e.label?c.a?e.label:"":void 0),g=(0,n.EW)(()=>{let i=e.label||e.labelOutside;return i||(0,n.R8)("You need to add a label to the NcInputField component. Either use the prop label or use an external one, as per the example in the documentation."),i}),m=(0,n.EW)(()=>{let i=[];return e.helperText&&i.push(`${e.id}-helper-text`),s["aria-describedby"]&&i.push(String(s["aria-describedby"])),i.join(" ")||void 0});function k(i){let t=i.target;p.value="number"===e.type&&"number"==typeof p.value?parseFloat(t.value):t.value}return(i,s)=>((0,n.uX)(),(0,n.CE)("div",{class:(0,a.normalizeClass)(["input-field",[{"input-field--disabled":e.disabled,"input-field--error":e.error,"input-field--label-outside":e.labelOutside||!g.value,"input-field--leading-icon":!!i.$slots.icon,"input-field--trailing-icon":h.value,"input-field--pill":e.pill,"input-field--success":e.success,"input-field--legacy":(0,r.R1)(c.a)},i.$props.class]])},[(0,n.Lk)("div",b,[(0,n.Lk)("input",(0,n.v6)(i.$attrs,{id:e.id,ref:"input","aria-describedby":m.value,"aria-live":"polite",class:["input-field__input",e.inputClass],disabled:e.disabled,placeholder:E.value,type:e.type,value:p.value.toString(),onInput:k}),null,16,A),!e.labelOutside&&g.value?((0,n.uX)(),(0,n.CE)("label",{key:0,class:"input-field__label",for:e.id},(0,a.toDisplayString)(e.label),9,v)):(0,n.Q3)("",!0),(0,n.bo)((0,n.Lk)("div",f,[(0,n.RG)(i.$slots,"icon",{},void 0,!0)],512),[[o.vShow,!!i.$slots.icon]]),e.showTrailingButton?((0,n.uX)(),(0,n.Wv)(d.N,{key:1,class:"input-field__trailing-button","aria-label":e.trailingButtonLabel,disabled:e.disabled,variant:"tertiary-no-background",onClick:s[0]||(s[0]=e=>t("trailingButtonClick",e))},{icon:(0,n.k6)(()=>[(0,n.RG)(i.$slots,"trailing-button-icon",{},void 0,!0)]),_:3},8,["aria-label","disabled"])):e.success||e.error?((0,n.uX)(),(0,n.CE)("div",C,[e.success?((0,n.uX)(),(0,n.Wv)(u.N,{key:0,path:(0,r.R1)(l.d)},null,8,["path"])):((0,n.uX)(),(0,n.Wv)(u.N,{key:1,path:(0,r.R1)(l.j)},null,8,["path"]))])):(0,n.Q3)("",!0)]),e.helperText?((0,n.uX)(),(0,n.CE)("p",{key:0,id:`${e.id}-helper-text`,class:"input-field__helper-text-message"},[e.success?((0,n.uX)(),(0,n.Wv)(u.N,{key:0,class:"input-field__helper-text-message__icon",path:(0,r.R1)(l.d),inline:""},null,8,["path"])):e.error?((0,n.uX)(),(0,n.Wv)(u.N,{key:1,class:"input-field__helper-text-message__icon",path:(0,r.R1)(l.j),inline:""},null,8,["path"])):(0,n.Q3)("",!0),(0,n.eW)(" "+(0,a.toDisplayString)(e.helperText),1)],8,_)):(0,n.Q3)("",!0)],2))}}),h=(0,s._)(x,[["__scopeId","data-v-8e16cbb5"]]);t.d(i,{},{N:h})},51420(e,i,t){"use strict";var n=t(20641),a=t(50953),r=t(98190),o=t(22436),l=t(51012),d=t(26089);(0,o.r)(o.c,o.b);let u=(0,n.pM)({__name:"NcTextField",props:(0,n.zz)({class:{},inputClass:{},id:{},label:{},labelOutside:{type:Boolean},type:{},placeholder:{},showTrailingButton:{type:Boolean},trailingButtonLabel:{default:void 0},success:{type:Boolean},error:{type:Boolean},helperText:{},disabled:{type:Boolean},pill:{type:Boolean},trailingButtonIcon:{default:"close"}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(e,{expose:i}){let t=(0,n.fn)(e,"modelValue");i({focus:function(e){u.value.focus(e)},select:function(){u.value.select()}});let u=(0,n.rk)("inputField"),p={arrowEnd:(0,o.a)("Save changes"),close:(0,o.a)("Clear text"),undo:(0,o.a)("Undo changes")},c=new Set(Object.keys(d.N.props)),s=(0,n.EW)(()=>{let i=Object.fromEntries(Object.entries(e).filter(([e])=>c.has(e)));return i.trailingButtonLabel??=p[e.trailingButtonIcon],i});return(i,o)=>((0,n.uX)(),(0,n.Wv)((0,a.R1)(d.N),(0,n.v6)(s.value,{ref:"inputField",modelValue:t.value,"onUpdate:modelValue":o[0]||(o[0]=e=>t.value=e)}),(0,n.eX)({_:2},[i.$slots.icon?{name:"icon",fn:(0,n.k6)(()=>[(0,n.RG)(i.$slots,"icon")]),key:"0"}:void 0,"search"!==e.type?{name:"trailing-button-icon",fn:(0,n.k6)(()=>["arrowEnd"===e.trailingButtonIcon?((0,n.uX)(),(0,n.Wv)((0,a.R1)(l.N),{key:0,directional:"",path:(0,a.R1)(r.m)},null,8,["path"])):((0,n.uX)(),(0,n.Wv)((0,a.R1)(l.N),{key:1,path:"undo"===e.trailingButtonIcon?(0,a.R1)(r.a):(0,a.R1)(r.b)},null,8,["path"]))]),key:"1"}:void 0]),1040,["modelValue"]))}});t.d(i,{},{_:u})}}]);
//# sourceMappingURL=calendar-defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcTextField_vue_vue_type_script_setup_t-715f22.js.map?v=526281ea042a03b4