OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "O endereço de e-mail fornecido é muito longo",
    "User-Session unexpectedly expired" : "Sessão do usuário expirou inesperadamente",
    "Provided email-address is not valid" : "O e-mail fornecido não é válido",
    "An error occured during sending email" : "Ocorreu um erro ao enviar o e-mail",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Erro inesperado ao enviar e-mail. Entre em contato com o administrador.",
    "Successfully sent email to %1$s" : "E-mail enviado com sucesso para %1$s",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "Sem mais eventos para hoje",
    "No upcoming events" : "Nenhum evento próximo",
    "More events" : "Mais eventos",
    "%1$s with %2$s" : "%1$s com %2$s",
    "Calendar" : "Calendário",
    "New booking {booking}" : "Nova reserva {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) marcou o compromisso \"{config_display_name}\" em {date_time}.",
    "Appointments" : "Compromissos",
    "Schedule appointment \"%s\"" : "Marcar compromisso \"%s\"",
    "Schedule an appointment" : "Marcar compromisso",
    "Requestor Comments:" : "Comentários do Solicitante:",
    "Appointment Description:" : "Descrição do Compromisso:",
    "Prepare for %s" : "Preparar para %s",
    "Follow up for %s" : "Seguimento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Seu compromisso \"%s\" com %s precisa de confirmação",
    "Dear %s, please confirm your booking" : "Olá %s, por favor confirme a sua reserva",
    "Confirm" : "Confirmar",
    "Appointment with:" : "Compromisso com:",
    "Description:" : "Descrição:",
    "This confirmation link expires in %s hours." : "Este link de confirmação expirará em %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Se quiser cancelar o compromisso, entre em contato com o organizador respondendo a este e-mail ou visitando a página de perfil dele.",
    "Your appointment \"%s\" with %s has been accepted" : "Seu compromisso \"%s\" com %s foi aceito",
    "Dear %s, your booking has been accepted." : "Olá %s, sua reserva foi aceita.",
    "Appointment for:" : "Compromisso para:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Você receberá um link no e-mail de confirmação",
    "Where:" : "Local:",
    "Comment:" : "Comentário:",
    "You have a new appointment booking \"%s\" from %s" : "Você tem um novo compromisso \"%s\" de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Bom dia %s, %s (%s) marcou um compromisso com você.",
    "%s has proposed a meeting" : "%s propôs uma reunião",
    "%s has updated a proposed meeting" : "%s atualizou uma proposta de reunião",
    "%s has canceled a proposed meeting" : "%s cancelou uma proposta de reunião",
    "Dear %s, a new meeting has been proposed" : "Olá %s, uma nova reunião foi proposta",
    "Dear %s, a proposed meeting has been updated" : "Olá %s, uma proposta de reunião foi atualizada",
    "Dear %s, a proposed meeting has been cancelled" : "Olá %s, uma proposta de reunião foi cancelada",
    "Respond" : "Responder",
    "Location:" : "Localização:",
    "%1$s minutes" : "%1$s minutos",
    "Duration:" : "Duração:",
    "%1$s from %2$s to %3$s" : "%1$s de %2$s a %3$s",
    "Dates:" : "Datas:",
    "[Proposed] %1$s" : "[Proposto] %1$s",
    "Calendar App" : "Aplicativo Calendário",
    "Calendars App settings including proposals and appointments schedule configurations." : "Configurações do aplicativo Calendário, incluindo propostas e configurações da agenda de compromissos.",
    "A Calendar app for Nextcloud" : "Um aplicativo de Calendário para Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Um aplicativo de Calendário para Nextcloud. Sincronize facilmente eventos de vários dispositivos com seu Nextcloud e edite-os on-line.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Como Contatos, Talk, Tarefas, Deck e Círculos\n* 🌐 **Suporte WebCal!** Quer ver os jogos do seu time favorito no seu calendário? Sem problemas!\n* 🙋 **Participantes!** Convide pessoas para seus eventos\n* ⌚ **Livre/Ocupado!** Veja quando seus participantes estão disponíveis para se reunir\n* ⏰ **Lembretes!** Receba alarmes para eventos no seu navegador e por e-mail\n* 🔍 **Pesquisar!** Encontre seus eventos com facilidade\n* ☑️ **Tarefas!** Veja tarefas ou cartões do Deck com data de vencimento diretamente no calendário\n* 🔈 **Salas do Talk!** Crie uma sala do Talk associada ao agendar uma reunião com apenas um clique\n* 📆 **Agendamento de compromissos** Envie às pessoas um link para que elas possam agendar uma consulta com você [usando este aplicativo](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Anexos!** Adicione, carregue e visualize anexos de eventos\n* 🙈 **Não estamos reinventando a roda!** Baseado nas excelentes bibliotecas [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Dia anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Ano anterior",
    "Previous month" : "Mês anterior",
    "Next day" : "Próximo dia",
    "Next week" : "Próxima semana",
    "Next year" : "Próximo ano",
    "Next month" : "Próximo mês",
    "Create new event" : "Criar novo evento",
    "Event" : "Evento",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Year" : "Ano",
    "List" : "Lista",
    "Filter events …" : "Filtrar eventos …",
    "Appointment link was copied to clipboard" : "O link do compromisso foi copiado para a área de transferência",
    "Appointment link could not be copied to clipboard" : "Não foi possível copiar o link do compromisso para a área de transferência",
    "Preview" : "Pré-visualização",
    "Copy link" : "Copiar link",
    "Duplicate" : "Duplicar",
    "Edit" : "Editar",
    "Delete" : "Excluir",
    "Appointment schedules" : "Agendamentos de compromissos",
    "Create new" : "Criar novo",
    "Disable calendar \"{calendar}\"" : "Desativar calendário \"{calendar}\"",
    "Disable untitled calendar" : "Desativar calendário sem título",
    "Enable calendar \"{calendar}\"" : "Ativar calendário \"{calendar}\"",
    "Enable untitled calendar" : "Ativar calendário sem título",
    "An error occurred, unable to change visibility of the calendar." : "Erro ao alterar a visibilidade do calendário.",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Não foi possível copiar o link da agenda para a área de transferência.",
    "Untitled calendar" : "Calendário sem título",
    "Delegated to you by" : "Delegado a você por",
    "Shared with you by" : "Compartilhado com você por",
    "Copy public link" : "Copiar link público",
    "Edit and share calendar" : "Editar e compartilhar calendário",
    "Edit calendar" : "Editar calendário",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Descompartilhando o calendário em {countdown} segundo","Descompartilhando o calendário em {countdown} segundos","Descompartilhando o calendário em {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Excluindo o calendário em {countdown} segundo","Excluindo o calendário em {countdown} segundos","Excluindo o calendário em {countdown} segundos"],
    "Calendar name can not be blank" : "O nome do calendário não pode ficar em branco",
    "An error occurred, unable to create the calendar." : "Erro ao criar o calendário.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Digite um link válido (começando com http://, https://, webcal://, ou webcals://)",
    "My calendars" : "Meus calendários",
    "Add new" : "Adicionar novo",
    "New calendar" : "Novo calendário",
    "Name for new calendar" : "Nome do novo calendário",
    "Creating calendar …" : "Criando calendário...",
    "New calendar with task list" : "Novo calendário com lista de tarefas",
    "New subscription from link (read-only)" : "Nova assinatura de link (somente leitura)",
    "Creating subscription …" : "Criando assinatura …",
    "Add public holiday calendar" : "Adicionar calendário de feriados",
    "Add custom public calendar" : "Adicionar calendário público personalizado",
    "Copy subscription link" : "Copiar link de assinatura",
    "Copying link …" : "Copiando link...",
    "Copied link" : "Link copiado",
    "Could not copy link" : "Não foi possível copiar o link",
    "Export" : "Exportar",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos excluídos",
    "Could not delete calendar or event" : "Não foi possível excluir calendário ou evento",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento",
    "Do you really want to empty the trash bin?" : "Você realmente deseja esvaziar a lixeira?",
    "Empty trash bin" : "Esvaziar lixeira",
    "Trash bin" : "Lixeira",
    "Loading deleted items." : "Carregando itens excluídos.",
    "You do not have any deleted items." : "Você não tem itens excluídos.",
    "Name" : "Nome",
    "Deleted" : "Excluído",
    "Restore" : "Restaurar",
    "Delete permanently" : "Excluir permanentemente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Os itens na lixeira são excluídos após {numDays} dia","Os itens na lixeira são excluídos após {numDays} dias","Os itens na lixeira são excluídos após {numDays} dias"],
    "Could not update calendar order." : "Não foi possível atualizar o pedido da agenda.",
    "Shared calendars" : "Calendários compartilhados",
    "Deck" : "Deck",
    "Tasks" : "Tarefas",
    "Delegated by {name} (read-only)" : "Delegado por {name} (somente leitura)",
    "Delegated by {name}" : "Delegado por {name}",
    "Internal link" : "Link interno",
    "A private link that can be used with external clients" : "Um link privado que pode ser usado com clientes externos",
    "Copy internal link" : "Copiar link interno",
    "An error occurred, unable to publish calendar." : "Erro ao publicar calendário.",
    "An error occurred, unable to send email." : "Erro ao tentar enviar o e-mail.",
    "Embed code copied to clipboard." : "Código de incorporação copiado para a área de transferência.",
    "Embed code could not be copied to clipboard." : "O código de incorporação não pôde ser copiado para a área de transferência.",
    "Unpublishing calendar failed" : "Erro ao remover a publicação do calendário",
    "Share link" : "Compartilhar link",
    "Send link to calendar via email" : "Enviar link para o calendário via e-mail",
    "Enter one address" : "Digite um endereço",
    "Sending email …" : "Enviando e-mail...",
    "Copy embedding code" : "Copiar código de incorporação",
    "Copying code …" : "Copiando código...",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Não foi possível copiar o código",
    "Delete share link" : "Excluir compartilhamento do link",
    "Deleting share link …" : "Excluindo link de compartilhamento...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipe)",
    "An error occurred while unsharing the calendar." : "Ocorreu um erro ao cancelar o compartilhamento do calendário.",
    "An error occurred, unable to change the permission of the share." : "Erro ao alterar a permissão do compartilhamento.",
    "can edit and see confidential events" : "pode editar e ver eventos confidenciais",
    "Unshare with {displayName}" : "Descompartilhar com {displayName}",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "No users or groups" : "Nenhum usuário ou grupo",
    "events" : "eventos",
    "tasks" : "tarefas",
    "journal entries" : "entradas de diário",
    "This calendar supports neither events, tasks nor journal entries." : "Este calendário não suporta eventos, tarefas ou entradas de diário.",
    "_This calendar supports only {types}._::_This calendar supports {types}._" : ["Este calendário suporta apenas {types}.","Este calendário suporta {types}.","Este calendário suporta {types}."],
    "None" : "Nenhum",
    "Failed to save calendar name and color" : "Falha ao salvar o nome e a cor do calendário",
    "Calendar name" : "Nome do calendário",
    "Never show me as busy (set this calendar to transparent)" : "Nunca me mostrar como ocupado (definir este calendário como transparente)",
    "Default reminder for part-day events" : "Lembrete padrão para eventos de parte do dia",
    "Select default reminder" : "Selecione o lembrete padrão",
    "Default reminder for full-day events" : "Lembrete padrão para eventos de dia inteiro",
    "These reminders will be automatically added to new events created in this calendar" : "Esses lembretes serão adicionados automaticamente aos novos eventos criados neste calendário",
    "Share calendar" : "Compartilhar calendário",
    "Unshare from me" : "Descompartilhar comigo",
    "Save" : "Salvar",
    "No title" : "Sem título",
    "Are you sure you want to delete \"{title}\"?" : "Tem certeza de que deseja excluir \"{title}\"?",
    "Cancel" : "Cancelar",
    "Deleting proposal \"{title}\"" : "Excluindo a proposta \"{title}\"",
    "Successfully deleted proposal" : "Proposta excluída com sucesso",
    "Failed to delete proposal" : "Falha ao excluir proposta",
    "Failed to retrieve proposals" : "Falha ao recuperar propostas",
    "Meeting proposals" : "Propostas de reuniões",
    "A configured email address is required to use meeting proposals" : "É necessário configurar um endereço de e-mail para utilizar as propostas de reuniões.",
    "No active meeting proposals" : "Nenhuma proposta de reunião ativa",
    "View" : "Exibir",
    "Delete proposal" : "Excluir proposta",
    "Event legend" : "Legenda do evento",
    "Calendar events are styled to convey additional information at a glance." : "Os eventos do calendário são apresentados de forma a transmitir informações adicionais à primeira vista.",
    "Free / Busy" : "Livre / Ocupado",
    "Busy" : "Ocupado",
    "Busy: your time is marked as occupied" : "Ocupado: seu horário está marcado como ocupado",
    "Free" : "Livre",
    "Free: your time is still available" : "Livre: você ainda tem tempo disponível",
    "Participation status" : "Status de participação",
    "Accepted" : "Aceito",
    "Accepted: you confirmed your attendance" : "Aceito: você confirmou sua presença",
    "Tentative" : "Tentativa",
    "Tentative: your participation is uncertain" : "Tentativa: sua participação ainda é incerta",
    "Invited" : "Convidado",
    "Invited: you have not yet responded to this invitation" : "Convidado: você ainda não respondeu a este convite",
    "Declined" : "Recusado",
    "Declined: you declined this event" : "Recusado: você recusou este evento",
    "All declined" : "Todos recusaram",
    "All declined: all participants declined" : "Todos recusaram: todos os participantes recusaram",
    "Icons" : "Ícones",
    "Attendees" : "Participantes",
    "This event has one or more attendees" : "Este evento tem um ou mais participantes",
    "Past events" : "Eventos passados",
    "Past event" : "Evento passado",
    "Events that have already ended are shown with a more faded background" : "Os eventos que já terminaram são exibidos com um fundo mais desbotado",
    "Import destination selection" : "Seleção do destino da importação",
    "Import calendars" : "Importar calendários",
    "Please select a calendar to import into …" : "Selecione o calendário no qual importar …",
    "Filename" : "Nome de arquivo",
    "Calendar to import into" : "Calendário no qual importar",
    "_Import calendar_::_Import calendars_" : ["Importar calendário","Importar calendários","Importar calendários"],
    "Some calendars are disabled because this file contains {types}." : "Alguns calendários estão desativados porque este arquivo contém {types}.",
    "Select the default location for attachments" : "Selecione o local padrão para os anexos",
    "Pick" : "Escolher",
    "Invalid location selected" : "Local inválido selecionado",
    "Attachments folder successfully saved." : "Pasta de anexos salva com sucesso.",
    "Error on saving attachments folder." : "Erro ao salvar a pasta de anexos.",
    "Attachments folder" : "Pasta para os anexos",
    "{email} will no longer be able to act on your behalf." : "{email} não poderá mais agir em seu nome.",
    "Revoke" : "Revogar",
    "Viewer" : "Visualizador",
    "Editor" : "Editor",
    "Could not revoke access." : "Não foi possível revogar o acesso.",
    "Access revoked successfully." : "Acesso revogado com êxito.",
    "{name} can now view your calendars." : "{name} agora pode ver seus calendários.",
    "{name} can now act on your behalf." : "{name} agora pode agir em seu nome.",
    "Could not add delegate." : "Não foi possível adicionar o delegado.",
    "Could not load delegates." : "Não foi possível carregar os delegados.",
    "Delegates" : "Delegados",
    "Allow users to manage your calendar events and invitations on your behalf." : "Permita que os usuários gerenciem seus eventos de calendário e convites em seu nome.",
    "Loading delegates…" : "Carregando delegados…",
    "Revoke access" : "Revogar acesso",
    "No delegates yet." : "Ainda sem delegados.",
    "Add delegate" : "Adicionar delegado",
    "Revoke access?" : "Revogar acesso?",
    "Search for a user…" : "Pesquisar um usuário…",
    "No users found" : "Nenhum usuário encontrado",
    "Choose whether they can view and edit events, or only view them." : "Escolha se eles podem visualizar e editar eventos, ou apenas visualizá-los.",
    "Add as viewer" : "Adicionar como visualizador",
    "Add as editor" : "Adicionar como editor",
    "{filename} could not be parsed" : "{filename} não pôde ser analisado",
    "No valid files found, aborting import" : "Nenhum arquivo válido encontrado, importação interrompida",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Importou %n evento com sucesso","Importou %n eventos com sucesso","Importou %n eventos com sucesso"],
    "Import partially failed. Imported {accepted} out of {total}." : "Erro na importação. Importado {accepted} de {total}.",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "Automático ({timezone})",
    "New setting was not saved successfully." : "A nova configuração não foi salva.",
    "Timezone" : "Fuso horário",
    "Navigation" : "Navegação",
    "Previous period" : "Período anterior",
    "Next period" : "Próximo período",
    "Views" : "Visualizações",
    "Day view" : "Visão diária",
    "Week view" : "Visualização de semana",
    "Month view" : "Visualização de mês",
    "Year view" : "Visualização de ano",
    "List view" : "Visualização de lista",
    "Actions" : "Ações",
    "Create event" : "Criar evento",
    "Show shortcuts" : "Mostrar atalhos",
    "Close editor" : "Fechar editor",
    "Save edited event" : "Salvar evento editado",
    "Delete edited event" : "Excluir evento editado",
    "Duplicate event" : "Duplicar evento",
    "or" : "ou",
    "Calendar settings" : "Configurações do calendário",
    "No reminder" : "Nenhum lembrete",
    "At event start" : "No início do evento",
    "Failed to save default calendar" : "Falha ao salvar o calendário padrão",
    "General" : "Geral",
    "Default calendar for incoming invitations" : "Calendário padrão para convites recebidos",
    "Availability settings" : "Configurações de disponibilidade",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Acesse os calendários do Nextcloud a partir de outros aplicativos e dispositivos",
    "CalDAV URL" : "URL CalDAV",
    "Server Address for iOS and macOS" : "Endereço do Servidor para iOS e macOS",
    "Appearance" : "Aparência",
    "Birthday calendar" : "Calendários de aniversários",
    "Tasks in calendar" : "Tarefas no calendário",
    "Weekends" : "Fins de semana",
    "Week numbers" : "Números de semanas",
    "Limit number of events shown in Month view" : "Limitar o número de eventos exibidos na visualização de mês",
    "Density in Day and Week View" : "Densidade na visualização de dia e semana",
    "Editing" : "Edição",
    "Simple event editor" : "Editor de eventos simples",
    "\"More details\" opens the detailed editor" : "\"Mais detalhes\" abre o editor detalhado",
    "Files" : "Arquivos",
    "Delegation" : "Delegação",
    "Appointment schedule successfully created" : "Agendamento de compromissos criado com sucesso",
    "Appointment schedule successfully updated" : "Agendamento de compromissos atualizado com sucesso",
    "0 minutes" : "0 minutos",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dias","{duration} dias"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mês","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos","{duration} anos"],
    "To configure appointments, add your email address in personal settings." : "Para configurar compromissos, adicione seu endereço de e-mail nas configurações pessoais.",
    "Public – shown on profile page" : "Público – exibido na página de perfil",
    "Private – only accessible via link" : "Privado – acessível apenas por meio de link",
    "Appointment schedule saved" : "Agendamento de compromissos salvo",
    "Create appointment schedule" : "Criar agendamento de compromissos",
    "Edit appointment schedule" : "Editar agendamento de compromissos",
    "Update" : "Atualizar",
    "(copy)" : "(cópia)",
    "Appointment name" : "Nome do compromisso",
    "Location" : "Localização",
    "Create a Talk room" : "Criar uma sala do Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Um link exclusivo será gerado para cada compromisso agendado e enviado por e-mail de confirmação",
    "Description" : "Descrição",
    "Duration (minutes)" : "Duração (minutos)",
    "Increments" : "Incrementos",
    "Booking calendar" : "Calendário de reservas",
    "Calendars to check for conflicts" : "Calendários para verificar se há conflitos",
    "Visibility" : "Visibilidade",
    "Booking availability" : "Disponibilidade de reservas",
    "to" : "às",
    "Delete slot" : "Excluir vaga",
    "No times set" : "Nenhum horário definido",
    "Add" : "Adicionar",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Weekdays" : "Dias de semana",
    "Planning restrictions" : "Restrições de planejamento",
    "Buffer before the event" : "Tempo antes do evento",
    "Buffer after the event" : "Tempo após o evento",
    "Minimum time before next slot" : "Tempo mínimo até o próximo horário disponível",
    "Max slots per day" : "Máximo de vagas por dia",
    "Limit how far in the future appointments can be booked" : "Limite de tempo para reserva de agendamentos futuros",
    "It seems a rate limit has been reached. Please try again later." : "Parece que um limite de taxa foi atingido. Por favor, tente novamente mais tarde.",
    "Please confirm your reservation" : "Por favor, confirme sua reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Enviamos a você um e-mail com os detalhes. Por favor, confirme seu compromisso usando o link no e-mail. Você pode fechar esta página agora.",
    "Your name" : "Seu nome",
    "Your email address" : "Seu endereço de e-mail",
    "Please share anything that will help prepare for our meeting" : "Por favor, compartilhe qualquer coisa que ajude a se preparar para nosso encontro",
    "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar o compromisso. Tente novamente mais tarde ou entre em contato com o organizador.",
    "Back" : "Voltar",
    "Book appointment" : "Marcar agendamento",
    "Error fetching Talk conversations." : "Erro ao buscar conversas do Talk.",
    "Conversation does not have a valid URL." : "A conversa não tem um URL válido.",
    "Successfully added Talk conversation link to location." : "Adicionado com sucesso o link da conversa do Talk à localização.",
    "Successfully added Talk conversation link to description." : "Adicionado com sucesso o link da conversa do Talk na descrição.",
    "Failed to apply Talk room." : "Falha ao aplicar a sala do Talk.",
    "Talk conversation for event" : "Conversa do Talk para o evento",
    "Error creating Talk conversation" : "Erro ao criar conversa do Talk",
    "Select a Talk Room" : "Selecione uma Sala do Talk",
    "Fetching Talk rooms…" : "Buscando salas do Talk…",
    "No Talk room available" : "Nenhuma sala do Talk disponível",
    "Select existing conversation" : "Selecione uma conversa existente",
    "Select conversation" : "Selecione conversa",
    "Or create a new conversation" : "Ou crie uma nova conversa",
    "Create public conversation" : "Criar conversa pública",
    "Create private conversation" : "Criar conversa privada",
    "on" : "ligado",
    "at" : "em",
    "Default reminder of calendar" : "Lembrete padrão do calendário",
    "Amount" : "Quantidade",
    "before at" : "antes às",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar horário",
    "Save time" : "Salvar horário",
    "Remove reminder" : "Remover lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "dias",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
    "Choose a file to share as a link" : "Escolha um arquivo para compartilhar como link",
    "Attachment {name} already exist!" : "Anexo {name} já existe!",
    "Could not upload attachment(s)" : "Não foi possível carregar anexo(s)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Você está prestes a navegar para {link}. Tem certeza de que deseja continuar?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Você está prestes a navegar para {host}. Tem certeza de que deseja prosseguir? Link: {link}",
    "Proceed" : "Prosseguir",
    "No attachments" : "Sem anexos",
    "Add from Files" : "Adicionar de Arquivos",
    "Upload from device" : "Fazer upload do dispositivo",
    "Delete file" : "Excluir arquivo",
    "Confirmation" : "Confirmação",
    "_{count} attachment_::_{count} attachments_" : ["{count} anexo","{count} anexos","{count} anexos"],
    "Suggested" : "Sugerido",
    "Available" : "Disponível",
    "Invitation accepted" : "Convite aceito",
    "Accepted {organizerName}'s invitation" : "Aceitou o convite de {organizerName}",
    "Participation marked as tentative" : "Participação marcada como tentativa",
    "Invitation is delegated" : "O convite é delegado",
    "Not available" : "Indisponível",
    "Invitation declined" : "Convite recusado",
    "Declined {organizerName}'s invitation" : "Recusou o convite de {organizerName}",
    "Availability will be checked" : "A disponibilidade será verificada",
    "Invitation will be sent" : "O convite será enviado",
    "Failed to check availability" : "Falha ao verificar a disponibilidade",
    "Failed to deliver invitation" : "Falha na entrega do convite",
    "Awaiting response" : "Esperando resposta",
    "Checking availability" : "Verificando disponibilidade",
    "Has not responded to {organizerName}'s invitation yet" : "Ainda não respondeu ao convite de {organizerName}",
    "{name} (delegated by {delegator})" : "{name} (delegado por {delegator})",
    "Duration" : "Duração:",
    "15 minutes" : "15 minutos",
    "30 minutes" : "30 minutos",
    "45 minutes" : "45 minutos",
    "1 hour" : "1 hora",
    "1 hour 30 minutes" : "1 hora e 30 minutos",
    "2 hours" : "2 horas",
    "Custom" : "Personalizado",
    "_{i} day_::_{i} days_" : ["{i} dia","{i} de dias","{i} dias"],
    "_{i} hour_::_{i} hours_" : ["{i} hora","{i} de horas","{i} horas"],
    "_{i} minute_::_{i} minutes_" : ["{i} minuto","{i} de minutos","{i} minutos"],
    "Days" : "Dias",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Suggested times" : "Horários sugeridos",
    "chairperson" : "presidente",
    "required participant" : "participante obrigatório",
    "non-participant" : "não participante",
    "optional participant" : "participante opcional",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Vaga selecionada",
    "Availability of attendees, resources and rooms" : "Disponibilidade de participantes, recursos e salas",
    "Suggestion accepted" : "Sugestão aceita",
    "Previous date" : "Data anterior",
    "Next date" : "Próxima data",
    "Legend" : "Legenda",
    "Out of office" : "Fora do escritório",
    "Attendees:" : "Participantes:",
    "local time" : "tempo local",
    "Done" : "Concluído",
    "Search room" : "Pesquisar sala",
    "Room name" : "Nome da sala",
    "Check room availability" : "Verificar disponibilidade da sala",
    "Busy (tentative)" : "Ocupado (tentativa)",
    "Unknown" : "Desconhecido",
    "Find a time" : "Encontrar um horário",
    "The invitation has been accepted successfully." : "O convite foi aceito com sucesso.",
    "Failed to accept the invitation." : "Falha ao aceitar o convite.",
    "The invitation has been declined successfully." : "O convite foi recusado com sucesso.",
    "Failed to decline the invitation." : "Falha ao recusar o convite.",
    "Your participation has been marked as tentative." : "Sua participação foi marcada como tentativa.",
    "Failed to set the participation status to tentative." : "Falha ao marcar seu status da participação como tentativa.",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Copied to clipboard" : "Copiado para a área de transferência",
    "Failed to copy" : "Falha ao copiar",
    "Copy name and email address" : "Copiar o nome e o endereço de e-mail",
    "Send email to {email}" : "Enviar e-mail para {email}",
    "No attendees yet" : "Nenhum participante ainda",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} confirmados, {waitingCount} aguardando resposta",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Por favor, adicione pelo menos um participante para usar o recurso \"Encontrar um horário\".",
    "Status" : "Status",
    "Role" : "Função",
    "Delegated" : "Delegado",
    "Chairperson" : "Presidente",
    "Required participant" : "Participante obrigatório",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "Não participante",
    "Attendees copied to clipboard" : "Participantes copiados para a área de transferência",
    "Failed to copy attendees to clipboard" : "Falha ao copiar os participantes para a área de transferência",
    "Copy attendees to clipboard" : "Copiar participantes para a área de transferência",
    "_%n more attendee_::_%n more attendees_" : ["Mais %n participante","Mais %n de participantes","Mais %n participantes"],
    "Remove group" : "Remover grupo",
    "Remove attendee" : "Remover participante",
    "Request reply" : "Solicitar resposta",
    "_%n member_::_%n members_" : ["%n membro","%n membros","%n membros"],
    "Search for emails, users, contacts, contact groups or teams" : "Pesquise e-mails, usuários, contatos, grupos de contatos ou equipes",
    "No match found" : "Nenhuma correspondência encontrada",
    "Note that members of circles get invited but are not synced yet." : "Observe que os membros dos círculos são convidados, mas ainda não estão sincronizados.",
    "Note that members of contact groups get invited but are not synced yet." : "Observe que os membros dos grupos de contatos são convidados, mas ainda não estão sincronizados.",
    "(organizer)" : "(organizador)",
    "Make {label} the organizer" : "Torne {label} o organizador",
    "Make {label} the organizer and attend" : "Torne {label} o organizador e participe",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar convites e gerenciar respostas, [linkopen]adicione seu endereço de e-mail nas configurações pessoais[linkclose].",
    "Remove color" : "Remover cor",
    "Title" : "Título",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Não é possível modificar a configuração de dia inteiro para eventos que fazem parte de um conjunto de recorrência.",
    "From" : "De",
    "To" : "Para",
    "Your Time" : "Seu Horário",
    "Repeat" : "Repetir",
    "Repeat event" : "Repetir evento",
    "Set repetition" : "Definir repetição",
    "never" : "nunca",
    "on date" : "na data",
    "after" : "após",
    "End repeat" : "Terminar repetição",
    "Occurrences" : "Ocorrências",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento é a exceção de recorrência de um conjunto de recorrência. Você não pode adicionar uma regra de recorrência a ele.",
    "first" : "primeiro",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Alterações na regra de recorrência serão aplicadas somente a esta e a todas as ocorrências futuras.",
    "Repeat every" : "Repetir a cada",
    "By day of the month" : "Pelo dia do mês",
    "On the" : "Em",
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "_month_::_months_" : ["mês","meses","meses"],
    "_year_::_years_" : ["ano","anos","anos"],
    "On specific day" : "Em um dia específico",
    "weekday" : "Dia da semana",
    "weekend day" : "dia da semana",
    "Does not repeat" : "Não se repete",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "A definição de recorrência deste evento não é totalmente suportada pelo Nextcloud. Se você editar as opções de recorrência, determinadas recorrências poderão ser perdidas.",
    "No rooms or resources yet" : "Ainda não há salas ou recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} assento","{seatingCapacity} assentos","{seatingCapacity} assentos"],
    "Add resource" : "Adicionar recurso",
    "Has a projector" : "Tem projetor",
    "Has a whiteboard" : "Tem quadro branco",
    "Wheelchair accessible" : "Acessível a cadeiras de rodas",
    "Remove resource" : "Remover recurso",
    "Search for resources or rooms" : "Pesquise recursos ou salas",
    "available" : "disponível",
    "unavailable" : "indisponível",
    "Show all rooms" : "Mostrar todas as salas",
    "Projector" : "Projetor",
    "Whiteboard" : "Quadro branco",
    "Room type" : "Tipo de sala",
    "Any" : "Qualquer uma",
    "Minimum seating capacity" : "Capacidade mínima de assentos",
    "More details" : "Mais detalhes",
    "Update this and all future" : "Atualizar este e todos os futuros",
    "Update this occurrence" : "Atualizar esta ocorrência",
    "Public calendar does not exist" : "Calendário público não existe",
    "Maybe the share was deleted or has expired?" : "Talvez o compartilhamento esteja excluído ou expirado?",
    "Remove date" : "Remover data",
    "Attendance required" : "Presença requerida",
    "Attendance optional" : "Presença opcional ",
    "Remove participant" : "Remover participante",
    "Yes" : "Sim",
    "No" : "Não",
    "Maybe" : "Talvez",
    "Select your meeting availability" : "Selecione sua disponibilidade para reuniões",
    "Create a meeting for this date and time" : "Criar uma reunião para esta data e hora",
    "Create" : "Criar",
    "No participants or dates available" : "Nenhum participante ou data disponível",
    "(delegated by {name})" : "(delegado por {name})",
    "Type to search time zone" : "Digite para pesquisar o fuso horário",
    "Global" : "Global",
    "Holidays in {region}" : "Feriados em {region}",
    "An error occurred, unable to read public calendars." : "Ocorreu um erro, não foi possível ler calendários públicos.",
    "An error occurred, unable to subscribe to calendar." : "Ocorreu um erro, não foi possível assinar o calendário.",
    "Public calendar subscriptions selection" : "Seleção de inscrições de calendários públicos",
    "Public holiday calendars" : "Calendários de feriados",
    "Public calendars" : "Calendários públicos",
    "No valid public calendars configured" : "Nenhum calendário público válido configurado",
    "Contact your server administrator to resolve this issue." : "Entre em contato com a administração do servidor para resolver esse problema.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Os calendários de feriados públicos são fornecidos pelo Thunderbird. Os dados do calendário serão baixados de {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Estes calendários públicos são sugeridos pela administração do servidor. Os dados do calendário serão baixados do respectivo site.",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Assinado",
    "Subscribe" : "Assinar",
    "Could not fetch slots" : "Não foi possível buscar vagas",
    "Select a date" : "Selecione uma data",
    "Select slot" : "Selecione vaga",
    "No slots available" : "Nenhuma vaga disponível",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Obrigado. Sua reserva de {startDate} a {endDate} foi confirmada.",
    "Book another appointment:" : "Marcar outro compromisso:",
    "See all available slots" : "Ver todas as vagas disponíveis",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "A vaga de seu compromisso, de {startDate} a {endDate}, não está mais disponível.",
    "Please book a different slot:" : "Por favor, reserve uma vaga diferente:",
    "This booking link is no longer valid" : "Este link de reserva não é mais válido",
    "The confirmation link has expired or has already been used. Please contact the organizer to rebook." : "O link de confirmação expirou ou já foi utilizado. Entre em contato com o organizador para fazer uma nova reserva.",
    "Confirm your appointment" : "Confirmar seu compromisso",
    "Could not confirm the appointment. Please try again later or contact the organizer." : "Não foi possível confirmar o compromisso. Tente novamente mais tarde ou entre em contato com o organizador.",
    "Book an appointment with {name}" : "Marque um compromisso com {name}",
    "No public appointments found for {name}" : "Não foi encontrado nenhum compromisso público para {name}",
    "Personal" : "Pessoal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A detecção automática determinou que seu fuso horário seja UTC.\nProvavelmente, isso é resultado de medidas de segurança do seu navegador.\nDefina seu fuso horário manualmente nas configurações do calendário.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Seu fuso horário configurado ({timezoneId}) não foi encontrado. Retornando ao UTC.\nAltere seu fuso horário nas configurações e informe este problema.",
    "Show unscheduled tasks" : "Mostrar tarefas não agendadas",
    "Unscheduled tasks" : "Tarefas não agendadas",
    "Availability of {displayName}" : "Disponibilidade de {displayName}",
    "Discard changes" : "Descartar alterações",
    "Allow forwarding" : "Permitir encaminhamento",
    "Anyone with the invitation can respond" : "Qualquer pessoa que tenha recebido o convite pode responder",
    "Only invited attendees can respond" : "Somente os participantes convidados podem responder",
    "Choose \"Only invited attendees can respond\" to prevent attendees from forwarding the invitation to others." : "Selecione \"Somente os participantes convidados podem responder\" para impedir que os participantes encaminhem o convite a outras pessoas.",
    "Edit event" : "Editar evento",
    "Event does not exist" : "O evento não existe",
    "Delete this occurrence" : "Excluir esta ocorrência",
    "Delete this and all future" : "Excluir esta e todas as futuras",
    "All day" : "Dia inteiro",
    "Modifications wont get propagated to the organizer and other attendees" : "As modificações não serão propagadas para o organizador e outros participantes",
    "Add Talk conversation" : "Adicionar conversa do Talk",
    "Managing shared access" : "Gerenciar acesso compartilhado",
    "Deny access" : "Negar acesso",
    "Invite" : "Convidar",
    "Discard changes?" : "Descartar alterações?",
    "Are you sure you want to discard the changes made to this event?" : "Tem certeza de que deseja descartar as alterações feitas neste evento?",
    "_User requires access to your file_::_Users require access to your file_" : ["Usuário requer acesso ao seu arquivo","Usuários requerem acesso ao seu arquivo","Usuários requerem acesso ao seu arquivo"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Anexo exige acesso compartilhado","Anexos exigem acesso compartilhado","Anexos exigem acesso compartilhado"],
    "Untitled event" : "Evento sem título",
    "Close" : "Fechar",
    "Modifications will not get propagated to the organizer and other attendees" : "As modificações não serão propagadas para o organizador e outros participantes",
    "This event was cancelled" : "Este evento foi cancelado",
    "Meeting proposals overview" : "Visão geral de propostas de reunião",
    "Edit meeting proposal" : "Editar proposta de reunião",
    "Create meeting proposal" : "Criar proposta de reunião",
    "Update meeting proposal" : "Atualizar proposta de reunião",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Criar reunião para \"{date}\"? Isso criará um evento no calendário de todos os participantes.",
    "Create meeting" : "Criar reunião",
    "Saving proposal \"{title}\"" : "Salvando proposta \"{title}\"",
    "Successfully saved proposal" : "Proposta salva com sucesso",
    "Failed to save proposal" : "Falha ao salvar a proposta",
    "Please enter a valid duration in minutes." : "Por favor, insira uma duração em minutos válida.",
    "Failed to fetch proposals" : "Falha ao buscar propostas",
    "Creating meeting for {date}" : "Criando reunião para {date}",
    "Successfully created meeting for {date}" : "Reunião criada com sucesso para {date}",
    "Failed to create a meeting for {date}" : "Falha ao criar reunião para {date}",
    "Failed to fetch free/busy data" : "Falha ao buscar dados de livre/ocupado",
    "Selected" : "Selecionado",
    "No Description" : "Sem Descrição",
    "No Location" : "Sem Localização",
    "Edit this meeting proposal" : "Editar esta proposta de reunião",
    "Delete this meeting proposal" : "Excluir esta proposta de reunião",
    "Participants" : "Participantes",
    "Selected times" : "Horários selecionados",
    "Previous span" : "Período anterior",
    "Next span" : "Próximo período",
    "Less days" : "Menos dias",
    "More days" : "Mais dias",
    "Loading meeting proposal" : "Carregando proposta de reunião",
    "No meeting proposal found" : "Nenhuma proposta de reunião encontrada",
    "Please wait while we load the meeting proposal." : "Por favor, aguarde enquanto carregamos a proposta da reunião",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "O link que você acessou pode estar quebrado ou a proposta de reunião pode não existir mais.",
    "Thank you for your response!" : "Obrigado pela sua resposta!",
    "Your vote has been recorded. Thank you for participating!" : "Seu voto for gravado. Obrigado por participar!",
    "Unknown User" : "Usuário Desconhecido",
    "No Title" : "Sem Título",
    "No Duration" : "Sem Duração",
    "Select a different time zone" : "Selecione um fuso horário diferente",
    "Submit" : "Enviar",
    "Subscribe to {name}" : "Assinar {name}",
    "Export {name}" : "Exportar {name}",
    "Show availability" : "Mostrar disponibilidade",
    "Anniversary" : "Aniversário",
    "Appointment" : "Compromisso",
    "Business" : "Negócio",
    "Education" : "Educação",
    "Holiday" : "Feriado",
    "Meeting" : "Reunião",
    "Miscellaneous" : "Diversos",
    "Non-working hours" : "Horas fora do expediente",
    "Not in office" : "Fora do escritório",
    "Phone call" : "Chamada telefônica",
    "Sick day" : "Dia ruim",
    "Special occasion" : "Ocasião especial",
    "Travel" : "Viagem",
    "Vacation" : "Férias",
    "Midnight on the day the event starts" : "Meia-noite do dia em que o evento começa",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "no dia do evento às {formattedHourMinute}",
    "at the event's start" : "no início do evento",
    "at the event's end" : "no fim do evento",
    "{time} before the event starts" : "{time} antes de iniciar o evento",
    "{time} before the event ends" : "{time} antes do evento terminar",
    "{time} after the event starts" : "{time} após o evento iniciar",
    "{time} after the event ends" : "{time} após o evento terminar",
    "on {time}" : "às {time}",
    "on {time} ({timezoneId})" : "às {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensalmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["A cada %n dia","A cada %n dias","A cada %n dias"],
    "_Every %n week_::_Every %n weeks_" : ["A cada %n semana","A cada %n semanas","A cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["A cada %n mês","A cada %n meses","A cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["A cada %n ano","A cada %n anos","A cada %n anos"],
    "_on {weekday}_::_on {weekdays}_" : ["em {weekday}","em {weekdays}","em {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["no dia {dayOfMonthList}","nos dias {dayOfMonthList}","nos dias {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "no {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "em {monthNames} no dia {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "em {monthNames} no {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "até {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n vezes","%n vezes"],
    "second" : "segundo",
    "third" : "terceiro",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "segundos atrás",
    "last" : "último",
    "Untitled task" : "Tarefa sem título",
    "Please ask your administrator to enable the Tasks App." : "Peça ao administrador para ativar o aplicativo Tarefas.",
    "You are not allowed to edit this event as an attendee." : "Você não tem permissão para editar esse evento como participante.",
    "W" : "S",
    "%n more" : "mais %n",
    "No events to display" : "Não há mais eventos a mostrar",
    "All participants declined" : "Todos os participantes recusaram",
    "Please confirm your participation" : "Por favor, confirme sua participação",
    "You declined this event" : "Você recusou este evento",
    "Your participation is tentative" : "Sua participação é tentativa",
    "_+%n more_::_+%n more_" : ["mais +%n","mais +%n","mais +%n"],
    "No events" : "Sem eventos",
    "Create a new event or change the visible time-range" : "Crie um novo evento ou altere o intervalo de tempo visível",
    "It might have been deleted, or there was a typo in a link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "Failed to save event" : "Falha ao salvar o evento",
    "Event link copied to clipboard" : "Link do evento copiado para a área de transferência",
    "Failed to copy event link" : "Não foi possível copiar o link do evento",
    "It might have been deleted, or there was a typo in the link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "Meeting room" : "Sala de reuniões",
    "Lecture hall" : "Auditório",
    "Seminar room" : "Sala de seminários",
    "Other" : "Outro",
    "When shared show" : "Quando compartilhando mostrar",
    "When shared show full event" : "Quando compartilhado, mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado, mostrar somente ocupado",
    "When shared hide this event" : "Quando compartilhado, ocultar este evento",
    "The visibility of this event in read-only shared calendars." : "A visibilidade deste evento nos calendários compartilhados somente leitura.",
    "Add a location" : "Adicione uma localização",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Adicione uma descrição\n\n- Sobre o que é esta reunião\n- Itens da agenda\n- Qualquer coisa que os participantes precisem preparar",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Confirmation about the overall status of the event." : "Confirmação sobre o status geral do evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Leve esse evento em consideração ao calcular informações de disponibilidade.",
    "Categories" : "Categorias",
    "Categories help you to structure and organize your events." : "As categorias ajudam a estruturar e organizar seus eventos.",
    "Search or add categories" : "Pesquisar ou adicionar categorias",
    "Add this as a new category" : "Adicione isso como uma nova categoria",
    "Custom color" : "Cor personalizada",
    "Special color of this event. Overrides the calendar-color." : "Cor especial deste evento. Substitui a cor do calendário.",
    "Error while sharing file" : "Erro ao compartilhar arquivo",
    "Error while sharing file with user" : "Erro ao compartilhar arquivo com o usuário",
    "Error creating a folder {folder}" : "Erro ao criar uma pasta {folder}",
    "Attachment {fileName} already exists!" : "Anexo {fileName} já existe!",
    "Attachment {fileName} added!" : "Anexo {fileName} adicionado!",
    "An error occurred during uploading file {fileName}" : "Ocorreu um erro durante o upload do arquivo {fileName}",
    "An error occurred during getting file information" : "Ocorreu um erro ao obter informações sobre o arquivo",
    "Talk conversation for proposal" : "Conversa Talk para proposta",
    "An error occurred, unable to delete the calendar." : "Erro ao excluir o calendário.",
    "Imported {filename}" : "Importado {filename}",
    "Could not load delegated calendars. Make sure the server supports calendar delegation." : "Não foi possível carregar os calendários delegados. Certifique-se de que o servidor suporta delegação de calendário.",
    "This is an event reminder." : "Este é um lembrete de evento.",
    "Error while parsing a PROPFIND error" : "Erro ao analisar um erro PROPFIND",
    "Appointment not found" : "Compromisso não encontrado",
    "User not found" : "Usuário não encontrado",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendars" : "Calendários ",
    "Hidden" : "Ocultos",
    "Calendar name …" : "Nome do calendário …",
    "Default attachments location" : "Local padrão dos anexos",
    "Automatic ({detected})" : "Automático ({detected})",
    "Shortcut overview" : "Visão geral de atalhos",
    "CalDAV link copied to clipboard." : "Link CalDAV copiado para a área de transferência.",
    "CalDAV link could not be copied to clipboard." : "Link CalDAV não copiado para a área de transferência.",
    "Enable birthday calendar" : "Ativar calendário de aniversários",
    "Show tasks in calendar" : "Mostrar tarefas no calendário",
    "Enable simplified editor" : "Ativar o editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limitar número de eventos mostrados no modo de visualização mensal",
    "Show weekends" : "Mostrar fins de semana",
    "Show week numbers" : "Exibir o número das semanas",
    "Time increments" : "Incrementos de tempo",
    "Default reminder" : "Lembrete padrão",
    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
    "Personal availability settings" : "Configurações de disponibilidade pessoal",
    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
    "Public – shown on the profile page" : "Público – mostrado na página do perfil",
    "Private – only accessible via secret link" : "Privado – acessível apenas por meio de link secreto",
    "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
    "Pick time ranges where appointments are allowed" : "Selecione intervalos de tempo em que os compromissos são permitidos",
    "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Depois do evento",
    "Minimum time before next available slot" : "Tempo mínimo antes da próxima vaga disponível",
    "Create a new public conversation" : "Criar uma nova conversa pública",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidados, {confirmedCount} confirmados",
    "Successfully appended link to talk room to location." : "Link da sala do Talk anexado com sucesso à localização.",
    "Successfully appended link to talk room to description." : "O link para a sala Talk foi adicionado com sucesso na descrição",
    "Error creating Talk room" : "Erro ao criar a sala Talk",
    "_%n more guest_::_%n more guests_" : ["Mais %n convidado","Mais %n convidados","Mais %n convidados"],
    "Event title" : "Título do evento",
    "_time_::_times_" : ["vez","vezes","vezes"],
    "Select to end repeat" : "Selecione para finalizar a repetição",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "até {formattedDate}",
    "on {formattedDate}" : "em {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "de {formattedDate} às {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "até {formattedDate} às {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "em {formattedDate} às {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} às {formattedTime}",
    "Please enter a valid date" : "Digite uma data válida",
    "Please enter a valid date and time" : "Digite uma data e hora válida",
    "Select a time zone" : "Selecione um fuso horário",
    "Please select a time zone:" : "Selecione um fuso horário:",
    "Pick a time" : "Escolha um horário",
    "Pick a date" : "Escolha uma data",
    "Speak to the server administrator to resolve this issue." : "Fale com o administrador do servidor para resolver este problema.",
    "The slot for your appointment has been confirmed" : "A vaga para seu compromisso foi confirmada",
    "Appointment Details:" : "Detalhes do Compromisso:",
    "Time:" : "Hórario:",
    "Booked for:" : "Reservado para:",
    "Duration suggestions" : "Sugestões de duração",
    "{duration} min" : "{duration} min"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
