(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["node_modules_moment_locale_sk_js"],{5784(e,r,s){!function(e){"use strict";function r(e){return e>1&&e<5}function s(e,s,n,t){var a=e+" ";switch(n){case"s":return s||t?"p\xe1r sek\xfand":"p\xe1r sekundami";case"ss":if(s||t)return a+(r(e)?"sekundy":"sek\xfand");return a+"sekundami";case"m":return s?"min\xfata":t?"min\xfatu":"min\xfatou";case"mm":if(s||t)return a+(r(e)?"min\xfaty":"min\xfat");return a+"min\xfatami";case"h":return s?"hodina":t?"hodinu":"hodinou";case"hh":if(s||t)return a+(r(e)?"hodiny":"hod\xedn");return a+"hodinami";case"d":return s||t?"deň":"dňom";case"dd":if(s||t)return a+(r(e)?"dni":"dn\xed");return a+"dňami";case"M":return s||t?"mesiac":"mesiacom";case"MM":if(s||t)return a+(r(e)?"mesiace":"mesiacov");return a+"mesiacmi";case"y":return s||t?"rok":"rokom";case"yy":if(s||t)return a+(r(e)?"roky":"rokov");return a+"rokmi"}}e.defineLocale("sk",{months:"janu\xe1r_febru\xe1r_marec_apr\xedl_m\xe1j_j\xfan_j\xfal_august_september_okt\xf3ber_november_december".split("_"),monthsShort:"jan_feb_mar_apr_m\xe1j_j\xfan_j\xfal_aug_sep_okt_nov_dec".split("_"),weekdays:"nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota".split("_"),weekdaysShort:"ne_po_ut_st_št_pi_so".split("_"),weekdaysMin:"ne_po_ut_st_št_pi_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm"},calendar:{sameDay:"[dnes o] LT",nextDay:"[zajtra o] LT",nextWeek:function(){switch(this.day()){case 0:return"[v nedeľu o] LT";case 1:case 2:return"[v] dddd [o] LT";case 3:return"[v stredu o] LT";case 4:return"[vo štvrtok o] LT";case 5:return"[v piatok o] LT";case 6:return"[v sobotu o] LT"}},lastDay:"[včera o] LT",lastWeek:function(){switch(this.day()){case 0:return"[minul\xfa nedeľu o] LT";case 1:case 2:case 4:case 5:return"[minul\xfd] dddd [o] LT";case 3:return"[minul\xfa stredu o] LT";case 6:return"[minul\xfa sobotu o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"pred %s",s:s,ss:s,m:s,mm:s,h:s,hh:s,d:s,dd:s,M:s,MM:s,y:s,yy:s},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(s(95093))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_sk_js.js.map?v=f1d6276aee922539