(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["node_modules_moment_locale_sl_js"],{46637(e,s,a){!function(e){"use strict";function s(e,s,a,n){var r=e+" ";switch(a){case"s":return s||n?"nekaj sekund":"nekaj sekundami";case"ss":return 1===e?r+=s?"sekundo":"sekundi":2===e?r+=s||n?"sekundi":"sekundah":e<5?r+=s||n?"sekunde":"sekundah":r+="sekund",r;case"m":return s?"ena minuta":"eno minuto";case"mm":return 1===e?r+=s?"minuta":"minuto":2===e?r+=s||n?"minuti":"minutama":e<5?r+=s||n?"minute":"minutami":r+=s||n?"minut":"minutami",r;case"h":return s?"ena ura":"eno uro";case"hh":return 1===e?r+=s?"ura":"uro":2===e?r+=s||n?"uri":"urama":e<5?r+=s||n?"ure":"urami":r+=s||n?"ur":"urami",r;case"d":return s||n?"en dan":"enim dnem";case"dd":return 1===e?r+=s||n?"dan":"dnem":2===e?r+=s||n?"dni":"dnevoma":r+=s||n?"dni":"dnevi",r;case"M":return s||n?"en mesec":"enim mesecem";case"MM":return 1===e?r+=s||n?"mesec":"mesecem":2===e?r+=s||n?"meseca":"mesecema":e<5?r+=s||n?"mesece":"meseci":r+=s||n?"mesecev":"meseci",r;case"y":return s||n?"eno leto":"enim letom";case"yy":return 1===e?r+=s||n?"leto":"letom":2===e?r+=s||n?"leti":"letoma":e<5?r+=s||n?"leta":"leti":r+=s||n?"let":"leti",r}}e.defineLocale("sl",{months:"januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december".split("_"),monthsShort:"jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota".split("_"),weekdaysShort:"ned._pon._tor._sre._čet._pet._sob.".split("_"),weekdaysMin:"ne_po_to_sr_če_pe_so".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD. MM. YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danes ob] LT",nextDay:"[jutri ob] LT",nextWeek:function(){switch(this.day()){case 0:return"[v] [nedeljo] [ob] LT";case 3:return"[v] [sredo] [ob] LT";case 6:return"[v] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[v] dddd [ob] LT"}},lastDay:"[včeraj ob] LT",lastWeek:function(){switch(this.day()){case 0:return"[prejšnjo] [nedeljo] [ob] LT";case 3:return"[prejšnjo] [sredo] [ob] LT";case 6:return"[prejšnjo] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[prejšnji] dddd [ob] LT"}},sameElse:"L"},relativeTime:{future:"čez %s",past:"pred %s",s:s,ss:s,m:s,mm:s,h:s,hh:s,d:s,dd:s,M:s,MM:s,y:s,yy:s},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(a(95093))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_sl_js.js.map?v=33d5836d7fda2fb4