OC.L10N.register(
    "calendar",
    {
    "Hello," : "Azul,",
    "Open »%s«" : "Ldi »%s«",
    "Calendar" : "Awitay",
    "Confirm" : "Sergeg",
    "Description:" : "Aglam:",
    "Date:" : "Azemz:",
    "Comment:" : "Awennit:",
    "Location:" : "Adig:",
    "Duration:" : "Tanzagt:",
    "Previous day" : "Ass yezrin",
    "Previous week" : "Amalas yezrin",
    "Previous year" : "Ilindi",
    "Previous month" : "Ayyur yezrin",
    "Next week" : "Dduṛt d-iteddun",
    "Next year" : "Qabel",
    "Next month" : "Aggur d-iteddun",
    "Event" : "Tadyant",
    "Today" : "Ass-a",
    "Day" : "Ass",
    "Week" : "Amalas",
    "Month" : "Ayyur",
    "Year" : "Aseggas",
    "List" : "Tabdart",
    "Preview" : "Pre-timeẓriwt",
    "Copy link" : "Nɣel aseɣwen",
    "Duplicate" : "Sleg",
    "Edit" : "Ẓreg",
    "Delete" : "Kkes",
    "Create new" : "Snulfu-d amaynut",
    "Edit calendar" : "Ẓreg awitay",
    "Add new" : "Rnu amaynut",
    "New calendar" : "Awitay amaynut",
    "Export" : "Sifeḍ",
    "Empty trash bin" : "Silem taqecwalt",
    "Name" : "Isem",
    "Deleted" : "Yettwakkes",
    "Restore" : "Err-it-id",
    "Delete permanently" : "Kkes-it i lebda",
    "Tasks" : "Tiwura",
    "Copy internal link" : "Nɣel aseɣwen adigan",
    "Share link" : "Bḍu aseɣwen",
    "None" : "Ula d yiwen",
    "Save" : "Sekles",
    "Cancel" : "Semmet",
    "View" : "Askan",
    "Busy" : "Ur yestuf ara",
    "Free" : "Baṭel",
    "Accepted" : "Yettwaqbel",
    "Tentative" : "Tentative",
    "Declined" : "Yettwagi",
    "Icons" : "Tignitin",
    "Attendees" : "Imttekkiyen",
    "Filename" : "Isem n ufaylu",
    "Pick" : "Fren",
    "Revoke" : "Kkes",
    "Editor" : "Amaẓrag",
    "Automatic" : "Awurman",
    "Timezone" : "Tamnaḍt tasragant",
    "Navigation" : "Tunigin",
    "Views" : "Timezriyin",
    "Week view" : "Taskant n dduṛt",
    "Month view" : "Taskant n wayyur",
    "List view" : "Timeẓri n tebdart",
    "Actions" : "Tigawin",
    "Show shortcuts" : "Sken-d inegzumen",
    "Close editor" : "Mdel amaẓrag",
    "or" : "neɣ",
    "General" : "Amatu",
    "CalDAV" : "CalDAV",
    "Appearance" : "Udem",
    "Weekends" : "Imalasen",
    "Editing" : "Asiẓreg",
    "Files" : "Ifuyla",
    "0 minutes" : "0 n tisdatin",
    "Update" : "Leqqem",
    "(copy)" : "(anɣel)",
    "Location" : "Adig",
    "Description" : "Aglam",
    "Visibility" : "Tawalit",
    "to" : "ɣer",
    "Add" : "Rnu",
    "Monday" : "Arim",
    "Tuesday" : "Aram",
    "Wednesday" : "Ahad",
    "Thursday" : "Amhad",
    "Friday" : "Sem",
    "Saturday" : "Sed",
    "Sunday" : "Acer",
    "Weekdays" : "Ussan n umalas",
    "Your name" : "Isem-ik·im",
    "Your email address" : "Tansa-k·m imayl",
    "Back" : "Uɣal",
    "on" : "yermed",
    "at" : "deg",
    "Amount" : "Tasmekta",
    "Notification" : "Alɣu",
    "Email" : "Imayl",
    "Remove reminder" : "Remove reminder",
    "Add reminder" : "Rnu yiwen n usmekti",
    "seconds" : "tisinin",
    "minutes" : "tesdatin",
    "hours" : "isragen",
    "days" : "ussan",
    "weeks" : "imalasen",
    "Proceed" : "Kemmel",
    "Add from Files" : "Rnu seg yifulya",
    "Delete file" : "Kkes afaylu",
    "Confirmation" : "Asentem",
    "Suggested" : "Yettusumer",
    "Available" : "I yellan",
    "Not available" : "Ulac",
    "Duration" : "Tanzagt",
    "15 minutes" : "15 n tesdatin",
    "30 minutes" : "30 n tesdatin",
    "45 minutes" : "45 n tisdatin",
    "1 hour" : "1 n usrag",
    "2 hours" : "2 n yesragen",
    "Custom" : "Udmawan",
    "Days" : "Ussan",
    "Hours" : "Isragen",
    "Minutes" : "Tisdatin",
    "Suggestion accepted" : "Yettwaqbel usumer",
    "Legend" : "Aglam",
    "Done" : "Immed",
    "Unknown" : "Arussin",
    "Accept" : "Agez",
    "Decline" : "Agwi",
    "Copied to clipboard" : "Aḍris yettwanγel γef afus",
    "Status" : "Addad",
    "Role" : "Tamlilt",
    "Chairperson" : "Aselway",
    "Remove attendee" : "Remove attendee",
    "Title" : "Azwel",
    "From" : "Seg",
    "To" : "Ɣer",
    "Repeat" : "Ales",
    "Repeat event" : "Repeat event",
    "never" : "werjin",
    "after" : "mbaɛd",
    "first" : "amezwaru",
    "_day_::_days_" : ["ass","ussan"],
    "_month_::_months_" : ["ayyur","ayyuren"],
    "Resources" : "Tiɣbula",
    "Wheelchair accessible" : "D anekcum i at ukersi n yimeεdar",
    "unavailable" : "ulac-it",
    "Any" : "Menwala",
    "Yes" : "Ih",
    "No" : "Uhu",
    "Maybe" : "Ahat",
    "Create" : "Snulfu-d",
    "Global" : "Amatu",
    "Subscribe" : "Lteɣ",
    "Select a date" : "Fren Azemz",
    "Personal" : "Udmawan",
    "Discard changes" : "Sefsex ibeddilen",
    "Edit event" : "Edit event",
    "All day" : "Ass kamel",
    "Invite" : "Snubget",
    "Discard changes?" : "Sefsex ibeddilen?",
    "Close" : "Mdel",
    "Selected" : "Yettwafren",
    "Participants" : "Imttekkiyen",
    "Unknown User" : "Aseqdac arussin",
    "No Title" : "Ulac azwel",
    "Submit" : "Azen",
    "Anniversary" : "Amulli",
    "Business" : "Takebbanit",
    "Education" : "Asegmi",
    "Holiday" : "Amaras",
    "Miscellaneous" : "Miscellaneous",
    "Travel" : "Asikel",
    "Vacation" : "Amaras",
    "Daily" : "S wass",
    "Weekly" : "S umalas",
    "Monthly" : "Yal ayyur",
    "Yearly" : "Yal aseggas",
    "second" : "tasint",
    "last" : "aneggaru",
    "W" : "Ha",
    "No events" : "Ulac tidyanin",
    "Other" : "Wayeḍ",
    "Confirmed" : "Yettwasentem",
    "Canceled" : "Yettwasemmet",
    "Categories" : "Taggayin",
    "Custom color" : "Ini yugnen",
    "User not found" : "Ur yettwaf ara useqdac",
    "Calendars" : "Iwitayen",
    "Hidden" : "Udrig",
    "Show keyboard shortcuts" : "Sken inegzumen n unasiw",
    "Pick a date" : "Fren azemz",
    "Time:" : "Akud:"
},
"nplurals=2; plural=(n != 1);");
