(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["node_modules_moment_locale_tlh_js"],{31052(a,j,e){!function(a){"use strict";var j="pagh_wa’_cha’_wej_loS_vagh_jav_Soch_chorgh_Hut".split("_");function e(a,e,r,t){var _,h,l,s,n,o=(h=Math.floor((_=a)%1e3/100),l=Math.floor(_%100/10),s=_%10,n="",h>0&&(n+=j[h]+"vatlh"),l>0&&(n+=(""!==n?" ":"")+j[l]+"maH"),s>0&&(n+=(""!==n?" ":"")+j[s]),""===n?"pagh":n);switch(r){case"ss":return o+" lup";case"mm":return o+" tup";case"hh":return o+" rep";case"dd":return o+" jaj";case"MM":return o+" jar";case"yy":return o+" DIS"}}a.defineLocale("tlh",{months:"tera’ jar wa’_tera’ jar cha’_tera’ jar wej_tera’ jar loS_tera’ jar vagh_tera’ jar jav_tera’ jar Soch_tera’ jar chorgh_tera’ jar Hut_tera’ jar wa’maH_tera’ jar wa’maH wa’_tera’ jar wa’maH cha’".split("_"),monthsShort:"jar wa’_jar cha’_jar wej_jar loS_jar vagh_jar jav_jar Soch_jar chorgh_jar Hut_jar wa’maH_jar wa’maH wa’_jar wa’maH cha’".split("_"),monthsParseExact:!0,weekdays:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysShort:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysMin:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[DaHjaj] LT",nextDay:"[wa’leS] LT",nextWeek:"LLL",lastDay:"[wa’Hu’] LT",lastWeek:"LLL",sameElse:"L"},relativeTime:{future:function(a){var j=a;return -1!==a.indexOf("jaj")?j.slice(0,-3)+"leS":-1!==a.indexOf("jar")?j.slice(0,-3)+"waQ":-1!==a.indexOf("DIS")?j.slice(0,-3)+"nem":j+" pIq"},past:function(a){var j=a;return -1!==a.indexOf("jaj")?j.slice(0,-3)+"Hu’":-1!==a.indexOf("jar")?j.slice(0,-3)+"wen":-1!==a.indexOf("DIS")?j.slice(0,-3)+"ben":j+" ret"},s:"puS lup",ss:e,m:"wa’ tup",mm:e,h:"wa’ rep",hh:e,d:"wa’ jaj",dd:e,M:"wa’ jar",MM:e,y:"wa’ DIS",yy:e},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(e(95093))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_tlh_js.js.map?v=ad95f3b41cdfd309