OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Pateiktas el. pašto adresas yra per ilgas",
    "User-Session unexpectedly expired" : "Netikėtai pasibaigė vartotojo seanso galiojimas",
    "Provided email-address is not valid" : "Pateiktas el. pašto adresas nėra teisingas",
    "An error occured during sending email" : "Siunčiant el. laišką įvyko klaida",
    "%s has published the calendar »%s«" : "%s paskelbė kalendorių „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Netikėta klaida siunčiant el. laišką. Susisiekite su savo administratoriumi.",
    "Successfully sent email to %1$s" : "El. laiškas sėkmingai išsiųstas į %1$s",
    "Hello," : "Sveiki,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Norėtume informuoti, kad %s paskelbė kalendorių „%s“.",
    "Open »%s«" : "Atverti „%s“",
    "Cheers!" : "Sveikinimai!",
    "Upcoming events" : "Artėjantys įvykiai",
    "No more events today" : "Šiandien daugiau įvykių nėra",
    "No upcoming events" : "Artėjančių įvykių nėra",
    "More events" : "Daugiau įvykių",
    "%1$s with %2$s" : "%1$s su %2$s",
    "Calendar" : "Kalendorius",
    "New booking {booking}" : "Nauja rezervacija: {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) užsisakė susitikimą „{config_display_name}‟ {date_time}",
    "Appointments" : "Susitikimai",
    "Schedule appointment \"%s\"" : "Suplanuoti susitikimą „%s“",
    "Schedule an appointment" : "Suplanuoti susitikimą",
    "Requestor Comments:" : "Pareiškėjo pastabos:",
    "Appointment Description:" : "Susitikimo aprašymas:",
    "Prepare for %s" : "Ruoštis %s",
    "Follow up for %s" : "Sekti %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Jūsų susitikimui „%s“ su %s reikalingas patvirtinimas",
    "Dear %s, please confirm your booking" : "Gerb. %s, prašome patvirtinti savo rezervaciją.",
    "Confirm" : "Patvirtinti",
    "Appointment with:" : "Susitikimas su:",
    "Description:" : "Aprašas:",
    "This confirmation link expires in %s hours." : "Ši patvirtinimo nuoroda baigia galioti po %s val.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jei vis dėlto norite atšaukti susitikimą, susisiekite su organizatoriumi atsakydami į šį el. laišką arba apsilankydami jo profilio puslapyje.",
    "Your appointment \"%s\" with %s has been accepted" : "Jūsų susitikimas „%s“ su %s buvo patvirtintas",
    "Dear %s, your booking has been accepted." : "Gerb. %s, jūsų susitikimo rezervacija buvo patvirtinta.",
    "Appointment for:" : "Susitikimas dėl:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Gausite nuorodą su patvirtinimo el. laišku",
    "Where:" : "Kur:",
    "Comment:" : "Komentaras:",
    "You have a new appointment booking \"%s\" from %s" : "Jūs turite naują susitikimo rezervaciją „%s“ iš %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Gerb. %s, %s (%s) užrezervavo su jumis susitikimą.",
    "%s has proposed a meeting" : "%s pasiūlė posėdį",
    "%s has updated a proposed meeting" : "%s atnaujino siūlomą susitikimą",
    "%s has canceled a proposed meeting" : "%s atšaukė pasiūlytą susitikimą",
    "Dear %s, a new meeting has been proposed" : "Gerb. %s, buvo pasiūlytas naujas susitikimas",
    "Dear %s, a proposed meeting has been updated" : "Gerb. %s, pasiūlytas susitikimas buvo atnaujintas",
    "Dear %s, a proposed meeting has been cancelled" : "Gerb. %s, pasiūlytas susitikimas buvo atšauktas",
    "Respond" : "Atsakyti",
    "Location:" : "Vieta:",
    "%1$s minutes" : "%1$s minučių",
    "Duration:" : "Trukmė:",
    "%1$s from %2$s to %3$s" : "%1$s nuo %2$s iki %3$s",
    "Dates:" : "Datos:",
    "[Proposed] %1$s" : "[Pasiūlyta] %1$s",
    "Calendar App" : "Kalendoriaus programėlė",
    "Calendars App settings including proposals and appointments schedule configurations." : "Kalendorių programėlės nustatymai, įskaitant pasiūlymus ir susitikimų tvarkaraščio konfigūracijas.",
    "A Calendar app for Nextcloud" : "Kalendoriaus programėlė, skirta Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "„Nextcloud“ kalendoriaus programėlė. Lengvai sinchronizuokite įvykius iš įvairių įrenginių su savo „Nextcloud“ paskyra ir redaguokite juos internete.\n\n* 🚀 **Integracija su kitomis „Nextcloud“ programėlėmis!** Pavyzdžiui, „Kontaktai“, „Pokalbiai“, „Užduotys“, „Darbai“ ir „Ratai“\n* 🌐 **„WebCal“ palaikymas!** Norite kalendoriuje matyti savo mėgstamos komandos rungtynių datas? Jokių problemų!\n* 🙋 **Dalyviai!** Kviečiate žmones į savo renginius\n* ⌚ **Laisvas/Užimtas!** Matykite, kada jūsų dalyviai gali susitikti\n* ⏰ **Priminimai!** Gaukite priminimus apie renginius savo naršyklėje ir el. paštu\n* 🔍 **Paieška!** Lengvai suraskite savo renginius\n* ☑️ **Užduotys!** Peržiūrėkite užduotis arba Darbų korteles su terminu tiesiogiai kalendoriuje\n* 🔈 **Pokalbių kambariai!** Sukurkite susijusį pokalbių kambarį, kai užsisakote susitikimą, vos vienu paspaudimu\n* 📆 **Susitikimų rezervavimas** Siųskite žmonėms nuorodą, kad jie galėtų rezervuoti susitikimą su jumis [naudodami šią programėlę](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Priedai!** Pridėkite, įkelkite ir peržiūrėkite renginių priedus\n* 🙈 **Mes neišradinėjame dviračio iš naujo!** Remiantis puikiomis [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ir [fullcalendar](https://github.com/fullcalendar/fullcalendar) bibliotekomis.",
    "Previous day" : "Ankstesnė diena",
    "Previous week" : "Ankstesnė savaitė",
    "Previous year" : "Ankstesni metai",
    "Previous month" : "Ankstesnis mėnuo",
    "Next day" : "Kita diena",
    "Next week" : "Kita savaitė",
    "Next year" : "Kiti metai",
    "Next month" : "Kitas mėnuo",
    "Create new event" : "Sukurti naują įvykį",
    "Event" : "Įvykis",
    "Today" : "Šiandiena",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Year" : "Metai",
    "List" : "Sąrašas",
    "Filter events …" : "Filtruoti įvykius …",
    "Appointment link was copied to clipboard" : "Susitikimo nuoroda buvo nukopijuota į iškarpinę",
    "Appointment link could not be copied to clipboard" : "Susitikimo nuorodos nepavyko nukopijuoti į iškarpinę",
    "Preview" : "Peržiūra",
    "Copy link" : "Kopijuoti nuorodą",
    "Duplicate" : "Dublikatai",
    "Edit" : "Redaguoti",
    "Delete" : "Ištrinti",
    "Appointment schedules" : "Susitikimų tvarkaraščiai",
    "Create new" : "Sukurti naują",
    "Disable calendar \"{calendar}\"" : "Išjungti kalendorių „{calendar}“",
    "Disable untitled calendar" : "Išjungti kalendorių be pavadinimo",
    "Enable calendar \"{calendar}\"" : "Įjungti kalendorių „{calendar}“",
    "Enable untitled calendar" : "Įjungti kalendorių be pavadinimo",
    "An error occurred, unable to change visibility of the calendar." : "Įvyko klaida, nepavyko pakeisti kalendoriaus matomumo.",
    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
    "Untitled calendar" : "Kalendorius be pavadinimo",
    "Delegated to you by" : "Jums delegavo",
    "Shared with you by" : "Su jumis bendrina",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Edit and share calendar" : "Redaguoti ir bendrinti kalendorių",
    "Edit calendar" : "Redaguoti kalendorių",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendorius nustojamas bendrinti po {countdown} sekundės","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundės"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendorius ištrinamas po {countdown} sekundės","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundės"],
    "Calendar name can not be blank" : "Kalendoriaus pavadinimo laukas negali būti tuščias",
    "An error occurred, unable to create the calendar." : "Įvyko klaida, nepavyko sukurti kalendoriaus.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Įveskite teisingą nuorodą (prasidedančią http://, https://, webcal:// ar webcals://)",
    "My calendars" : "Mano kalendoriai",
    "Add new" : "Pridėti naują",
    "New calendar" : "Naujas kalendorius",
    "Name for new calendar" : "Naujo kalendoriaus pavadinimas",
    "Creating calendar …" : "Kuriamas kalendorius …",
    "New calendar with task list" : "Naujas kalendorius su užduočių sąrašu",
    "New subscription from link (read-only)" : "Nauja prenumerata iš nuorodos (tik skaitymui)",
    "Creating subscription …" : "Kuriama prenumerata …",
    "Add public holiday calendar" : "Pridėti valstybinių švenčių kalendorių",
    "Add custom public calendar" : "Pridėkite tinkintą viešąjį kalendorių",
    "Copy subscription link" : "Kopijuoti prenumeratos nuorodą",
    "Copying link …" : "Kopijuojama nuoroda …",
    "Copied link" : "Nuoroda nukopijuota",
    "Could not copy link" : "Nepavyko nukopijuoti nuorodos",
    "Export" : "Eksportuoti",
    "Untitled item" : "Elementas be pavadinimo",
    "Unknown calendar" : "Nežinomas kalendorius",
    "Could not load deleted calendars and objects" : "Nepavyko įkelti ištrintų kalendorių ir objektų",
    "Could not delete calendar or event" : "Nepavyko ištrinti kalendoriaus ar įvykio",
    "Could not restore calendar or event" : "Nepavyko atkurti kalendoriaus ar įvykio",
    "Do you really want to empty the trash bin?" : "Ar tikrai norite išvalyti šiukšlinę?",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "Trash bin" : "Šiukšlinė",
    "Loading deleted items." : "Įkeliami ištrinti elementai.",
    "You do not have any deleted items." : "Jūs neturite jokių ištrintų elementų.",
    "Name" : "Pavadinimas",
    "Deleted" : "Ištrintas",
    "Restore" : "Atkurti",
    "Delete permanently" : "Ištrinti visam laikui",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Elementai šiukšlinėje yra ištrinami po {numDays} dienos","Elementai šiukšlinėje yra ištrinami po {numDays} dienų","Elementai šiukšlinėje yra ištrinami po {numDays} dienų","Elementai šiukšlinėje yra ištrinami po {numDays} dienos"],
    "Could not update calendar order." : "Nepavyko atnaujinti kalendoriaus tvarkos.",
    "Shared calendars" : "Bendrinti kalendoriai",
    "Deck" : "Darbai",
    "Tasks" : "Užduotys",
    "Delegated by {name} (read-only)" : "{name} delegavo (tik skaitymui)",
    "Delegated by {name}" : "Delegavo {name}",
    "Internal link" : "Vidinė nuoroda",
    "A private link that can be used with external clients" : "Privati ​​nuoroda, kurią galima naudoti su išoriniais klientais",
    "Copy internal link" : "Kopijuoti vidinę nuorodą",
    "An error occurred, unable to publish calendar." : "Įvyko klaida, nepavyko paskelbti kalendoriaus.",
    "An error occurred, unable to send email." : "Įvyko klaida, nepavyko išsiųsti el. laiško.",
    "Embed code copied to clipboard." : "Įterpimo kodas nukopijuotas į iškarpinę.",
    "Embed code could not be copied to clipboard." : "Įterpimo kodo nepavyko nukopijuoti į iškarpinę.",
    "Unpublishing calendar failed" : "Nepavyko atšaukti kalendoriaus paskelbimo",
    "Share link" : "Bendrinimo nuoroda",
    "Send link to calendar via email" : "Siųsti el. paštu nuorodą į kalendorių",
    "Enter one address" : "Įveskite vieną adresą",
    "Sending email …" : "Siunčiamas el. laiškas …",
    "Copy embedding code" : "Kopijuoti įterpimo kodą",
    "Copying code …" : "Kopijuojamas kodas …",
    "Copied code" : "Kodas nukopijuotas",
    "Could not copy code" : "Nepavyko nukopijuoti kodo",
    "Delete share link" : "Ištrinti viešinio nuorodą",
    "Deleting share link …" : "Ištrinama viešinio nuoroda …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Komanda)",
    "An error occurred while unsharing the calendar." : "Nutraukiant kalendoriaus bendrinimą įvyko klaida.",
    "An error occurred, unable to change the permission of the share." : "Įvykio klaida, nepavyko pakeisti bendrinimo leidimo.",
    "can edit and see confidential events" : "gali redaguoti ir matyti konfidencialius įvykius",
    "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "events" : "įvykiai",
    "tasks" : "užduotys",
    "journal entries" : "žurnalo įrašai",
    "This calendar supports neither events, tasks nor journal entries." : "Šis kalendorius nepalaiko nei įvykių, nei užduočių, nei žurnalo įrašų.",
    "_This calendar supports only {types}._::_This calendar supports {types}._" : ["Šis kalendorius palaiko tik {types}.","Šis kalendorius palaiko {types}.","Šis kalendorius palaiko {types}.","Šis kalendorius palaiko {types}."],
    "None" : "Nėra",
    "Failed to save calendar name and color" : "Nepavyko įrašyti kalendoriaus pavadinimo ir spalvos",
    "Calendar name" : "Kalendoriaus pavadinimas",
    "Never show me as busy (set this calendar to transparent)" : "Niekada nerodyti manęs kaip užimto ​​(nustatyti šį kalendorių kaip skaidrų)",
    "Default reminder for part-day events" : "Numatytasis priminimas apie trumpus renginius",
    "Select default reminder" : "Pasirinkite numatytąjį priminimą",
    "Default reminder for full-day events" : "Numatytasis priminimas apie visos dienos renginius",
    "These reminders will be automatically added to new events created in this calendar" : "Šie priminimai bus automatiškai pridedami prie naujų įvykių, kuriamų šiame kalendoriuje",
    "Share calendar" : "Bendrinti kalendorių",
    "Unshare from me" : "Nustoti bendrinti su manimi",
    "Save" : "Įrašyti",
    "No title" : "Nėra antraštės",
    "Are you sure you want to delete \"{title}\"?" : "Ar tikrai norite ištrinti „{title}“?",
    "Cancel" : "Atsisakyti",
    "Deleting proposal \"{title}\"" : "Ištrinamas pasiūlymas „{title}“",
    "Successfully deleted proposal" : "Sėkmingai ištrintas pasiūlymas",
    "Failed to delete proposal" : "Nepavyko ištrinti pasiūlymo",
    "Failed to retrieve proposals" : "Nepavyko gauti pasiūlymų",
    "Meeting proposals" : "Susitikimų pasiūlymai",
    "A configured email address is required to use meeting proposals" : "Norint naudoti susitikimų pasiūlymus, reikalingas sukonfigūruotas el. pašto adresas",
    "No active meeting proposals" : "Nėra aktyvių susitikimo pasiūlymų",
    "View" : "Rodyti",
    "Delete proposal" : "Ištrinti pasiūlymą",
    "Event legend" : "Renginio paaiškinimas",
    "Calendar events are styled to convey additional information at a glance." : "Kalendoriaus įrašų stilius parinktas taip, kad papildomą informaciją būtų galima įvertinti iš pirmo žvilgsnio.",
    "Free / Busy" : "Laisvas / Užimtas",
    "Busy" : "Užimtas laikas",
    "Busy: your time is marked as occupied" : "Užimta: jūsų laikas pažymėtas kaip užimtas",
    "Free" : "Laisvas laikas",
    "Free: your time is still available" : "Laisva: jūsų laikas vis dar laisvas",
    "Participation status" : "Dalyvavimo būsena",
    "Accepted" : "Priimta",
    "Accepted: you confirmed your attendance" : "Patvirtinta: jūs patvirtinote savo dalyvavimą",
    "Tentative" : "Preliminarus",
    "Tentative: your participation is uncertain" : "Preliminari informacija: jūsų dalyvavimas nėra aiškus",
    "Invited" : "Pakviestas",
    "Invited: you have not yet responded to this invitation" : "Kvietimas: dar neatsakėte į šį kvietimą",
    "Declined" : "Atmesta",
    "Declined: you declined this event" : "Atmetėte: jūs atmetėte šį renginį",
    "All declined" : "Viskas atmesta",
    "All declined: all participants declined" : "Viskas atmesta: visi dalyviai atsisakė",
    "Icons" : "Piktogramos",
    "Attendees" : "Dalyviai",
    "This event has one or more attendees" : "Šiame renginyje dalyvauja vienas ar daugiau dalyvių",
    "Past events" : "Ankstesni renginiai",
    "Past event" : "Ankstesnis renginys",
    "Events that have already ended are shown with a more faded background" : "Jau pasibaigę renginiai rodomi su labiau išblukusiu fonu",
    "Import destination selection" : "Importuoti paskirties vietos pasirinkimą",
    "Import calendars" : "Importuoti kalendorius",
    "Please select a calendar to import into …" : "Pasirinkite kalendorių į kurį importuoti …",
    "Filename" : "Failo pavadinimas",
    "Calendar to import into" : "Kalendorius, į kurį importuoti",
    "_Import calendar_::_Import calendars_" : ["Importuoti kalendorių","Importuoti kalendorius","Importuoti kalendorius","Importuoti kalendorius"],
    "Some calendars are disabled because this file contains {types}." : "Kai kurie kalendoriai išjungti, nes šiame faile yra {types}.",
    "Select the default location for attachments" : "Pasirinkti numatytąją vietą priedams",
    "Pick" : "Pasirinkti",
    "Invalid location selected" : "Pasirinkta neteisinga vieta",
    "Attachments folder successfully saved." : "Priedų aplankas sėkmingai įrašytas.",
    "Error on saving attachments folder." : "Klaida įrašant priedų aplanką.",
    "Attachments folder" : "Priedų aplankas",
    "{email} will no longer be able to act on your behalf." : "{email} nebegalės veikti jūsų vardu.",
    "Revoke" : "Panaikinti",
    "Viewer" : "Žiūryklė",
    "Editor" : "Redaktorius",
    "Could not revoke access." : "Nepavyko atšaukti prieigos.",
    "Access revoked successfully." : "Prieiga sėkmingai atšaukta.",
    "{name} can now view your calendars." : "{name} dabar gali peržiūrėti jūsų kalendorius.",
    "{name} can now act on your behalf." : "{name} dabar gali veikti jūsų vardu.",
    "Could not add delegate." : "Nepavyko pridėti atstovo.",
    "Could not load delegates." : "Nepavyko įkelti delegatų.",
    "Delegates" : "Delegatai",
    "Allow users to manage your calendar events and invitations on your behalf." : "Leiskite vartotojams tvarkyti jūsų kalendoriaus įvykius ir kvietimus jūsų vardu.",
    "Loading delegates…" : "Įkeliami delegatai…",
    "Revoke access" : "Atšaukti prieigą",
    "No delegates yet." : "Delegatų dar nėra.",
    "Add delegate" : "Pridėti delegatą",
    "Revoke access?" : "Atšaukti prieigą?",
    "Search for a user…" : "Ieškoti vartotojo…",
    "No users found" : "Nerasta jokių vartotojų",
    "Choose whether they can view and edit events, or only view them." : "Pasirinkite, ar jie gali peržiūrėti ir redaguoti įvykius, ar tik juos peržiūrėti.",
    "Add as viewer" : "Pridėti kaip žiūrėtoją",
    "Add as editor" : "Pridėti kaip redaktorių",
    "{filename} could not be parsed" : "Nepavyko išnagrinėti {filename}",
    "No valid files found, aborting import" : "Nerasta jokių tinkamų failų, importavimas nutraukiamas",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sėkmingai importuotas %n įvykis","Sėkmingai importuoti %n įvykiai","Sėkmingai importuota %n įvykių","Sėkmingai importuotas %n įvykis"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importavimas dalinai nepavyko. Importuota {accepted} iš {total}.",
    "Automatic" : "Automatinė",
    "Automatic ({timezone})" : "Automatinė ({timezone})",
    "New setting was not saved successfully." : "Naujas nustatymas nebuvo sėkmingai įrašytas.",
    "Timezone" : "Laiko juosta",
    "Navigation" : "Navigacija",
    "Previous period" : "Ankstesnis laikotarpis",
    "Next period" : "Kitas laikotarpis",
    "Views" : "Rodiniai",
    "Day view" : "Dienos rodinys",
    "Week view" : "Savaitės rodinys",
    "Month view" : "Mėnesio rodinys",
    "Year view" : "Metų rodinys",
    "List view" : "Sąrašo rodinys",
    "Actions" : "Veiksmai",
    "Create event" : "Sukurti įvykį",
    "Show shortcuts" : "Rodyti sparčiąsias nuorodas",
    "Close editor" : "Užverti redaktorių",
    "Save edited event" : "Įrašyti redaguotą įvykį",
    "Delete edited event" : "Ištrinti redaguotą įvykį",
    "Duplicate event" : "Dubliuoti įvykį",
    "or" : "ar",
    "Calendar settings" : "Kalendoriaus nustatymai",
    "No reminder" : "Jokio priminimo",
    "At event start" : "Įvykio pradžioje",
    "Failed to save default calendar" : "Nepavyko įrašyti numatytojo kalendoriaus",
    "General" : "Bendra",
    "Default calendar for incoming invitations" : "Numatytasis gaunamų kvietimų kalendorius",
    "Availability settings" : "Užimtumo nustatymai",
    "CalDAV" : "„CalDAV“",
    "Access Nextcloud calendars from other apps and devices" : "Pasiekite „Nextcloud“ kalendorius iš kitų programų ir įrenginių",
    "CalDAV URL" : "„CalDAV“ URL",
    "Server Address for iOS and macOS" : "Serverio adresas skirtas iOS ir macOS",
    "Appearance" : "Išvaizda",
    "Birthday calendar" : "Gimtadienių kalendorius",
    "Tasks in calendar" : "Užduotys kalendoriuje",
    "Weekends" : "Savaitgaliai",
    "Week numbers" : "Savaičių numeriai",
    "Limit number of events shown in Month view" : "Apriboti mėnesio rodinyje rodomų įvykių skaičių",
    "Density in Day and Week View" : "Rodinio glaustumas dienos ir savaitės režimuose",
    "Editing" : "Redagavimas",
    "Simple event editor" : "Paprastas įvykių redaktorius",
    "\"More details\" opens the detailed editor" : "„Daugiau informacijos“ atidaro išsamų redaktorių",
    "Files" : "Failai",
    "Delegation" : "Delegavimas",
    "Appointment schedule successfully created" : "Susitikimų tvarkaraštis sėkmingai sukurtas",
    "Appointment schedule successfully updated" : "Susitikimų tvarkaraštis sėkmingai atnaujintas",
    "0 minutes" : "0 minučių",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutė","{duration} minutės","{duration} minučių","{duration} minutė"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} valanda","{duration} valandos","{duration} valandų","{duration} valanda"],
    "_{duration} day_::_{duration} days_" : ["{duration} diena","{duration} dienos","{duration} dienų","{duration} diena"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} savaitė","{duration} savaitės","{duration} savaičių","{duration} savaitė"],
    "_{duration} month_::_{duration} months_" : ["{duration} mėnesis","{duration} mėnesiai","{duration} mėnesių","{duration} mėnesis"],
    "_{duration} year_::_{duration} years_" : ["{duration} metai","{duration} metai","{duration} metų","{duration} metai"],
    "To configure appointments, add your email address in personal settings." : "Norėdami konfigūruoti susitikimus, asmeniniuose nustatymuose pridėkite savo el. pašto adresą.",
    "Public – shown on profile page" : "Vieša – rodoma profilio puslapyje",
    "Private – only accessible via link" : "Privatu – pasiekiama tik per nuorodą",
    "Appointment schedule saved" : "Susitikimų tvarkaraštis išsaugotas",
    "Create appointment schedule" : "Sukurti susitikimų tvarkaraštį",
    "Edit appointment schedule" : "Redaguoti susitikimų tvarkaraštį",
    "Update" : "Atnaujinti",
    "(copy)" : "(kopija)",
    "Appointment name" : "Susitikimo pavadinimas",
    "Location" : "Vieta",
    "Create a Talk room" : "Sukurti „Pokalbių“ kambarį",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Kiekvienam rezervuotam susitikimui bus sugeneruota unikali nuoroda ir išsiųsta patvirtinimo el. paštu.",
    "Description" : "Aprašas",
    "Duration (minutes)" : "Trukmė (minutėmis)",
    "Increments" : "Intervalai",
    "Booking calendar" : "Rezervacijų kalendorius",
    "Calendars to check for conflicts" : "Kalendoriai, kuriuose galima patikrinti, ar nėra konfliktų",
    "Visibility" : "Matomumas",
    "Booking availability" : "Rezervacijų prieinamumas",
    "to" : "iki",
    "Delete slot" : "Ištrinti laiko tarpą",
    "No times set" : "Nėra nustatytų laikų",
    "Add" : "Pridėti",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sunday" : "Sekmadienis",
    "Weekdays" : "Šiokiadieniai",
    "Planning restrictions" : "Planavimo apribojimai",
    "Buffer before the event" : "Laiko atsarga prieš renginį",
    "Buffer after the event" : "Laiko atsarga po renginio",
    "Minimum time before next slot" : "Minimalus laikas iki kito laiko tarpsnio",
    "Max slots per day" : "Maksimalus laiko tarpsnis per dieną",
    "Limit how far in the future appointments can be booked" : "Apriboti, kiek tolimos ateities susitikimų galima užsisakyti",
    "It seems a rate limit has been reached. Please try again later." : "Panašu, kad pasiektas greičio limitas. Bandykite dar kartą vėliau.",
    "Please confirm your reservation" : "Patvirtinkite rezervaciją",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Išsiuntėme jums el. laišką su išsamia informacija. Patvirtinkite savo susitikimą naudodami el. laiške esančią nuorodą. Dabar galite uždaryti šį puslapį.",
    "Your name" : "Jūsų vardas",
    "Your email address" : "Jūsų el. pašto adresas",
    "Please share anything that will help prepare for our meeting" : "Pasidalinkite informacija, kuri padės mums pasiruošti šiam susitikimui",
    "Could not book the appointment. Please try again later or contact the organizer." : "Nepavyko užsisakyti susitikimo. Bandykite dar kartą vėliau arba susisiekite su organizatoriumi.",
    "Back" : "Atgal",
    "Book appointment" : "Rezervuokite susitikimą",
    "Error fetching Talk conversations." : "Klaida gaunant „Talk“ pokalbius.",
    "Conversation does not have a valid URL." : "Pokalbis neturi galiojančio URL.",
    "Successfully added Talk conversation link to location." : "„Talk“ pokalbio nuoroda sėkmingai pridėta prie vietos.",
    "Successfully added Talk conversation link to description." : "„Talk“ pokalbio nuoroda sėkmingai pridėta prie aprašymo.",
    "Failed to apply Talk room." : "Nepavyko pritaikyti „Talk“ pokalbių kambario.",
    "Talk conversation for event" : "„Pokalbiai“ pokalbis renginiui",
    "Error creating Talk conversation" : "Klaida kuriant „Pokalbiai“ pokalbį",
    "Select a Talk Room" : "Pasirinkti „Pokalbių“ kambarį",
    "Fetching Talk rooms…" : "Gaunami „Talk“ pokalbių kambariai",
    "No Talk room available" : "Nėra „Talk“ pokalbių kambarių",
    "Select existing conversation" : "Pasirinkite esamą pokalbį",
    "Select conversation" : "Pasirinkite pokalbį",
    "Or create a new conversation" : "Arba sukurkite naują pokalbį",
    "Create public conversation" : "Sukurti viešą pokalbį",
    "Create private conversation" : "Sukurti privatų pokalbį",
    "on" : "šiomis dienomis",
    "at" : ",",
    "Default reminder of calendar" : "Numatytasis kalendoriaus priminimas",
    "Amount" : "Kiekis",
    "before at" : "prieš įvykį, ties",
    "Notification" : "Pranešimas",
    "Email" : "Elektroninis laiškas",
    "Audio notification" : "Garsinis pranešimas",
    "Other notification" : "Kitas pranešimas",
    "Relative to event" : "Susieta su įvykiu",
    "On date" : "data",
    "Edit time" : "Redaguoti laiką",
    "Save time" : "Įrašyti laiką",
    "Remove reminder" : "Šalinti priminimą",
    "Add reminder" : "Pridėti priminimą",
    "seconds" : "sekundes",
    "minutes" : "minučių",
    "hours" : "valandų",
    "days" : "dienų",
    "weeks" : "savaičių",
    "Choose a file to add as attachment" : "Pasirinkite failą, kurį norite pridėti kaip priedą",
    "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
    "Attachment {name} already exist!" : "Priedas {name} jau egzistuoja!",
    "Could not upload attachment(s)" : "Nepavyko įkelti priedo (-ų)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Jūs ruošiatės naviguoti į {link}. Ar tikrai norite tęsti?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Jūs ruošiatės pereiti į {host}. Ar tikrai norite tęsti? Nuoroda: {link}",
    "Proceed" : "Tęsti",
    "No attachments" : "Priedų nėra",
    "Add from Files" : "Pridėti iš Failų",
    "Upload from device" : "Įkelti iš įrenginio",
    "Delete file" : "Ištrinti failą",
    "Confirmation" : "Patvirtinimas",
    "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
    "Suggested" : "Pasiūlyta",
    "Available" : "Prieinamas",
    "Invitation accepted" : "Pakvietimas priimtas",
    "Accepted {organizerName}'s invitation" : "Priimtas pakvietimas iš {organizerName}",
    "Participation marked as tentative" : "Dalyvavimas pažymėtas kaip preliminarus.",
    "Invitation is delegated" : "Pakvietimas yra deleguotas",
    "Not available" : "Užimta",
    "Invitation declined" : "Pakvietimas atmestas.",
    "Declined {organizerName}'s invitation" : "Atmestas pakvietimas iš {organizerName}",
    "Availability will be checked" : "Užimtumas bus patikrintas",
    "Invitation will be sent" : "Pakvietimas bus išsiųstas",
    "Failed to check availability" : "Nepavyko patikrinti užimtumo",
    "Failed to deliver invitation" : "Nepavyko pristatyti pakvietimo",
    "Awaiting response" : "Laukiama atsakymo",
    "Checking availability" : "Tikrinamas prieinamumas",
    "Has not responded to {organizerName}'s invitation yet" : "Dar neatsakė į {organizerName} kvietimą",
    "{name} (delegated by {delegator})" : "{name} (delegavo {delegator})",
    "Duration" : "Trukmė",
    "15 minutes" : "15 minučių",
    "30 minutes" : "30 minučių",
    "45 minutes" : "45 minutės",
    "1 hour" : "1 valanda",
    "1 hour 30 minutes" : "1 valanda 30 minučių",
    "2 hours" : "2 valandos",
    "Custom" : "Tinkinta",
    "_{i} day_::_{i} days_" : ["{i} diena","{i} dienos","{i} dienų","{i} dienų"],
    "_{i} hour_::_{i} hours_" : ["{i} valanda","{i} valandos","{i} valandų","{i} valandų"],
    "_{i} minute_::_{i} minutes_" : ["{i} minutė","{i} minutės","{i} minučių","{i} minučių"],
    "Days" : "Dienos",
    "Hours" : "Valandos",
    "Minutes" : "Minutės",
    "Suggested times" : "Siūlomas laikas",
    "chairperson" : "pirmininkas",
    "required participant" : "būtinas dalyvis",
    "non-participant" : "Ne dalyvis",
    "optional participant" : "nebūtinas dalyvis",
    "{organizer} (organizer)" : "{organizer} (organizatorius)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Pasirinktas tarpas",
    "Availability of attendees, resources and rooms" : "Dalyvių, išteklių ir kambarių prieinamumas",
    "Suggestion accepted" : "Pasiūlymas priimtas",
    "Previous date" : "Ankstesnė data",
    "Next date" : "Sekanti data",
    "Legend" : "Sutartiniai ženklai",
    "Out of office" : "Ne darbo vietoje",
    "Attendees:" : "Dalyviai:",
    "local time" : "vietos laikas",
    "Done" : "Atlikta",
    "Search room" : "Ieškoti kambario",
    "Room name" : "Kambario pavadinimas",
    "Check room availability" : "Tikrinti kambarių užimtumą",
    "Busy (tentative)" : "Užimtas laikas (preliminariai)",
    "Unknown" : "Nežinoma",
    "Find a time" : "Rasti laiką",
    "The invitation has been accepted successfully." : "Pavietimas sėkmingai priimtas.",
    "Failed to accept the invitation." : "Nepavyko priimti pakvietimo.",
    "The invitation has been declined successfully." : "Pakvietimas buvo sėkmingai atšauktas.",
    "Failed to decline the invitation." : "Nepavyko atmesti pakvietimo.",
    "Your participation has been marked as tentative." : "Jūsų dalyvavimas pažymėtas kaip preliminarus.",
    "Failed to set the participation status to tentative." : "Nepavyko nustatyti dalyvavimo būsenos į preliminarią.",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Copied to clipboard" : "Nukopijuota į iškarpinę",
    "Failed to copy" : "Nepavyko nukopijuoti",
    "Copy name and email address" : "Kopijuoti vardą ir el. pašto adresą",
    "Send email to {email}" : "Nusiųsti žinutę į {email}",
    "No attendees yet" : "Kol kas dalyvių nėra",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} patvirtinta, {waitingCount} laukiama atsakymo",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Norėdami naudoti funkciją „Rasti laiką“, pridėkite bent vieną dalyvį.",
    "Status" : "Būsena",
    "Role" : "Vaidmuo",
    "Delegated" : "Deleguota",
    "Chairperson" : "Pirmininkas",
    "Required participant" : "Būtinas dalyvis",
    "Optional participant" : "Nebūtinas dalyvis",
    "Non-participant" : "Ne dalyvis",
    "Attendees copied to clipboard" : "Dalyviai nukopijuoti į iškarpinę",
    "Failed to copy attendees to clipboard" : "Nepavyko nukopijuoti dalyvių į iškarpinę",
    "Copy attendees to clipboard" : "Nukopijuokite dalyvius į iškarpinę",
    "_%n more attendee_::_%n more attendees_" : ["dar %n dalyvis","dar %n dalyviai","dar %n dalyvių","dar %n dalyvių"],
    "Remove group" : "Šalinti grupę",
    "Remove attendee" : "Šalinti dalyvį",
    "Request reply" : "Prašyti atsakymo",
    "_%n member_::_%n members_" : ["%n narys","%n nariai","%n narių","%n narys"],
    "Search for emails, users, contacts, contact groups or teams" : "Ieškoti el. laiškų, vartotojų, kontaktų, kontaktų grupių ar komandų",
    "No match found" : "Nerasta jokio atitikmens",
    "Note that members of circles get invited but are not synced yet." : "Atkreipkite dėmesį, kad draugų ratų nariai yra kviečiami, bet dar nėra sinchronizuojami.",
    "Note that members of contact groups get invited but are not synced yet." : "Atminkite, kad kontaktų grupių nariai yra kviečiami, bet dar nėra sinchronizuojami.",
    "(organizer)" : "(organizatorius)",
    "Make {label} the organizer" : "Padarykite {label} organizatoriumi",
    "Make {label} the organizer and attend" : "Padarykite {label} organizatoriumi ir dalyvaukite",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Norėdami siųsti pakvietimus ir apdoroti atsakymus, [linkopen]pridėkite į asmeninius nustatymus savo el. pašto adresą[linkclose].",
    "Remove color" : "Šalinti spalvą",
    "Title" : "Pavadinimas",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Negalima modifikuoti „Visos dienos“ nustatymą įvykiams, kurie yra pasikartojimo rinkinio dalis.",
    "From" : "Nuo",
    "To" : "Kam",
    "Your Time" : "Jūsų laikas",
    "Repeat" : "Kartoti",
    "Repeat event" : "Pakartoti įvykį",
    "Set repetition" : "Nustatykite pasikartojimą",
    "never" : "niekada",
    "on date" : "tam tikrą datą",
    "after" : "po",
    "End repeat" : "Užbaigti kartojimą",
    "Occurrences" : "Atvejai",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Šis įvykis yra pasikartojimo rinkinio pasikartojimo išimtis. Negalite jam pridėti pasikartojimo taisyklės.",
    "first" : "pirmas",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Pakeitimai pasikartojimo taisyklėje bus taikomi tik šiam ir būsimiems pasikartojimams.",
    "Repeat every" : "Kartoti kas",
    "By day of the month" : "Pagal mėnesio dienas",
    "On the" : "Ties",
    "_day_::_days_" : ["diena","dienos","dienų","diena"],
    "_week_::_weeks_" : ["savaitė","savaitės","savaičių","savaitė"],
    "_month_::_months_" : ["mėnesis","mėnesiai","mėnesių","mėnesis"],
    "_year_::_years_" : ["metai","metai","metų","metai"],
    "On specific day" : "Tam tikrą dieną",
    "weekday" : "savaitės darbo dienos",
    "weekend day" : "savaitgalio diena",
    "Does not repeat" : "Nekartojamas",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud nepalaiko pilnai šio įvykio pasikartojimo apibrėžimo. Jei taisysite pasikartojimo parinktis, tam tikri pasikartojimai gali būti prarasti.",
    "No rooms or resources yet" : "Kol kas nėra kambarių ar išteklių",
    "Resources" : "Ištekliai",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sėdima vieta","{seatingCapacity} sėdimos vietos","{seatingCapacity} sėdimų vietų","{seatingCapacity} sėdima vieta"],
    "Add resource" : "Pridėti išteklių",
    "Has a projector" : "Yra projektorius",
    "Has a whiteboard" : "Yra rašymo lenta",
    "Wheelchair accessible" : "Prieiga neįgaliųjų vežimėliu",
    "Remove resource" : "Šalinti išteklių",
    "Search for resources or rooms" : "Ieškoti išteklių ar kambarių",
    "available" : "prieinamas",
    "unavailable" : "neprieinamas",
    "Show all rooms" : "Rodyti visus kambarius",
    "Projector" : "Projektorius",
    "Whiteboard" : "Rašymo lenta",
    "Room type" : "Kambario tipas",
    "Any" : "Bet koks",
    "Minimum seating capacity" : "Mažiausias vietų skaičius",
    "More details" : "Išsamiau",
    "Update this and all future" : "Atnaujinti šį ir visus būsimus",
    "Update this occurrence" : "Atnaujinti šį pasikartojimą",
    "Public calendar does not exist" : "Viešojo kalendoriaus nėra",
    "Maybe the share was deleted or has expired?" : "Galbūt, bendrinimas buvo ištrintas arba nebegalioja?",
    "Remove date" : "Šalinti datą",
    "Attendance required" : "Būtina dalyvauti",
    "Attendance optional" : "Dalyvavimas nėra privalomas",
    "Remove participant" : "Šalinti dalyvį",
    "Yes" : "Taip",
    "No" : "Ne",
    "Maybe" : "Galbūt",
    "Select your meeting availability" : "Pasirinkite, kada galite dalyvauti susitikime",
    "Create a meeting for this date and time" : "Sukurti susitikimą šiai datai ir laikui",
    "Create" : "Sukurti",
    "No participants or dates available" : "Dalyvių nėra arba nėra nurodytų datų",
    "(delegated by {name})" : "(delegavo {name})",
    "Type to search time zone" : "Rašykite norėdami ieškoti laiko juostos",
    "Global" : "Visuotinis",
    "Holidays in {region}" : "Atostogos {region}",
    "An error occurred, unable to read public calendars." : "Įvyko klaida, nepavyko perskaityti viešųjų kalendorių.",
    "An error occurred, unable to subscribe to calendar." : "Įvyko klaida, nepavyko prenumeruoti kalendoriaus.",
    "Public calendar subscriptions selection" : "Viešojo kalendoriaus prenumeratų pasirinkimas",
    "Public holiday calendars" : "Valstybinių švenčių kalendorius",
    "Public calendars" : "Viešieji kalendoriai",
    "No valid public calendars configured" : "Nėra sukonfigūruota jokių galiojančių viešųjų kalendorių",
    "Contact your server administrator to resolve this issue." : "Norėdami išspręsti šią problemą, susisiekite su serverio administratoriumi.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Valstybinių švenčių dienų kalendorius pateikia „Thunderbird“. Kalendoriaus duomenys bus atsisiųsti iš {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Šiuos viešuosius kalendorius siūlo serverio administratorius. Kalendorių duomenys bus atsisiųsti iš atitinkamos svetainės.",
    "By {authors}" : "Autoriai: {authors}",
    "Subscribed" : "Prenumeruotas",
    "Subscribe" : "Prenumeruoti",
    "Could not fetch slots" : "Nepavyko gauti laiko tarpsnių",
    "Select a date" : "Pasirinkti datą",
    "Select slot" : "Pasirinkti laiko tarpsnį",
    "No slots available" : "Visi laiko tarpsniai užimti",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ačiū. Jūsų rezervacija nuo {startDate} iki {endDate} yra patvirtinta.",
    "Book another appointment:" : "Užrezervuokite kitą susitikimą:",
    "See all available slots" : "Žr. visus galimus laiko tarpsnius",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Jūsų pasirinktas laikas nuo {startDate} iki {endDate} nebėra laisvas.",
    "Please book a different slot:" : "Prašome rezervuoti kitą laiką:",
    "This booking link is no longer valid" : "Ši užsakymo nuoroda nebegalioja",
    "The confirmation link has expired or has already been used. Please contact the organizer to rebook." : "Patvirtinimo nuoroda nebegalioja arba jau buvo panaudota. Norėdami užsisakyti iš naujo, susisiekite su renginio organizatoriumi.",
    "Confirm your appointment" : "Patvirtinkite savo susitikimą",
    "Could not confirm the appointment. Please try again later or contact the organizer." : "Nepavyko patvirtinti susitikimo. Bandykite dar kartą vėliau arba susisiekite su organizatoriumi.",
    "Book an appointment with {name}" : "Rezervuokite susitikimą su {name}",
    "No public appointments found for {name}" : "Nerasta jokių viešų susitikimų su {name}",
    "Personal" : "Asmeniniai",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatinis laiko juostos aptikimas nustatė, kad jūsų laiko juosta yra UTC.\nTaip, greičiausiai, yra dėl jūsų saityno naršyklės saugos priemonių.\nKalendoriaus nustatymuose prašome rankiniu būdu nusistatyti laiko juostą.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Jūsų konfigūruota laiko juosta ({timezoneId}) nerasta. Grįžtama į UTC.\nPrašome nustatymuose pakeisti savo laiko juostą ir pranešti apie šią problemą.",
    "Show unscheduled tasks" : "Rodyti nesuplanuotas užduotis",
    "Unscheduled tasks" : "Nesuplanuotos užduotys",
    "Availability of {displayName}" : "{displayName} užimtumas",
    "Discard changes" : "Atmesti pakeitimus",
    "Allow forwarding" : "Leisti persiuntimą",
    "Anyone with the invitation can respond" : "Atsakyti gali kiekvienas, turintis kvietimą",
    "Only invited attendees can respond" : "Atsakyti gali tik pakviestieji dalyviai",
    "Choose \"Only invited attendees can respond\" to prevent attendees from forwarding the invitation to others." : "Pasirinkite „Atsakyti gali tik pakviestieji dalyviai“, kad dalyviai negalėtų persiųsti kvietimo kitiems.",
    "Edit event" : "Redaguoti įvykį",
    "Event does not exist" : "Įvykio nėra",
    "Delete this occurrence" : "Ištrinti šį pasikartojimą",
    "Delete this and all future" : "Ištrinti šį ir visus būsimus",
    "All day" : "Visą dieną",
    "Modifications wont get propagated to the organizer and other attendees" : "Pakeitimai nebus perduoti organizatoriui ir kitiems dalyviams.",
    "Add Talk conversation" : "Pridėti „Pokalbių“ pokalbį",
    "Managing shared access" : "Bendros prieigos valdymas",
    "Deny access" : "Uždrausti prieigą",
    "Invite" : "Pakviesti",
    "Discard changes?" : "Atmesti pakeitimus?",
    "Are you sure you want to discard the changes made to this event?" : "Ar tikrai norite atmesti šiame įvykyje atliktus pakeitimus?",
    "_User requires access to your file_::_Users require access to your file_" : ["Vartotojui reikalinga prieiga prie jūsų failo","Vartotojams reikalinga prieiga prie jūsų failo","Vartotojams reikalinga prieiga prie jūsų failo","Vartotojams reikalinga prieiga prie jūsų failo"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Priedui reikalinga bendra prieiga","Priedams reikalinga bendra prieiga","Priedams reikalinga bendra prieiga","Priedams reikalinga bendra prieiga"],
    "Untitled event" : "Įvykis be pavadinimo",
    "Close" : "Užverti",
    "Modifications will not get propagated to the organizer and other attendees" : "Pakeitimai nebus perduoti organizatoriui ir kitiems dalyviams.",
    "This event was cancelled" : "Šis renginys buvo atšauktas",
    "Meeting proposals overview" : "Susitikimų pasiūlymų apžvalga",
    "Edit meeting proposal" : "Redaguoti susitikimo pasiūlymą",
    "Create meeting proposal" : "Sukurti susitikimo pasiūlymą",
    "Update meeting proposal" : "Atnaujinti susitikimo pasiūlymą",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Sukurti susitikimą „{date}“? Tai sukurs kalendoriaus įvykį su visais dalyviais.",
    "Create meeting" : "Sukurti susitikimą",
    "Saving proposal \"{title}\"" : "Įrašomas pasiūlymas „{title}“",
    "Successfully saved proposal" : "Pasiūlymas sėkmingai išsaugotas",
    "Failed to save proposal" : "Nepavyko išsaugoti pasiūlymo",
    "Please enter a valid duration in minutes." : "Įveskite tinkamą trukmę minutėmis.",
    "Failed to fetch proposals" : "Nepavyko gauti pasiūlymų",
    "Creating meeting for {date}" : "Kuriamas susitikimas {date}",
    "Successfully created meeting for {date}" : "Sėkmingai sukurtas susitikimas {date}",
    "Failed to create a meeting for {date}" : "Nepavyko sukurti susitikimo {date}",
    "Failed to fetch free/busy data" : "Nepavyko gauti laisvo/užimto ​​laiko duomenų",
    "Selected" : "Pasirinkta",
    "No Description" : "Nėra aprašymo",
    "No Location" : "Nėra vietos",
    "Edit this meeting proposal" : "Redaguoti šį susitikimo pasiūlymą",
    "Delete this meeting proposal" : "Ištrinti šį susitikimo pasiūlymą",
    "Participants" : "Dalyviai",
    "Selected times" : "Pasirinkti laikai",
    "Previous span" : "Ankstesnis intervalas",
    "Next span" : "Sekantis intervalas",
    "Less days" : "Mažiau dienų",
    "More days" : "Daugiau dienų",
    "Loading meeting proposal" : "Įkeliamas susitikimo pasiūlymas",
    "No meeting proposal found" : "Nerasta jokių susitikimo pasiūlymų",
    "Please wait while we load the meeting proposal." : "Prašome palaukti, kol įkelsime susitikimo pasiūlymą.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Nuoroda, kuria sekėte, gali neveikti arba susitikimo pasiūlymas gali neegzistuoti.",
    "Thank you for your response!" : "Ačiū už jūsų atsakymą!",
    "Your vote has been recorded. Thank you for participating!" : "Jūsų balsas užregistruotas. Dėkojame, kad dalyvavote!",
    "Unknown User" : "Nežinomas vartotojas",
    "No Title" : "Be pavadinimo",
    "No Duration" : "Nėra trukmės",
    "Select a different time zone" : "Pasirinkite kitą laiko juostą",
    "Submit" : "Pateikti",
    "Subscribe to {name}" : "Prenumeruoti {name}",
    "Export {name}" : "Eksportuoti {name}",
    "Show availability" : "Rodyti prieinamumą",
    "Anniversary" : "Metinės",
    "Appointment" : "Paskyrimas",
    "Business" : "Verslas",
    "Education" : "Švietimas",
    "Holiday" : "Šventinė diena",
    "Meeting" : "Susitikimas",
    "Miscellaneous" : "Įvairūs",
    "Non-working hours" : "Ne darbo valandos",
    "Not in office" : "Ne darbo vietoje",
    "Phone call" : "Telefono skambutis",
    "Sick day" : "Nedarbingumo dėl ligos diena",
    "Special occasion" : "Ypatinga proga",
    "Travel" : "Kelionės",
    "Vacation" : "Atostogos",
    "Midnight on the day the event starts" : "Vidurnaktį, įvykio pradžios dieną",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dieną prieš įvykį, ties {formattedHourMinute}","%n dienas prieš įvykį, ties {formattedHourMinute}","%n dienų prieš įvykį, ties {formattedHourMinute}","%n dieną prieš įvykį, ties {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n savaitę prieš įvykį, ties {formattedHourMinute}","%n savaites prieš įvykį, ties {formattedHourMinute}","%n savaičių prieš įvykį, ties {formattedHourMinute}","%n savaitę prieš įvykį, ties {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "įvykio dieną ties {formattedHourMinute}",
    "at the event's start" : "įvykio pradžioje",
    "at the event's end" : "įvykio pabaigoje",
    "{time} before the event starts" : "{time} prieš įvykio pradžią",
    "{time} before the event ends" : "{time} prieš įvykio pabaigą",
    "{time} after the event starts" : "{time} po įvykio pradžios",
    "{time} after the event ends" : "{time} po įvykio pabaigos",
    "on {time}" : "ties {time}",
    "on {time} ({timezoneId})" : "ties {time} ({timezoneId})",
    "Week {number} of {year}" : "{year}-ųjų metų {number} savaitė",
    "Daily" : "Kasdien",
    "Weekly" : "Kas savaitę",
    "Monthly" : "Kas mėnesį",
    "Yearly" : "Kas metus",
    "_Every %n day_::_Every %n days_" : ["Kas %n dieną","Kas %n dienas","Kas %n dienų","Kas %n dieną"],
    "_Every %n week_::_Every %n weeks_" : ["Kas %n savaitę","Kas %n savaites","Kas %n savaičių","Kas %n savaitę"],
    "_Every %n month_::_Every %n months_" : ["Kas %n mėnesį","Kas %n mėnesius","Kas %n mėnesių","Kas %n mėnesį"],
    "_Every %n year_::_Every %n years_" : ["Kas %n metus","Kas %n metus","Kas %n metų","Kas %n metus"],
    "_on {weekday}_::_on {weekdays}_" : ["ties {weekday}","ties {weekdays}","ties {weekdays}","ties {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ties {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames} mėn. {dayOfMonthList} d.",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "ties {monthNames}, ties {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "iki {untilDate}",
    "_%n time_::_%n times_" : ["%n kartą","%n kartus","%n kartų","%n kartą"],
    "second" : "antras",
    "third" : "trečias",
    "fourth" : "ketvirtas",
    "fifth" : "penktas",
    "second to last" : "priešpaskutinis",
    "last" : "paskutinis",
    "Untitled task" : "Užduotis be pavadinimo",
    "Please ask your administrator to enable the Tasks App." : "Paprašykite administratoriaus įjungti Užduočių programą.",
    "You are not allowed to edit this event as an attendee." : "Jūs neturite teisės redaguoti šio įvykio kaip dalyvis.",
    "W" : "Sav.",
    "%n more" : "dar %n",
    "No events to display" : "Nėra rodytinų įvykių",
    "All participants declined" : "Visi dalyviai atsisakė",
    "Please confirm your participation" : "Prašome patvirtinti savo dalyvavimą",
    "You declined this event" : "Jūs atmetėte šį įvykį",
    "Your participation is tentative" : "Jūsų dalyvavimas yra preliminarus",
    "_+%n more_::_+%n more_" : ["+ dar %n","+ dar %n","+ dar %n","+ dar %n"],
    "No events" : "Įvykių nėra",
    "Create a new event or change the visible time-range" : "Sukurti naują įvykį ar keisti matomą laiko rėžį",
    "It might have been deleted, or there was a typo in a link" : "Galbūt nuoroda buvo ištrinta arba joje buvo rašybos klaida.",
    "Failed to save event" : "Nepavyko įrašyti įvykio",
    "Event link copied to clipboard" : "Renginio nuoroda nukopijuota į iškarpinę",
    "Failed to copy event link" : "Nepavyko nukopijuoti renginio nuorodos",
    "It might have been deleted, or there was a typo in the link" : "Galbūt nuoroda buvo ištrinta arba joje buvo rašybos klaida",
    "Meeting room" : "Susitikimų kambarys",
    "Lecture hall" : "Paskaitų auditorija",
    "Seminar room" : "Seminarų salė",
    "Other" : "Kita",
    "When shared show" : "Bendrinant rodyti",
    "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
    "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
    "The visibility of this event in read-only shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose, skirtuose tik skaitymui.",
    "Add a location" : "Pridėti vietą",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Pridėkite aprašymą\n\n- Kokia šio susitikimo tema\n- Darbotvarkės punktai\n- Ką dalyviai turi pasiruošti",
    "Confirmed" : "Patvirtintas",
    "Canceled" : "Atsisakytas",
    "Confirmation about the overall status of the event." : "Patvirtinimas apie bendrą įvykio būseną.",
    "Show as" : "Rodyti kaip",
    "Take this event into account when calculating free-busy information." : "Atsižvelgti į šį įvykį apskaičiuojant laisvo ir užimto laiko informaciją.",
    "Categories" : "Kategorijos",
    "Categories help you to structure and organize your events." : "Kategorijos padeda jums struktūrizuoti ir valdyti savo įvykius.",
    "Search or add categories" : "Ieškoti ar pridėti kategorijas",
    "Add this as a new category" : "Pridėti tai kaip naują kategoriją",
    "Custom color" : "Tinkinta spalva",
    "Special color of this event. Overrides the calendar-color." : "Speciali šio įvykio spalva. Nustelbia kalendoriaus spalvą.",
    "Error while sharing file" : "Klaida bendrinant failą",
    "Error while sharing file with user" : "Klaida bendrinant failą su naudotoju",
    "Error creating a folder {folder}" : "Klaida kuriant aplanką {folder}",
    "Attachment {fileName} already exists!" : "Priedas „{fileName}“ jau yra!",
    "Attachment {fileName} added!" : "Priedas {fileName} pridėtas!",
    "An error occurred during uploading file {fileName}" : "Įkeliant {fileName} failą įvyko klaida ",
    "An error occurred during getting file information" : "Gaunant informaciją apie failą įvyko klaida",
    "Talk conversation for proposal" : "„Pokalbiai“ pokalbis dėl pasiūlymo",
    "An error occurred, unable to delete the calendar." : "Įvyko klaida, nepavyko ištrinti kalendorių.",
    "Imported {filename}" : "Importuotas {filename}",
    "Could not load delegated calendars. Make sure the server supports calendar delegation." : "Nepavyko įkelti deleguotų kalendorių. Įsitikinkite, kad serveris palaiko kalendorių delegavimą.",
    "This is an event reminder." : "Tai priminimas apie įvykį.",
    "Error while parsing a PROPFIND error" : "Klaida analizuojant „PROPFIND“ klaidą",
    "Appointment not found" : "Susitikimas nerastas",
    "User not found" : "Naudotojas nerastas",
    "%1$s - %2$s" : "%1$s – %2$s",
    "Calendars" : "Kalendoriai",
    "Hidden" : "Paslėpta",
    "Calendar name …" : "Kalendoriaus pavadinimas…",
    "Default attachments location" : "Numatytoji priedų vieta",
    "Automatic ({detected})" : "Automatinė ({detected})",
    "Shortcut overview" : "Sparčiųjų nuorodų apžvalga",
    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
    "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
    "Limit the number of events displayed in the monthly view" : "Riboti mėnesio rodinyje rodomų įvykių skaičių",
    "Show weekends" : "Rodyti savaitgalius",
    "Show week numbers" : "Rodyti savaičių numerius",
    "Time increments" : "Laiko intervalai",
    "Default reminder" : "Numatytasis priminimas",
    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
    "Public – shown on the profile page" : "Viešas – rodomas profilio puslapyje",
    "Private – only accessible via secret link" : "Privatus – pasiekiamas tik per slaptą nuorodą",
    "Additional calendars to check for conflicts" : "Papildomi kalendoriai, kuriuos reikia patikrinti dėl konfliktų",
    "Pick time ranges where appointments are allowed" : "Pasirinkite laiko rėžius, kuomet bus leidžiami susitikimai",
    "Add time before and after the event" : "Pridėti laiką prieš ir po įvykio",
    "Before the event" : "Prieš įvykį",
    "After the event" : "Po įvykio",
    "Minimum time before next available slot" : "Minimalus laikas iki kito laisvo laiko tarpsnio",
    "Create a new public conversation" : "Sukurti naują viešą pokalbį",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} pakviesta, {confirmedCount} patvirtino",
    "Successfully appended link to talk room to location." : "Pokalbių kambario nuoroda sėkmingai pridėta prie vietos.",
    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
    "_%n more guest_::_%n more guests_" : ["dar %n svečias","dar %n svečiai","dar %n svečių","dar %n svečių"],
    "Event title" : "Įvykio pavadinimas",
    "_time_::_times_" : ["karto","kartų","kartų","karto"],
    "Select to end repeat" : "Pasirinkite norėdami užbaigti kartojimą",
    "from {formattedDate}" : "nuo {formattedDate}",
    "to {formattedDate}" : "iki {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "nuo {formattedDate}, {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "iki {formattedDate}, {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "Please enter a valid date" : "Įveskite teisingą datą",
    "Please enter a valid date and time" : "Įveskite teisingą datą ir laiką",
    "Select a time zone" : "Pasirinkti laiko juostą",
    "Please select a time zone:" : "Pasirinkite laiko juostą:",
    "Pick a time" : "Pasirinkite laiką",
    "Pick a date" : "Pasirinkite datą",
    "Speak to the server administrator to resolve this issue." : "Dėl šios problemos kreipkitės į serverio administratorių.",
    "The slot for your appointment has been confirmed" : "Jūsų susitikimo laikas patvirtintas",
    "Appointment Details:" : "Susitikimo duomenys:",
    "Time:" : "Laikas:",
    "Booked for:" : "Užsakyta:",
    "Duration suggestions" : "Trukmės pasiūlymai",
    "{duration} min" : "{duration} min"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
