OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Өгсөн имэйл хаяг хэт урт байна",
    "User-Session unexpectedly expired" : "Хэрэглэгчийн сессион гэнэт дууслаа",
    "Provided email-address is not valid" : "Өгсөн имэйл хаяг буруу байна",
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Unexpected error sending email. Please contact your administrator." : "Имэйл илгээхэд гэнэтийн алдаа гарлаа. Администратортай холбогдоно уу.",
    "Successfully sent email to %1$s" : "%1$s руу имэйл амжилттай илгээгдлээ",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "–ë–æ–ª–∂ –±–∞–π–Ω–∞!",
    "Upcoming events" : "–£–¥–∞—Ö–≥“Ø–π –±–æ–ª–æ—Ö “Ø–π–ª —è–≤–¥–ª—É—É–¥",
    "No more events today" : "Өнөөдөр өөр үйл явдал байхгүй",
    "No upcoming events" : "Удахгүй болох үйл явдал байхгүй",
    "More events" : "Нэмэлт үйл явдлууд",
    "%1$s with %2$s" : "%1$s %2$s-тай",
    "Calendar" : "Календарь",
    "New booking {booking}" : "Шинэ захиалга {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) \"{config_display_name}\" цаг товлолтыг {date_time}-д захиалсан.",
    "Appointments" : "Уулзалтууд",
    "Schedule appointment \"%s\"" : "\"%s\" уулзалт товлох",
    "Schedule an appointment" : "Уулзалт товлох",
    "Requestor Comments:" : "Хүсэлт гаргагчийн тайлбар:",
    "Appointment Description:" : "Уулзалтын тайлбар:",
    "Prepare for %s" : "%s-д бэлтгэх",
    "Follow up for %s" : "%s-ийн дагаж мөрдөх",
    "Your appointment \"%s\" with %s needs confirmation" : "Таны %s-тай \"%s\" уулзалт баталгаажуулалт шаардаж байна",
    "Dear %s, please confirm your booking" : "Эрхэм %s, захиалгаа баталгаажуулна уу",
    "Confirm" : "–ë–∞—Ç–ª–∞—Ö",
    "Appointment with:" : "Уулзалт:",
    "Description:" : "Тайлбар:",
    "This confirmation link expires in %s hours." : "–≠–Ω—ç –±–∞—Ç–∞–ª–≥–∞–∞–∂—É—É–ª–∞—Ö —Ö–æ–ª–±–æ–æ—Å %s —Ü–∞–≥–∏–π–Ω –¥–∞—Ä–∞–∞ –¥—É—É—Å–Ω–∞ ",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Хэрэв та цаг товлолтыг цуцлахыг хүсвэл энэ имэйлд хариу бичих эсвэл зохион байгуулагчийн профайл хуудсанд зочлон холбогдоно уу.",
    "Your appointment \"%s\" with %s has been accepted" : "Таны %s-тай \"%s\" уулзалт хүлээн зөвшөөрөгдлөө",
    "Dear %s, your booking has been accepted." : "Эрхэм %s, таны захиалга хүлээн зөвшөөрөгдлөө.",
    "Appointment for:" : "Уулзалт:",
    "Date:" : "–û–≥–Ω–æ–æ:",
    "You will receive a link with the confirmation email" : "Та баталгаажуулах имэйлтэй хамт холбоос хүлээн авна",
    "Where:" : " –•–∞–∞–Ω–∞:",
    "Comment:" : "Тайлбар:",
    "You have a new appointment booking \"%s\" from %s" : "Танд %s-ээс \"%s\" шинэ уулзалтын захиалга ирлээ",
    "Dear %s, %s (%s) booked an appointment with you." : "Эрхэм %s, %s (%s) тантай уулзалт захиалсан.",
    "%s has proposed a meeting" : "%s уулзалт санал болгосон",
    "%s has updated a proposed meeting" : "%s санал болгосон уулзалтыг шинэчилсэн",
    "%s has canceled a proposed meeting" : "%s санал болгосон уулзалтыг цуцалсан",
    "Dear %s, a new meeting has been proposed" : "Эрхэм %s, шинэ уулзалт санал болгогдлоо",
    "Dear %s, a proposed meeting has been updated" : "Эрхэм %s, санал болгосон уулзалт шинэчлэгдлээ",
    "Dear %s, a proposed meeting has been cancelled" : "Эрхэм %s, санал болгосон уулзалт цуцлагдлаа",
    "Respond" : "Хариулах",
    "Location:" : "–ë–∞–π—Ä—à–∏–ª:",
    "%1$s minutes" : "%1$s минут",
    "Duration:" : "Үргэлжлэх хугацаа:",
    "%1$s from %2$s to %3$s" : "%1$s %2$s-ээс %3$s хүртэл",
    "Dates:" : "Огноонууд:",
    "[Proposed] %1$s" : "[Санал] %1$s",
    "Calendar App" : "Календарын програм",
    "Calendars App settings including proposals and appointments schedule configurations." : "Санал болон цаг товлолтын хуваарийн тохиргоог багтаасан Календарь аппын тохиргоо.",
    "A Calendar app for Nextcloud" : "–ù—ç–∫—Å—Ç–∫–ª–∞—É–¥ –ö–∞–ª–µ–Ω–¥–∞—Ä—å –∞–ø–ø ",
    "Previous day" : "”®–º–Ω”©—Ö ”©–¥”©—Ä",
    "Previous week" : "”®–Ω–º”©—Ö 7 —Ö–æ–Ω–æ–≥",
    "Previous year" : "Өмнөх жил",
    "Previous month" : "”®–º–Ω”©—Ö —Å–∞—Ä",
    "Next day" : "–ú–∞—Ä–≥–∞–∞—à",
    "Next week" : "–î–∞—Ä–∞–∞ 7 —Ö–æ–Ω–æ–≥",
    "Next year" : "Дараагийн жил",
    "Next month" : "–î–∞—Ä–∞–∞ —Å–∞—Ä",
    "Create new event" : "Шинэ үйл явдал үүсгэх",
    "Event" : "Үйл явдал",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "Year" : "Жил",
    "List" : "–ñ–∞–≥—Å–∞–∞–ª—Ç",
    "Appointment link was copied to clipboard" : "Уулзалтын холбоос түр санах ойд хуулагдлаа",
    "Appointment link could not be copied to clipboard" : "Уулзалтын холбоосыг түр санах ойд хуулж чадсангүй",
    "Preview" : "—à–∞–ª–≥–∞—Ö",
    "Copy link" : "–•–æ–ª–±–æ–æ—Å —Ö—É—É–ª–∞—Ö",
    "Duplicate" : "Хуулбарлах",
    "Edit" : "–∑–∞—Å–≤–∞—Ä–ª–∞—Ö",
    "Delete" : "Устгах",
    "Appointment schedules" : "Уулзалтын хуваарь",
    "Create new" : "Шинээр үүсгэх",
    "Disable calendar \"{calendar}\"" : "–ö–∞–¥–µ–Ω–¥–∞—Ä—å –ò–¥—ç–≤—Ö–∏–≥“Ø–π –±–æ–ª–≥–æ—Ö \"{calendar}\"",
    "Disable untitled calendar" : "Нэргүй календарыг идэвхгүй болгох",
    "Enable calendar \"{calendar}\"" : "\"{calendar}\" календарыг идэвхжүүлэх",
    "Enable untitled calendar" : "Нэргүй календарыг идэвхжүүлэх",
    "An error occurred, unable to change visibility of the calendar." : "Алдаа гарлаа, календарын харагдах байдлыг өөрчилж чадсангүй.",
    "Calendar link copied to clipboard." : "Календарын холбоос санах ойд хуулагдлаа.",
    "Calendar link could not be copied to clipboard." : "Календарын холбоосыг санах ойд хуулж чадсангүй.",
    "Untitled calendar" : "Гарчиггүй календар",
    "Shared with you by" : "–¢–∞–Ω—å–¥ —Ö—É–≤–∞–∞–ª—Ü—Å–∞–Ω",
    "Copy public link" : "Нийтийн холбоос хуулах",
    "Edit and share calendar" : " –ö–∞–ª–µ–Ω–¥–∞—Ä—å –∑–∞—Å–≤–∞—Ä–ª–∞—Ö –±–æ–ª–æ–Ω —Ö—É–≤–∞–∞–ª—Ü–∞—Ö",
    "Edit calendar" : "–ö–∞–ª–µ–Ω–¥–∞—Ä –∑–∞—Å–≤–∞—Ä–ª–∞—Ö",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown} секундын дараа календарийн хуваалцалт цуцлагдана","{countdown} секундын дараа календарийн хуваалцалт цуцлагдана"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown} секундын дараа календар устгагдана","{countdown} секундын дараа календар устгагдана"],
    "An error occurred, unable to create the calendar." : "Алдаа гарлаа, календар үүсгэж чадсангүй.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Зөв линк оруулна уу (http://, https://, webcal://, эсвэл webcals://-ээр эхэлсэн)",
    "Add new" : "–®–∏–Ω—ç—ç—Ä –Ω—ç–º—ç—Ö",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Name for new calendar" : "Шинэ календарын нэр",
    "New calendar with task list" : "Даалгаврын жагсаалттай шинэ календар",
    "New subscription from link (read-only)" : "Холбоосоос шинэ захиалга (зөвхөн унших)",
    "Add public holiday calendar" : "Нийтийн баярын календар нэмэх",
    "Add custom public calendar" : "Тусгай нийтийн календар нэмэх",
    "Copy subscription link" : "Захиалгын холбоос хуулах",
    "Copied link" : "Холбоос хуулагдлаа",
    "Could not copy link" : "Холбоосыг хуулж чадсангүй",
    "Export" : "–≠–∫—Å–ø–æ—Ä—Ç",
    "Untitled item" : "Гарчиггүй зүйл",
    "Unknown calendar" : "Тодорхойгүй календар",
    "Could not load deleted calendars and objects" : "Устгасан календар болон объектуудыг ачаалж чадсангүй",
    "Could not delete calendar or event" : "Календар эсвэл үйл явдлыг устгаж чадсангүй",
    "Could not restore calendar or event" : "Календар эсвэл үйл явдлыг сэргээж чадсангүй",
    "Do you really want to empty the trash bin?" : "Та хогийн савыг хоослохыг хүсэж байна уу?",
    "Empty trash bin" : "Хогийн савыг хоослох",
    "Trash bin" : "Хогийн сав",
    "Loading deleted items." : "Устгасан зүйлсийг ачаалж байна.",
    "You do not have any deleted items." : "Танд устгасан зүйлс байхгүй.",
    "Name" : "–ù—ç—Ä",
    "Deleted" : "–£—Å—Ç–≥–∞–≥–¥—Å–∞–Ω",
    "Restore" : "–°—ç—Ä–≥—ç—ç—Ö",
    "Delete permanently" : "–±“Ø—Ä –º”©—Å”©–Ω —É—Å—Ç–≥–∞—Ö",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Хогийн сав дахь зүйлс {numDays} өдрийн дараа устгагдана","Хогийн сав дахь зүйлс {numDays} өдрийн дараа устгагдана"],
    "Could not update calendar order." : "Календарын дарааллыг шинэчилж чадсангүй.",
    "Shared calendars" : "Хуваалцсан календарууд",
    "Deck" : "–ê–∂–ª—ã–Ω —Ç–∞–ª–±–∞—Ä",
    "Tasks" : "–î–∞–∞–ª–≥–∞–≤–∞—Ä",
    "Internal link" : "Дотоод холбоос",
    "A private link that can be used with external clients" : "Гадаад клиентүүдтэй ашиглаж болох хувийн холбоос",
    "Copy internal link" : "Дотоод холбоос хуулах",
    "An error occurred, unable to publish calendar." : "Алдаа гарлаа, календарыг нийтлэж чадсангүй.",
    "An error occurred, unable to send email." : "Алдаа гарлаа, имэйл илгээж чадсангүй.",
    "Embed code copied to clipboard." : "Суулгах код түр санах ойд хуулагдлаа.",
    "Embed code could not be copied to clipboard." : "Суулгах кодыг түр санах ойд хуулж чадсангүй.",
    "Unpublishing calendar failed" : "Календарын нийтлэлтийг цуцлахад алдаа гарлаа",
    "Share link" : "Холбоос хуваалцах",
    "Send link to calendar via email" : "Календарын холбоосыг имэйлээр илгээх",
    "Enter one address" : "Нэг хаяг оруулна уу",
    "Copy embedding code" : "Суулгах кодыг хуулах",
    "Copied code" : "Код хуулагдлаа",
    "Could not copy code" : "Кодыг хуулж чадсангүй",
    "Delete share link" : "Хуваалцах холбоос устгах",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Баг)",
    "An error occurred while unsharing the calendar." : "Календарын хуваалцалтыг цуцлахад алдаа гарлаа.",
    "An error occurred, unable to change the permission of the share." : "Алдаа гарлаа, хуваалцалтын зөвшөөрлийг өөрчилж чадсангүй.",
    "can edit and see confidential events" : "засах болон нууц үйл явдлуудыг харах боломжтой",
    "Unshare with {displayName}" : "{displayName}-тай хуваалцахыг болих",
    "Share with users or groups" : "–ë—É—Å–∞–¥ —Ö—ç—Ä—ç–≥–ª—ç–≥—á, –±“Ø–ª—ç–≥—Ç —Ö—É–≤–∞–∞–ª—Ü–∞—Ö",
    "No users or groups" : "Хэрэглэгч эсвэл бүлэг байхгүй",
    "events" : "үйл явдлууд",
    "tasks" : "даалгаврууд",
    "journal entries" : "өдрийн тэмдэглэлүүд",
    "This calendar supports neither events, tasks nor journal entries." : "Энэ календарь нь үйл явдал, даалгавар, өдрийн тэмдэглэлийн аль нь ч дэмждэггүй.",
    "_This calendar supports only {types}._::_This calendar supports {types}._" : ["Энэ календар зөвхөн {types}-г дэмждэг.","Энэ календар {types}-г дэмждэг."],
    "None" : "—é—É —á “Ø–≥“Ø–π",
    "Failed to save calendar name and color" : "Календарын нэр болон өнгийг хадгалж чадсангүй",
    "Calendar name" : "Календарын нэр",
    "Never show me as busy (set this calendar to transparent)" : "Намайг хэзээ ч завгүй гэж бүү харуул (энэ календарыг ил тод болгох)",
    "Share calendar" : "Календар хуваалцах",
    "Unshare from me" : "Миний хуваалцалтыг цуцлах",
    "Save" : "–•–∞–¥–≥–∞–ª–∞—Ö",
    "No title" : "Гарчиг байхгүй",
    "Are you sure you want to delete \"{title}\"?" : "Та \"{title}\"-г устгахыг хүсэж байна уу?",
    "Cancel" : "Цуцлах",
    "Deleting proposal \"{title}\"" : "\"{title}\" саналыг устгаж байна",
    "Successfully deleted proposal" : "Санал амжилттай устгагдлаа",
    "Failed to delete proposal" : "Саналыг устгаж чадсангүй",
    "Failed to retrieve proposals" : "Саналуудыг авч чадсангүй",
    "Meeting proposals" : "Уулзалтын саналууд",
    "A configured email address is required to use meeting proposals" : "Уулзалтын саналуудыг ашиглахын тулд тохируулсан имэйл хаяг шаардлагатай",
    "No active meeting proposals" : "Идэвхтэй уулзалтын санал байхгүй",
    "View" : "Харах",
    "Busy" : "–ó–∞–≤–≥“Ø–π",
    "Free" : "Чөлөөт",
    "Tentative" : "–£—Ä—å–¥—á–∏–ª—Å–∞–Ω —Ç–æ–≤",
    "Invited" : "Уригдах",
    "Icons" : "тэмдэгт",
    "Attendees" : "Оролцогчид",
    "Import destination selection" : "Импортын очих газрын сонголт",
    "Import calendars" : "Календар импортлох",
    "Filename" : "–§–∞–π–ª—ã–Ω –Ω—ç—Ä",
    "Calendar to import into" : "Импортлох календар",
    "_Import calendar_::_Import calendars_" : ["Календар импортлох","Календарууд импортлох"],
    "Select the default location for attachments" : "Хавсралтуудын өгөгдмөл байршлыг сонгоно уу",
    "Pick" : "Сонгох",
    "Invalid location selected" : "Буруу байршил сонгогдсон",
    "Attachments folder successfully saved." : "Хавсралтуудын хавтас амжилттай хадгалагдлаа.",
    "Error on saving attachments folder." : "Хавсралтуудын хавтсыг хадгалахад алдаа гарлаа.",
    "Attachments folder" : "Хавсралтын хавтас",
    "Revoke" : "Цуцлах",
    "Viewer" : "Үзэгч",
    "Editor" : "Засварлагч",
    "{filename} could not be parsed" : "{filename}-г задалж чадсангүй",
    "No valid files found, aborting import" : "Зөв файл олдсонгүй, импортыг зогсоож байна",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n үйл явдал амжилттай импортлогдлоо","%n үйл явдал амжилттай импортлогдлоо"],
    "Import partially failed. Imported {accepted} out of {total}." : "Импорт хэсэгчлэн амжилтгүй. {total}-ийн {accepted} импортлогдлоо.",
    "Automatic" : "Автомат",
    "Automatic ({timezone})" : "Автомат ({timezone})",
    "New setting was not saved successfully." : "Шинэ тохиргоог амжилттай хадгалж чадсангүй.",
    "Timezone" : "Цагийн бүс",
    "Navigation" : "Навигаци",
    "Previous period" : "Өмнөх үе",
    "Next period" : "Дараагийн үе",
    "Views" : "Харагдацууд",
    "Day view" : "Өдрийн харагдац",
    "Week view" : "Долоо хоногийн харагдац",
    "Month view" : "Сарын харагдац",
    "Year view" : "Жилийн харагдац",
    "List view" : "Жагсаалт харагдац",
    "Actions" : "“Æ–π–ª –∞–∂–∏–ª–ª–∞–≥–∞–∞",
    "Create event" : "Үйл явдал үүсгэх",
    "Show shortcuts" : "Товчлолуудыг харуулах",
    "Close editor" : "Засварлагчийг хаах",
    "Save edited event" : "Засварласан үйл явдлыг хадгалах",
    "Delete edited event" : "Засварласан үйл явдлыг устгах",
    "Duplicate event" : "Үйл явдлыг хуулбарлах",
    "or" : "эсвэл",
    "Calendar settings" : "Календарын тохиргоо",
    "No reminder" : "Сануулга байхгүй",
    "At event start" : "Үйл явдал эхлэхэд",
    "Failed to save default calendar" : "Өгөгдмөл календарыг хадгалж чадсангүй",
    "General" : "–µ—Ä”©–Ω—Ö–∏–π",
    "Default calendar for incoming invitations" : "Ирж буй урилгын өгөгдмөл календар",
    "Availability settings" : "Боломжийн тохиргоо",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Бусад програм болон төхөөрөмжөөс Nextcloud календарт хандах",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "iOS болон macOS-д зориулсан серверийн хаяг",
    "Appearance" : "Гадаад төрх",
    "Birthday calendar" : "Төрсөн өдрийн календар",
    "Tasks in calendar" : "Календарын даалгаврууд",
    "Weekends" : "Амралтын өдрүүд",
    "Week numbers" : "Долоо хоногийн дугаар",
    "Limit number of events shown in Month view" : "Сарын харагдацад харуулах үйл явдлын тоог хязгаарлах",
    "Density in Day and Week View" : "Өдөр болон Долоо хоногийн харагдацын нягтрал",
    "Editing" : "Засварлаж байна",
    "Simple event editor" : "Энгийн үйл явдлын засварлагч",
    "\"More details\" opens the detailed editor" : "\"Дэлгэрэнгүй\" дэлгэрэнгүй засварлагчийг нээнэ",
    "Files" : "–§–∞–π–ª—É—É–¥",
    "Appointment schedule successfully created" : "Уулзалтын хуваарь амжилттай үүсгэгдлээ",
    "Appointment schedule successfully updated" : "Уулзалтын хуваарь амжилттай шинэчлэгдлээ",
    "0 minutes" : "0 минут",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минут","{duration} минут"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} цаг","{duration} цаг"],
    "_{duration} day_::_{duration} days_" : ["{duration} өдөр","{duration} өдөр"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} долоо хоног","{duration} долоо хоног"],
    "_{duration} month_::_{duration} months_" : ["{duration} сар","{duration} сар"],
    "_{duration} year_::_{duration} years_" : ["{duration} жил","{duration} жил"],
    "To configure appointments, add your email address in personal settings." : "Цаг захиалга тохируулахын тулд хувийн тохиргоонд имэйл хаягаа нэмнэ үү.",
    "Appointment schedule saved" : "Уулзалтын хуваарь хадгалагдлаа",
    "Create appointment schedule" : "Уулзалтын хуваарь үүсгэх",
    "Edit appointment schedule" : "Уулзалтын хуваарь засах",
    "Update" : "Шинэчлэх",
    "(copy)" : "(хуулбар)",
    "Appointment name" : "Уулзалтын нэр",
    "Location" : "–ë–∞–π—Ä—à–∏–ª",
    "Create a Talk room" : "Talk өрөө үүсгэх",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Захиалсан цаг товлолт бүрт өвөрмөц линк үүсгэгдэж, баталгаажуулах имэйлээр илгээгдэнэ",
    "Description" : "–¢–æ–¥–æ—Ä—Ö–æ–π–ª–æ–ª—Ç",
    "Increments" : "Нэмэгдэл",
    "Visibility" : "Харагдац",
    "to" : "–î—É—É—Å–∞—Ö –Ω—å",
    "Delete slot" : "Слот устгах",
    "No times set" : "Цаг тогтоогоогүй",
    "Add" : "–Ω—ç–º—ç—Ö",
    "Monday" : "–¥–∞–≤–∞–∞",
    "Tuesday" : "–º—è–≥–º–∞—Ä",
    "Wednesday" : "–ª—Ö–∞–≥–≤–∞",
    "Thursday" : "–ø“Ø—Ä—ç–≤",
    "Friday" : "–±–∞–∞—Å–∞–Ω",
    "Saturday" : "–±—è–º–±–∞",
    "Sunday" : "–Ω—è–º –≥–∞—Ä–∏–≥",
    "Weekdays" : "Ажлын өдрүүд",
    "Planning restrictions" : "Төлөвлөлтийн хязгаарлалт",
    "Max slots per day" : "Өдөрт хамгийн их слот",
    "Limit how far in the future appointments can be booked" : "Ирээдүйд хэр хол уулзалт захиалах боломжтойг хязгаарлах",
    "It seems a rate limit has been reached. Please try again later." : "Хязгаарт хүрсэн бололтой. Дараа дахин оролдоно уу.",
    "Please confirm your reservation" : "Захиалгаа баталгаажуулна уу",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Бид танд дэлгэрэнгүй мэдээлэл бүхий имэйл илгээлээ. Имэйл доторх линкээр цаг товлолтоо баталгаажуулна уу. Та энэ хуудсыг одоо хааж болно.",
    "Your name" : "Таны нэр",
    "Your email address" : "Таны имэйл хаяг",
    "Please share anything that will help prepare for our meeting" : "Уулзалтад бэлтгэхэд туслах мэдээллийг хуваалцана уу",
    "Could not book the appointment. Please try again later or contact the organizer." : "Цаг товлолтыг захиалж чадсангүй. Дараа дахин оролдоно уу эсвэл зохион байгуулагчтай холбогдоно уу.",
    "Back" : "–ë—É—Ü–∞—Ö",
    "Book appointment" : "Уулзалт захиалах",
    "Error fetching Talk conversations." : "Talk яриа авахад алдаа гарлаа.",
    "Conversation does not have a valid URL." : "Яриа хүчинтэй URL-гүй байна.",
    "Successfully added Talk conversation link to location." : "Talk яриа холбоосыг байршилд амжилттай нэмлээ.",
    "Successfully added Talk conversation link to description." : "Talk яриа холбоосыг тайлбарт амжилттай нэмлээ.",
    "Failed to apply Talk room." : "Talk өрөө хэрэглэж чадсангүй.",
    "Talk conversation for event" : "Үйл явдлын Talk яриа",
    "Error creating Talk conversation" : "Talk яриа үүсгэхэд алдаа гарлаа",
    "Select a Talk Room" : "Talk өрөө сонгоно уу",
    "No Talk room available" : "Боломжтой Talk өрөө байхгүй",
    "Select existing conversation" : "Одоо байгаа яриа сонгох",
    "Select conversation" : "Яриа сонгох",
    "Or create a new conversation" : "Эсвэл шинэ яриа үүсгэх",
    "Create public conversation" : "Нийтийн яриа үүсгэх",
    "Create private conversation" : "Хувийн яриа үүсгэх",
    "on" : "дээр",
    "at" : "-д",
    "Amount" : "Хэмжээ",
    "before at" : "өмнө",
    "Notification" : "–ú—ç–¥—ç–≥–¥—ç–ª",
    "Email" : "Цахим шуудан",
    "Audio notification" : "Дуут мэдэгдэл",
    "Other notification" : "Бусад мэдэгдэл",
    "Relative to event" : "Үйл явдалтай холбоотой",
    "On date" : "Тухайн өдөр",
    "Edit time" : "Цаг засах",
    "Save time" : "Цаг хадгалах",
    "Remove reminder" : "Сануулга устгах",
    "Add reminder" : "Сануулга нэмэх",
    "seconds" : "—Å–µ–∫—É–Ω–¥",
    "minutes" : "минут",
    "hours" : "—Ö—É–≥–∞—Ü–∞–∞",
    "days" : "”©–¥—Ä“Ø“Ø–¥",
    "weeks" : "долоо хоног",
    "Choose a file to add as attachment" : "Хавсралт болгох файл сонгоно уу",
    "Choose a file to share as a link" : "Холбоосоор хуваалцах файл сонгоно уу",
    "Attachment {name} already exist!" : "{name} хавсралт аль хэдийн байна!",
    "Could not upload attachment(s)" : "Хавсралт(ууд)ыг байршуулж чадсангүй",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Та {link} руу шилжих гэж байна. Үргэлжлүүлэхийг хүсэж байна уу?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Та {host} руу шилжих гэж байна. Үргэлжлүүлэх үү? Холбоос: {link}",
    "Proceed" : "Үргэлжлүүлэх",
    "No attachments" : "Хавсралт байхгүй",
    "Add from Files" : "Файлуудаас нэмэх",
    "Upload from device" : "Төхөөрөмжөөс байршуулах",
    "Delete file" : "–§–∞–π–ª —É—Å—Ç–≥–∞—Ö",
    "Confirmation" : "Баталгаажуулалт",
    "_{count} attachment_::_{count} attachments_" : ["{count} хавсралт","{count} хавсралт"],
    "Suggested" : "Санал болгосон",
    "Available" : "–ë–æ–ª–æ–º–∂—Ç–æ–π",
    "Invitation accepted" : "Урилга хүлээн зөвшөөрөгдлөө",
    "Accepted {organizerName}'s invitation" : "{organizerName}-ийн урилгыг хүлээн зөвшөөрсөн",
    "Participation marked as tentative" : "Оролцоо түр гэж тэмдэглэгдсэн",
    "Invitation is delegated" : "Урилга шилжүүлэгдсэн",
    "Not available" : "Боломжгүй",
    "Invitation declined" : "Урилга татгалзагдсан",
    "Declined {organizerName}'s invitation" : "{organizerName}-ийн урилгыг татгалзсан",
    "Availability will be checked" : "Боломжтой байдлыг шалгана",
    "Invitation will be sent" : "Урилга илгээгдэнэ",
    "Failed to check availability" : "Боломжтой байдлыг шалгаж чадсангүй",
    "Failed to deliver invitation" : "Урилга хүргэж чадсангүй",
    "Awaiting response" : "Хариу хүлээж байна",
    "Checking availability" : "Боломжтой байдлыг шалгаж байна",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName}-ийн урилгад хариу өгөөгүй байна",
    "Duration" : "Хугацаа",
    "15 minutes" : "15 минут",
    "30 minutes" : "30 минут",
    "1 hour" : "1 —Ü–∞–≥",
    "Custom" : "–î—É—Ä—ã–Ω",
    "Days" : "Хоног",
    "Hours" : "Цаг",
    "Minutes" : "Минут",
    "Suggested times" : "Санал болгосон цагууд",
    "chairperson" : "дарга",
    "required participant" : "шаардлагатай оролцогч",
    "non-participant" : "оролцогч бус",
    "optional participant" : "сонголттой оролцогч",
    "{organizer} (organizer)" : "{organizer} (зохион байгуулагч)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Сонгосон слот",
    "Availability of attendees, resources and rooms" : "Оролцогчид, нөөц болон өрөөнүүдийн боломжтой байдал",
    "Suggestion accepted" : "Санал хүлээн зөвшөөрөгдлөө",
    "Previous date" : "Өмнөх огноо",
    "Next date" : "Дараагийн огноо",
    "Legend" : "Тайлбар",
    "Out of office" : "–û—Ñ—Ñ–∏—Å–æ–æ—Å –≥–∞–¥—É—É—Ä",
    "Attendees:" : "Оролцогчид:",
    "local time" : "орон нутгийн цаг",
    "Done" : "Дууслаа",
    "Search room" : "Өрөө хайх",
    "Room name" : "Өрөөний нэр",
    "Check room availability" : "Өрөөний боломжтой байдлыг шалгах",
    "Busy (tentative)" : "Завгүй (түр)",
    "Unknown" : "“Æ–ª —Ç–∞–Ω–∏–≥–¥–∞—Ö –∑“Ø–π–ª",
    "Find a time" : "Цаг олох",
    "The invitation has been accepted successfully." : "Урилга амжилттай хүлээн зөвшөөрөгдлөө.",
    "Failed to accept the invitation." : "Урилгыг хүлээн зөвшөөрч чадсангүй.",
    "The invitation has been declined successfully." : "Урилга амжилттай татгалзагдлаа.",
    "Failed to decline the invitation." : "Урилгыг татгалзаж чадсангүй.",
    "Your participation has been marked as tentative." : "Таны оролцоо түр гэж тэмдэглэгдлээ.",
    "Failed to set the participation status to tentative." : "Оролцооны төлөвийг түр болгож чадсангүй.",
    "Accept" : "–•“Ø–ª—ç—ç–Ω –∑”©–≤—à”©”©—Ä”©—Ö",
    "Decline" : "–ó”©–≤—à”©”©—Ä”©—Ö–≥“Ø–π",
    "Copied to clipboard" : "Түр санах ойд хуулагдлаа",
    "Failed to copy" : "Хуулж чадсангүй",
    "Copy name and email address" : "Нэр болон имэйл хаяг хуулах",
    "No attendees yet" : "Одоохондоо оролцогч байхгүй",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} баталгаажсан, {waitingCount} хариу хүлээж байна",
    "Please add at least one attendee to use the \"Find a time\" feature." : "\"Цаг олох\" функцыг ашиглахын тулд дор хаяж нэг оролцогч нэмнэ үү.",
    "Status" : "—Ç”©–ª”©–≤",
    "Role" : "Үүрэг",
    "Chairperson" : "Дарга",
    "Required participant" : "Шаардлагатай оролцогч",
    "Optional participant" : "Сонголттой оролцогч",
    "Non-participant" : "Оролцогч бус",
    "_%n more attendee_::_%n more attendees_" : ["%n бусад оролцогч","%n бусад оролцогч"],
    "Remove group" : "Бүлэг хасах",
    "Remove attendee" : "Оролцогч хасах",
    "Request reply" : "Хариу хүсэх",
    "_%n member_::_%n members_" : ["%n гишүүн","%n гишүүн"],
    "Search for emails, users, contacts, contact groups or teams" : "Имэйл, хэрэглэгч, харилцагч, харилцагчийн бүлэг эсвэл баг хайх",
    "No match found" : "Тохирол олдсонгүй",
    "Note that members of circles get invited but are not synced yet." : "Дугуйн гишүүд урилга авах боловч одоохондоо синк хийгдээгүй байгааг анхаарна уу.",
    "Note that members of contact groups get invited but are not synced yet." : "Харилцагчийн бүлгийн гишүүд урилга авах боловч хараахан синхрончлогдоогүй байгааг анхаарна уу.",
    "(organizer)" : "(зохион байгуулагч)",
    "Make {label} the organizer" : "{label}-г зохион байгуулагч болгох",
    "Make {label} the organizer and attend" : "{label}-г зохион байгуулагч болгож, оролцох",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Урилга илгээж, хариултуудыг удирдахын тулд [linkopen]хувийн тохиргоонд имэйл хаягаа нэмнэ үү[linkclose].",
    "Remove color" : "Өнгө хасах",
    "Title" : "Гарчиг",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Давтагддаг цувралын нэг хэсэг болох үйл явдлуудын бүтэн өдрийн тохиргоог өөрчлөх боломжгүй.",
    "From" : "Эхлэх",
    "To" : "Хүртэл",
    "Your Time" : "Таны цаг",
    "Repeat" : "–î–∞–≤—Ç–∞—Ö",
    "Repeat event" : "Үйл явдлыг давтах",
    "never" : "хэзээ ч үгүй",
    "on date" : "огноо дээр",
    "after" : "дараа",
    "End repeat" : "Давталт дуусгах",
    "Occurrences" : "Давталтууд",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Энэ үйл явдал нь давталтын олонлогийн давталтын үл хамаарах тохиолдол юм. Та үүнд давталтын дүрэм нэмэх боломжгүй.",
    "first" : "эхний",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Давталтын дүрмийн өөрчлөлтүүд зөвхөн энэ болон бүх ирээдүйн тохиолдлуудад хамаарна.",
    "Repeat every" : "Давтах бүр",
    "By day of the month" : "Сарын өдрөөр",
    "On the" : "-д",
    "_day_::_days_" : ["өдөр","өдөр"],
    "_week_::_weeks_" : ["долоо хоног","долоо хоног"],
    "_month_::_months_" : ["сар","сар"],
    "_year_::_years_" : ["жил","жил"],
    "On specific day" : "Тодорхой өдөр",
    "weekday" : "ажлын өдөр",
    "weekend day" : "амралтын өдөр",
    "Does not repeat" : "Давтагдахгүй",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Энэ үйл явдлын давталтын тодорхойлолтыг Nextcloud бүрэн дэмжихгүй байна. Хэрэв та давталтын сонголтуудыг засварлавал зарим давталтууд алдагдаж болзошгүй.",
    "No rooms or resources yet" : "Одоохондоо өрөө эсвэл нөөц байхгүй",
    "Resources" : "Нөөцүүд",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} суудал","{seatingCapacity} суудал"],
    "Add resource" : "Нөөц нэмэх",
    "Has a projector" : "Проектортой",
    "Has a whiteboard" : "Самбартай",
    "Wheelchair accessible" : "Тэргэнцэртэй хүнд тохирсон",
    "Remove resource" : "Нөөц хасах",
    "Search for resources or rooms" : "Нөөц эсвэл өрөө хайх",
    "available" : "боломжтой",
    "unavailable" : "боломжгүй",
    "Show all rooms" : "Бүх өрөөнүүдийг харуулах",
    "Projector" : "Проектор",
    "Whiteboard" : "Самбар",
    "Room type" : "Өрөөний төрөл",
    "Any" : "Аль ч",
    "Minimum seating capacity" : "Хамгийн бага суудлын багтаамж",
    "More details" : "Дэлгэрэнгүй",
    "Update this and all future" : "Энэ болон бүх ирээдүйг шинэчлэх",
    "Update this occurrence" : "Энэ тохиолдлыг шинэчлэх",
    "Public calendar does not exist" : "Нийтийн календар байхгүй",
    "Maybe the share was deleted or has expired?" : "Хуваалцалт устгагдсан эсвэл хугацаа дууссан уу?",
    "Remove date" : "Огноо хасах",
    "Attendance required" : "Оролцоо шаардлагатай",
    "Attendance optional" : "Оролцоо сонголттой",
    "Remove participant" : "Оролцогчийг хасах",
    "Yes" : "Тийм",
    "No" : "Үгүй",
    "Maybe" : "Магадгүй",
    "Select your meeting availability" : "Уулзалтын боломжоо сонгоно уу",
    "Create a meeting for this date and time" : "Энэ огноо, цагт уулзалт үүсгэх",
    "Create" : "“Ø“Ø—Å–≥—ç—Ö",
    "No participants or dates available" : "Оролцогч эсвэл боломжтой огноо байхгүй",
    "Type to search time zone" : "Цагийн бүс хайхын тулд бичнэ үү",
    "Global" : "–ù–∏–π—Ç–∏–π–Ω",
    "Holidays in {region}" : "{region}-ийн баярууд",
    "An error occurred, unable to read public calendars." : "Алдаа гарлаа, нийтийн календаруудыг уншиж чадсангүй.",
    "An error occurred, unable to subscribe to calendar." : "Алдаа гарлаа, календарт захиалга хийж чадсангүй.",
    "Public calendar subscriptions selection" : "Нийтийн календарийн захиалгын сонголт",
    "Public holiday calendars" : "Нийтийн баярын календарууд",
    "Public calendars" : "Нийтийн календарууд",
    "No valid public calendars configured" : "Зөв нийтийн календар тохируулагдаагүй",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Нийтийн баярын календарийг Thunderbird хангаж байна. Календарийн өгөгдлийг {website}-с татаж авна",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Эдгээр нийтийн календарийг серверийн администратор санал болгосон. Календарийн өгөгдлийг тухайн вэбсайтаас татаж авна.",
    "By {authors}" : "{authors}-ийн",
    "Subscribed" : "Бүртгүүлсэн",
    "Subscribe" : "–ó–∞—Ö–∏–∞–ª–≥–∞",
    "Could not fetch slots" : "Слотуудыг авч чадсангүй",
    "Select a date" : "Огноо сонгох",
    "Select slot" : "Слот сонгох",
    "No slots available" : "Боломжтой слот байхгүй",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Баярлалаа. Таны {startDate}-аас {endDate} хүртэлх захиалга баталгаажлаа.",
    "Book another appointment:" : "Өөр уулзалт захиалах:",
    "See all available slots" : "Бүх боломжтой слотуудыг харах",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{startDate}-с {endDate} хүртэлх таны цаг товлолтын цонх ашиглах боломжгүй болсон.",
    "Please book a different slot:" : "Өөр слот захиална уу:",
    "Book an appointment with {name}" : "{name}-тай уулзалт захиалах",
    "No public appointments found for {name}" : "{name}-д нийтийн уулзалт олдсонгүй",
    "Personal" : "–•—É–≤–∏–π–Ω",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автомат цагийн бүсийн илрүүлэлт таны цагийн бүсийг UTC гэж тодорхойлсон.\nЭнэ нь таны вэб хөтчийн аюулгүй байдлын арга хэмжээний үр дүн байх магадлалтай.\nКалендарийн тохиргооноос цагийн бүсээ гараар тохируулна уу.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Таны тохируулсан цагийн бүс ({timezoneId}) олдсонгүй. UTC руу буцаж байна.\nТохиргооноос цагийн бүсээ өөрчилж, энэ асуудлыг мэдэгдэнэ үү.",
    "Show unscheduled tasks" : "Товлоогүй даалгавруудыг харуулах",
    "Unscheduled tasks" : "Товлоогүй даалгаврууд",
    "Availability of {displayName}" : "{displayName}-ийн боломжтой байдал",
    "Discard changes" : "Өөрчлөлтүүдийг хаях",
    "Edit event" : "“Æ–π–ª —è–≤–¥–ª—ã–≥ –∑–∞—Å–≤–∞—Ä–ª–∞—Ö",
    "Event does not exist" : "Үйл явдал байхгүй",
    "Delete this occurrence" : "Энэ тохиолдлыг устгах",
    "Delete this and all future" : "Энэ болон бүх ирээдүйг устгах",
    "All day" : "Бүтэн өдөр",
    "Modifications wont get propagated to the organizer and other attendees" : "Өөрчлөлтүүд зохион байгуулагч болон бусад оролцогчдод дамжигдахгүй",
    "Add Talk conversation" : "Talk яриа нэмэх",
    "Managing shared access" : "Хуваалцсан хандалтыг удирдах",
    "Deny access" : "Хандалтаас татгалзах",
    "Invite" : "Урих",
    "Discard changes?" : "Өөрчлөлтийг цуцлах уу?",
    "Are you sure you want to discard the changes made to this event?" : "Та энэ үйл явдалд хийсэн өөрчлөлтийг цуцлахыг хүсэж байна уу?",
    "_User requires access to your file_::_Users require access to your file_" : ["Хэрэглэгч таны файлд хандах эрх шаардлагатай","Хэрэглэгчид таны файлд хандах эрх шаардлагатай"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Хавсралтад хуваалцсан хандалт шаардлагатай","Хуваалцсан хандалт шаардлагатай хавсралтууд"],
    "Untitled event" : "Гарчиггүй үйл явдал",
    "Close" : "Хаах",
    "Modifications will not get propagated to the organizer and other attendees" : "Өөрчлөлтүүд зохион байгуулагч болон бусад оролцогчдод хүрэхгүй",
    "This event was cancelled" : "Энэ үйл явдал цуцлагдлаа",
    "Meeting proposals overview" : "Уулзалтын саналуудын тойм",
    "Edit meeting proposal" : "Уулзалтын санал засах",
    "Create meeting proposal" : "Уулзалтын санал үүсгэх",
    "Update meeting proposal" : "Уулзалтын санал шинэчлэх",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "\"{date}\"-д уулзалт үүсгэх үү? Бүх оролцогчтой календарийн үйл явдал үүсгэнэ.",
    "Saving proposal \"{title}\"" : "\"{title}\" саналыг хадгалж байна",
    "Successfully saved proposal" : "Санал амжилттай хадгалагдлаа",
    "Failed to save proposal" : "Саналыг хадгалж чадсангүй",
    "Please enter a valid duration in minutes." : "Минутаар зөв үргэлжлэх хугацаа оруулна уу.",
    "Failed to fetch proposals" : "Саналуудыг авч чадсангүй",
    "Creating meeting for {date}" : "{date}-д уулзалт үүсгэж байна",
    "Successfully created meeting for {date}" : "{date}-д уулзалт амжилттай үүсгэгдлээ",
    "Failed to create a meeting for {date}" : "{date}-д уулзалт үүсгэж чадсангүй",
    "Failed to fetch free/busy data" : "Чөлөөт/завгүй өгөгдлийг авч чадсангүй",
    "Selected" : "Сонгогдсон",
    "No Description" : "Тайлбар байхгүй",
    "No Location" : "Байршил байхгүй",
    "Edit this meeting proposal" : "Энэ уулзалтын саналыг засах",
    "Delete this meeting proposal" : "Энэ уулзалтын саналыг устгах",
    "Participants" : "Оролцогчид",
    "Selected times" : "Сонгосон цагууд",
    "Previous span" : "Өмнөх хүрээ",
    "Next span" : "Дараагийн хүрээ",
    "Less days" : "Бага өдөр",
    "More days" : "Олон өдөр",
    "Loading meeting proposal" : "Уулзалтын санал ачаалж байна",
    "No meeting proposal found" : "Уулзалтын санал олдсонгүй",
    "Please wait while we load the meeting proposal." : "Уулзалтын санал ачаалж байхад түр хүлээнэ үү.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Таны дагасан линк эвдэрсэн эсвэл уулзалтын санал байхгүй болсон байж болзошгүй.",
    "Thank you for your response!" : "Хариултад баярлалаа!",
    "Your vote has been recorded. Thank you for participating!" : "Таны санал бүртгэгдлээ. Оролцсонд баярлалаа!",
    "Unknown User" : "Тодорхойгүй хэрэглэгч",
    "No Title" : "Гарчиг байхгүй",
    "No Duration" : "Үргэлжлэх хугацаа байхгүй",
    "Select a different time zone" : "Өөр цагийн бүс сонгоно уу",
    "Submit" : "–º—ç–¥—ç–≥–¥—ç—Ö",
    "Subscribe to {name}" : "{name}-д захиалах",
    "Export {name}" : "{name} экспортлох",
    "Show availability" : "Боломжтой байдлыг харуулах",
    "Anniversary" : "Ойн өдөр",
    "Appointment" : "Уулзалт",
    "Business" : "Бизнес",
    "Education" : "Боловсрол",
    "Holiday" : "Баяр",
    "Meeting" : "Уулзалт",
    "Miscellaneous" : "Бусад",
    "Non-working hours" : "Ажлын бус цаг",
    "Not in office" : "Оффис дээр байхгүй",
    "Phone call" : "Утасны дуудлага",
    "Sick day" : "Өвчтэй өдөр",
    "Special occasion" : "Онцгой үйл явдал",
    "Travel" : "Аялал",
    "Vacation" : "Амралт",
    "Midnight on the day the event starts" : "Үйл явдал эхлэх өдрийн шөнө дунд",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Үйл явдлаас %n өдрийн өмнө {formattedHourMinute}-д","Үйл явдлаас %n өдрийн өмнө {formattedHourMinute}-д"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Үйл явдлаас %n долоо хоногийн өмнө {formattedHourMinute}-д","Үйл явдлаас %n долоо хоногийн өмнө {formattedHourMinute}-д"],
    "on the day of the event at {formattedHourMinute}" : "үйл явдлын өдөр {formattedHourMinute}-д",
    "at the event's start" : "үйл явдал эхлэхэд",
    "at the event's end" : "үйл явдал дуусахад",
    "{time} before the event starts" : "үйл явдал эхлэхээс {time} өмнө",
    "{time} before the event ends" : "үйл явдал дуусахаас {time} өмнө",
    "{time} after the event starts" : "үйл явдал эхэлсний {time} дараа",
    "{time} after the event ends" : "үйл явдал дууссаны {time} дараа",
    "on {time}" : "{time}-д",
    "on {time} ({timezoneId})" : "{time} ({timezoneId})-д",
    "Week {number} of {year}" : "{year} –æ–Ω—ã {number}-—Ä –¥–æ–ª–æ–æ —Ö–æ–Ω–æ–≥ ",
    "Daily" : "”®–¥”©—Ä –±“Ø—Ä",
    "Weekly" : "–î–æ–ª–æ–æ —Ö–æ–Ω–æ–≥ –±“Ø—Ä",
    "Monthly" : "–°–∞—Ä –±“Ø—Ä",
    "Yearly" : "–ñ–∏–ª –±“Ø—Ä",
    "_Every %n day_::_Every %n days_" : ["Өдөр бүр","%n өдөр тутам"],
    "_Every %n week_::_Every %n weeks_" : ["Долоо хоног бүр","%n долоо хоног тутам"],
    "_Every %n month_::_Every %n months_" : ["Сар бүр","%n сар тутам"],
    "_Every %n year_::_Every %n years_" : ["Жил бүр","%n жил тутам"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}-д","{weekdays}-д"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} өдөр","{dayOfMonthList} өдрүүдэд"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames}-ийн {dayOfMonthList}-д",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames}-ийн {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "{untilDate} хүртэл",
    "_%n time_::_%n times_" : ["%n удаа","%n удаа"],
    "second" : "хоёр дахь",
    "third" : "гурав дахь",
    "fourth" : "дөрөв дэх",
    "fifth" : "тав дахь",
    "second to last" : "сүүлээс хоёр дахь",
    "last" : "сүүлийн",
    "Untitled task" : "Гарчиггүй даалгавар",
    "Please ask your administrator to enable the Tasks App." : "Даалгаврын програмыг идэвхжүүлэхийг администратороос хүснэ үү.",
    "You are not allowed to edit this event as an attendee." : "Та оролцогчийн хувьд энэ үйл явдлыг засах боломжгүй.",
    "W" : "Д",
    "%n more" : "%n нэмэлт",
    "No events to display" : "Харуулах үйл явдал байхгүй",
    "All participants declined" : "Бүх оролцогчид татгалзсан",
    "Please confirm your participation" : "Оролцоогоо баталгаажуулна уу",
    "You declined this event" : "Та энэ үйл явдлаас татгалзсан",
    "Your participation is tentative" : "Таны оролцоо түр",
    "_+%n more_::_+%n more_" : ["+%n бусад","+%n бусад"],
    "No events" : "Үйл явдал байхгүй",
    "Create a new event or change the visible time-range" : "Шинэ үйл явдал үүсгэх эсвэл харагдах цагийн хүрээг өөрчлөх",
    "It might have been deleted, or there was a typo in a link" : "Устгагдсан байж болзошгүй, эсвэл холбоосонд алдаа байсан",
    "Failed to save event" : "Үйл явдлыг хадгалж чадсангүй",
    "It might have been deleted, or there was a typo in the link" : "Устгагдсан байж болзошгүй, эсвэл холбоосонд алдаа байсан",
    "Meeting room" : "Хурлын өрөө",
    "Lecture hall" : "Лекцийн танхим",
    "Seminar room" : "Семинарын өрөө",
    "Other" : "–ë—É—Å–∞–¥",
    "When shared show" : "Хуваалцсан үед харуулах",
    "When shared show full event" : "–¢“Ø–≥—ç—ç—Å—ç–Ω —Ç–æ—Ö–∏–æ–ª–¥–æ–ª–¥ “Ø–π–ª —è–≤–¥–ª—ã–≥ –±“Ø—Ç–Ω—ç—ç—Ä –Ω—å —Ö–∞—Ä—É—É–ª",
    "When shared show only busy" : "–¢“Ø–≥—ç—ç—Å—ç–Ω —Ç–æ—Ö–∏–æ–ª–¥–æ–ª–¥ –∑”©–≤—Ö”©–Ω –∑–∞–≤–≥“Ø–π –≥—ç–∂ —Ö–∞—Ä—É—É–ª",
    "When shared hide this event" : "–¢“Ø–≥—ç—ç—Å—ç–Ω —Ç–æ—Ö–∏–æ–ª–¥–æ–ª–¥ —ç–Ω—ç “Ø–π–ª —è–≤–¥–ª—ã–≥ –Ω—É—É",
    "The visibility of this event in read-only shared calendars." : "Зөвхөн унших хуваалцсан календарууд дахь энэ үйл явдлын харагдах байдал.",
    "Add a location" : "Байршил нэмэх",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Тайлбар нэмэх\n\n- Энэ уулзалт юуны тухай вэ\n- Хэлэлцэх асуудлууд\n- Оролцогчдын бэлтгэх зүйлс",
    "Confirmed" : "–ë–∞—Ç–∞–ª–≥–∞–∞–∂—Å–∞–Ω",
    "Canceled" : "Цуцлагдсан",
    "Confirmation about the overall status of the event." : "Үйл явдлын ерөнхий төлөвийн баталгаажуулалт.",
    "Show as" : "Харуулах",
    "Take this event into account when calculating free-busy information." : "Чөлөөт-завгүй мэдээлэл тооцоолохдоо энэ үйл явдлыг харгалзан үзнэ.",
    "Categories" : "—Ç”©—Ä”©–ª",
    "Categories help you to structure and organize your events." : "Ангилалууд үйл явдлуудыг бүтэцлэх, зохион байгуулахад тусалдаг.",
    "Search or add categories" : "Ангилал хайх эсвэл нэмэх",
    "Add this as a new category" : "Үүнийг шинэ ангилал болгон нэмэх",
    "Custom color" : "Тусгай өнгө",
    "Special color of this event. Overrides the calendar-color." : "Энэ үйл явдлын тусгай өнгө. Календарын өнгийг дарна.",
    "Error while sharing file" : "Файл хуваалцахад алдаа гарлаа",
    "Error while sharing file with user" : "Хэрэглэгчтэй файл хуваалцахад алдаа гарлаа",
    "Error creating a folder {folder}" : "{folder} хавтас үүсгэхэд алдаа гарлаа",
    "Attachment {fileName} already exists!" : "{fileName} хавсралт аль хэдийн байна!",
    "Attachment {fileName} added!" : "{fileName} хавсралт нэмэгдлээ!",
    "An error occurred during uploading file {fileName}" : "{fileName} файл байршуулахад алдаа гарлаа",
    "An error occurred during getting file information" : "Файлын мэдээлэл авахад алдаа гарлаа",
    "Talk conversation for proposal" : "Саналын Talk яриа",
    "An error occurred, unable to delete the calendar." : "Алдаа гарлаа, календарыг устгах боломжгүй.",
    "Imported {filename}" : "{filename} импортлогдлоо",
    "This is an event reminder." : "Энэ бол үйл явдлын сануулагч.",
    "Error while parsing a PROPFIND error" : "PROPFIND алдааг задлахад алдаа гарлаа",
    "Appointment not found" : "Уулзалт олдсонгүй",
    "User not found" : "Хэрэглэгч олдсонгүй",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendars" : "Календарууд",
    "Hidden" : "–î–∞–ª–¥",
    "Default attachments location" : "Хавсралтуудын өгөгдмөл байршил",
    "Automatic ({detected})" : "Автомат ({detected})",
    "Shortcut overview" : "Товчлолын тойм",
    "CalDAV link copied to clipboard." : "CalDAV холбоос түр санах ойд хуулагдлаа.",
    "CalDAV link could not be copied to clipboard." : "CalDAV холбоосыг түр санах ойд хуулж чадсангүй.",
    "Enable birthday calendar" : "Төрсөн өдрийн календарыг идэвхжүүлэх",
    "Show tasks in calendar" : "Даалгавруудыг календарт харуулах",
    "Enable simplified editor" : "Хялбаршуулсан засварлагчийг идэвхжүүлэх",
    "Limit the number of events displayed in the monthly view" : "Сарын харагдацад харуулах үйл явдлын тоог хязгаарлах",
    "Show weekends" : "Амралтын өдрүүдийг харуулах",
    "Show week numbers" : "7 —Ö–æ–Ω–æ–≥–∏–π–Ω –¥—É–≥–∞–∞—Ä—ã–≥ —Ö–∞—Ä—É—É–ª–∞—Ö",
    "Time increments" : "Цагийн нэмэгдэл",
    "Default reminder" : "Өгөгдмөл сануулагч",
    "Copy primary CalDAV address" : "Үндсэн CalDAV хаяг хуулах",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV хаяг хуулах",
    "Personal availability settings" : "Хувийн боломжтой байдлын тохиргоо",
    "Show keyboard shortcuts" : "Гарын товчлолуудыг харуулах",
    "Additional calendars to check for conflicts" : "Зөрчлийг шалгах нэмэлт календарууд",
    "Pick time ranges where appointments are allowed" : "Уулзалт зөвшөөрөгдөх цагийн хүрээг сонгоно уу",
    "Add time before and after the event" : "Үйл явдлын өмнө болон дараа цаг нэмэх",
    "Before the event" : "Үйл явдлын өмнө",
    "After the event" : "Үйл явдлын дараа",
    "Minimum time before next available slot" : "Дараагийн боломжтой слот хүртэлх хамгийн бага хугацаа",
    "Create a new public conversation" : "Шинэ нийтийн яриа үүсгэх",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} урилга авсан, {confirmedCount} баталгаажсан",
    "Successfully appended link to talk room to location." : "Talk өрөөний холбоосыг байршилд амжилттай нэмлээ.",
    "Successfully appended link to talk room to description." : "Talk өрөөний холбоосыг тайлбарт амжилттай нэмлээ.",
    "Error creating Talk room" : "Talk өрөө үүсгэхэд алдаа гарлаа",
    "_%n more guest_::_%n more guests_" : ["%n бусад зочин","%n бусад зочин"],
    "Event title" : "Үйл явдлын гарчиг",
    "_time_::_times_" : ["удаа","удаа"],
    "Select to end repeat" : "Давталт дуусгахыг сонгоно уу",
    "from {formattedDate}" : "{formattedDate}-ээс",
    "to {formattedDate}" : "{formattedDate} хүртэл",
    "on {formattedDate}" : "{formattedDate}-д",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}-ээс",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} хүртэл",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}-д",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "Зөв огноо оруулна уу",
    "Please enter a valid date and time" : "Зөв огноо, цаг оруулна уу",
    "Select a time zone" : "Цагийн бүс сонгоно уу",
    "Please select a time zone:" : "Цагийн бүс сонгоно уу:",
    "Pick a time" : "Цаг сонгох",
    "Pick a date" : "Огноо сонгох",
    "Speak to the server administrator to resolve this issue." : "Энэ асуудлыг шийдвэрлэхийн тулд серверийн администратортай холбогдоно уу.",
    "The slot for your appointment has been confirmed" : "Таны уулзалтын слот баталгаажлаа",
    "Appointment Details:" : "Уулзалтын дэлгэрэнгүй:",
    "Time:" : "Цаг:",
    "Booked for:" : "Захиалсан:",
    "Duration suggestions" : "Үргэлжлэх хугацааны санал",
    "{duration} min" : "{duration} мин"
},
"nplurals=2; plural=(n != 1);");
