OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Provided email-address is too long",
    "User-Session unexpectedly expired" : "نشست کاربر به طور غیر منتظره منقضی شد",
    "Provided email-address is not valid" : "ایمیل ارائه شده معتبر نیست",
    "An error occured during sending email" : "An error occured during sending email",
    "%s has published the calendar »%s«" : "%sتقویم %s را منتشر کرده است.",
    "Unexpected error sending email. Please contact your administrator." : "خطای غیر منتظره در ارسال ایمیل. لطفا با مدیر خود تماس بگیرید.",
    "Successfully sent email to %1$s" : "Successfully sent email to %1$s",
    "Hello," : "سلام،",
    "We wanted to inform you that %s has published the calendar »%s«." : "مایل هستیم به شما اطلاع دهیم که %s تقویم شماره %s را منتشر کرده است.",
    "Open »%s«" : "باز کن »%s«",
    "Cheers!" : "سلامتی!",
    "Upcoming events" : "رویدادهای پیش‌رو",
    "No more events today" : "هیچ رویداد دیگری برای امروز وجود ندارد",
    "No upcoming events" : "رویداد پیش‌رویی وجود ندارد",
    "More events" : "More events",
    "%1$s with %2$s" : "%1$s with %2$s",
    "Calendar" : "تقویم",
    "New booking {booking}" : "New booking {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}.",
    "Appointments" : "قرارها",
    "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
    "Schedule an appointment" : "Schedule an appointment",
    "Requestor Comments:" : "Requestor Comments:",
    "Appointment Description:" : "Appointment Description:",
    "Prepare for %s" : "Prepare for %s",
    "Follow up for %s" : "Follow up for %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
    "Dear %s, please confirm your booking" : "Dear %s, please confirm your booking",
    "Confirm" : "تائید",
    "Appointment with:" : "Appointment with:",
    "Description:" : "توضیحات:",
    "This confirmation link expires in %s hours." : "This confirmation link expires in %s hours.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page.",
    "Your appointment \"%s\" with %s has been accepted" : "Your appointment \"%s\" with %s has been accepted",
    "Dear %s, your booking has been accepted." : "Dear %s, your booking has been accepted.",
    "Appointment for:" : "Appointment for:",
    "Date:" : "تاریخ:",
    "You will receive a link with the confirmation email" : "You will receive a link with the confirmation email",
    "Where:" : "مکان:",
    "Comment:" : "Comment:",
    "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
    "%s has proposed a meeting" : "%s has proposed a meeting",
    "%s has updated a proposed meeting" : "%s has updated a proposed meeting",
    "%s has canceled a proposed meeting" : "%s has canceled a proposed meeting",
    "Dear %s, a new meeting has been proposed" : "Dear %s, a new meeting has been proposed",
    "Dear %s, a proposed meeting has been updated" : "Dear %s, a proposed meeting has been updated",
    "Dear %s, a proposed meeting has been cancelled" : "Dear %s, a proposed meeting has been cancelled",
    "Respond" : "Respond",
    "Location:" : "مکان:",
    "%1$s minutes" : "%1$s minutes",
    "Duration:" : "Duration:",
    "%1$s from %2$s to %3$s" : "%1$s from %2$s to %3$s",
    "Dates:" : "Dates:",
    "[Proposed] %1$s" : "[Proposed] %1$s",
    "Calendar App" : "Calendar App",
    "Calendars App settings including proposals and appointments schedule configurations." : "Calendars App settings including proposals and appointments schedule configurations.",
    "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries.",
    "Previous day" : "روز قبل",
    "Previous week" : "هفته قبل",
    "Previous year" : "Previous year",
    "Previous month" : "ماه قبل",
    "Next day" : "روز بعد",
    "Next week" : "هفته بعد",
    "Next year" : "Next year",
    "Next month" : "ماه بعد",
    "Create new event" : "Create new event",
    "Event" : "رویداد",
    "Today" : "امروز",
    "Day" : "روز",
    "Week" : "هفته",
    "Month" : "ماه",
    "Year" : "سال",
    "List" : "فهرست",
    "Filter events …" : "Filter events …",
    "Appointment link was copied to clipboard" : "Appointment link was copied to clipboard",
    "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
    "Preview" : "پیش‌نمایش",
    "Copy link" : "کپی کردن لینک",
    "Duplicate" : "Duplicate",
    "Edit" : "ویرایش",
    "Delete" : "حذف",
    "Appointment schedules" : "Appointment schedules",
    "Create new" : "ایجاد جدید",
    "Disable calendar \"{calendar}\"" : "Disable calendar \"{calendar}\"",
    "Disable untitled calendar" : "Disable untitled calendar",
    "Enable calendar \"{calendar}\"" : "Enable calendar \"{calendar}\"",
    "Enable untitled calendar" : "Enable untitled calendar",
    "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
    "Untitled calendar" : "تقویم بدون عنوان",
    "Delegated to you by" : "Delegated to you by",
    "Shared with you by" : "با شما به اشتراک گذاشته شده است",
    "Copy public link" : "پیوند عمومی را کپی کنید",
    "Edit and share calendar" : "Edit and share calendar",
    "Edit calendar" : "ویرایش تقویم",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {شمارش معکوس} ثانیه ها","حذف تقویم در {شمارش معکوس} ثانیه ها"],
    "Calendar name can not be blank" : "Calendar name can not be blank",
    "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
    "My calendars" : "My calendars",
    "Add new" : "افزودن مورد تازه",
    "New calendar" : "تقویم جدید",
    "Name for new calendar" : "Name for new calendar",
    "Creating calendar …" : "ایجاد تقویم ...",
    "New calendar with task list" : "تقویم جدید با لیست کارها",
    "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
    "Creating subscription …" : "ایجاد اشتراک…",
    "Add public holiday calendar" : "Add public holiday calendar",
    "Add custom public calendar" : "Add custom public calendar",
    "Copy subscription link" : "پیوند اشتراک را کپی کنید",
    "Copying link …" : "کپی پیوند ...",
    "Copied link" : "پیوند کپی شد",
    "Could not copy link" : "نمی توان پیوند را کپی کرد",
    "Export" : "دریافت خروجی",
    "Untitled item" : "مورد بدون عنوان",
    "Unknown calendar" : "تقویم ناشناخته",
    "Could not load deleted calendars and objects" : "تقویم و اشیاء حذف شده بارگیری نشد",
    "Could not delete calendar or event" : "تقویم یا رویداد حذف نشد",
    "Could not restore calendar or event" : "تقویم یا رویداد بازیابی نشد",
    "Do you really want to empty the trash bin?" : "آیا واقعاً می خواهید سطل زباله را خالی کنید؟",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "Trash bin" : "زباله‌دان",
    "Loading deleted items." : "Loading deleted items.",
    "You do not have any deleted items." : "You do not have any deleted items.",
    "Name" : "نام",
    "Deleted" : "حذف شده",
    "Restore" : "بازیابی",
    "Delete permanently" : "حذف قطعی",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Items in the trash bin are deleted after {numDays} days"],
    "Could not update calendar order." : "Could not update calendar order.",
    "Shared calendars" : "Shared calendars",
    "Deck" : "برگه‌دان",
    "Tasks" : "وظایف",
    "Delegated by {name} (read-only)" : "Delegated by {name} (read-only)",
    "Delegated by {name}" : "Delegated by {name}",
    "Internal link" : "پیوند داخلی",
    "A private link that can be used with external clients" : "A private link that can be used with external clients",
    "Copy internal link" : "کپی کردن پیوند داخلی",
    "An error occurred, unable to publish calendar." : "خطایی روی داد ، قادر به انتشار تقویم نیست.",
    "An error occurred, unable to send email." : "خطایی روی داد ، قادر به ارسال ایمیل نیست.",
    "Embed code copied to clipboard." : "کد قرار داده شده در حافظه کپی شد.",
    "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
    "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
    "Share link" : "لینک را به اشتراک بگذارید",
    "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
    "Enter one address" : "یک آدرس وارد کنید",
    "Sending email …" : "ارسال ایمیل…",
    "Copy embedding code" : "کد تعبیه شده را کپی کنید",
    "Copying code …" : "کپی کردن کد ...",
    "Copied code" : "کد کپی شد",
    "Could not copy code" : "نمی توان کد را کپی کرد",
    "Delete share link" : "پیوند اشتراک را حذف کنید",
    "Deleting share link …" : "در حال حذف پیوند اشتراک ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
    "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
    "can edit and see confidential events" : "can edit and see confidential events",
    "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "events" : "events",
    "tasks" : "tasks",
    "journal entries" : "journal entries",
    "This calendar supports neither events, tasks nor journal entries." : "This calendar supports neither events, tasks nor journal entries.",
    "_This calendar supports only {types}._::_This calendar supports {types}._" : ["This calendar supports only {types}.","This calendar supports {types}."],
    "None" : "هیچ‌کدام",
    "Failed to save calendar name and color" : "Failed to save calendar name and color",
    "Calendar name" : "نام تقویم",
    "Never show me as busy (set this calendar to transparent)" : "Never show me as busy (set this calendar to transparent)",
    "Default reminder for part-day events" : "Default reminder for part-day events",
    "Select default reminder" : "Select default reminder",
    "Default reminder for full-day events" : "Default reminder for full-day events",
    "These reminders will be automatically added to new events created in this calendar" : "These reminders will be automatically added to new events created in this calendar",
    "Share calendar" : "Share calendar",
    "Unshare from me" : "بی خبر از من",
    "Save" : "ذخیره",
    "No title" : "No title",
    "Are you sure you want to delete \"{title}\"?" : "آیا از حذف \"{title}\" مطمئن هستید؟",
    "Cancel" : "منصرف شدن",
    "Deleting proposal \"{title}\"" : "Deleting proposal \"{title}\"",
    "Successfully deleted proposal" : "Successfully deleted proposal",
    "Failed to delete proposal" : "Failed to delete proposal",
    "Failed to retrieve proposals" : "Failed to retrieve proposals",
    "Meeting proposals" : "Meeting proposals",
    "A configured email address is required to use meeting proposals" : "A configured email address is required to use meeting proposals",
    "No active meeting proposals" : "No active meeting proposals",
    "View" : "نمایش",
    "Delete proposal" : "Delete proposal",
    "Event legend" : "Event legend",
    "Calendar events are styled to convey additional information at a glance." : "Calendar events are styled to convey additional information at a glance.",
    "Free / Busy" : "Free / Busy",
    "Busy" : "مشغول",
    "Busy: your time is marked as occupied" : "Busy: your time is marked as occupied",
    "Free" : "آزاد",
    "Free: your time is still available" : "Free: your time is still available",
    "Participation status" : "Participation status",
    "Accepted" : "Accepted",
    "Accepted: you confirmed your attendance" : "Accepted: you confirmed your attendance",
    "Tentative" : "آزمایشی",
    "Tentative: your participation is uncertain" : "Tentative: your participation is uncertain",
    "Invited" : "دعوت کردن",
    "Invited: you have not yet responded to this invitation" : "Invited: you have not yet responded to this invitation",
    "Declined" : "Declined",
    "Declined: you declined this event" : "Declined: you declined this event",
    "All declined" : "All declined",
    "All declined: all participants declined" : "All declined: all participants declined",
    "Icons" : "آیکون ها",
    "Attendees" : "شرکت کنندگان",
    "This event has one or more attendees" : "This event has one or more attendees",
    "Past events" : "Past events",
    "Past event" : "Past event",
    "Events that have already ended are shown with a more faded background" : "Events that have already ended are shown with a more faded background",
    "Import destination selection" : "Import destination selection",
    "Import calendars" : "وارد کردن تقویم ها",
    "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
    "Filename" : "نام پرونده",
    "Calendar to import into" : "تقویم برای وارد کردن",
    "_Import calendar_::_Import calendars_" : ["وارد کردن تقویم","وارد کردن تقویم ها"],
    "Some calendars are disabled because this file contains {types}." : "Some calendars are disabled because this file contains {types}.",
    "Select the default location for attachments" : "Select the default location for attachments",
    "Pick" : "Pick",
    "Invalid location selected" : "مکان نامعتبر انتخاب شده است",
    "Attachments folder successfully saved." : "Attachments folder successfully saved.",
    "Error on saving attachments folder." : "Error on saving attachments folder.",
    "Attachments folder" : "Attachments folder",
    "{email} will no longer be able to act on your behalf." : "{email} will no longer be able to act on your behalf.",
    "Revoke" : "لغو",
    "Viewer" : "Viewer",
    "Editor" : "ویرایشگر",
    "Could not revoke access." : "Could not revoke access.",
    "Access revoked successfully." : "Access revoked successfully.",
    "{name} can now view your calendars." : "{name} can now view your calendars.",
    "{name} can now act on your behalf." : "{name} can now act on your behalf.",
    "Could not add delegate." : "Could not add delegate.",
    "Could not load delegates." : "Could not load delegates.",
    "Delegates" : "Delegates",
    "Allow users to manage your calendar events and invitations on your behalf." : "Allow users to manage your calendar events and invitations on your behalf.",
    "Loading delegates…" : "Loading delegates…",
    "Revoke access" : "Revoke access",
    "No delegates yet." : "No delegates yet.",
    "Add delegate" : "Add delegate",
    "Revoke access?" : "Revoke access?",
    "Search for a user…" : "Search for a user…",
    "No users found" : "No users found",
    "Choose whether they can view and edit events, or only view them." : "Choose whether they can view and edit events, or only view them.",
    "Add as viewer" : "Add as viewer",
    "Add as editor" : "Add as editor",
    "{filename} could not be parsed" : "{filename} could not be parsed",
    "No valid files found, aborting import" : "No valid files found, aborting import",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
    "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
    "Automatic" : "خودکار",
    "Automatic ({timezone})" : "خودکار ({شناسایی})",
    "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
    "Timezone" : "Timezone",
    "Navigation" : "جهت یابی",
    "Previous period" : "دوره قبلی",
    "Next period" : "دوره بعدی",
    "Views" : "بازدیدها",
    "Day view" : "نمای روز",
    "Week view" : "نمای هفته",
    "Month view" : "نمای ماه",
    "Year view" : "نمای سال",
    "List view" : "نمایش لیست",
    "Actions" : "فعالیت ها",
    "Create event" : "ایجاد رویداد",
    "Show shortcuts" : "نمایش میانبرها",
    "Close editor" : "ویرایشگر را ببندید",
    "Save edited event" : "رویداد ویرایش شده را ذخیره کنید",
    "Delete edited event" : "حذف رویداد ویرایش شده",
    "Duplicate event" : "رویداد تکراری",
    "or" : "یا",
    "Calendar settings" : "تنظیمات تقویم",
    "No reminder" : "No reminder",
    "At event start" : "At event start",
    "Failed to save default calendar" : "Failed to save default calendar",
    "General" : "عمومی",
    "Default calendar for incoming invitations" : "Default calendar for incoming invitations",
    "Availability settings" : "Availability settings",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Access Nextcloud calendars from other apps and devices",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "Server Address for iOS and macOS",
    "Appearance" : "ظاهر",
    "Birthday calendar" : "Birthday calendar",
    "Tasks in calendar" : "Tasks in calendar",
    "Weekends" : "Weekends",
    "Week numbers" : "Week numbers",
    "Limit number of events shown in Month view" : "Limit number of events shown in Month view",
    "Density in Day and Week View" : "Density in Day and Week View",
    "Editing" : "ویرایش کردن",
    "Simple event editor" : "Simple event editor",
    "\"More details\" opens the detailed editor" : "\"More details\" opens the detailed editor",
    "Files" : "پرونده‌ها",
    "Delegation" : "Delegation",
    "Appointment schedule successfully created" : "Appointment schedule successfully created",
    "Appointment schedule successfully updated" : "Appointment schedule successfully updated",
    "0 minutes" : "0 minutes",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
    "_{duration} day_::_{duration} days_" : ["{duration} day","{duration} days"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} weeks"],
    "_{duration} month_::_{duration} months_" : ["{duration} month","{duration} months"],
    "_{duration} year_::_{duration} years_" : ["{duration} year","{duration} years"],
    "To configure appointments, add your email address in personal settings." : "To configure appointments, add your email address in personal settings.",
    "Public – shown on profile page" : "Public – shown on profile page",
    "Private – only accessible via link" : "Private – only accessible via link",
    "Appointment schedule saved" : "Appointment schedule saved",
    "Create appointment schedule" : "Create appointment schedule",
    "Edit appointment schedule" : "Edit appointment schedule",
    "Update" : "به روز رسانی",
    "(copy)" : "(کپی)",
    "Appointment name" : "Appointment name",
    "Location" : "مکان",
    "Create a Talk room" : "ایجاد اتاق گفتگو",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "A unique link will be generated for every booked appointment and sent via the confirmation email",
    "Description" : "توضیحات",
    "Duration (minutes)" : "Duration (minutes)",
    "Increments" : "Increments",
    "Booking calendar" : "Booking calendar",
    "Calendars to check for conflicts" : "Calendars to check for conflicts",
    "Visibility" : "Visibility",
    "Booking availability" : "Booking availability",
    "to" : "به",
    "Delete slot" : "Delete slot",
    "No times set" : "No times set",
    "Add" : "افزودن",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه‌شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنج‌شنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sunday" : "یکشنبه",
    "Weekdays" : "روزهای هفته",
    "Planning restrictions" : "Planning restrictions",
    "Buffer before the event" : "Buffer before the event",
    "Buffer after the event" : "Buffer after the event",
    "Minimum time before next slot" : "Minimum time before next slot",
    "Max slots per day" : "Max slots per day",
    "Limit how far in the future appointments can be booked" : "Limit how far in the future appointments can be booked",
    "It seems a rate limit has been reached. Please try again later." : "It seems a rate limit has been reached. Please try again later.",
    "Please confirm your reservation" : "Please confirm your reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now.",
    "Your name" : "اسم شما",
    "Your email address" : "پست الکترونیکی شما",
    "Please share anything that will help prepare for our meeting" : "Please share anything that will help prepare for our meeting",
    "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organizer.",
    "Back" : "Back",
    "Book appointment" : "Book appointment",
    "Error fetching Talk conversations." : "Error fetching Talk conversations.",
    "Conversation does not have a valid URL." : "Conversation does not have a valid URL.",
    "Successfully added Talk conversation link to location." : "Successfully added Talk conversation link to location.",
    "Successfully added Talk conversation link to description." : "Successfully added Talk conversation link to description.",
    "Failed to apply Talk room." : "Failed to apply Talk room.",
    "Talk conversation for event" : "Talk conversation for event",
    "Error creating Talk conversation" : "Error creating Talk conversation",
    "Select a Talk Room" : "Select a Talk Room",
    "Fetching Talk rooms…" : "Fetching Talk rooms…",
    "No Talk room available" : "No Talk room available",
    "Select existing conversation" : "Select existing conversation",
    "Select conversation" : "مکالمه را انتخاب کنید",
    "Or create a new conversation" : "Or create a new conversation",
    "Create public conversation" : "Create public conversation",
    "Create private conversation" : "Create private conversation",
    "on" : "بر",
    "at" : "در",
    "Default reminder of calendar" : "Default reminder of calendar",
    "Amount" : "Amount",
    "before at" : "قبل از در",
    "Notification" : "اطلاع",
    "Email" : "ایمیل",
    "Audio notification" : "اعلان صوتی",
    "Other notification" : "سایر اعلان ها",
    "Relative to event" : "نسبت به واقعه",
    "On date" : "در تاریخ",
    "Edit time" : "ویرایش زمان",
    "Save time" : "صرفه جویی در وقت",
    "Remove reminder" : "یادآوری را حذف کنید",
    "Add reminder" : "Add reminder",
    "seconds" : "ثانیه ها",
    "minutes" : "دقیقه",
    "hours" : "ساعت",
    "days" : "روز",
    "weeks" : "هفته",
    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
    "Choose a file to share as a link" : "Choose a file to share as a link",
    "Attachment {name} already exist!" : "Attachment {name} already exist!",
    "Could not upload attachment(s)" : "Could not upload attachment(s)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "You are about to navigate to {link}. Are you sure to proceed?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "You are about to navigate to {host}. Are you sure to proceed? Link: {link}",
    "Proceed" : "ادامه دادن",
    "No attachments" : "No attachments",
    "Add from Files" : "Add from Files",
    "Upload from device" : "Upload from device",
    "Delete file" : "حذف پرونده",
    "Confirmation" : "Confirmation",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Suggested" : "Suggested",
    "Available" : "در دسترس",
    "Invitation accepted" : "Invitation accepted",
    "Accepted {organizerName}'s invitation" : "Accepted {organizerName}'s invitation",
    "Participation marked as tentative" : "Participation marked as tentative",
    "Invitation is delegated" : "Invitation is delegated",
    "Not available" : "در دسترس نیست",
    "Invitation declined" : "Invitation declined",
    "Declined {organizerName}'s invitation" : "Declined {organizerName}'s invitation",
    "Availability will be checked" : "Availability will be checked",
    "Invitation will be sent" : "Invitation will be sent",
    "Failed to check availability" : "Failed to check availability",
    "Failed to deliver invitation" : "Failed to deliver invitation",
    "Awaiting response" : "Awaiting response",
    "Checking availability" : "Checking availability",
    "Has not responded to {organizerName}'s invitation yet" : "Has not responded to {organizerName}'s invitation yet",
    "{name} (delegated by {delegator})" : "{name} (delegated by {delegator})",
    "Duration" : "مدت زمان",
    "15 minutes" : "۱۵ دقیقه",
    "30 minutes" : "۳۰ دقیقه",
    "45 minutes" : "45 دقیقه",
    "1 hour" : "۱ ساعت",
    "1 hour 30 minutes" : "1 hour 30 minutes",
    "2 hours" : "2 ساعت",
    "Custom" : "Custom",
    "_{i} day_::_{i} days_" : ["{i} روز","{i} روز"],
    "_{i} hour_::_{i} hours_" : ["{i} hour","{i} hours"],
    "_{i} minute_::_{i} minutes_" : ["{i} minute","{i} minutes"],
    "Days" : "روزها",
    "Hours" : "ساعت ها",
    "Minutes" : "دقایق",
    "Suggested times" : "Suggested times",
    "chairperson" : "chairperson",
    "required participant" : "required participant",
    "non-participant" : "non-participant",
    "optional participant" : "optional participant",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Selected slot",
    "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
    "Suggestion accepted" : "Suggestion accepted",
    "Previous date" : "Previous date",
    "Next date" : "Next date",
    "Legend" : "Legend",
    "Out of office" : "بیرون از دفتر",
    "Attendees:" : "شرکت‌کنندگان:",
    "local time" : "local time",
    "Done" : "Done",
    "Search room" : "Search room",
    "Room name" : "Room name",
    "Check room availability" : "Check room availability",
    "Busy (tentative)" : "مشغول (آزمایشی)",
    "Unknown" : "نامشخص",
    "Find a time" : "Find a time",
    "The invitation has been accepted successfully." : "The invitation has been accepted successfully.",
    "Failed to accept the invitation." : "Failed to accept the invitation.",
    "The invitation has been declined successfully." : "The invitation has been declined successfully.",
    "Failed to decline the invitation." : "Failed to decline the invitation.",
    "Your participation has been marked as tentative." : "Your participation has been marked as tentative.",
    "Failed to set the participation status to tentative." : "Failed to set the participation status to tentative.",
    "Accept" : "تایید",
    "Decline" : "کاهش می یابد",
    "Copied to clipboard" : "در حافظه رونویسی شد",
    "Failed to copy" : "Failed to copy",
    "Copy name and email address" : "Copy name and email address",
    "Send email to {email}" : "Send email to {email}",
    "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} confirmed, {waitingCount} awaiting response",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Please add at least one attendee to use the \"Find a time\" feature.",
    "Status" : "وضعیت",
    "Role" : "نقش",
    "Delegated" : "Delegated",
    "Chairperson" : "رئیس",
    "Required participant" : "شرکت کننده مورد نیاز",
    "Optional participant" : "شرکت کننده اختیاری",
    "Non-participant" : "غیر شرکت کننده",
    "Attendees copied to clipboard" : "Attendees copied to clipboard",
    "Failed to copy attendees to clipboard" : "Failed to copy attendees to clipboard",
    "Copy attendees to clipboard" : "Copy attendees to clipboard",
    "_%n more attendee_::_%n more attendees_" : ["%n more attendee","%n more attendees"],
    "Remove group" : "برداشتن گروه",
    "Remove attendee" : "شرکت کننده را حذف کنید",
    "Request reply" : "Request reply",
    "_%n member_::_%n members_" : ["%n عضو","%n عضو"],
    "Search for emails, users, contacts, contact groups or teams" : "Search for emails, users, contacts, contact groups or teams",
    "No match found" : "هیچ تطبیقی یافت نشد",
    "Note that members of circles get invited but are not synced yet." : "Note that members of circles get invited but are not synced yet.",
    "Note that members of contact groups get invited but are not synced yet." : "Note that members of contact groups get invited but are not synced yet.",
    "(organizer)" : "(تنظیم کننده)",
    "Make {label} the organizer" : "Make {label} the organizer",
    "Make {label} the organizer and attend" : "Make {label} the organizer and attend",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose].",
    "Remove color" : "Remove color",
    "Title" : "Title",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
    "From" : "از",
    "To" : "به",
    "Your Time" : "Your Time",
    "Repeat" : "تکرار",
    "Repeat event" : "Repeat event",
    "Set repetition" : "Set repetition",
    "never" : "هرگز",
    "on date" : "در تاریخ",
    "after" : "بعد از",
    "End repeat" : "پایان تکرار ",
    "Occurrences" : "Occurrences",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it.",
    "first" : "اولین",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغییر در قانون بازگشتی فقط در مورد این و همه وقایع آینده اعمال خواهد شد.",
    "Repeat every" : "همه را تکرار کنید",
    "By day of the month" : "تا روز ماه",
    "On the" : "در",
    "_day_::_days_" : ["روز","روز"],
    "_week_::_weeks_" : ["هفته","هفته"],
    "_month_::_months_" : ["ماه","ماه ها"],
    "_year_::_years_" : ["سال","سال ها"],
    "On specific day" : "در روزی مشخص",
    "weekday" : "روز هفته",
    "weekend day" : " آخر  هفته",
    "Does not repeat" : "تکرار نمی کند",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
    "No rooms or resources yet" : "No rooms or resources yet",
    "Resources" : "منابع",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} seats"],
    "Add resource" : "Add resource",
    "Has a projector" : "Has a projector",
    "Has a whiteboard" : "Has a whiteboard",
    "Wheelchair accessible" : "Wheelchair accessible",
    "Remove resource" : "Remove resource",
    "Search for resources or rooms" : "Search for resources or rooms",
    "available" : "در دسترس",
    "unavailable" : "unavailable",
    "Show all rooms" : "Show all rooms",
    "Projector" : "Projector",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Room type",
    "Any" : "Any",
    "Minimum seating capacity" : "Minimum seating capacity",
    "More details" : "More details",
    "Update this and all future" : "این و همه آینده را به روز کنید",
    "Update this occurrence" : "این رویداد را به روز کنید",
    "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
    "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
    "Remove date" : "Remove date",
    "Attendance required" : "Attendance required",
    "Attendance optional" : "Attendance optional",
    "Remove participant" : "Remove participant",
    "Yes" : "بله",
    "No" : "خیر",
    "Maybe" : "Maybe",
    "Select your meeting availability" : "Select your meeting availability",
    "Create a meeting for this date and time" : "Create a meeting for this date and time",
    "Create" : "ایجاد",
    "No participants or dates available" : "No participants or dates available",
    "(delegated by {name})" : "(delegated by {name})",
    "Type to search time zone" : "Type to search time zone",
    "Global" : "عمومی",
    "Holidays in {region}" : "Holidays in {region}",
    "An error occurred, unable to read public calendars." : "An error occurred, unable to read public calendars.",
    "An error occurred, unable to subscribe to calendar." : "An error occurred, unable to subscribe to calendar.",
    "Public calendar subscriptions selection" : "Public calendar subscriptions selection",
    "Public holiday calendars" : "Public holiday calendars",
    "Public calendars" : "Public calendars",
    "No valid public calendars configured" : "No valid public calendars configured",
    "Contact your server administrator to resolve this issue." : "Contact your server administrator to resolve this issue.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website.",
    "By {authors}" : "By {authors}",
    "Subscribed" : "Subscribed",
    "Subscribe" : "اشتراک گذاری",
    "Could not fetch slots" : "Could not fetch slots",
    "Select a date" : "تاریخ را انتخاب کنید",
    "Select slot" : "Select slot",
    "No slots available" : "No slots available",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Thank you. Your booking from {startDate} to {endDate} has been confirmed.",
    "Book another appointment:" : "Book another appointment:",
    "See all available slots" : "See all available slots",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "The slot for your appointment from {startDate} to {endDate} is not available any more.",
    "Please book a different slot:" : "Please book a different slot:",
    "This booking link is no longer valid" : "This booking link is no longer valid",
    "The confirmation link has expired or has already been used. Please contact the organizer to rebook." : "The confirmation link has expired or has already been used. Please contact the organizer to rebook.",
    "Confirm your appointment" : "Confirm your appointment",
    "Could not confirm the appointment. Please try again later or contact the organizer." : "Could not confirm the appointment. Please try again later or contact the organizer.",
    "Book an appointment with {name}" : "Book an appointment with {name}",
    "No public appointments found for {name}" : "No public appointments found for {name}",
    "Personal" : "شخصی",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
    "Show unscheduled tasks" : "Show unscheduled tasks",
    "Unscheduled tasks" : "Unscheduled tasks",
    "Availability of {displayName}" : "Availability of {displayName}",
    "Discard changes" : "Discard changes",
    "Allow forwarding" : "Allow forwarding",
    "Anyone with the invitation can respond" : "Anyone with the invitation can respond",
    "Only invited attendees can respond" : "Only invited attendees can respond",
    "Choose \"Only invited attendees can respond\" to prevent attendees from forwarding the invitation to others." : "Choose \"Only invited attendees can respond\" to prevent attendees from forwarding the invitation to others.",
    "Edit event" : "ویرایش رویداد",
    "Event does not exist" : "رویداد وجود ندارد",
    "Delete this occurrence" : "این رخداد را حذف کنید",
    "Delete this and all future" : "این و همه آینده را حذف کنید",
    "All day" : "تمام روز",
    "Modifications wont get propagated to the organizer and other attendees" : "Modifications wont get propagated to the organizer and other attendees",
    "Add Talk conversation" : "Add Talk conversation",
    "Managing shared access" : "Managing shared access",
    "Deny access" : "Deny access",
    "Invite" : "Invite",
    "Discard changes?" : "Discard changes?",
    "Are you sure you want to discard the changes made to this event?" : "Are you sure you want to discard the changes made to this event?",
    "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Users require access to your file"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
    "Untitled event" : "رویداد بدون عنوان",
    "Close" : "بستن",
    "Modifications will not get propagated to the organizer and other attendees" : "Modifications will not get propagated to the organizer and other attendees",
    "This event was cancelled" : "This event was cancelled",
    "Meeting proposals overview" : "Meeting proposals overview",
    "Edit meeting proposal" : "Edit meeting proposal",
    "Create meeting proposal" : "Create meeting proposal",
    "Update meeting proposal" : "Update meeting proposal",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Create a meeting for \"{date}\"? This will create a calendar event with all participants.",
    "Create meeting" : "Create meeting",
    "Saving proposal \"{title}\"" : "Saving proposal \"{title}\"",
    "Successfully saved proposal" : "Successfully saved proposal",
    "Failed to save proposal" : "Failed to save proposal",
    "Please enter a valid duration in minutes." : "Please enter a valid duration in minutes.",
    "Failed to fetch proposals" : "Failed to fetch proposals",
    "Creating meeting for {date}" : "Creating meeting for {date}",
    "Successfully created meeting for {date}" : "Successfully created meeting for {date}",
    "Failed to create a meeting for {date}" : "Failed to create a meeting for {date}",
    "Failed to fetch free/busy data" : "Failed to fetch free/busy data",
    "Selected" : "Selected",
    "No Description" : "No Description",
    "No Location" : "No Location",
    "Edit this meeting proposal" : "Edit this meeting proposal",
    "Delete this meeting proposal" : "Delete this meeting proposal",
    "Participants" : "شركت كنندگان",
    "Selected times" : "Selected times",
    "Previous span" : "Previous span",
    "Next span" : "Next span",
    "Less days" : "Less days",
    "More days" : "More days",
    "Loading meeting proposal" : "Loading meeting proposal",
    "No meeting proposal found" : "No meeting proposal found",
    "Please wait while we load the meeting proposal." : "Please wait while we load the meeting proposal.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "The link you followed may be broken, or the meeting proposal may no longer exist.",
    "Thank you for your response!" : "Thank you for your response!",
    "Your vote has been recorded. Thank you for participating!" : "Your vote has been recorded. Thank you for participating!",
    "Unknown User" : "Unknown User",
    "No Title" : "No Title",
    "No Duration" : "No Duration",
    "Select a different time zone" : "Select a different time zone",
    "Submit" : "ارسال",
    "Subscribe to {name}" : "اشتراک در {name}",
    "Export {name}" : "دریافت خروجی از {name}",
    "Show availability" : "Show availability",
    "Anniversary" : "سالگرد",
    "Appointment" : "وقت ملاقات",
    "Business" : "کسب و کار",
    "Education" : "تحصیلات",
    "Holiday" : "تعطیلات",
    "Meeting" : "ملاقات",
    "Miscellaneous" : "متفرقه",
    "Non-working hours" : "ساعات غیر کاری",
    "Not in office" : "در دفتر نیست",
    "Phone call" : "تماس تلفنی",
    "Sick day" : "روز بیماری",
    "Special occasion" : "مناسبت ویژه",
    "Travel" : "مسافرت رفتن",
    "Vacation" : "تعطیلات",
    "Midnight on the day the event starts" : "نیمه شب در روز آغاز این رویداد",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n روز قبل از این رویداد در {formattedHourMinute}","%n روزهای قبل از این رویداد در {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n هفته قبل از این رویداد در {formattedHourMinute}","%n هفته قبل از این رویدادها در {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "در روز رویداد در {formattedHourMinute}",
    "at the event's start" : "در شروع رویداد",
    "at the event's end" : "در پایان رویداد",
    "{time} before the event starts" : "{زمان} قبل از شروع رویداد",
    "{time} before the event ends" : "{زمان} قبل از پایان این رویداد",
    "{time} after the event starts" : "{زمان} بعد از شروع رویداد",
    "{time} after the event ends" : "{زمان} پس از پایان این رویداد",
    "on {time}" : "به {موقع}",
    "on {time} ({timezoneId})" : "در {time} ({timezoneId})",
    "Week {number} of {year}" : "هفتهٔ {number} از {year}",
    "Daily" : "روزانه",
    "Weekly" : "هفته گی",
    "Monthly" : "ماهانه",
    "Yearly" : "سالانه",
    "_Every %n day_::_Every %n days_" : ["هر %n روز","هر %n روزها"],
    "_Every %n week_::_Every %n weeks_" : ["هر %n هفته","هر %n هفته"],
    "_Every %n month_::_Every %n months_" : ["هر %n ماه","هر %n ماه ها"],
    "_Every %n year_::_Every %n years_" : ["هر %n سال","هر %n سال ها"],
    "_on {weekday}_::_on {weekdays}_" : ["در {weekday}","در {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["در روز {dayOfMonthList}","در روزها {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "روی {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "در {monthNames} در روزهای {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "در {monthNames} در {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "تا زمان {untilDate}",
    "_%n time_::_%n times_" : ["%n بار","%n بارها"],
    "second" : "دومین",
    "third" : "سوم",
    "fourth" : "چهارم",
    "fifth" : "پنجم",
    "second to last" : "دوم تا آخرین",
    "last" : "آخر",
    "Untitled task" : "کار بدون عنوان",
    "Please ask your administrator to enable the Tasks App." : "Please ask your administrator to enable the Tasks App.",
    "You are not allowed to edit this event as an attendee." : "You are not allowed to edit this event as an attendee.",
    "W" : "W",
    "%n more" : "%n more",
    "No events to display" : "هیچ رویدادی برای نمایش وجود ندارد",
    "All participants declined" : "All participants declined",
    "Please confirm your participation" : "Please confirm your participation",
    "You declined this event" : "You declined this event",
    "Your participation is tentative" : "Your participation is tentative",
    "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
    "No events" : "رویدادی وجود ندارد",
    "Create a new event or change the visible time-range" : "یک رویداد تازه بسازید یا بازه زمانی خود را تغییر بدهید",
    "It might have been deleted, or there was a typo in a link" : "It might have been deleted, or there was a typo in a link",
    "Failed to save event" : "Failed to save event",
    "Event link copied to clipboard" : "Event link copied to clipboard",
    "Failed to copy event link" : "Failed to copy event link",
    "It might have been deleted, or there was a typo in the link" : "It might have been deleted, or there was a typo in the link",
    "Meeting room" : "Meeting room",
    "Lecture hall" : "Lecture hall",
    "Seminar room" : "Seminar room",
    "Other" : "دیگر",
    "When shared show" : "هنگام نمایش مشترک",
    "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
    "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
    "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
    "The visibility of this event in read-only shared calendars." : "The visibility of this event in read-only shared calendars.",
    "Add a location" : "افزودن یک محل",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare",
    "Confirmed" : "تایید شده",
    "Canceled" : "لغو شد",
    "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
    "Show as" : "نمایش به عنوان",
    "Take this event into account when calculating free-busy information." : "این رویداد در زمان محاسبهٔ اطلاعات آزاد/مشغول، در نظر گرفته شود.",
    "Categories" : "دسته بندی ها",
    "Categories help you to structure and organize your events." : "دسته بندی ها به شما کمک می کنند تا وقایع خود را تنظیم و سازماندهی کنید.",
    "Search or add categories" : "دسته ها را جستجو یا اضافه کنید",
    "Add this as a new category" : "این را به عنوان یک دسته جدید اضافه کنید",
    "Custom color" : "رنگ سفارشی",
    "Special color of this event. Overrides the calendar-color." : "رنگ ویژه این رویداد. رنگ تقویم را نادیده می گیرد.",
    "Error while sharing file" : "Error while sharing file",
    "Error while sharing file with user" : "Error while sharing file with user",
    "Error creating a folder {folder}" : "Error creating a folder {folder}",
    "Attachment {fileName} already exists!" : "Attachment {fileName} already exists!",
    "Attachment {fileName} added!" : "Attachment {fileName} added!",
    "An error occurred during uploading file {fileName}" : "An error occurred during uploading file {fileName}",
    "An error occurred during getting file information" : "An error occurred during getting file information",
    "Talk conversation for proposal" : "Talk conversation for proposal",
    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
    "Imported {filename}" : "وارد شده {نام پرونده}",
    "Could not load delegated calendars. Make sure the server supports calendar delegation." : "Could not load delegated calendars. Make sure the server supports calendar delegation.",
    "This is an event reminder." : "This is an event reminder.",
    "Error while parsing a PROPFIND error" : "Error while parsing a PROPFIND error",
    "Appointment not found" : "Appointment not found",
    "User not found" : "کاربر یافت نشد",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendars" : "تقویم‌ها",
    "Hidden" : "مخفی",
    "Calendar name …" : "نام تقویم …",
    "Default attachments location" : "Default attachments location",
    "Automatic ({detected})" : "خودکار ({شناسایی})",
    "Shortcut overview" : "Shortcut overview",
    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
    "Show tasks in calendar" : "نمایش وظایف در تقویم",
    "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
    "Show weekends" : "آخر هفته ها را نشان دهید",
    "Show week numbers" : "نمایش شماره های هفته",
    "Time increments" : "Time increments",
    "Default reminder" : "Default reminder",
    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
    "Personal availability settings" : "Personal availability settings",
    "Show keyboard shortcuts" : "Show keyboard shortcuts",
    "Public – shown on the profile page" : "عمومی – در صفحهٔ نمایه نشان داده می‌شود",
    "Private – only accessible via secret link" : "Private – only accessible via secret link",
    "Additional calendars to check for conflicts" : "Additional calendars to check for conflicts",
    "Pick time ranges where appointments are allowed" : "Pick time ranges where appointments are allowed",
    "Add time before and after the event" : "Add time before and after the event",
    "Before the event" : "Before the event",
    "After the event" : "After the event",
    "Minimum time before next available slot" : "Minimum time before next available slot",
    "Create a new public conversation" : "Create a new public conversation",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invited, {confirmedCount} confirmed",
    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
    "_%n more guest_::_%n more guests_" : ["%n more guest","%n more guests"],
    "Event title" : "عنوان رویداد",
    "_time_::_times_" : ["بار","بارها"],
    "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
    "from {formattedDate}" : "از {formattedDate}",
    "to {formattedDate}" : "به {formattedDate}",
    "on {formattedDate}" : "در {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "از {formattedDate} در {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "به {formattedDate} در {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "در {formattedDate} در {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
    "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
    "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
    "Select a time zone" : "Select a time zone",
    "Please select a time zone:" : "Please select a time zone:",
    "Pick a time" : "Pick a time",
    "Pick a date" : "Pick a date",
    "Speak to the server administrator to resolve this issue." : "Speak to the server administrator to resolve this issue.",
    "The slot for your appointment has been confirmed" : "The slot for your appointment has been confirmed",
    "Appointment Details:" : "Appointment Details:",
    "Time:" : "Time:",
    "Booked for:" : "Booked for:",
    "Duration suggestions" : "Duration suggestions",
    "{duration} min" : "{duration} min"
},
"nplurals=2; plural=(n > 1);");
