OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Daeth y Sesiwn-Defnyddiwr i ben yn annisgwyl",
    "Provided email-address is not valid" : "Nid yw'r cyfeiriad e-bost hwn yn ddilys",
    "%s has published the calendar »%s«" : "Mae %s wedi cyhoeddi’r calendr » %s«",
    "Unexpected error sending email. Please contact your administrator." : "Gwall annisgwyl wrth anfon e-bost. Cysylltwch â'ch gweinyddwr.",
    "Successfully sent email to %1$s" : "Wedi anfon e-bost yn llwyddiannus at %1$s",
    "Hello," : "Helo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr » %s«.",
    "Open »%s«" : "Agor »%s«",
    "Cheers!" : "Hwyl!",
    "Upcoming events" : "Digwyddiadau i ddod",
    "No more events today" : "Dim mwy o ddigwyddiadau heddiw",
    "No upcoming events" : "Dim digwyddiadau i ddod",
    "Calendar" : "Calendr",
    "Appointments" : "Apwyntiadau",
    "Schedule appointment \"%s\"" : "Trefnu apwyntiad \"%s\"",
    "Schedule an appointment" : "Trefnwch apwyntiad",
    "Prepare for %s" : "Paratoi ar gyfer %s",
    "Follow up for %s" : "Dilyniant ar gyfer %s",
    "Dear %s, please confirm your booking" : "Annwyl %s, cadarnhewch eich archeb",
    "Confirm" : "Cadarnhau",
    "Description:" : "Disgrifiad:",
    "This confirmation link expires in %s hours." : "Mae'r ddolen gadarnhau hon yn dod i ben ymhen %s awr.",
    "Date:" : "Dyddiad:",
    "Where:" : "Lle:",
    "Location:" : "Lleoliad:",
    "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
    "Previous day" : "Diwrnod blaenorol",
    "Previous week" : "Wythnos flaenorol",
    "Previous month" : "Mis blaenorol",
    "Next day" : "Diwrnod nesaf",
    "Next week" : "Wythnos nesaf",
    "Next year" : "Blwyddyn nesaf",
    "Next month" : "Mis nesaf",
    "Today" : "Heddiw",
    "Day" : "Diwrnod",
    "Week" : "Wythnos",
    "Month" : "Mis",
    "Year" : "Blwyddyn",
    "List" : "Rhestr",
    "Appointment link was copied to clipboard" : "Cafodd dolen apwyntiad ei chopïo i'r clipfwrdd",
    "Appointment link could not be copied to clipboard" : "Ni fu modd copïo dolen apwyntiad i'r clipfwrdd",
    "Preview" : "Rhagolwg",
    "Copy link" : "Copïo dolen",
    "Edit" : "Golygu",
    "Delete" : "Dileu",
    "Create new" : "Creu newydd",
    "An error occurred, unable to change visibility of the calendar." : "Bu gwall, ni fu modd newid gwelededd y calendr.",
    "Calendar link copied to clipboard." : "Dolen calendr wedi'i chopïo i'r clipfwrdd.",
    "Calendar link could not be copied to clipboard." : "Nid oedd modd copïo dolen calendr i'r clipfwrdd.",
    "Untitled calendar" : "Calendr di-deitl",
    "Copy public link" : "Copïo dolen gyhoeddus",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dadrannu'r calendr mewn {countdown} eiliad","Dad-rannu'r calendr mewn {countdown} eiliad","Dad-rannu'r calendr mewn {countdown} eiliad","Dad-rannu'r calendr mewn {countdown} eiliad"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Wrthi'n dileu'r calendr ymhen {countdown} eiliad","Yn dileu'r calendr mewn {countdown} eiliad","Yn dileu'r calendr mewn {countdown} eiliad","Yn dileu'r calendr mewn {countdown} eiliad"],
    "An error occurred, unable to create the calendar." : "Bu gwall, ni fu modd creu'r calendr.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Rhowch ddolen ddilys (gan ddechrau gyda http://, https://, webcal://, neu webcals://)",
    "Add new" : "Ychwanegu newydd",
    "New calendar" : "Calendr newydd",
    "Name for new calendar" : "Enw ar gyfer calendr newydd",
    "Creating calendar …" : "Wrthi'n creu calendr …",
    "New calendar with task list" : "Calendr newydd gyda rhestr dasgau",
    "New subscription from link (read-only)" : "Tanysgrifiad newydd o'r ddolen (darllen yn unig)",
    "Creating subscription …" : "Wrthi'n creu tanysgrifiad …",
    "Copy subscription link" : "Copïo dolen tanysgrifiad",
    "Copying link …" : "Wrthi'n copïo dolen …",
    "Copied link" : "Dolen wedi'i chopïo",
    "Could not copy link" : "Methu â chopïo'r ddolen",
    "Export" : "Allforio",
    "Unknown calendar" : "Calendr anhysbys",
    "Could not load deleted calendars and objects" : "Methu llwytho calendrau a gwrthrychau wedi'u dileu",
    "Could not restore calendar or event" : "Methu ag adfer calendr neu ddigwyddiad",
    "Do you really want to empty the trash bin?" : "Ydych chi wir eisiau gwagio'r bin sbwriel?",
    "Empty trash bin" : "Bin sbwriel gwag",
    "Trash bin" : "Bin sbwriel",
    "Name" : "Enw",
    "Deleted" : "Wedi dileu",
    "Restore" : "Adfer",
    "Delete permanently" : "Dileu'n barhaol",
    "Could not update calendar order." : "Methu â diweddaru trefn y calendr.",
    "An error occurred, unable to publish calendar." : "Bu gwall, ni fu modd cyhoeddi'r calendr.",
    "An error occurred, unable to send email." : "Bu gwall, ni fu modd anfon e-bost.",
    "Embed code copied to clipboard." : "Mewnosod cod wedi'i gopïo i'r clipfwrdd.",
    "Embed code could not be copied to clipboard." : "Nid oedd modd copïo'r cod mewnosod i'r clipfwrdd.",
    "Unpublishing calendar failed" : "Methwyd â dadgyhoeddi'r calendr",
    "Share link" : "Rhannu dolen",
    "Send link to calendar via email" : "Anfon dolen i'r calendr trwy e-bost",
    "Enter one address" : "Rhowch un cyfeiriad",
    "Sending email …" : "Wrthi'n anfon e-bost …",
    "Copy embedding code" : "Copïo cod mewnosod",
    "Copying code …" : "Wrthi'n copïo cod …",
    "Copied code" : "Cod wedi'i gopïo",
    "Could not copy code" : "Methu â chopïo'r cod",
    "Delete share link" : "Dileu dolen rhannu",
    "Deleting share link …" : "Wrthi'n dileu dolen rhannu …",
    "An error occurred, unable to change the permission of the share." : "Bu gwall, ni fu modd newid caniatâd y gyfran.",
    "Unshare with {displayName}" : "Dadrannu gyda {displayName}",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "None" : "Dim",
    "Unshare from me" : "Dadrannwch oddi wrthyf",
    "Save" : "Cadw",
    "Cancel" : "Diddymu",
    "View" : "Golwg",
    "Busy" : "Prysur",
    "Free" : "Am ddim",
    "Tentative" : "I'w gadarnhau",
    "Icons" : "Eiconau",
    "Attendees" : "Mynychwyr",
    "Import calendars" : "Mewnforio calendrau",
    "Please select a calendar to import into …" : "Dewiswch galendr i fewnforio iddo …",
    "Filename" : "Enw ffeil",
    "Calendar to import into" : "Calendr i fewnforio iddo",
    "_Import calendar_::_Import calendars_" : ["Mewnforio'r calendr","Mewnforio calendrau","Mewnforio calendrau","Mewnforio calendrau"],
    "Editor" : "gafygau",
    "{filename} could not be parsed" : "Nid oedd modd dosrannu {filename}",
    "No valid files found, aborting import" : "Heb ganfod ffeiliau dilys, yn rhoi'r gorau i fewnforio",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Wedi mewnforio %n digwyddiad yn llwyddiannus","Wedi mewnforio %n digwyddiad yn llwyddiannus","Wedi mewnforio %n digwyddiad yn llwyddiannus","Wedi mewnforio %n digwyddiad yn llwyddiannus"],
    "Import partially failed. Imported {accepted} out of {total}." : "Methodd mewnforio yn rhannol. Wedi mewnforio {accepted} allan o {total}.",
    "Automatic" : "Awtomatig",
    "Automatic ({timezone})" : "Awtomatig  ({timezone})",
    "New setting was not saved successfully." : "Ni chafodd y gosodiad newydd ei gadw'n llwyddiannus.",
    "Timezone" : "Cylch amser",
    "Navigation" : "Llywio",
    "Previous period" : "Cyfnod blaenorol",
    "Next period" : "Cyfnod nesaf",
    "Views" : "Dangosiadau",
    "Day view" : "Golwg dydd",
    "Week view" : "Golwg wythnos",
    "Month view" : "Golwg mis",
    "List view" : "Golwg rhestr",
    "Actions" : "Gweithredoedd",
    "Create event" : "Creu digwyddiad",
    "Show shortcuts" : "Dangos llwybrau byr",
    "Close editor" : "Cau'r golygydd",
    "Save edited event" : "Cadw digwyddiad wedi'i olygu",
    "Delete edited event" : "Dileu digwyddiad wedi'i olygu",
    "or" : "neu",
    "No reminder" : "Dim nodyn atgoffa",
    "General" : "Cyffredinol",
    "0 minutes" : "0 munud",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} munud","{duration} funud","{duration} munud","{duration} munud"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} awr","{duration} awr","{duration} awr","{duration} awr"],
    "_{duration} day_::_{duration} days_" : ["{duration} diwrnod","{duration} ddiwrnod","{duration} diwrnod","{duration} diwrnod"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} wythnos","{duration} wythnos","{duration} wythnos","{duration} wythnos"],
    "_{duration} month_::_{duration} months_" : ["{duration} mis","{duration} fis","{duration} mis","{duration} mis"],
    "_{duration} year_::_{duration} years_" : ["{duration} blwyddyn","{duration} flynedd","{duration} blynedd","{duration} blynedd"],
    "To configure appointments, add your email address in personal settings." : "I ffurfweddu apwyntiadau, ychwanegwch eich cyfeiriad e-bost yn y gosodiadau personol.",
    "Update" : "Diweddaru",
    "Location" : "Lleoliad",
    "Description" : "Disgrifiad",
    "Increments" : "Cynyddiadau",
    "Visibility" : "Gwelededd",
    "to" : "at",
    "Delete slot" : "Dileu slot",
    "No times set" : "Dim amseroedd wedi'u gosod",
    "Add" : "Ychwanegu",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sunday" : "Sul",
    "Planning restrictions" : "Cyfyngiadau cynllunio",
    "Max slots per day" : "Uchafswm slotiau y dydd",
    "Limit how far in the future appointments can be booked" : "Cyfyngu ar ba mor bell yn y dyfodol y mae modd trefnu apwyntiadau",
    "Please confirm your reservation" : "Cadarnhewch eich archeb",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Rydym wedi anfon e-bost atoch gyda'r manylion. Cadarnhewch eich apwyntiad gan ddefnyddio'r ddolen yn yr e-bost. Gallwch chi gau'r dudalen hon nawr.",
    "Your name" : "Eich enw",
    "Your email address" : "Cyfeiriad E-bost",
    "Please share anything that will help prepare for our meeting" : "Rhannwch unrhyw beth a fydd yn helpu i baratoi ar gyfer ein cyfarfod",
    "Could not book the appointment. Please try again later or contact the organizer." : "Methu trefnu apwyntiad. Ceisiwch eto yn nes ymlaen neu cysylltwch â'r trefnydd.",
    "on" : "ar",
    "at" : "am",
    "before at" : "cyn am",
    "Notification" : "Hysbysiad",
    "Email" : "E-bost",
    "Audio notification" : "Hysbysiad sain",
    "Other notification" : "Hysbysiad arall",
    "Relative to event" : "Mewn perthynas â digwyddiad",
    "On date" : "Ar ddyddiad",
    "Edit time" : "Golygu amser",
    "Save time" : "Arbed amser",
    "Remove reminder" : "Dileu nodyn atgoffa",
    "Add reminder" : "Ychwanegu nodyn atgoffa",
    "seconds" : "eiliad",
    "minutes" : "munud",
    "hours" : "awr",
    "days" : "diwrnod",
    "weeks" : "wythnos",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "Suggested" : "Awgrym",
    "Available" : "Ar gael?",
    "Invitation accepted" : "Derbyniwyd y gwahoddiad",
    "Accepted {organizerName}'s invitation" : "Derbyniwyd y gwahoddiad {organizerName}",
    "Participation marked as tentative" : "Cyfrannu wedi'i nodi fel o bosib",
    "Invitation is delegated" : "Mae gwahoddiad yn cael ei ddirprwyo",
    "Not available" : "Ddim ar gael",
    "Invitation declined" : "Gwrthodwyd y gwahoddiad",
    "Declined {organizerName}'s invitation" : "Gwrthodwyd gwahoddiad {organizerName}",
    "Checking availability" : "Gwirio argaeledd",
    "Has not responded to {organizerName}'s invitation yet" : "Nid yw wedi ymateb i wahoddiad {organizerName} eto",
    "Duration" : "Hyd",
    "Custom" : "Cyfaddas",
    "{organizer} (organizer)" : "{organizer} (trefnydd)",
    "Availability of attendees, resources and rooms" : "Argaeledd mynychwyr, adnoddau ac ystafelloedd",
    "Out of office" : "Allan o'r swyddfa",
    "Busy (tentative)" : "Prysur (o bosib)",
    "Unknown" : "Anhysbys",
    "The invitation has been accepted successfully." : "Derbyniwyd y gwahoddiad yn llwyddiannus.",
    "Failed to accept the invitation." : "Methwyd â derbyn y gwahoddiad.",
    "The invitation has been declined successfully." : "Gwrthodwyd y gwahoddiad yn llwyddiannus.",
    "Failed to decline the invitation." : "Methwyd â gwrthod y gwahoddiad.",
    "Your participation has been marked as tentative." : "Mae eich cyfranogiad wedi'i nodi fel o bosib.",
    "Failed to set the participation status to tentative." : "Wedi methu â gosod y statws cyfranogiad i o bosib.",
    "Accept" : "Derbyn",
    "Decline" : "Gwrthod",
    "Copied to clipboard" : "Wedi'i gopïo i'r clipfwrdd",
    "No attendees yet" : "Dim mynychwyr eto",
    "Status" : "Statws",
    "Chairperson" : "Cadeirydd",
    "Required participant" : "Cyfranogwr gofynnol",
    "Optional participant" : "Cyfranogwr dewisol",
    "Non-participant" : "Nid cyfranogwr",
    "Remove attendee" : "Dileu mynychwr",
    "No match found" : "Heb ganfod cyfatebiaeth",
    "(organizer)" : "(trefnydd)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "I anfon gwahoddiadau a thrin ymatebion, [linkopen]ychwanegwch eich cyfeiriad e-bost yn y gosodiadau personol[linkclose].",
    "Remove color" : "Tynnu lliw",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nid oes modd addasu gosodiad diwrnod cyfan ar gyfer digwyddiadau sy'n rhan o set ailadrodd.",
    "Repeat" : "Ailadrodd",
    "never" : "byth",
    "on date" : "ar ddyddiad",
    "after" : "wedi",
    "End repeat" : "Gorffen ailadrodd",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Mae'r digwyddiad hwn yn eithriad i ddigwyddiadau o set sy'n ailadrodd. Ni allwch ychwanegu rheol ailadrodd ato.",
    "first" : "cyntaf",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Dim ond i hwn a phob digwyddiad yn y dyfodol y bydd newidiadau i'r rheol ailadrodd yn berthnasol.",
    "Repeat every" : "Ailadrodd bob",
    "By day of the month" : "Yn ôl dydd o'r mis",
    "On the" : "Ar y",
    "_day_::_days_" : ["diwrnod","diwrnod","diwrnod","diwrnod"],
    "_week_::_weeks_" : ["wythnos","wythnos","wythnos","wythnos"],
    "_month_::_months_" : ["mis","mis","mis","mis"],
    "_year_::_years_" : ["blwyddyn","blwyddyn","flwyddyn","blwyddyn"],
    "weekday" : "yn ystod yr wythnos",
    "weekend day" : "diwrnod penwythnos",
    "Does not repeat" : "Nid yw'n ailadrodd",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nid yw Nextcloud yn cefnogi'r diffiniad sy'n ailadrodd y digwyddiad hwn yn llawn. Os ydych chi'n golygu'r opsiynau ailadrodd, mae'n bosibl y byddwch chi'n colli rhai ailadroddiadau.",
    "No rooms or resources yet" : "Dim ystafelloedd nac adnoddau eto",
    "Resources" : "Adnoddau",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedd","{seatingCapacity} sedd","{seatingCapacity} sedd","{seatingCapacity} sedd"],
    "Add resource" : "Ychwanegu adnodd",
    "Has a projector" : "Taflunydd yno",
    "Has a whiteboard" : "Bwrdd gwyn yno",
    "Wheelchair accessible" : "Hygyrch i gadeiriau olwyn",
    "Remove resource" : "Dileu adnodd",
    "Search for resources or rooms" : "Chwilio am adnoddau neu ystafelloedd",
    "available" : "ar gael",
    "unavailable" : "ddim ar gael",
    "Projector" : "Taflunydd",
    "Whiteboard" : "Bwrdd gwyn",
    "Room type" : "Math o ystafell",
    "Any" : "Unrhyw",
    "Minimum seating capacity" : "Lleiafswm seddi",
    "Update this and all future" : "Diweddaru hwn a phob un i'r dyfodol",
    "Update this occurrence" : "Diweddaru'r digwyddiad hwn",
    "Public calendar does not exist" : "Nid oes calendr cyhoeddus yn bodoli",
    "Maybe the share was deleted or has expired?" : "Efallai bod y gyfran wedi'i dileu neu wedi dod i ben?",
    "Yes" : "Ie",
    "No" : "Na",
    "Type to search time zone" : "Teipiwch i chwilio'r gylchfa amser",
    "Global" : "Eang",
    "Subscribe" : "Tanysgrifio",
    "Select slot" : "Dewiswch slot",
    "No slots available" : "Dim slotiau ar gael",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Diolch. Mae eich archeb o {startDate} i {endDate} wedi'i chadarnhau.",
    "Book another appointment:" : "Trefnwch apwyntiad arall:",
    "See all available slots" : "Gweler yr holl slotiau sydd ar gael",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Nid yw'r slot ar gyfer eich apwyntiad o {startDate} i {endDate} ar gael mwyach.",
    "Please book a different slot:" : "Archebwch slot gwahanol:",
    "Book an appointment with {name}" : "Trefnwch apwyntiad gyda {name}",
    "No public appointments found for {name}" : "Heb ganfod unrhyw apwyntiadau cyhoeddus ar gyfer {name}",
    "Personal" : "Personol",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Penderfynodd y darganfyddiad parth amser awtomatig mai UTC oedd eich parth amser.\nMae hyn yn fwyaf tebygol o ganlyniad i fesurau diogelwch eich porwr gwe.\nGosodwch eich cylchfa amser â llaw yng ngosodiadau'r calendr.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Heb ganfod eich cylchfa amser ffurfweddu ({timezoneId}). Mynd nôl i UTC.\nNewidiwch eich cylchfa amser yn y gosodiadau ac adroddwch am y mater hwn.",
    "Edit event" : "Golygu digwyddiad",
    "Event does not exist" : "Nid yw'r digwyddiad yn bodoli",
    "Delete this occurrence" : "Dileu'r digwyddiad hwn",
    "Delete this and all future" : "Dileu hwn a phob dyfodol",
    "All day" : "Drwy'r dydd",
    "Invite" : "Gwahoddiad",
    "Untitled event" : "Digwyddiad di-deitl",
    "Close" : "Cau",
    "Subscribe to {name}" : "Tanysgrifio i {name}",
    "Export {name}" : "Allforio {name}",
    "Anniversary" : "Dathliad",
    "Appointment" : "Apwyntiad",
    "Business" : "Busnes",
    "Education" : "Addysg",
    "Holiday" : "Gwyliau",
    "Meeting" : "Cyfarfod",
    "Miscellaneous" : "Amrywiol",
    "Non-working hours" : "Oriau heb fod yn waith",
    "Not in office" : "Ddim yn y swyddfa",
    "Phone call" : "Galwad ffôn",
    "Sick day" : "Diwrnod yn sâl",
    "Special occasion" : "Achlysur arbennig",
    "Travel" : "Teithio",
    "Vacation" : "Gwyliau",
    "Midnight on the day the event starts" : "Hanner nos ar y diwrnod y mae'r digwyddiad yn dechrau",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n diwrnod cyn y digwyddiad am {formattedHourMinute}","%n ddiwrnod cyn y digwyddiad am {formattedHourMinute}","%n diwrnod cyn y digwyddiad am {formattedHourMinute}","%n diwrnod cyn y digwyddiad am {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n wythnos cyn y digwyddiad am {formattedHourMinute}","%n wythnos cyn y digwyddiad am {formattedHourMinute}","%n wythnos cyn y digwyddiad am {formattedHourMinute}","%n wythnos cyn y digwyddiad am {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "ar ddiwrnod y digwyddiad am {formattedHourMinute}",
    "at the event's start" : "ar ddechrau'r digwyddiad",
    "at the event's end" : "ar ddiwedd y digwyddiad",
    "{time} before the event starts" : "{time} cyn i'r digwyddiad ddechrau",
    "{time} before the event ends" : "{time} cyn i'r digwyddiad ddod i ben",
    "{time} after the event starts" : "{time} ar ôl i'r digwyddiad ddechrau",
    "{time} after the event ends" : "{time} ar ôl i'r digwyddiad ddod i ben",
    "on {time}" : "ar {time}",
    "on {time} ({timezoneId})" : "ar {time} ({timezoneId})",
    "Week {number} of {year}" : "Wythnos {number} o {year}",
    "Daily" : "Dyddiol",
    "Weekly" : "Wythnosol",
    "Monthly" : "Misol",
    "Yearly" : "Blynyddol",
    "_Every %n day_::_Every %n days_" : ["Bob %n diwrnod","Bob %n ddiwrnod","Bob %n diwrnod","Bob %n diwrnod"],
    "_Every %n week_::_Every %n weeks_" : ["Bob %n wythnos","Bob %n wythnos","Bob %n wythnos","Bob %n wythnos"],
    "_Every %n month_::_Every %n months_" : ["Bob %n mis","Bob %n fis","Bob %n mis","Bob %n mis"],
    "_Every %n year_::_Every %n years_" : ["Bob %n blwyddyn","Bob %n flynedd","Bob %n blynedd","Bob %n mlynedd"],
    "_on {weekday}_::_on {weekdays}_" : ["ar {weekday}","ar {weekdays}","ar {weekdays}","ar {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["ar ddiwrnod {dayOfMonthList}","ar ddiwrnodau {dayOfMonthList}","ar ddiwrnodau {dayOfMonthList}","ar ddiwrnodau {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ar y {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "yn {monthNames} ar y {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "tan {untilDate}",
    "_%n time_::_%n times_" : ["%n waith","%n o weithiau","%n o weithiau","%n o weithiau"],
    "second" : "ail",
    "third" : "trydydd",
    "fourth" : "pedwerydd",
    "fifth" : "pumed",
    "second to last" : "ail i olaf",
    "last" : "o;af",
    "Untitled task" : "Tasg di-deitl",
    "Please ask your administrator to enable the Tasks App." : "Gofynnwch i'ch gweinyddwr alluogi'r Ap Tasgau.",
    "W" : "M",
    "%n more" : "%n arall",
    "No events to display" : "Dim digwyddiadau i'w dangos",
    "_+%n more_::_+%n more_" : ["+%n arall","+%n arall","+%n arall","+%n arall"],
    "No events" : "Dim digwyddiadau",
    "Create a new event or change the visible time-range" : "Creu digwyddiad newydd neu newid yr ystod amser gweladwy",
    "It might have been deleted, or there was a typo in a link" : "Efallai ei fod wedi'i ddileu, neu roedd gwall mewn dolen",
    "It might have been deleted, or there was a typo in the link" : "Efallai ei fod wedi'i ddileu, neu fod gwall yn y ddolen",
    "Meeting room" : "Ystafell cyfarfod",
    "Lecture hall" : "Neuadd ddarlithio",
    "Seminar room" : "Ystafell seminar",
    "Other" : "Arall",
    "When shared show" : "Wrth rannu dangos",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Add a location" : "Ychwanegu lleoliad",
    "Confirmed" : "Cadarnhawyd",
    "Canceled" : "Wedi diddymu",
    "Confirmation about the overall status of the event." : "Cadarnhad o statws cyffredinol y digwyddiad.",
    "Show as" : "Dangos fel",
    "Take this event into account when calculating free-busy information." : "Cymerwch y digwyddiad hwn i ystyriaeth wrth gyfrifo gwybodaeth amser rhydd-prysur.",
    "Categories" : "Categorïau",
    "Categories help you to structure and organize your events." : "Mae categorïau yn eich helpu i strwythuro a threfnu eich digwyddiadau.",
    "Search or add categories" : "Chwilio am neu ychwanegu categorïau",
    "Add this as a new category" : "Ychwanegu hwn fel categori newydd",
    "Custom color" : "Lliw personol",
    "Special color of this event. Overrides the calendar-color." : "Lliw arbennig y digwyddiad hwn. Yn diystyru lliw y calendr.",
    "An error occurred, unable to delete the calendar." : "Bu gwall, ni fu modd dileu'r calendr.",
    "Imported {filename}" : "Mewnforiwyd {filename}",
    "Appointment not found" : "Apwyntiad heb ei ganfod",
    "User not found" : "Defnyddiwr heb ei ganfod",
    "Hidden" : "Cudd",
    "Automatic ({detected})" : "Awtomatig ({detected})",
    "Shortcut overview" : "Trosolwg llwybr byr",
    "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
    "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
    "Enable simplified editor" : "Galluogi golygydd symlach",
    "Show weekends" : "Dangos penwythnosau",
    "Show week numbers" : "Dangos rhifau wythnosau",
    "Time increments" : "Cynyddiadau amser",
    "Default reminder" : "Nodyn atgoffa rhagosodedig",
    "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
    "Personal availability settings" : "Gosodiadau argaeledd personol",
    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
    "Public – shown on the profile page" : "Cyhoeddus – dangos ar y dudalen proffil",
    "Private – only accessible via secret link" : "Preifat – dim ond ar gael trwy gyswllt cyfrinachol",
    "Additional calendars to check for conflicts" : "Calendrau ychwanegol i wirio am wrthdrawoiadau",
    "Pick time ranges where appointments are allowed" : "Dewiswch ystodau amser lle apwyntiadau'n cael eu caniatáu",
    "Add time before and after the event" : "Ychwanegu amser cyn ac ar ôl y digwyddiad",
    "Before the event" : "Cyn y digwyddiad",
    "After the event" : "Ar ôl y digwyddiad",
    "Minimum time before next available slot" : "Lleiafswm amser cyn y slot nesaf sydd ar gael",
    "Successfully appended link to talk room to description." : "Llwyddwyd i atodi dolen i'r ystafell siarad i'r disgrifiad.",
    "Error creating Talk room" : "Gwall wrth greu ystafell Siarad",
    "Event title" : "Teitl y digwyddiad",
    "_time_::_times_" : ["amser","gwaith","gwaith","gwaith"],
    "Select to end repeat" : "Dewiswch i orffen ailadrodd",
    "from {formattedDate}" : "o {formattedDate}",
    "to {formattedDate}" : "i {formattedDate}",
    "on {formattedDate}" : "ar {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "o {formattedDate} am {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "i {formattedDate} am {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "ar {formattedDate} am {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} am {formattedTime}",
    "Please enter a valid date" : "Rhowch ddyddiad dilys",
    "Please enter a valid date and time" : "Rhowch ddyddiad ac amser dilys",
    "Please select a time zone:" : "Dewiswch gylchfa amser:",
    "Pick a time" : "Dewiswch amser",
    "Pick a date" : "Dewiswch ddyddiad",
    "The slot for your appointment has been confirmed" : "Mae'r slot ar gyfer eich apwyntiad wedi'i gadarnhau",
    "Appointment Details:" : "Manylion Apwyntiad:",
    "Time:" : "Dewis amser",
    "Booked for:" : "Archebwyd ar gyfer:"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
