"use strict";(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["node_modules_nextcloud_vue_dist_components_NcColorPicker_index_mjs"],{71415(e,s,c){c.r(s);var d=c(15135);c.d(s,{default:()=>d.N})}}]);