"use strict";(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["defaultVendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-DWYoSaVg_mjs-node_module-4c3472"],{286(e,t,i){let l;i.d(t,{default:()=>td});var a,n,r=i(20641),o=i(90033),s=i(50953),d=i(53751),u=i(61338),c=i(94434),p=i(37523),v=i(50240),f=i(44931),m=i(15446),h=i(86296),g=i(71225),y=i(10997),k=i(9165);(a=n||(n={}))[a.User=0]="User",a[a.Group=1]="Group",a[a.Link=3]="Link",a[a.Email=4]="Email",a[a.Remote=6]="Remote",a[a.Team=7]="Team",a[a.Guest=8]="Guest",a[a.RemoteGroup=9]="RemoteGroup",a[a.Room=10]="Room",a[a.Deck=12]="Deck",a[a.FederatedGroup=14]="FederatedGroup",a[a.ScienceMesh=15]="ScienceMesh";var w=i(82510),_=i(43016),b=i(3133),C=i(29504),E=i(81222),R=i(63814);function L(){return(0,E.C)("files_sharing","isPublic",null)??null!==document.querySelector('input#isPublic[type="hidden"][name="isPublic"][value="1"]')}var F=i(39771),S=i(15797),z=i(66139),X=i(4055),W=i(21777),D=i(3710),N=i(79455);function P(){return(0,E.C)("files_sharing","isPublic",null)??null!==document.querySelector('input#isPublic[type="hidden"][name="isPublic"][value="1"]')}var $=i(44719),V=i(70970);let x=["d:getcontentlength","d:getcontenttype","d:getetag","d:getlastmodified","d:creationdate","d:displayname","d:quota-available-bytes","d:resourcetype","nc:has-preview","nc:is-encrypted","nc:mount-type","oc:comments-unread","oc:favorite","oc:fileid","oc:owner-display-name","oc:owner-id","oc:permissions","oc:size"],B={d:"DAV:",nc:"http://nextcloud.org/ns",oc:"http://owncloud.org/ns",ocs:"http://open-collaboration-services.org/ns"};function M(){return V.s.davProperties??=[...x],V.s.davProperties.map(e=>`<${e} />`).join(" ")}function A(){return V.s.davNamespaces??={...B},Object.keys(V.s.davNamespaces).map(e=>`xmlns:${e}="${V.s.davNamespaces?.[e]}"`).join(" ")}function I(){return`<?xml version="1.0"?>
		<d:propfind ${A()}>
			<d:prop>
				${M()}
			</d:prop>
		</d:propfind>`}let H=P()?`/files/${(0,E.C)("files_sharing","sharingToken",null)??document.querySelector('input#sharingToken[type="hidden"]')?.value??null}`:`/files/${(0,W.HW)()?.uid}`,K=(l=(0,R.dC)("dav"),P()?l.replace("remote.php","public.php"):l);function T(e=K,t={}){let i=(0,$.UU)(e,{headers:t});function l(e){i.setHeaders({...t,"X-Requested-With":"XMLHttpRequest",requesttoken:e??""})}return(0,W.zo)(l),l((0,W.do)()),(0,$.Gu)().patch("fetch",(e,t)=>{let i=t.headers;return i?.method&&(t.method=i.method,delete i.method),fetch(e,t)}),i}async function U(e={}){let t=e.client??T(),i=e.path??"/",l=e.davRoot??H;return(await t.getDirectoryContents(`${l}${i}`,{signal:e.signal,details:!0,data:`<?xml version="1.0"?>
		<oc:filter-files ${A()}>
			<d:prop>
				${M()}
			</d:prop>
			<oc:filter-rules>
				<oc:favorite>1</oc:favorite>
			</oc:filter-rules>
		</oc:filter-files>`,headers:{method:"REPORT"},includeSelf:!0})).data.filter(e=>e.filename!==i).map(e=>q(e,l))}function q(e,t=H,i=K){let l=(0,W.HW)()?.uid;if(P())l=l??"anonymous";else if(!l)throw Error("No user id found");let a=e.props,n=function(e=""){let t=V.P.NONE;return e&&(e.includes("G")&&(t|=V.P.READ),e.includes("W")&&(t|=V.P.WRITE),e.includes("CK")&&(t|=V.P.CREATE),e.includes("NV")&&(t|=V.P.UPDATE),e.includes("D")&&(t|=V.P.DELETE),e.includes("R")&&(t|=V.P.SHARE)),t}(a?.permissions),r=String(a?.["owner-id"]||l),o=a.fileid||0,s=new Date(Date.parse(e.lastmod)),d=new Date(Date.parse(a.creationdate)),u={id:o,source:`${i}${e.filename}`,mtime:isNaN(s.getTime())||0===s.getTime()?void 0:s,crtime:isNaN(d.getTime())||0===d.getTime()?void 0:d,mime:e.mime||"application/octet-stream",displayname:void 0!==a.displayname?String(a.displayname):void 0,size:a?.size||Number.parseInt(a.getcontentlength||"0"),status:o<0?V.c.FAILED:void 0,permissions:n,owner:r,root:t,attributes:{...e,...a,hasPreview:a?.["has-preview"]}};return delete u.attributes?.props,"file"===e.type?new V.a(u):new V.b(u)}let Q=["aria-hidden","aria-label"],j=["fill","width","height"],G={d:"M13,9V3.5L18.5,9M6,2C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2H6Z"},Z={key:0},O=(0,v._)({name:"FileIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon file-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",G,[i.title?((0,r.uX)(),(0,r.CE)("title",Z,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,j))],16,Q)}]]),J=["aria-hidden","aria-label"],Y=["fill","width","height"],ee={d:"M7,10L12,15L17,10H7Z"},et={key:0},ei=(0,v._)({name:"MenuDownIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon menu-down-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",ee,[i.title?((0,r.uX)(),(0,r.CE)("title",et,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,Y))],16,J)}]]),el=["aria-hidden","aria-label"],ea=["fill","width","height"],en={d:"M7,15L12,10L17,15H7Z"},er={key:0},eo=(0,v._)({name:"MenuUpIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon menu-up-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",en,[i.title?((0,r.uX)(),(0,r.CE)("title",er,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,ea))],16,el)}]]),es=["aria-hidden","aria-label"],ed=["fill","width","height"],eu={d:"M10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6H12L10,4Z"},ec={key:0},ep=(0,v._)({name:"FolderIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon folder-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",eu,[i.title?((0,r.uX)(),(0,r.CE)("title",ec,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,ed))],16,es)}]]),ev={"file-picker__file-icon":"_file-picker__file-icon_1aykw_9","file-picker__file-icon--primary":"_file-picker__file-icon--primary_1aykw_22","file-picker__file-icon-overlay":"_file-picker__file-icon-overlay_1aykw_26"},ef=(0,r.pM)({__name:"FilePreview",props:{node:{},cropImagePreviews:{type:Boolean}},setup(e){let t=(0,s.KR)(ev),{previewURL:i,previewLoaded:l}=(0,_.u)((0,s.lW)(e,"node"),(0,r.EW)(()=>({cropPreview:e.cropImagePreviews}))),a=(0,r.EW)(()=>e.node.type===f.pt.File),d=(0,r.EW)(()=>{if(e.node.type!==f.pt.Folder)return null;if(e.node.attributes?.["is-encrypted"]===1)return k.EYN;if(e.node.attributes?.["is-tag"])return k.bTm;let t=Object.values(e.node.attributes?.["share-types"]||{}).flat();if(t.some(e=>e===n.Link||e===n.Email))return k.Brj;if(t.length>0)return k.IyB;switch(e.node.attributes?.["mount-type"]){case"external":case"external-session":return k.VR;case"group":return k.dgQ;case"shared":return k.IyB}return null});return(e,n)=>((0,r.uX)(),(0,r.CE)("div",{style:(0,o.normalizeStyle)((0,s.R1)(l)?{backgroundImage:`url(${(0,s.R1)(i)})`}:void 0),class:(0,o.normalizeClass)(t.value["file-picker__file-icon"])},[(0,s.R1)(l)?(0,r.Q3)("",!0):((0,r.uX)(),(0,r.CE)(r.FK,{key:0},[a.value?((0,r.uX)(),(0,r.Wv)(O,{key:0,size:32})):((0,r.uX)(),(0,r.CE)(r.FK,{key:1},[d.value?((0,r.uX)(),(0,r.Wv)((0,s.R1)(w.A),{key:0,class:(0,o.normalizeClass)(t.value["file-picker__file-icon-overlay"]),inline:"",path:d.value,size:16},null,8,["class","path"])):(0,r.Q3)("",!0),(0,r.bF)(ep,{class:(0,o.normalizeClass)(t.value["file-picker__file-icon--primary"]),size:32},null,8,["class"])],64))],64))],6))}}),em=["tabindex","aria-selected","data-filename"],eh={class:"row-name"},eg={class:"file-picker__name-container","data-testid":"row-name"},ey=["title","textContent"],ek=["textContent"],ew={class:"row-size"},e_={class:"row-modified"},eb=(0,r.pM)({__name:"FileListRow",props:{allowPickDirectory:{type:Boolean},selected:{type:Boolean},showCheckbox:{type:Boolean},canPick:{type:Boolean},node:{},cropImagePreviews:{type:Boolean}},emits:["update:selected","enterDirectory"],setup(e,{emit:t}){let i=(0,r.EW)(()=>e.node.mtime??0),l=(0,r.EW)(()=>(0,g.LC)(e.node.displayname)),a=(0,r.EW)(()=>e.node.displayname.slice(0,l.value?-l.value.length:void 0)),n=(0,r.EW)(()=>e.node.type===f.pt.Folder),u=(0,r.EW)(()=>e.canPick&&(e.allowPickDirectory||!n.value)),c=(0,r.EW)(()=>(e.node.permissions&f.aX.READ)===f.aX.READ);function p(){u.value&&t("update:selected",!e.selected)}function v(){n.value?c.value&&t("enterDirectory",e.node):p()}function m(e){"Enter"===e.key&&v()}return(t,g)=>((0,r.uX)(),(0,r.CE)("tr",(0,r.v6)({tabindex:e.showCheckbox&&!n.value?void 0:0,"aria-selected":u.value?e.selected:void 0,class:["file-picker__row",[{"file-picker__row--selected":e.selected&&!e.showCheckbox,"file-picker__row--not-navigatable":n.value&&!c.value,"file-picker__row--not-pickable":!u.value}]],"data-filename":e.node.basename,"data-testid":"file-list-row"},(0,r.Tb)({click:v,...!e.showCheckbox||n.value?{keydown:m}:{}},!0)),[e.showCheckbox?((0,r.uX)(),(0,r.CE)("td",{key:0,class:"row-checkbox",onClick:(0,d.withModifiers)(()=>{},["stop"])},[(0,r.bF)((0,s.R1)(h.A),{"aria-label":(0,s.R1)(b.t)("Select the row for {nodename}",{nodename:a.value}),disabled:!u.value,"data-testid":"row-checkbox",modelValue:e.selected,"onUpdate:modelValue":p},null,8,["aria-label","disabled","modelValue"])])):(0,r.Q3)("",!0),(0,r.Lk)("td",eh,[(0,r.Lk)("div",eg,[(0,r.bF)(ef,{node:e.node,cropImagePreviews:e.cropImagePreviews},null,8,["node","cropImagePreviews"]),(0,r.Lk)("div",{class:"file-picker__file-name",title:a.value,textContent:(0,o.toDisplayString)(a.value)},null,8,ey),(0,r.Lk)("div",{class:"file-picker__file-extension",textContent:(0,o.toDisplayString)(l.value)},null,8,ek)])]),(0,r.Lk)("td",ew,(0,o.toDisplayString)((0,s.R1)(f.v7)(e.node.size||0)),1),(0,r.Lk)("td",e_,[(0,r.bF)((0,s.R1)(y.A),{timestamp:i.value,ignoreSeconds:""},null,8,["timestamp"])])],16,em))}}),eC=(0,v._)(eb,[["__scopeId","data-v-7857e8bd"]]),eE={"aria-hidden":"true",class:"file-picker__row loading-row"},eR={key:0,class:"row-checkbox"},eL={class:"row-name"},eF={class:"row-wrapper"},eS=(0,r.pM)({__name:"LoadingTableRow",props:{showCheckbox:{type:Boolean}},setup:e=>(t,i)=>((0,r.uX)(),(0,r.CE)("tr",eE,[e.showCheckbox?((0,r.uX)(),(0,r.CE)("td",eR,[...i[0]||(i[0]=[(0,r.Lk)("span",null,null,-1)])])):(0,r.Q3)("",!0),(0,r.Lk)("td",eL,[(0,r.Lk)("div",eF,[(0,r.Lk)("span",{class:(0,o.normalizeClass)((0,s.R1)(ev)["file-picker__file-icon"])},null,2),i[1]||(i[1]=(0,r.Lk)("span",null,null,-1))])]),i[2]||(i[2]=(0,r.Lk)("td",{class:"row-size"},[(0,r.Lk)("span")],-1)),i[3]||(i[3]=(0,r.Lk)("td",{class:"row-modified"},[(0,r.Lk)("span")],-1))]))}),ez=(0,v._)(eS,[["__scopeId","data-v-1f96131b"]]);function eX(){let e=(0,E.C)("files","config",null),t=(0,s.KR)(e?.show_hidden??!0),i=(0,s.KR)(e?.sort_favorites_first??!0),l=(0,s.KR)(e?.crop_image_previews??!0);return(0,r.sV)(async()=>{if(L())b.l.debug("Skip loading files settings - currently on public share");else try{let{data:e}=await C.Ay.get((0,R.Jv)("/apps/files/api/v1/configs"));t.value=e?.data?.show_hidden??!1,i.value=e?.data?.sort_favorites_first??!0,l.value=e?.data?.crop_image_previews??!0}catch(e){b.l.error("Could not load files settings",{error:e}),(0,b.s)((0,b.t)("Could not load files settings"))}}),{showHiddenFiles:t,sortFavoritesFirst:i,cropImagePreviews:l}}let eW={key:0,class:"row-checkbox"},eD={class:"hidden-visually"},eN=["aria-sort"],eP={class:"header-wrapper"},e$={key:2,style:{width:"44px"}},eV=["aria-sort"],ex={key:2,style:{width:"44px"}},eB=["aria-sort"],eM={key:2,style:{width:"44px"}},eA=(0,r.pM)({__name:"FileList",props:(0,r.zz)({currentView:{},multiselect:{type:Boolean},allowPickDirectory:{type:Boolean},loading:{type:Boolean},files:{},canPick:{type:Function}},{path:{required:!0},pathModifiers:{},selectedFiles:{required:!0},selectedFilesModifiers:{}}),emits:["update:path","update:selectedFiles"],setup(e){var t;let i,l,a,n,d,u,c,p,v=(0,r.fn)(e,"path"),g=(0,r.fn)(e,"selectedFiles"),y=(0,s.KR)(),{currentConfig:k}=(t=e.currentView,i=e=>"asc"===e?"ascending":"desc"===e?"descending":"none",l=(0,E.C)("files","viewConfigs",null),a=(0,s.KR)({sortBy:l?.files?.sorting_mode??"basename",order:i(l?.files?.sorting_direction??"asc")}),n=(0,s.KR)({sortBy:l?.recent?.sorting_mode??"basename",order:i(l?.recent?.sorting_direction??"asc")}),d=(0,s.KR)({sortBy:l?.favorites?.sorting_mode??"basename",order:i(l?.favorites?.sorting_direction??"asc")}),(0,r.sV)(async()=>{if(L())b.l.debug("Skip loading files views - currently on public share");else try{let{data:e}=await C.Ay.get((0,R.Jv)("/apps/files/api/v1/views"));a.value={sortBy:e?.data?.files?.sorting_mode??"basename",order:i(e?.data?.files?.sorting_direction)},d.value={sortBy:e?.data?.favorites?.sorting_mode??"basename",order:i(e?.data?.favorites?.sorting_direction)},n.value={sortBy:e?.data?.recent?.sorting_mode??"basename",order:i(e?.data?.recent?.sorting_direction)}}catch(e){b.l.error("Could not load files views",{error:e}),(0,b.s)((0,b.t)("Could not load files views"))}}),u=(0,r.EW)(()=>"files"===(0,s.BA)(t||"files")?a.value:"recent"===(0,s.BA)(t)?n.value:d.value),c=(0,r.EW)(()=>u.value.sortBy),p=(0,r.EW)(()=>u.value.order),{filesViewConfig:a,favoritesViewConfig:d,recentViewConfig:n,currentConfig:u,sortBy:c,order:p}),w=(0,r.EW)(()=>y.value??k.value),_=(0,r.EW)(()=>"basename"===w.value.sortBy?"none"===w.value.order?void 0:w.value.order:void 0),F=(0,r.EW)(()=>"size"===w.value.sortBy?"none"===w.value.order?void 0:w.value.order:void 0),S=(0,r.EW)(()=>"mtime"===w.value.sortBy?"none"===w.value.order?void 0:w.value.order:void 0);function z(e){w.value.sortBy===e?"ascending"===w.value.order?y.value={sortBy:w.value.sortBy,order:"descending"}:y.value={sortBy:w.value.sortBy,order:"ascending"}:y.value={sortBy:e,order:"ascending"}}let{sortFavoritesFirst:X,cropImagePreviews:W}=eX(),D=(0,r.EW)(()=>(0,f.ur)(e.files,{sortFoldersFirst:!0,sortFavoritesFirst:X.value,sortingOrder:"descending"===w.value.order?"desc":"asc",sortingMode:w.value.sortBy})),N=(0,r.EW)(()=>e.files.filter(t=>e.allowPickDirectory||t.type!==f.pt.Folder)),P=(0,r.EW)(()=>!e.loading&&g.value.length>0&&g.value.length>=N.value.length);function $(){g.value.length<N.value.length?g.value=[...N.value]:g.value=[]}function V(e){v.value=e.path}let x=(0,s.KR)(4),B=(0,s.KR)();{let e=()=>(0,r.dY)(()=>{let e=B.value?.parentElement?.children||[],t=B.value?.parentElement?.clientHeight||450;for(let i=0;i<e.length;i++)B.value?.isSameNode(e[i])||(t-=e[i].clientHeight);x.value=Math.max(1,Math.floor((t-50)/50))});(0,r.sV)(()=>{window.addEventListener("resize",e),e()}),(0,r.hi)(()=>{window.removeEventListener("resize",e)})}return(t,i)=>((0,r.uX)(),(0,r.CE)("div",{ref_key:"fileContainer",ref:B,class:"file-picker__files"},[(0,r.Lk)("table",null,[(0,r.Lk)("thead",null,[(0,r.Lk)("tr",null,[e.multiselect?((0,r.uX)(),(0,r.CE)("th",eW,[(0,r.Lk)("span",eD,(0,o.toDisplayString)((0,s.R1)(b.t)("Select entry")),1),e.multiselect?((0,r.uX)(),(0,r.Wv)((0,s.R1)(h.A),{key:0,"aria-label":(0,s.R1)(b.t)("Select all entries"),"data-testid":"select-all-checkbox",modelValue:P.value,"onUpdate:modelValue":$},null,8,["aria-label","modelValue"])):(0,r.Q3)("",!0)])):(0,r.Q3)("",!0),(0,r.Lk)("th",{"aria-sort":_.value,class:"row-name"},[(0,r.Lk)("div",eP,[i[3]||(i[3]=(0,r.Lk)("span",{class:"file-picker__header-preview"},null,-1)),(0,r.bF)((0,s.R1)(m.A),{"data-test":"file-picker_sort-name",variant:"tertiary",wide:"",onClick:i[0]||(i[0]=e=>z("basename"))},{icon:(0,r.k6)(()=>["ascending"===_.value?((0,r.uX)(),(0,r.Wv)(eo,{key:0,size:20})):"descending"===_.value?((0,r.uX)(),(0,r.Wv)(ei,{key:1,size:20})):((0,r.uX)(),(0,r.CE)("span",e$))]),default:(0,r.k6)(()=>[(0,r.eW)(" "+(0,o.toDisplayString)((0,s.R1)(b.t)("Name")),1)]),_:1})])],8,eN),(0,r.Lk)("th",{"aria-sort":F.value,class:"row-size"},[(0,r.bF)((0,s.R1)(m.A),{variant:"tertiary",wide:"",onClick:i[1]||(i[1]=e=>z("size"))},{icon:(0,r.k6)(()=>["ascending"===F.value?((0,r.uX)(),(0,r.Wv)(eo,{key:0,size:20})):"descending"===F.value?((0,r.uX)(),(0,r.Wv)(ei,{key:1,size:20})):((0,r.uX)(),(0,r.CE)("span",ex))]),default:(0,r.k6)(()=>[(0,r.eW)(" "+(0,o.toDisplayString)((0,s.R1)(b.t)("Size")),1)]),_:1})],8,eV),(0,r.Lk)("th",{"aria-sort":S.value,class:"row-modified"},[(0,r.bF)((0,s.R1)(m.A),{variant:"tertiary",wide:"",onClick:i[2]||(i[2]=e=>z("mtime"))},{icon:(0,r.k6)(()=>["ascending"===S.value?((0,r.uX)(),(0,r.Wv)(eo,{key:0,size:20})):"descending"===S.value?((0,r.uX)(),(0,r.Wv)(ei,{key:1,size:20})):((0,r.uX)(),(0,r.CE)("span",eM))]),default:(0,r.k6)(()=>[(0,r.eW)(" "+(0,o.toDisplayString)((0,s.R1)(b.t)("Modified")),1)]),_:1})],8,eB)])]),(0,r.Lk)("tbody",null,[e.loading?((0,r.uX)(!0),(0,r.CE)(r.FK,{key:0},(0,r.pI)(x.value,t=>((0,r.uX)(),(0,r.Wv)(ez,{key:t,showCheckbox:e.multiselect},null,8,["showCheckbox"]))),128)):((0,r.uX)(!0),(0,r.CE)(r.FK,{key:1},(0,r.pI)(D.value,t=>((0,r.uX)(),(0,r.Wv)(eC,{key:t.fileid||t.path,allowPickDirectory:e.allowPickDirectory,showCheckbox:e.multiselect,canPick:(e.multiselect||0===g.value.length||g.value.includes(t))&&(void 0===e.canPick||e.canPick(t)),selected:g.value.includes(t),node:t,cropImagePreviews:(0,s.R1)(W),"onUpdate:selected":i=>{g.value.includes(t)?g.value=g.value.filter(e=>e.path!==t.path):e.multiselect?g.value=[...g.value,t]:g.value=[t]},onEnterDirectory:V},null,8,["allowPickDirectory","showCheckbox","canPick","selected","node","cropImagePreviews","onUpdate:selected"]))),128))])])],512))}}),eI=(0,v._)(eA,[["__scopeId","data-v-412efd5c"]]),eH=["aria-hidden","aria-label"],eK=["fill","width","height"],eT={d:"M10,20V14H14V20H19V12H22L12,3L2,12H5V20H10Z"},eU={key:0},eq=(0,v._)({name:"HomeIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon home-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",eT,[i.title?((0,r.uX)(),(0,r.CE)("title",eU,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,eK))],16,eH)}]]),eQ=["aria-hidden","aria-label"],ej=["fill","width","height"],eG={d:"M19,13H13V19H11V13H5V11H11V5H13V11H19V13Z"},eZ={key:0},eO=(0,v._)({name:"PlusIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon plus-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",eG,[i.title?((0,r.uX)(),(0,r.CE)("title",eZ,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,ej))],16,eQ)}]]),eJ=(0,r.pM)({__name:"FilePickerBreadcrumbs",props:(0,r.zz)({showMenu:{type:Boolean}},{path:{required:!0},pathModifiers:{}}),emits:(0,r.zz)(["createNode"],["update:path"]),setup(e,{emit:t}){let i=(0,r.fn)(e,"path"),l=(0,s.KR)(!1),a=(0,s.KR)(""),n=(0,r.rk)("nameInput");function o(){let e=a.value.trim(),t=n.value?.$el?.querySelector("input"),i="";try{(0,f.KT)(e)}catch(e){if(!(e instanceof f.di))throw e;switch(e.reason){case f.nF.Character:i=(0,b.t)('"{char}" is not allowed inside a folder name.',{char:e.segment});break;case f.nF.ReservedName:i=(0,b.t)('"{segment}" is a reserved name and not allowed for folder names.',{segment:e.segment});break;case f.nF.Extension:i=(0,b.t)('Folder names must not end with "{extension}".',{extension:e.segment});break;default:i=(0,b.t)("Invalid folder name.")}}return t&&t.setCustomValidity(i),""===i}function d(){let e=a.value.trim();o()&&(l.value=!1,t("createNode",e),a.value="")}let u=(0,r.EW)(()=>i.value.split("/").filter(e=>""!==e).map((e,t,i)=>({name:e,path:"/"+i.slice(0,t+1).join("/")})));return(t,c)=>((0,r.uX)(),(0,r.Wv)((0,s.R1)(X.N),{class:"file-picker__breadcrumbs"},(0,r.eX)({default:(0,r.k6)(()=>[(0,r.bF)((0,s.R1)(z.N),{name:(0,s.R1)(b.t)("All files"),title:(0,s.R1)(b.t)("Home"),onClick:c[0]||(c[0]=e=>i.value="/")},{icon:(0,r.k6)(()=>[(0,r.bF)(eq,{size:20})]),_:1},8,["name","title"]),((0,r.uX)(!0),(0,r.CE)(r.FK,null,(0,r.pI)(u.value,e=>((0,r.uX)(),(0,r.Wv)((0,s.R1)(z.N),{key:e.path,name:e.name,title:e.path,onClick:t=>i.value=e.path},null,8,["name","title","onClick"]))),128))]),_:2},[e.showMenu?{name:"actions",fn:(0,r.k6)(()=>[(0,r.bF)((0,s.R1)(S.A),{open:l.value,"onUpdate:open":c[2]||(c[2]=e=>l.value=e),"aria-label":(0,s.R1)(b.t)("Create directory"),forceMenu:!0,forceName:!0,menuName:(0,s.R1)(b.t)("New"),variant:"secondary",onClose:c[3]||(c[3]=e=>a.value="")},{icon:(0,r.k6)(()=>[(0,r.bF)(eO,{size:20})]),default:(0,r.k6)(()=>[(0,r.bF)((0,s.R1)(F.N),{ref_key:"nameInput",ref:n,modelValue:a.value,"onUpdate:modelValue":[c[1]||(c[1]=e=>a.value=e),o],label:(0,s.R1)(b.t)("New folder"),placeholder:(0,s.R1)(b.t)("New folder name"),onSubmit:d},{icon:(0,r.k6)(()=>[(0,r.bF)(ep,{size:20})]),_:1},8,["modelValue","label","placeholder"])]),_:1},8,["open","aria-label","menuName"])]),key:"0"}:void 0]),1024))}}),eY=(0,v._)(eJ,[["__scopeId","data-v-b448b141"]]),e0=["aria-hidden","aria-label"],e1=["fill","width","height"],e2={d:"M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z"},e4={key:0},e6=(0,v._)({name:"CloseIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon close-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",e2,[i.title?((0,r.uX)(),(0,r.CE)("title",e4,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,e1))],16,e0)}]]),e5=["aria-hidden","aria-label"],e3=["fill","width","height"],e9={d:"M9.5,3A6.5,6.5 0 0,1 16,9.5C16,11.11 15.41,12.59 14.44,13.73L14.71,14H15.5L20.5,19L19,20.5L14,15.5V14.71L13.73,14.44C12.59,15.41 11.11,16 9.5,16A6.5,6.5 0 0,1 3,9.5A6.5,6.5 0 0,1 9.5,3M9.5,5C7,5 5,7 5,9.5C5,12 7,14 9.5,14C12,14 14,12 14,9.5C14,7 12,5 9.5,5Z"},e8={key:0},e7=(0,v._)({name:"MagnifyIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(e,t,i,l,a,n){return(0,r.uX)(),(0,r.CE)("span",(0,r.v6)(e.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon magnify-icon",role:"img",onClick:t[0]||(t[0]=t=>e.$emit("click",t))}),[((0,r.uX)(),(0,r.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,r.Lk)("path",e9,[i.title?((0,r.uX)(),(0,r.CE)("title",e8,(0,o.toDisplayString)(i.title),1)):(0,r.Q3)("",!0)])],8,e3))],16,e5)}]]),te={key:0,class:"file-picker__side"},tt=(0,r.pM)({__name:"FilePickerNavigation",props:{currentView:{},filterString:{},isCollapsed:{type:Boolean},disabledNavigation:{type:Boolean}},emits:["update:currentView","update:filterString"],setup(e,{emit:t}){var i;let l,a,{availableViews:n}=(i=(0,s.KR)(null===(0,W.HW)()),l=[{id:"files",label:(0,b.t)("All files"),icon:k.fEr},{id:"recent",label:(0,b.t)("Recent"),icon:k.NZC},{id:"favorites",label:(0,b.t)("Favorites"),icon:k.ZL5}],a=i.value?l.filter(({id:e})=>"files"===e):l,{allViews:l,availableViews:a}),d=(0,r.EW)(()=>n.filter(t=>t.id===e.currentView)[0]??n[0]),u=e=>t("update:filterString",e.toString());return(i,l)=>((0,r.uX)(),(0,r.CE)(r.FK,null,[(0,r.bF)((0,s.R1)(N.A),{class:"file-picker__filter-input",label:(0,s.R1)(b.t)("Filter file list"),showTrailingButton:!!e.filterString,modelValue:e.filterString,"onUpdate:modelValue":u,onTrailingButtonClick:l[0]||(l[0]=e=>u(""))},{"trailing-button-icon":(0,r.k6)(()=>[(0,r.bF)(e6,{size:16})]),default:(0,r.k6)(()=>[(0,r.bF)(e7,{size:16})]),_:1},8,["label","showTrailingButton","modelValue"]),(0,s.R1)(n).length>1&&!e.disabledNavigation?((0,r.uX)(),(0,r.CE)(r.FK,{key:0},[e.isCollapsed?((0,r.uX)(),(0,r.Wv)((0,s.R1)(D.default),{key:1,"aria-label":(0,s.R1)(b.t)("Current view selector"),clearable:!1,searchable:!1,options:(0,s.R1)(n),modelValue:d.value,"onUpdate:modelValue":l[1]||(l[1]=e=>t("update:currentView",e.id))},null,8,["aria-label","options","modelValue"])):((0,r.uX)(),(0,r.CE)("ul",te,[((0,r.uX)(!0),(0,r.CE)(r.FK,null,(0,r.pI)((0,s.R1)(n),t=>((0,r.uX)(),(0,r.CE)("li",{key:t.id},[(0,r.bF)((0,s.R1)(m.A),{variant:e.currentView===t.id?"primary":"tertiary",wide:!0,onClick:e=>i.$emit("update:currentView",t.id)},{icon:(0,r.k6)(()=>[(0,r.bF)((0,s.R1)(w.A),{path:t.icon,size:20},null,8,["path"])]),default:(0,r.k6)(()=>[(0,r.eW)(" "+(0,o.toDisplayString)(t.label),1)]),_:2},1032,["variant","onClick"])]))),128))]))],64)):(0,r.Q3)("",!0)],64))}}),ti=(0,v._)(tt,[["__scopeId","data-v-e1c54e23"]]);async function tl({client:e,signal:t}){let i=Math.round(Date.now()/1e3)-1209600,{data:l}=await e.search("/",{signal:t,details:!0,data:`<?xml version="1.0" encoding="UTF-8"?>
<d:searchrequest ${A()}
	xmlns:ns="https://github.com/icewind1991/SearchDAV/ns">
	<d:basicsearch>
		<d:select>
			<d:prop>
				${M()}
			</d:prop>
		</d:select>
		<d:from>
			<d:scope>
				<d:href>/files/${(0,W.HW)()?.uid}/</d:href>
				<d:depth>infinity</d:depth>
			</d:scope>
		</d:from>
		<d:where>
			<d:and>
				<d:or>
					<d:not>
						<d:eq>
							<d:prop>
								<d:getcontenttype/>
							</d:prop>
							<d:literal>httpd/unix-directory</d:literal>
						</d:eq>
					</d:not>
					<d:eq>
						<d:prop>
							<oc:size/>
						</d:prop>
						<d:literal>0</d:literal>
					</d:eq>
				</d:or>
				<d:gt>
					<d:prop>
						<d:getlastmodified/>
					</d:prop>
					<d:literal>${i}</d:literal>
				</d:gt>
			</d:and>
		</d:where>
		<d:orderby>
			<d:order>
				<d:prop>
					<d:getlastmodified/>
				</d:prop>
				<d:descending/>
			</d:order>
		</d:orderby>
		<d:limit>
			<d:nresults>100</d:nresults>
			<ns:firstresult>0</ns:firstresult>
		</d:limit>
	</d:basicsearch>
</d:searchrequest>`});return l.results.map(e=>q(e))}async function ta({client:e,path:t,signal:i}){let l=(await e.getDirectoryContents((0,g.fj)(H,t),{signal:i,details:!0,includeSelf:!0,data:I()})).data.map(e=>q(e));return{contents:l.filter(({path:e})=>e!==t),folder:l.find(({path:e})=>t===e)}}async function tn(e,t){let{data:i}=await e.stat((0,g.fj)(H,t),{details:!0,data:I()});return q(i)}let tr={class:"file-picker__main"},to={key:1,class:"file-picker__view"},ts=(0,r.pM)({__name:"FilePicker",props:{buttons:{},name:{},allowPickDirectory:{type:Boolean,default:!1},noMenu:{type:Boolean,default:!1},disabledNavigation:{type:Boolean,default:!1},filterFn:{type:Function,default:void 0},canPickFn:{type:Function,default:void 0},mimetypeFilter:{default:()=>[]},multiselect:{type:Boolean,default:!1},path:{default:void 0}},emits:["close"],setup(e,{emit:t}){var i;let l,a=(0,s.KR)(!0),n=(0,s.KR)("files"),d=(0,s.KR)(window?.sessionStorage.getItem("NC.FilePicker.LastPath")||"/"),v=(0,s.KR)(""),f=(0,r.EW)({get:()=>"files"===n.value?v.value||e.path||d.value:"/",set:e=>{v.value=e}}),m=(0,s.IJ)([]),h=(0,s.KR)(""),{files:y,folder:k,isLoading:w,loadFiles:_,createDirectory:C}=function(e,t){let i,l=T(),a=(0,s.IJ)([]),n=(0,s.IJ)(null),o=(0,s.KR)(!0);async function d(e){let i=(0,g.fj)(t.value,e);await l.createDirectory((0,g.fj)(H,i));let n=await tn(l,i);return a.value=[...a.value,n],n}async function u(){i&&(i.abort(),i=void 0),i=new AbortController,o.value=!0;try{if("favorites"===e.value)a.value=await U({client:l,path:t.value,signal:i.signal}),n.value=null;else if("recent"===e.value)a.value=await tl({client:l,signal:i.signal}),n.value=null;else{let e=await ta({client:l,path:t.value,signal:i.signal});n.value=e.folder,a.value=e.contents}}catch(e){if(e instanceof Error&&"AbortError"===e.name)return;throw e}finally{i=void 0,o.value=!1}}return(0,r.wB)([e,t],()=>u()),(0,r.sV)(()=>u()),{isLoading:o,files:a,folder:n,loadFiles:u,createDirectory:d}}(n,f);(0,r.wB)([v],()=>{void 0===e.path&&v.value&&window.sessionStorage.setItem("NC.FilePicker.LastPath",v.value),m.value=[],h.value=""});let E=!1,R=(0,r.EW)(()=>{let t=0===m.value.length&&e.allowPickDirectory&&k.value?[k.value]:m.value;return("function"==typeof e.buttons?e.buttons(t,f.value,n.value):e.buttons).map(e=>({...e,disabled:e.disabled||w.value,callback:()=>{E=!0,L(e.callback,t)}}))});async function L(e,i){await e(i),t("close",i),E=!1}let F=(0,r.EW)(()=>"favorites"===n.value?(0,b.t)("Favorites"):"recent"===n.value?(0,b.t)("Recent"):""),{isSupportedMimeType:S}=(i=(0,s.lW)(e,"mimetypeFilter"),l=(0,r.EW)(()=>i.value.map(e=>e.split("/"))),{isSupportedMimeType:e=>{let t=e.split("/");return l.value.some(([e,i])=>(t[0]===e||"*"===e)&&(t[1]===i||"*"===i))}});(0,r.sV)(()=>_());let{showHiddenFiles:z}=eX(),X=(0,r.EW)(()=>{let t=y.value;return z.value||(t=t.filter(e=>!e.basename.startsWith("."))),e.mimetypeFilter.length>0&&(t=t.filter(e=>"folder"===e.type||e.mime&&S(e.mime))),h.value&&(t=t.filter(e=>e.basename.toLowerCase().includes(h.value.toLowerCase()))),e.filterFn&&(t=t.filter(t=>e.filterFn(t))),t}),W=(0,r.EW)(()=>"files"===n.value?(0,b.t)("Upload some content or sync with your devices!"):"recent"===n.value?(0,b.t)("Files and folders you recently modified will show up here."):(0,b.t)("Files and folders you mark as favorite will show up here."));async function D(e){try{v.value=(await C(e)).path,(0,u.Ic)("files:node:created",y.value.filter(t=>t.basename===e)[0])}catch(t){b.l.warn("Could not create new folder",{name:e,error:t}),(0,b.s)((0,b.t)("Could not create the new folder"))}}function N(e){e||E||t("close")}return(t,i)=>((0,r.uX)(),(0,r.Wv)((0,s.R1)(c.A),{open:a.value,"onUpdate:open":[i[6]||(i[6]=e=>a.value=e),N],buttons:R.value,name:e.name,size:"large",contentClasses:"file-picker__content",dialogClasses:"file-picker",navigationClasses:"file-picker__navigation"},{navigation:(0,r.k6)(({isCollapsed:t})=>[(0,r.bF)(ti,{currentView:n.value,"onUpdate:currentView":i[0]||(i[0]=e=>n.value=e),filterString:h.value,"onUpdate:filterString":i[1]||(i[1]=e=>h.value=e),isCollapsed:t,disabledNavigation:e.disabledNavigation},null,8,["currentView","filterString","isCollapsed","disabledNavigation"])]),default:(0,r.k6)(()=>[(0,r.Lk)("div",tr,["files"===n.value?((0,r.uX)(),(0,r.Wv)(eY,{key:0,path:f.value,"onUpdate:path":i[2]||(i[2]=e=>f.value=e),showMenu:!e.noMenu,onCreateNode:D},null,8,["path","showMenu"])):((0,r.uX)(),(0,r.CE)("div",to,[(0,r.Lk)("h3",null,(0,o.toDisplayString)(F.value),1)])),(0,s.R1)(w)||X.value.length>0?((0,r.uX)(),(0,r.Wv)(eI,{key:2,path:f.value,"onUpdate:path":[i[3]||(i[3]=e=>f.value=e),i[5]||(i[5]=e=>n.value="files")],selectedFiles:m.value,"onUpdate:selectedFiles":i[4]||(i[4]=e=>m.value=e),allowPickDirectory:e.allowPickDirectory,currentView:n.value,files:X.value,multiselect:e.multiselect,loading:(0,s.R1)(w),name:F.value,canPick:e.canPickFn},null,8,["path","selectedFiles","allowPickDirectory","currentView","files","multiselect","loading","name","canPick"])):h.value?((0,r.uX)(),(0,r.Wv)((0,s.R1)(p.A),{key:3,name:(0,s.R1)(b.t)("No matching files"),description:(0,s.R1)(b.t)("No files matching your filter were found.")},{icon:(0,r.k6)(()=>[(0,r.bF)(O)]),_:1},8,["name","description"])):((0,r.uX)(),(0,r.Wv)((0,s.R1)(p.A),{key:4,name:(0,s.R1)(b.t)("No files in here"),description:W.value},{icon:(0,r.k6)(()=>[(0,r.bF)(O)]),_:1},8,["name","description"]))])]),_:1},8,["open","buttons","name"]))}}),td=(0,v._)(ts,[["__scopeId","data-v-4f89ed79"]])},3639(e,t,i){i(29461);var l=i(20641),a=i(90033),n=i(22436),r=i(34163),o=i(52697);(0,n.r)(n.x);let s=["for"],d=["id","type","value","min","max"],u=(0,l.pM)({...{inheritAttrs:!1},__name:"NcDateTimePickerNative",props:(0,l.zz)({class:{default:void 0},id:{default:()=>(0,r.c)()},inputClass:{default:""},type:{default:"date"},label:{default:()=>(0,n.a)("Please choose a date")},min:{default:null},max:{default:null},hideLabel:{type:Boolean}},{modelValue:{default:null},modelModifiers:{}}),emits:["update:modelValue"],setup(e){let t=(0,l.fn)(e,"modelValue"),i=(0,l.EW)(()=>t.value?u(t.value):""),n=(0,l.EW)(()=>e.max?u(e.max):void 0),r=(0,l.EW)(()=>e.min?u(e.min):void 0);function o(e){let t=e.getFullYear().toString().padStart(4,"0"),i=(e.getMonth()+1).toString().padStart(2,"0"),l=e.getDate().toString().padStart(2,"0");return{yyyy:t,MM:i,dd:l,hh:e.getHours().toString().padStart(2,"0"),mm:e.getMinutes().toString().padStart(2,"0")}}function u(t){let{yyyy:i,MM:l,dd:a,hh:n,mm:r}=o(t);if("datetime-local"===e.type)return`${i}-${l}-${a}T${n}:${r}`;if("date"===e.type)return`${i}-${l}-${a}`;if("month"===e.type)return`${i}-${l}`;if("time"===e.type)return`${n}:${r}`;if("week"===e.type){let e=new Date(Number.parseInt(i),0,1),l=Math.ceil(Math.floor((t.getTime()-e.getTime())/864e5)/7);return`${i}-W${l}`}return""}function c(i){let l=i.target;if(!l||isNaN(l.valueAsNumber))t.value=null;else if("time"===e.type){let e=l.value,{yyyy:i,MM:a,dd:n}=o(t.value||new Date);t.value=new Date(`${i}-${a}-${n}T${e}`)}else if("month"===e.type){let e=(new Date(l.value).getMonth()+1).toString().padStart(2,"0"),{yyyy:i,dd:a,hh:n,mm:r}=o(t.value||new Date);t.value=new Date(`${i}-${e}-${a}T${n}:${r}`)}else{let e=1e3*new Date(l.valueAsNumber).getTimezoneOffset()*60;t.value=new Date(l.valueAsNumber+e)}}return(t,o)=>((0,l.uX)(),(0,l.CE)("div",{class:(0,a.normalizeClass)(["native-datetime-picker",t.$props.class])},[(0,l.Lk)("label",{class:(0,a.normalizeClass)(["native-datetime-picker__label",{"hidden-visually":e.hideLabel}]),for:e.id},(0,a.toDisplayString)(e.label),11,s),(0,l.Lk)("input",(0,l.v6)({id:e.id,class:["native-datetime-picker__input",e.inputClass],type:e.type,value:i.value,min:r.value,max:n.value},t.$attrs,{onInput:c}),null,16,d)],2))}}),c=(0,o._)(u,[["__scopeId","data-v-b97e1f7a"]]);i.d(t,{},{N:c})},15797(e,t,i){var l=i(65048);i.d(t,{A:()=>l.N})},37523(e,t,i){var l=i(1722);i.d(t,{A:()=>l.N})},3710(e,t,i){i.r(t);var l=i(85951);i.d(t,{default:()=>l.N})},79455(e,t,i){var l=i(51420);i.d(t,{A:()=>l._})}}]);
//# sourceMappingURL=calendar-defaultVendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-DWYoSaVg_mjs-node_module-4c3472.js.map?v=786882692f20e3b7