OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Alamat email yang diberikan terlalu panjang",
    "User-Session unexpectedly expired" : "Sesi-Pengguna kedaluwarsa secara tidak terduga",
    "Provided email-address is not valid" : "Alamat email tidak valid",
    "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim email. Silakan hubungi administrator Anda.",
    "Successfully sent email to %1$s" : "Berhasil mengirim email ke %1$s",
    "Hello," : "Halo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
    "Open »%s«" : "Buka »%s«",
    "Cheers!" : "Horee!",
    "Upcoming events" : "Acara mendatang",
    "No more events today" : "Tidak ada acara lagi hari ini",
    "No upcoming events" : "Tdak ada acara mendatang",
    "More events" : "Lebih banyak acara",
    "%1$s with %2$s" : "%1$sdengan %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Pemesanan baru (pemesanan)",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) memesan janji temu \"{config_display_name}\" pada {date_time}.",
    "Appointments" : "Janji temu",
    "Schedule appointment \"%s\"" : "Jadwalkan janji temu \"%s\"",
    "Schedule an appointment" : "Jadwalkan janji temu",
    "Requestor Comments:" : "Komentar Pemohon:",
    "Appointment Description:" : "Deskripsi Janji Temu:",
    "Prepare for %s" : "Bersiaplah untuk %s",
    "Follow up for %s" : "Tindak lanjut untuk %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Janji temu Anda \"%s\" dengan %s membutuhkan konfirmasi ",
    "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
    "Confirm" : "Konfirmasi",
    "Appointment with:" : "Janji temu dengan:",
    "Description:" : "Deskripsi:",
    "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas email ini atau mengunjungi halaman profil mereka",
    "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
    "Dear %s, your booking has been accepted." : "Kepada %s, pemesanan Anda telah diterima.",
    "Appointment for:" : "Janji temu untuk:",
    "Date:" : "Tanggal:",
    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan email konfirmasi",
    "Where:" : "Tempat:",
    "Comment:" : "Komentar:",
    "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kepada %s, %s (%s) memesan janji temu dengan Anda.",
    "%s has proposed a meeting" : "%s telah mengusulkan pertemuan",
    "%s has updated a proposed meeting" : "%s telah memperbarui pertemuan yang diusulkan",
    "%s has canceled a proposed meeting" : "%s telah membatalkan pertemuan yang diusulkan",
    "Dear %s, a new meeting has been proposed" : "Halo %s, pertemuan baru telah diusulkan",
    "Dear %s, a proposed meeting has been updated" : "Halo %s, pertemuan yang diusulkan telah diperbarui",
    "Dear %s, a proposed meeting has been cancelled" : "Halo %s, pertemuan yang diusulkan telah dibatalkan",
    "Respond" : "Tanggapi",
    "Location:" : "Lokasi:",
    "%1$s minutes" : "%1$s menit",
    "Duration:" : "Durasi:",
    "%1$s from %2$s to %3$s" : "%1$s dari %2$s hingga %3$s",
    "Dates:" : "Tanggal:",
    "[Proposed] %1$s" : "[Diusulkan] %1$s",
    "Calendar App" : "Aplikasi Kalender",
    "Calendars App settings including proposals and appointments schedule configurations." : "Pengaturan aplikasi Kalender termasuk konfigurasi jadwal usulan dan janji temu.",
    "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikasi Kalender untuk Nextcloud. Sinkronkan acara dengan mudah dari berbagai perangkat dengan Nextcloud Anda dan edit secara daring.\n\n* 🚀 **Integrasi dengan aplikasi Nextcloud lainnya!** Seperti Contacts, Talk, Tasks, Deck, dan Circles\n* 🌐 **Dukungan WebCal!** Ingin melihat hari pertandingan tim favorit Anda di kalender Anda? Tidak masalah!\n* 🙋 **Peserta!** Undang orang ke acara Anda\n* ⌚ **Sibuk/Luang!** Lihat kapan peserta Anda tersedia untuk bertemu\n* ⏰ **Pengingat!** Dapatkan alarm untuk acara di dalam peramban Anda dan melalui email\n* 🔍 **Pencarian!** Temukan acara Anda dengan mudah\n* ☑️ **Tugas!** Lihat tugas atau kartu Deck dengan tanggal jatuh tempo langsung di kalender\n* 🔈 **Ruangan Talk!** Buat ruangan Talk terkait saat memesan pertemuan hanya dengan satu klik\n* 📆 **Pemesanan janji temu** Kirim tautan kepada orang agar mereka dapat memesan janji temu dengan Anda [menggunakan aplikasi ini](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Lampiran!** Tambahkan, unggah, dan lihat lampiran acara\n* 🙈 **Kami tidak menemukan kembali roda!** Berdasarkan pustaka [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js), dan [fullcalendar](https://github.com/fullcalendar/fullcalendar) yang hebat.",
    "Previous day" : "Hari sebelum",
    "Previous week" : "Minggu sebelum",
    "Previous year" : "Tahun lalu",
    "Previous month" : "Bulan sebelum",
    "Next day" : "Hari setelah",
    "Next week" : "Minggu setelah",
    "Next year" : "Tahun depan",
    "Next month" : "Bulan setelah",
    "Create new event" : "Buat acara baru",
    "Event" : "Acara",
    "Today" : "Hari Ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Year" : "Tahun",
    "List" : "daftar",
    "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
    "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
    "Preview" : "Pratinjau",
    "Copy link" : "Salin tautan",
    "Duplicate" : "Gandakan",
    "Edit" : "Sunting",
    "Delete" : "Hapus",
    "Appointment schedules" : "Jadwal janji temu",
    "Create new" : "Buat",
    "Disable calendar \"{calendar}\"" : "Nonaktifkan kalender \"{calendar}\"",
    "Disable untitled calendar" : "Nonaktifkan kalender tanpa judul",
    "Enable calendar \"{calendar}\"" : "Aktifkan kalender \"{calendar}\"",
    "Enable untitled calendar" : "Aktifkan kalender tanpa judul",
    "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "Untitled calendar" : "Kalender tanpa judul",
    "Shared with you by" : "Dibagikan dengan Anda oleh",
    "Copy public link" : "Salin tautan publik",
    "Edit and share calendar" : "Edit dan bagikan kalender",
    "Edit calendar" : "Edit kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
    "Add new" : "Tambahkan baru",
    "New calendar" : "Kalender baru",
    "Name for new calendar" : "Nama untuk kalender baru",
    "Creating calendar …" : "Membuat kalender …",
    "New calendar with task list" : "Kalender baru dengan daftar tugas",
    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
    "Creating subscription …" : "Membuat langganan …",
    "Add public holiday calendar" : "Tambahkan kalender hari libur nasional",
    "Add custom public calendar" : "Tambahkan kalender publik khusus",
    "Copy subscription link" : "Salin tautan berlangganan",
    "Copying link …" : "Menyalin tautan …",
    "Copied link" : "Tautan tersalin",
    "Could not copy link" : "Tidak dapat menyalin tautan",
    "Export" : "Ekspor",
    "Untitled item" : "Item tanpa judul",
    "Unknown calendar" : "Kalender tidak diketahui",
    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
    "Could not delete calendar or event" : "Tidak dapat menghapus kalender atau acara",
    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Trash bin" : "Keranjang sampah",
    "Loading deleted items." : "Memuat item yang dihapus.",
    "You do not have any deleted items." : "Anda tidak memiliki item yang dihapus.",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
    "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
    "Shared calendars" : "Kalender yang dibagikan",
    "Deck" : "Longgok",
    "Tasks" : "Tugas",
    "Internal link" : "Tautan internal",
    "A private link that can be used with external clients" : "Tautan pribadi yang dapat digunakan dengan klien eksternal",
    "Copy internal link" : "Salin tautan internal",
    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
    "Share link" : "Bagikan tautan",
    "Send link to calendar via email" : "Kirim tautan kalender via email",
    "Enter one address" : "Masukkan satu alamat",
    "Sending email …" : "Mengirim email …",
    "Copy embedding code" : "Salin kode penyemat",
    "Copying code …" : "Menyalin kode …",
    "Copied code" : "Kode tersalin",
    "Could not copy code" : "Tidak dapat menyalin kode",
    "Delete share link" : "Hapus tautan berbagi",
    "Deleting share link …" : "Menghapus tautan berbagi …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Tim)",
    "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
    "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
    "can edit and see confidential events" : "dapat mengedit dan melihat acara rahasia",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "None" : "Tidak ada",
    "Failed to save calendar name and color" : "Gagal menyimpan nama dan warna kalender",
    "Never show me as busy (set this calendar to transparent)" : "Jangan pernah tampilkan saya sebagai sibuk (atur kalender ini ke transparan)",
    "Share calendar" : "Bagikan kalender",
    "Unshare from me" : "Berhenti berbagi dari saya",
    "Save" : "Simpan",
    "No title" : "Tanpa judul",
    "Are you sure you want to delete \"{title}\"?" : "Apakah Anda yakin ingin menghapus \"{title}\"?",
    "Cancel" : "Batal",
    "Deleting proposal \"{title}\"" : "Menghapus usulan \"{title}\"",
    "Successfully deleted proposal" : "Berhasil menghapus usulan",
    "Failed to delete proposal" : "Gagal menghapus usulan",
    "Failed to retrieve proposals" : "Gagal mengambil usulan",
    "Meeting proposals" : "Usulan pertemuan",
    "A configured email address is required to use meeting proposals" : "Alamat email yang dikonfigurasi diperlukan untuk menggunakan usulan pertemuan",
    "No active meeting proposals" : "Tidak ada usulan pertemuan aktif",
    "View" : "Tampilan",
    "Busy" : "Sibuk",
    "Free" : "Luang",
    "Accepted" : "Diterima",
    "Tentative" : "Tentatif",
    "Icons" : "Ikon",
    "Attendees" : "Peserta",
    "Import calendars" : "Impor kalender",
    "Please select a calendar to import into …" : "Silakan pilih kalender untuk diimpor ke …",
    "Filename" : "Nama berkas",
    "Calendar to import into" : "Kalender untuk diimpor ke",
    "_Import calendar_::_Import calendars_" : ["Impor kalender"],
    "Select the default location for attachments" : "Pilih lokasi default untuk lampiran",
    "Pick" : "Pilih",
    "Invalid location selected" : "Lokasi yang tidak valid dipilih",
    "Attachments folder successfully saved." : "Folder lampiran berhasil disimpan.",
    "Error on saving attachments folder." : "Kesalahan saat menyimpan folder lampiran.",
    "Attachments folder" : "Folder lampiran",
    "Revoke" : "Cabut",
    "Viewer" : "Penampil",
    "Editor" : "Editor",
    "No users found" : "Tidak ada pengguna yang ditemukan",
    "{filename} could not be parsed" : "{filename} tidak dapat diurai",
    "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Berhasil mengimpor %n acara"],
    "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
    "Automatic" : "Otomatis",
    "Automatic ({timezone})" : "Otomatis ({timezone})",
    "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
    "Timezone" : "Zona waktu",
    "Navigation" : "Navigasi",
    "Previous period" : "Periode sebelum",
    "Next period" : "Periode sesudah",
    "Views" : "Tampilan",
    "Day view" : "Tampilan hari",
    "Week view" : "Tampilan minggu",
    "Month view" : "Tampilan bulan",
    "Year view" : "Tampilan tahun",
    "List view" : "Tampilan lis",
    "Actions" : "Tindakan",
    "Create event" : "Buat acara",
    "Show shortcuts" : "Tampilkan pintasan",
    "Close editor" : "Tutup editor",
    "Save edited event" : "Simpan acara yang diedit",
    "Delete edited event" : "Hapus acara yang diedit",
    "Duplicate event" : "Gandakan acara",
    "or" : "atau",
    "Calendar settings" : "Pengaturan kalender",
    "No reminder" : "Tanpa pengingat",
    "At event start" : "Saat acara dimulai",
    "Failed to save default calendar" : "Gagal menyimpan kalender default",
    "General" : "Umum",
    "Default calendar for incoming invitations" : "Kalender default untuk undangan masuk",
    "Availability settings" : "Pengaturan ketersediaan",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Akses kalender Nextcloud dari aplikasi dan perangkat lain",
    "CalDAV URL" : "URL CalDAV",
    "Server Address for iOS and macOS" : "Alamat Server untuk iOS dan macOS",
    "Appearance" : "Tampilan",
    "Birthday calendar" : "Kalender ulang tahun",
    "Tasks in calendar" : "Tugas di kalender",
    "Weekends" : "Akhir pekan",
    "Week numbers" : "Nomor minggu",
    "Limit number of events shown in Month view" : "Batasi jumlah acara yang ditampilkan di tampilan Bulan",
    "Density in Day and Week View" : "Kepadatan dalam Tampilan Hari dan Minggu",
    "Editing" : "Pengeditan",
    "Simple event editor" : "Editor acara sederhana",
    "\"More details\" opens the detailed editor" : "\"Detail lebih lanjut\" membuka editor terperinci",
    "Files" : "File",
    "Appointment schedule successfully created" : "Jadwal janji temu berhasil dibuat",
    "Appointment schedule successfully updated" : "Jadwal janji temu berhasil diperbarui",
    "0 minutes" : "0 menit",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
    "_{duration} day_::_{duration} days_" : ["{duration} hari"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} minggu"],
    "_{duration} month_::_{duration} months_" : ["{duration} bulan"],
    "_{duration} year_::_{duration} years_" : ["{duration} tahun"],
    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
    "Appointment schedule saved" : "Jadwal janji temu disimpan",
    "Create appointment schedule" : "Buat jadwal janji temu",
    "Edit appointment schedule" : "Edit jadwal janji temu",
    "Update" : "Perbarui",
    "(copy)" : "(salinan)",
    "Appointment name" : "Nama janji temu",
    "Location" : "Lokasi",
    "Create a Talk room" : "Buat ruangan Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Tautan unik akan dibuat untuk setiap janji temu yang dipesan dan dikirim melalui email konfirmasi",
    "Description" : "Deskrisi",
    "Increments" : "Kenaikan",
    "Visibility" : "Visibilitas",
    "to" : "untuk",
    "Delete slot" : "Hapus slot",
    "No times set" : "Tidak ada waktu yang ditetapkan",
    "Add" : "Masukkan",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sunday" : "Minggu",
    "Weekdays" : "Hari kerja",
    "Planning restrictions" : "Pembatasan perencanaan",
    "Max slots per day" : "Slot maksimal per hari",
    "Limit how far in the future appointments can be booked" : "Batasi seberapa jauh ke depan janji temu dapat dipesan",
    "It seems a rate limit has been reached. Please try again later." : "Sepertinya batas tingkat telah tercapai. Silakan coba lagi nanti.",
    "Please confirm your reservation" : "Silakan konfirmasi reservasi Anda",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim email dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam email tersebut. Anda dapat menutup halaman ini sekarang.",
    "Your name" : "Nama Anda",
    "Your email address" : "Alamat email Anda",
    "Please share anything that will help prepare for our meeting" : "Silakan bagikan apa pun yang akan membantu persiapan untuk pertemuan kami",
    "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
    "Back" : "Kembali",
    "Book appointment" : "Pesan janji temu",
    "Error fetching Talk conversations." : "Kesalahan saat mengambil percakapan Talk.",
    "Conversation does not have a valid URL." : "Percakapan tidak memiliki URL yang valid.",
    "Successfully added Talk conversation link to location." : "Berhasil menambahkan tautan percakapan Talk ke lokasi.",
    "Successfully added Talk conversation link to description." : "Berhasil menambahkan tautan percakapan Talk ke deskripsi.",
    "Failed to apply Talk room." : "Gagal menerapkan ruangan Talk.",
    "Talk conversation for event" : "Percakapan Talk untuk acara",
    "Error creating Talk conversation" : "Kesalahan membuat percakapan Talk",
    "Select a Talk Room" : "Pilih Ruangan Talk",
    "Fetching Talk rooms…" : "Mengambil ruangan Talk…",
    "No Talk room available" : "Tidak ada ruangan Talk tersedia",
    "Select existing conversation" : "Pilih percakapan yang ada",
    "Select conversation" : "Pilih percakapan",
    "Or create a new conversation" : "Atau buat percakapan baru",
    "Create public conversation" : "Buat percakapan publik",
    "Create private conversation" : "Buat percakapan pribadi",
    "on" : "pada",
    "at" : "di",
    "Amount" : "Jumlah",
    "before at" : "sebelumnya pada",
    "Notification" : "Notifikasi",
    "Email" : "Email",
    "Audio notification" : "Notifikasi audio",
    "Other notification" : "Notifikasi lain",
    "Relative to event" : "Relatif terhadap acara",
    "On date" : "Pada tanggal",
    "Edit time" : "Ubah waktu",
    "Save time" : "Simpan waktu",
    "Remove reminder" : "Buang pengingat",
    "Add reminder" : "Tambahkan pengingat",
    "seconds" : "detik",
    "minutes" : "menit",
    "hours" : "jam",
    "days" : "hari",
    "weeks" : "minggu",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Choose a file to share as a link" : "Pilih berkas untuk dibagikan sebagai tautan",
    "Attachment {name} already exist!" : "Lampiran {name} sudah ada!",
    "Could not upload attachment(s)" : "Tidak dapat mengunggah lampiran",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Anda akan menavigasi ke {link}. Apakah Anda yakin untuk melanjutkan?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Anda akan menavigasi ke {host}. Apakah Anda yakin untuk melanjutkan? Tautan: {link}",
    "Proceed" : "Lanjutkan",
    "No attachments" : "Tidak ada lampiran",
    "Add from Files" : "Tambahkan dari Berkas",
    "Upload from device" : "Unggah dari perangkat",
    "Delete file" : "Hapus berkas",
    "Confirmation" : "Konfirmasi",
    "_{count} attachment_::_{count} attachments_" : ["{count} lampiran"],
    "Suggested" : "Disarankan",
    "Available" : "Tersedia",
    "Invitation accepted" : "Undangan diterima",
    "Accepted {organizerName}'s invitation" : "Menerima undangan {organizerName}",
    "Participation marked as tentative" : "Partisipasi ditandai sebagai tentatif",
    "Invitation is delegated" : "Undangan didelegasikan",
    "Not available" : "Tidak tersedia",
    "Invitation declined" : "Undangan ditolak",
    "Declined {organizerName}'s invitation" : "Menolak undangan {organizerName}",
    "Availability will be checked" : "Ketersediaan akan diperiksa",
    "Invitation will be sent" : "Undangan akan dikirim",
    "Failed to check availability" : "Gagal memeriksa ketersediaan",
    "Failed to deliver invitation" : "Gagal mengirimkan undangan",
    "Awaiting response" : "Menunggu respons",
    "Checking availability" : "Memeriksa ketersediaan",
    "Has not responded to {organizerName}'s invitation yet" : "Belum menanggapi undangan {organizerName}",
    "Duration" : "Durasi",
    "15 minutes" : "15 menit",
    "30 minutes" : "30 menit",
    "45 minutes" : "45 menit",
    "1 hour" : "1 jam",
    "2 hours" : "2 jam",
    "Custom" : "Kustom",
    "Days" : "Hari",
    "Hours" : "Jam",
    "Minutes" : "Menit",
    "Suggested times" : "Waktu yang disarankan",
    "chairperson" : "ketua",
    "required participant" : "peserta wajib",
    "non-participant" : "bukan peserta",
    "optional participant" : "peserta opsional",
    "{organizer} (organizer)" : "{organizer} (penyelenggara)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Slot yang dipilih",
    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
    "Suggestion accepted" : "Saran diterima",
    "Previous date" : "Tanggal sebelumnya",
    "Next date" : "Tanggal berikutnya",
    "Legend" : "Legenda",
    "Out of office" : "Keluar kantor",
    "Attendees:" : "Peserta:",
    "local time" : "waktu lokal",
    "Done" : "Selesai",
    "Search room" : "Cari ruangan",
    "Room name" : "Nama ruang",
    "Check room availability" : "Periksa ketersediaan ruangan",
    "Busy (tentative)" : "Sibuk (tentatif)",
    "Unknown" : "Tidak diketahui",
    "Find a time" : "Temukan waktu",
    "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
    "Failed to accept the invitation." : "Gagal menerima undangan.",
    "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
    "Failed to decline the invitation." : "Gagal menolak undangan.",
    "Your participation has been marked as tentative." : "Partisipasi Anda telah ditandai sebagai belum pasti.",
    "Failed to set the participation status to tentative." : "Gagal menyetel status partisipasi menjadi belum pasti.",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Copied to clipboard" : "Disalin ke papan klip",
    "Failed to copy" : "Gagal menyalin",
    "Copy name and email address" : "Salin nama dan alamat email",
    "No attendees yet" : "Belum ada peserta",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} dikonfirmasi, {waitingCount} menunggu respons",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Silakan tambahkan setidaknya satu peserta untuk menggunakan fitur \"Temukan waktu\".",
    "Status" : "Status",
    "Role" : "Peran",
    "Chairperson" : "Ketua",
    "Required participant" : "Partisipan wajib",
    "Optional participant" : "Partisipan opsional",
    "Non-participant" : "Bukan partisipan",
    "_%n more attendee_::_%n more attendees_" : ["%n peserta lainnya"],
    "Remove group" : "Hapus grup",
    "Remove attendee" : "Hapus peserta",
    "Request reply" : "Minta balasan",
    "_%n member_::_%n members_" : ["%n anggota"],
    "Search for emails, users, contacts, contact groups or teams" : "Cari email, pengguna, kontak, grup kontak, atau tim",
    "No match found" : "Tidak ditemukan kecocokan",
    "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
    "Note that members of contact groups get invited but are not synced yet." : "Perhatikan bahwa anggota grup kontak diundang tetapi belum disinkronkan.",
    "(organizer)" : "(penyelenggara)",
    "Make {label} the organizer" : "Jadikan {label} sebagai penyelenggara",
    "Make {label} the organizer and attend" : "Jadikan {label} sebagai penyelenggara dan hadiri",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat email Anda di pengaturan pribadi[linkclose].",
    "Remove color" : "Hapus warna",
    "Title" : "Judul",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
    "From" : "Dari",
    "To" : "Hingga",
    "Your Time" : "Waktu Anda",
    "Repeat" : "Ulang",
    "Repeat event" : "Ulangi acara",
    "never" : "tidak pernah",
    "on date" : "pada tanggal",
    "after" : "setelah",
    "End repeat" : "Akhiri perulangan",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acara ini merupakan pengecualian pengulangan dari set pengulangan. Anda tidak dapat menambahkan aturan pengulangan pada acara ini.",
    "first" : "pertama",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Perubahan pada aturan pengulangan hanya akan diterapkan untuk acara ini dan semua acara selanjutnya.",
    "Repeat every" : "Ulang setiap",
    "By day of the month" : "Berdasarkan hari pada bulan",
    "On the" : "Pada",
    "_day_::_days_" : ["hari"],
    "_week_::_weeks_" : ["minggu"],
    "_month_::_months_" : ["bulang"],
    "_year_::_years_" : ["tahun"],
    "On specific day" : "Pada hari tertentu",
    "weekday" : "akhir pekan",
    "weekend day" : "akhir pekan",
    "Does not repeat" : "Tidak berulang",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
    "No rooms or resources yet" : "Belum ada ruangan atau sumber daya",
    "Resources" : "Sumber daya",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} tempat duduk"],
    "Add resource" : "Tambahkan sumber daya",
    "Has a projector" : "Memiliki proyektor",
    "Has a whiteboard" : "Memiliki papan tulis",
    "Wheelchair accessible" : "Dapat diakses kursi roda",
    "Remove resource" : "Hapus sumber daya",
    "Search for resources or rooms" : "Cari sumber daya atau ruangan",
    "available" : "tersedia",
    "unavailable" : "tidak tersedia",
    "Show all rooms" : "Tampilkan semua ruangan",
    "Projector" : "Proyektor",
    "Whiteboard" : "Papan tulis",
    "Room type" : "Jenis ruangan",
    "Any" : "Apa saja",
    "Minimum seating capacity" : "Kapasitas tempat duduk minimum",
    "More details" : "Detail lebih lanjut",
    "Update this and all future" : "Perbarui ini dan semua yang akan datang",
    "Update this occurrence" : "Perbarui kejadian ini",
    "Public calendar does not exist" : "Kalender publik tidak eksis",
    "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
    "Remove date" : "Hapus tanggal",
    "Attendance required" : "Kehadiran diperlukan",
    "Attendance optional" : "Kehadiran opsional",
    "Remove participant" : "Hapus peserta",
    "Yes" : "Ya",
    "No" : "Tidak",
    "Maybe" : "Mungkin",
    "Select your meeting availability" : "Pilih ketersediaan pertemuan Anda",
    "Create a meeting for this date and time" : "Buat pertemuan untuk tanggal dan waktu ini",
    "Create" : "Buat",
    "No participants or dates available" : "Tidak ada peserta atau tanggal yang tersedia",
    "Type to search time zone" : "Ketik untuk mencari zona waktu",
    "Global" : "Global",
    "Holidays in {region}" : "Hari libur di {region}",
    "An error occurred, unable to read public calendars." : "Terjadi kesalahan, tidak dapat membaca kalender umum.",
    "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
    "Public holiday calendars" : "Kalender hari libur umum",
    "Public calendars" : "Kalender publik",
    "No valid public calendars configured" : "Tidak ada kalender publik yang valid dikonfigurasi",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalender hari libur nasional disediakan oleh Thunderbird. Data kalender akan diunduh dari {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Kalender publik ini disarankan oleh administrator server. Data kalender akan diunduh dari situs web masing-masing.",
    "By {authors}" : "Oleh {authors}",
    "Subscribed" : "Berlangganan",
    "Subscribe" : "Berlangganan",
    "Could not fetch slots" : "Tidak dapat mengambil slot",
    "Select a date" : "Pilih tanggal",
    "Select slot" : "Pilih slot",
    "No slots available" : "Tidak ada slot tersedia",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Terima kasih. Pemesanan Anda dari {startDate} hingga  {endDate} telah dikonfirmasi.",
    "Book another appointment:" : "Pesan janji temu lain:",
    "See all available slots" : "Lihat semua slot tersedia",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot untuk janji temu Anda dari {startDate} hingga {endDate} tidak lagi tersedia.",
    "Please book a different slot:" : "Silakan pesan slot yang berbeda:",
    "Book an appointment with {name}" : "Pesan janji temu dengan {name}",
    "No public appointments found for {name}" : "Tidak ada janji temu publik ditemukan untuk {name}",
    "Personal" : "Pribadi",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
    "Show unscheduled tasks" : "Tampilkan tugas yang belum dijadwalkan",
    "Unscheduled tasks" : "Tugas yang belum dijadwalkan",
    "Availability of {displayName}" : "Ketersediaan {displayName}",
    "Discard changes" : "Buang perubahan",
    "Edit event" : "Sunting agenda",
    "Event does not exist" : "Acara tidak ada",
    "Delete this occurrence" : "Hapus kejadian ini",
    "Delete this and all future" : "Hapus ini dan semua yang akan datang",
    "All day" : "Sepanjang hari",
    "Modifications wont get propagated to the organizer and other attendees" : "Modifikasi tidak akan disebarkan ke penyelenggara dan peserta lain",
    "Add Talk conversation" : "Tambahkan percakapan Talk",
    "Managing shared access" : "Mengelola akses bersama",
    "Deny access" : "Tolak akses",
    "Invite" : "Undangan",
    "Discard changes?" : "Buang perubahan?",
    "Are you sure you want to discard the changes made to this event?" : "Apakah Anda yakin ingin membuang perubahan yang dibuat pada acara ini?",
    "_User requires access to your file_::_Users require access to your file_" : ["Pengguna memerlukan akses ke berkas Anda"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Lampiran yang memerlukan akses bersama"],
    "Untitled event" : "Acara tanpa judul",
    "Close" : "Tutup",
    "Modifications will not get propagated to the organizer and other attendees" : "Modifikasi tidak akan disebarkan ke penyelenggara dan peserta lain",
    "This event was cancelled" : "Acara ini telah dibatalkan",
    "Meeting proposals overview" : "Tinjauan usulan pertemuan",
    "Edit meeting proposal" : "Edit usulan pertemuan",
    "Create meeting proposal" : "Buat usulan pertemuan",
    "Update meeting proposal" : "Perbarui usulan pertemuan",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Buat pertemuan untuk \"{date}\"? Ini akan membuat acara kalender dengan semua peserta.",
    "Saving proposal \"{title}\"" : "Menyimpan usulan \"{title}\"",
    "Successfully saved proposal" : "Berhasil menyimpan usulan",
    "Failed to save proposal" : "Gagal menyimpan usulan",
    "Please enter a valid duration in minutes." : "Silakan masukkan durasi yang valid dalam menit.",
    "Failed to fetch proposals" : "Gagal mengambil usulan",
    "Creating meeting for {date}" : "Membuat pertemuan untuk {date}",
    "Successfully created meeting for {date}" : "Berhasil membuat pertemuan untuk {date}",
    "Failed to create a meeting for {date}" : "Gagal membuat pertemuan untuk {date}",
    "Failed to fetch free/busy data" : "Gagal mengambil data sibuk/luang",
    "Selected" : "Dipilih",
    "No Description" : "Tanpa Deskripsi",
    "No Location" : "Tanpa Lokasi",
    "Edit this meeting proposal" : "Edit usulan pertemuan ini",
    "Delete this meeting proposal" : "Hapus usulan pertemuan ini",
    "Participants" : "Peserta",
    "Selected times" : "Waktu yang dipilih",
    "Previous span" : "Rentang sebelumnya",
    "Next span" : "Rentang berikutnya",
    "Less days" : "Lebih sedikit hari",
    "More days" : "Lebih banyak hari",
    "Loading meeting proposal" : "Memuat usulan pertemuan",
    "No meeting proposal found" : "Tidak ada usulan pertemuan ditemukan",
    "Please wait while we load the meeting proposal." : "Silakan tunggu sementara kami memuat usulan pertemuan.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Tautan yang Anda ikuti mungkin rusak, atau usulan pertemuan mungkin tidak ada lagi.",
    "Thank you for your response!" : "Terima kasih atas tanggapan Anda!",
    "Your vote has been recorded. Thank you for participating!" : "Suara Anda telah dicatat. Terima kasih telah berpartisipasi!",
    "Unknown User" : "Pengguna Tidak Dikenal",
    "No Title" : "Tanpa Judul",
    "No Duration" : "Tanpa Durasi",
    "Select a different time zone" : "Pilih zona waktu yang berbeda",
    "Submit" : "Kirim",
    "Subscribe to {name}" : "Berlangganan ke {name}",
    "Export {name}" : "Ekspor {name}",
    "Show availability" : "Tampilkan ketersediaan",
    "Anniversary" : "Hari jadi",
    "Appointment" : "Janji",
    "Business" : "Bisnis",
    "Education" : "Edukasi",
    "Holiday" : "Hari raya",
    "Meeting" : "Rapat",
    "Miscellaneous" : "Lain-lain",
    "Non-working hours" : "Luar waktu kerja",
    "Not in office" : "Tidak ada di kantor",
    "Phone call" : "Panggilan telepon",
    "Sick day" : "Hari sakit",
    "Special occasion" : "Acara khusus",
    "Travel" : "Perjalanan",
    "Vacation" : "Liburan",
    "Midnight on the day the event starts" : "Tengah malam pada hari acara dimulai",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n hari sebelum acara {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n pekan sebelum acara {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Pada hari acara {formattedHourMinute}",
    "at the event's start" : "pada awal acara",
    "at the event's end" : "pada akhir acara",
    "{time} before the event starts" : "{time} sebelum acara berlangsung",
    "{time} before the event ends" : "{time} sebelum acara berakhir",
    "{time} after the event starts" : "{time} setelah acara berlangsung",
    "{time} after the event ends" : "{time} setelah acara berakhir",
    "on {time}" : "pada {time}",
    "on {time} ({timezoneId})" : "pada {time} ({timezoneId})",
    "Week {number} of {year}" : "Pekan {number} tahun {year}",
    "Daily" : "Harian",
    "Weekly" : "Mingguan",
    "Monthly" : "Bulanan",
    "Yearly" : "Tahunan",
    "_Every %n day_::_Every %n days_" : ["Setiap %n hari"],
    "_Every %n week_::_Every %n weeks_" : ["Setiap %n pekan"],
    "_Every %n month_::_Every %n months_" : ["Setiap %n bulan"],
    "_Every %n year_::_Every %n years_" : ["Setiap %n tahun"],
    "_on {weekday}_::_on {weekdays}_" : ["pada {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "pada {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "di {monthNames} pada {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "di {monthNames} pada {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "sampai {untilDate}",
    "_%n time_::_%n times_" : ["%n kali"],
    "second" : "detik",
    "third" : "ke-3",
    "fourth" : "ke-4",
    "fifth" : "ke-5",
    "second to last" : "kedua terakhir",
    "last" : "terakhir",
    "Untitled task" : "Tugas tanpa judul",
    "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
    "You are not allowed to edit this event as an attendee." : "Anda tidak diizinkan mengedit acara ini sebagai peserta.",
    "W" : "M",
    "%n more" : "%n lainnya",
    "No events to display" : "Tidak ada acara untuk ditampilkan",
    "All participants declined" : "Semua peserta menolak",
    "Please confirm your participation" : "Silakan konfirmasi partisipasi Anda",
    "You declined this event" : "Anda menolak acara ini",
    "Your participation is tentative" : "Partisipasi Anda tentatif",
    "_+%n more_::_+%n more_" : ["+%n lagi"],
    "No events" : "Tidak ada acara",
    "Create a new event or change the visible time-range" : "Buat acara baru atau ubah rentang waktu yang terlihat",
    "It might have been deleted, or there was a typo in a link" : "Mungkin telah dihapus, atau ada kesalahan ketik di tautan",
    "Failed to save event" : "Gagal menyimpan acara",
    "It might have been deleted, or there was a typo in the link" : "Mungkin telah dihapus, atau ada kesalahan ketik di tautan",
    "Meeting room" : "Ruang pertemuan",
    "Lecture hall" : "Aula kuliah",
    "Seminar room" : "Ruang seminar",
    "Other" : "Lainnya",
    "When shared show" : "Saat dibagikan tampilkan",
    "When shared show full event" : "Saat dibagikan tampilkan acara lengkap",
    "When shared show only busy" : "Saat dibagikan tampilkan hanya sibuk",
    "When shared hide this event" : "Saat dibagikan sembunyikan acara ini",
    "The visibility of this event in read-only shared calendars." : "Visibilitas acara ini di kalender bersama baca-saja.",
    "Add a location" : "Tambah lokasi",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Tambahkan deskripsi\n\n- Tentang apa pertemuan ini\n- Item agenda\n- Apa pun yang perlu disiapkan peserta",
    "Confirmed" : "Terkonfirmasi",
    "Canceled" : "Dibatalkan",
    "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
    "Show as" : "Tampilkan sebagai",
    "Take this event into account when calculating free-busy information." : "Pertimbangkan acara ini saat perhitungan waktu luang dan sibuk.",
    "Categories" : "Kategori",
    "Categories help you to structure and organize your events." : "Kategori membantu Anda menyusun dan mengatur acara.",
    "Search or add categories" : "Cari atau tambah kategori",
    "Add this as a new category" : "Tambah sebagai kategori baru",
    "Custom color" : "Warna khusus",
    "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
    "Error while sharing file" : "Kesalahan saat membagikan berkas",
    "Error while sharing file with user" : "Kesalahan saat membagikan berkas dengan pengguna",
    "Error creating a folder {folder}" : "Kesalahan membuat folder {folder}",
    "Attachment {fileName} already exists!" : "Lampiran {fileName} sudah ada!",
    "Attachment {fileName} added!" : "Lampiran {fileName} ditambahkan!",
    "An error occurred during uploading file {fileName}" : "Terjadi kesalahan saat mengunggah berkas {fileName}",
    "An error occurred during getting file information" : "Terjadi kesalahan saat mendapatkan informasi berkas",
    "Talk conversation for proposal" : "Percakapan Talk untuk usulan",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Imported {filename}" : "Mengimpor {filename}",
    "This is an event reminder." : "Ini adalah pengingat acara.",
    "Error while parsing a PROPFIND error" : "Kesalahan saat mengurai kesalahan PROPFIND",
    "Appointment not found" : "Janji temu tidak ditemukan",
    "User not found" : "Pengguna tidak ditemukan",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendars" : "Kalender",
    "Hidden" : "Sembunyi",
    "Calendar name …" : "Nama kalender …",
    "Default attachments location" : "Lokasi lampiran default",
    "Automatic ({detected})" : "Otomatis ({detected})",
    "Shortcut overview" : "Ikhtisar pintasan",
    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
    "Enable simplified editor" : "Aktifkan editor serderhana",
    "Limit the number of events displayed in the monthly view" : "Batasi jumlah acara yang ditampilkan dalam tampilan bulanan",
    "Show weekends" : "Tampilkan akhir pekan",
    "Show week numbers" : "Tampilkan nomor pekan",
    "Time increments" : "Kenaikan waktu",
    "Default reminder" : "Pengingat default",
    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
    "Personal availability settings" : "Pengaturan ketersediaan pribadi",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Public – shown on the profile page" : "Publik – ditampilkan di halaman profil",
    "Private – only accessible via secret link" : "Pribadi – hanya dapat diakses melalui tautan rahasia",
    "Additional calendars to check for conflicts" : "Kalender tambahan untuk memeriksa konflik",
    "Pick time ranges where appointments are allowed" : "Pilih rentang waktu di mana janji temu diizinkan",
    "Add time before and after the event" : "Tambahkan waktu sebelum dan sesudah acara",
    "Before the event" : "Sebelum acara",
    "After the event" : "Setelah acara",
    "Minimum time before next available slot" : "Waktu minimum sebelum slot berikutnya tersedia",
    "Create a new public conversation" : "Buat percakapan publik baru",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} diundang, {confirmedCount} dikonfirmasi",
    "Successfully appended link to talk room to location." : "Berhasil menambahkan tautan ke ruangan talk ke lokasi.",
    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
    "Error creating Talk room" : "Galat membuat ruangan Talk",
    "_%n more guest_::_%n more guests_" : ["%n tamu lainnya"],
    "Event title" : "Judul acara",
    "_time_::_times_" : ["kali"],
    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
    "from {formattedDate}" : "dari {formattedDate}",
    "to {formattedDate}" : "hingga {formattedDate}",
    "on {formattedDate}" : "dalam {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "dari {formattedDate} pada {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "hingga {formattedDate} pada {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "pada {formattedDate} pada {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} pada {formattedTime}",
    "Please enter a valid date" : "Silakan isi tanggal valid",
    "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
    "Select a time zone" : "Pilih zona waktu",
    "Please select a time zone:" : "Silakan pilih zona waktu:",
    "Pick a time" : "Pilih waktu",
    "Pick a date" : "Pilih tanggal",
    "Speak to the server administrator to resolve this issue." : "Hubungi administrator server untuk menyelesaikan masalah ini.",
    "The slot for your appointment has been confirmed" : "Slot untuk janji temu Anda telah dikonfirmasi",
    "Appointment Details:" : "Detail Janji Temu:",
    "Time:" : "Waktu:",
    "Booked for:" : "Dipesan untuk:"
},
"nplurals=1; plural=0;");
