(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcColorPicker-CGE4Kei4_mjs"],{31223(e,a,t){"use strict";t.r(a);var r=t(71354),o=t.n(r),n=t(76314),i=t.n(n)()(o());i.push([e.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-fab7cffe] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
.color-picker[data-v-fab7cffe] {
  display: flex;
  overflow: hidden;
  align-content: flex-end;
  flex-direction: column;
  justify-content: space-between;
  padding: var(--border-radius-element);
  min-width: calc(4 * var(--default-clickable-area) + 2 * var(--border-radius-element));
}
.color-picker--clearable[data-v-fab7cffe] {
  min-width: calc(5 * var(--default-clickable-area) + 2 * var(--border-radius-element));
}
.color-picker--advanced-fields[data-v-fab7cffe] {
  min-width: 264px;
}
.color-picker__clear[data-v-fab7cffe] {
  color: var(--color-main-text);
}
.color-picker__clear[data-v-fab7cffe]:hover:not(:has(:checked)) {
  color: var(--color-text-maxcontrast);
}
.color-picker__simple[data-v-fab7cffe] {
  display: grid;
  grid-template-columns: repeat(auto-fit, var(--default-clickable-area));
  grid-auto-rows: var(--default-clickable-area);
}
.color-picker__simple-color-circle[data-v-fab7cffe] {
  display: flex;
  align-items: center;
  justify-content: center;
  width: calc(var(--default-clickable-area) - 10px);
  height: calc(var(--default-clickable-area) - 10px);
  min-height: calc(var(--default-clickable-area) - 10px);
  margin: auto;
  padding: 0;
  color: white;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 50%;
  font-size: 16px;
}
.color-picker__simple-color-circle[data-v-fab7cffe]:focus-within {
  outline: 2px solid var(--color-main-text);
}
.color-picker__simple-color-circle[data-v-fab7cffe]:hover {
  opacity: 0.6;
}
.color-picker__simple-color-circle--active[data-v-fab7cffe] {
  width: calc(var(--default-clickable-area) - 6px);
  height: calc(var(--default-clickable-area) - 6px);
  min-height: calc(var(--default-clickable-area) - 6px);
  transition: all 100ms ease-in-out;
  opacity: 1 !important;
}
.color-picker__advanced[data-v-fab7cffe] {
  box-shadow: none !important;
}
.color-picker__navigation[data-v-fab7cffe] {
  display: flex;
  flex-direction: row;
  gap: var(--default-grid-baseline);
  justify-content: space-between;
  margin-top: calc(2 * var(--default-grid-baseline));
}
[data-v-fab7cffe]  .vc-chrome {
  width: unset;
  background-color: var(--color-main-background);
}
[data-v-fab7cffe]  .vc-chrome-color-wrap {
  width: 30px;
  height: 30px;
}
[data-v-fab7cffe]  .vc-chrome-active-color {
  border-radius: 17px;
}
[data-v-fab7cffe]  .vc-chrome-body {
  padding: 14px 0 0 0;
  background-color: var(--color-main-background);
}
[data-v-fab7cffe]  .vc-chrome-body .vc-input__input {
  --input-border-radius: var(--border-radius-element);
  --input-border-width-offset: calc(var(--border-width-input-focused, 2px) - var(--border-width-input, 2px));
  width: 100%;
  height: var(--default-clickable-area);
  margin: 0;
  padding-inline: calc(var(--border-radius-element) + var(--input-border-width-offset));
  padding-block: var(--input-border-width-offset);
  border: var(--border-width-input, 2px) solid var(--color-border-maxcontrast);
  border-radius: var(--input-border-radius);
  font-size: var(--default-font-size);
  color: var(--color-main-text);
  box-shadow: none;
}
[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:active:not([disabled]),[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:hover:not([disabled]),[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:focus:not([disabled]) {
  --input-border-width-offset: 0px;
  border-color: var(--color-main-text);
  border-width: var(--border-width-input-focused, 2px);
  box-shadow: 0 0 0 2px var(--color-main-background) !important;
}
[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:active:not([disabled]) + .vc-input__label,[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:hover:not([disabled]) + .vc-input__label,[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:focus:not([disabled]) + .vc-input__label {
  color: var(--color-main-text);
}
[data-v-fab7cffe]  .vc-chrome-body .vc-input__label {
  position: absolute;
  inset-inline: var(--border-width-input-focused, 2px);
  inset-block-start: calc(-1.5 * var(--font-size-small, 13px) / 2);
  max-width: fit-content;
  margin-inline: calc(var(--border-radius-element) - var(--default-grid-baseline));
  margin-block: 0;
  padding-inline: var(--default-grid-baseline);
  font-family: var(--font-face);
  font-size: var(--font-size-small, 13px);
  line-height: 1.5;
  font-weight: var(--font-weight-element, 500);
  color: var(--color-text-maxcontrast);
  background-color: var(--color-main-background);
  pointer-events: none;
}
[data-v-fab7cffe]  .vc-chrome-toggle-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  width: var(--default-clickable-area);
  height: var(--default-clickable-area);
  margin-inline-start: 6px;
  filter: var(--background-invert-if-dark);
}
[data-v-fab7cffe]  .vc-chrome-toggle-icon {
  width: 24px;
  height: 24px;
  margin: 0;
}
[data-v-fab7cffe]  .vc-chrome-toggle-icon-highlight {
  width: var(--default-clickable-area);
  height: var(--default-clickable-area);
  inset: 0;
}
[data-v-fab7cffe]  .vc-chrome-saturation-wrap {
  border-radius: 3px;
}
[data-v-fab7cffe]  .vc-chrome-saturation-circle {
  width: 20px;
  height: 20px;
}
.slide-enter-from[data-v-fab7cffe] {
  transform: translateX(-50%);
  opacity: 0;
}
.slide-enter-to[data-v-fab7cffe] {
  transform: translateX(0);
  opacity: 1;
}
.slide-leave-from[data-v-fab7cffe] {
  transform: translateX(0);
  opacity: 1;
}
.slide-leave-to[data-v-fab7cffe] {
  transform: translateX(-50%);
  opacity: 0;
}
.slide-enter-active[data-v-fab7cffe], .slide-leave-active[data-v-fab7cffe] {
  transition: all 50ms ease-in-out;
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcColorPicker-DVYGs8R3.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,aAAa;EACb,gBAAgB;EAChB,uBAAuB;EACvB,sBAAsB;EACtB,8BAA8B;EAC9B,qCAAqC;EACrC,qFAAqF;AACvF;AACA;EACE,qFAAqF;AACvF;AACA;EACE,gBAAgB;AAClB;AACA;EACE,6BAA6B;AAC/B;AACA;EACE,oCAAoC;AACtC;AACA;EACE,aAAa;EACb,sEAAsE;EACtE,6CAA6C;AAC/C;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,iDAAiD;EACjD,kDAAkD;EAClD,sDAAsD;EACtD,YAAY;EACZ,UAAU;EACV,YAAY;EACZ,qCAAqC;EACrC,kBAAkB;EAClB,eAAe;AACjB;AACA;EACE,yCAAyC;AAC3C;AACA;EACE,YAAY;AACd;AACA;EACE,gDAAgD;EAChD,iDAAiD;EACjD,qDAAqD;EACrD,iCAAiC;EACjC,qBAAqB;AACvB;AACA;EACE,2BAA2B;AAC7B;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,iCAAiC;EACjC,8BAA8B;EAC9B,kDAAkD;AACpD;AACA;EACE,YAAY;EACZ,8CAA8C;AAChD;AACA;EACE,WAAW;EACX,YAAY;AACd;AACA;EACE,mBAAmB;AACrB;AACA;EACE,mBAAmB;EACnB,8CAA8C;AAChD;AACA;EACE,mDAAmD;EACnD,0GAA0G;EAC1G,WAAW;EACX,qCAAqC;EACrC,SAAS;EACT,qFAAqF;EACrF,+CAA+C;EAC/C,4EAA4E;EAC5E,yCAAyC;EACzC,mCAAmC;EACnC,6BAA6B;EAC7B,gBAAgB;AAClB;AACA;EACE,gCAAgC;EAChC,oCAAoC;EACpC,oDAAoD;EACpD,6DAA6D;AAC/D;AACA;EACE,6BAA6B;AAC/B;AACA;EACE,kBAAkB;EAClB,oDAAoD;EACpD,gEAAgE;EAChE,sBAAsB;EACtB,gFAAgF;EAChF,eAAe;EACf,4CAA4C;EAC5C,6BAA6B;EAC7B,uCAAuC;EACvC,gBAAgB;EAChB,4CAA4C;EAC5C,oCAAoC;EACpC,8CAA8C;EAC9C,oBAAoB;AACtB;AACA;EACE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,oCAAoC;EACpC,qCAAqC;EACrC,wBAAwB;EACxB,wCAAwC;AAC1C;AACA;EACE,WAAW;EACX,YAAY;EACZ,SAAS;AACX;AACA;EACE,oCAAoC;EACpC,qCAAqC;EACrC,QAAQ;AACV;AACA;EACE,kBAAkB;AACpB;AACA;EACE,WAAW;EACX,YAAY;AACd;AACA;EACE,2BAA2B;EAC3B,UAAU;AACZ;AACA;EACE,wBAAwB;EACxB,UAAU;AACZ;AACA;EACE,wBAAwB;EACxB,UAAU;AACZ;AACA;EACE,2BAA2B;EAC3B,UAAU;AACZ;AACA;EACE,gCAAgC;AAClC",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-fab7cffe] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.color-picker[data-v-fab7cffe] {\n  display: flex;\n  overflow: hidden;\n  align-content: flex-end;\n  flex-direction: column;\n  justify-content: space-between;\n  padding: var(--border-radius-element);\n  min-width: calc(4 * var(--default-clickable-area) + 2 * var(--border-radius-element));\n}\n.color-picker--clearable[data-v-fab7cffe] {\n  min-width: calc(5 * var(--default-clickable-area) + 2 * var(--border-radius-element));\n}\n.color-picker--advanced-fields[data-v-fab7cffe] {\n  min-width: 264px;\n}\n.color-picker__clear[data-v-fab7cffe] {\n  color: var(--color-main-text);\n}\n.color-picker__clear[data-v-fab7cffe]:hover:not(:has(:checked)) {\n  color: var(--color-text-maxcontrast);\n}\n.color-picker__simple[data-v-fab7cffe] {\n  display: grid;\n  grid-template-columns: repeat(auto-fit, var(--default-clickable-area));\n  grid-auto-rows: var(--default-clickable-area);\n}\n.color-picker__simple-color-circle[data-v-fab7cffe] {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: calc(var(--default-clickable-area) - 10px);\n  height: calc(var(--default-clickable-area) - 10px);\n  min-height: calc(var(--default-clickable-area) - 10px);\n  margin: auto;\n  padding: 0;\n  color: white;\n  border: 1px solid rgba(0, 0, 0, 0.25);\n  border-radius: 50%;\n  font-size: 16px;\n}\n.color-picker__simple-color-circle[data-v-fab7cffe]:focus-within {\n  outline: 2px solid var(--color-main-text);\n}\n.color-picker__simple-color-circle[data-v-fab7cffe]:hover {\n  opacity: 0.6;\n}\n.color-picker__simple-color-circle--active[data-v-fab7cffe] {\n  width: calc(var(--default-clickable-area) - 6px);\n  height: calc(var(--default-clickable-area) - 6px);\n  min-height: calc(var(--default-clickable-area) - 6px);\n  transition: all 100ms ease-in-out;\n  opacity: 1 !important;\n}\n.color-picker__advanced[data-v-fab7cffe] {\n  box-shadow: none !important;\n}\n.color-picker__navigation[data-v-fab7cffe] {\n  display: flex;\n  flex-direction: row;\n  gap: var(--default-grid-baseline);\n  justify-content: space-between;\n  margin-top: calc(2 * var(--default-grid-baseline));\n}\n[data-v-fab7cffe]  .vc-chrome {\n  width: unset;\n  background-color: var(--color-main-background);\n}\n[data-v-fab7cffe]  .vc-chrome-color-wrap {\n  width: 30px;\n  height: 30px;\n}\n[data-v-fab7cffe]  .vc-chrome-active-color {\n  border-radius: 17px;\n}\n[data-v-fab7cffe]  .vc-chrome-body {\n  padding: 14px 0 0 0;\n  background-color: var(--color-main-background);\n}\n[data-v-fab7cffe]  .vc-chrome-body .vc-input__input {\n  --input-border-radius: var(--border-radius-element);\n  --input-border-width-offset: calc(var(--border-width-input-focused, 2px) - var(--border-width-input, 2px));\n  width: 100%;\n  height: var(--default-clickable-area);\n  margin: 0;\n  padding-inline: calc(var(--border-radius-element) + var(--input-border-width-offset));\n  padding-block: var(--input-border-width-offset);\n  border: var(--border-width-input, 2px) solid var(--color-border-maxcontrast);\n  border-radius: var(--input-border-radius);\n  font-size: var(--default-font-size);\n  color: var(--color-main-text);\n  box-shadow: none;\n}\n[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:active:not([disabled]),[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:hover:not([disabled]),[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:focus:not([disabled]) {\n  --input-border-width-offset: 0px;\n  border-color: var(--color-main-text);\n  border-width: var(--border-width-input-focused, 2px);\n  box-shadow: 0 0 0 2px var(--color-main-background) !important;\n}\n[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:active:not([disabled]) + .vc-input__label,[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:hover:not([disabled]) + .vc-input__label,[data-v-fab7cffe]  .vc-chrome-body .vc-input__input:focus:not([disabled]) + .vc-input__label {\n  color: var(--color-main-text);\n}\n[data-v-fab7cffe]  .vc-chrome-body .vc-input__label {\n  position: absolute;\n  inset-inline: var(--border-width-input-focused, 2px);\n  inset-block-start: calc(-1.5 * var(--font-size-small, 13px) / 2);\n  max-width: fit-content;\n  margin-inline: calc(var(--border-radius-element) - var(--default-grid-baseline));\n  margin-block: 0;\n  padding-inline: var(--default-grid-baseline);\n  font-family: var(--font-face);\n  font-size: var(--font-size-small, 13px);\n  line-height: 1.5;\n  font-weight: var(--font-weight-element, 500);\n  color: var(--color-text-maxcontrast);\n  background-color: var(--color-main-background);\n  pointer-events: none;\n}\n[data-v-fab7cffe]  .vc-chrome-toggle-btn {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  width: var(--default-clickable-area);\n  height: var(--default-clickable-area);\n  margin-inline-start: 6px;\n  filter: var(--background-invert-if-dark);\n}\n[data-v-fab7cffe]  .vc-chrome-toggle-icon {\n  width: 24px;\n  height: 24px;\n  margin: 0;\n}\n[data-v-fab7cffe]  .vc-chrome-toggle-icon-highlight {\n  width: var(--default-clickable-area);\n  height: var(--default-clickable-area);\n  inset: 0;\n}\n[data-v-fab7cffe]  .vc-chrome-saturation-wrap {\n  border-radius: 3px;\n}\n[data-v-fab7cffe]  .vc-chrome-saturation-circle {\n  width: 20px;\n  height: 20px;\n}\n.slide-enter-from[data-v-fab7cffe] {\n  transform: translateX(-50%);\n  opacity: 0;\n}\n.slide-enter-to[data-v-fab7cffe] {\n  transform: translateX(0);\n  opacity: 1;\n}\n.slide-leave-from[data-v-fab7cffe] {\n  transform: translateX(0);\n  opacity: 1;\n}\n.slide-leave-to[data-v-fab7cffe] {\n  transform: translateX(-50%);\n  opacity: 0;\n}\n.slide-enter-active[data-v-fab7cffe], .slide-leave-active[data-v-fab7cffe] {\n  transition: all 50ms ease-in-out;\n}"],sourceRoot:""}]),t.d(a,{},{default:i})},34158(e,a,t){var r=t(31223);r.__esModule&&(r=r.default),"string"==typeof r&&(r=[[e.id,r,""]]),r.locals&&(e.exports=r.locals),(0,t(15739).A)("794b6178",r,!0,{})},15135(e,a,t){"use strict";t.d(a,{N:()=>eR}),t(34158);var r=t(20641),o=t(50953),n=t(90033),i=t(53751);function l(e,a){"string"==typeof(t=e)&&-1!==t.indexOf(".")&&1===parseFloat(t)&&(e="100%");var t,r,o="string"==typeof(r=e)&&-1!==r.indexOf("%");return(e=360===a?e:Math.min(a,Math.max(0,parseFloat(e))),o&&(e=parseInt(String(e*a),10)/100),1e-6>Math.abs(e-a))?1:e=360===a?(e<0?e%a+a:e%a)/parseFloat(String(a)):e%a/parseFloat(String(a))}function c(e){return Math.min(1,Math.max(0,e))}function s(e){return(isNaN(e=parseFloat(e))||e<0||e>1)&&(e=1),e}function h(e){return e<=1?"".concat(100*Number(e),"%"):e}function d(e){return 1===e.length?"0"+e:String(e)}function u(e,a,t){e=l(e,255);var r=Math.max(e,a=l(a,255),t=l(t,255)),o=Math.min(e,a,t),n=0,i=0,c=(r+o)/2;if(r===o)i=0,n=0;else{var s=r-o;switch(i=c>.5?s/(2-r-o):s/(r+o),r){case e:n=(a-t)/s+6*(a<t);break;case a:n=(t-e)/s+2;break;case t:n=(e-a)/s+4}n/=6}return{h:n,s:i,l:c}}function f(e,a,t){return(t<0&&(t+=1),t>1&&(t-=1),t<1/6)?e+6*t*(a-e):t<.5?a:t<2/3?e+(a-e)*(2/3-t)*6:e}function p(e,a,t){e=l(e,255);var r=Math.max(e,a=l(a,255),t=l(t,255)),o=Math.min(e,a,t),n=0,i=r-o;if(r===o)n=0;else{switch(r){case e:n=(a-t)/i+6*(a<t);break;case a:n=(t-e)/i+2;break;case t:n=(e-a)/i+4}n/=6}return{h:n,s:0===r?0:i/r,v:r}}function v(e,a,t,r){var o=[d(Math.round(e).toString(16)),d(Math.round(a).toString(16)),d(Math.round(t).toString(16))];return r&&o[0].startsWith(o[0].charAt(1))&&o[1].startsWith(o[1].charAt(1))&&o[2].startsWith(o[2].charAt(1))?o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0):o.join("")}function g(e){return parseInt(e,16)}var b={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",goldenrod:"#daa520",gold:"#ffd700",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavenderblush:"#fff0f5",lavender:"#e6e6fa",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"},A="(?:".concat("[-\\+]?\\d*\\.\\d+%?",")|(?:").concat("[-\\+]?\\d+%?",")"),m="[\\s|\\(]+(".concat(A,")[,|\\s]+(").concat(A,")[,|\\s]+(").concat(A,")\\s*\\)?"),C="[\\s|\\(]+(".concat(A,")[,|\\s]+(").concat(A,")[,|\\s]+(").concat(A,")[,|\\s]+(").concat(A,")\\s*\\)?"),x={CSS_UNIT:new RegExp(A),rgb:RegExp("rgb"+m),rgba:RegExp("rgba"+C),hsl:RegExp("hsl"+m),hsla:RegExp("hsla"+C),hsv:RegExp("hsv"+m),hsva:RegExp("hsva"+C),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/};function k(e){return!!x.CSS_UNIT.exec(String(e))}var w=function(){function e(a,t){if(void 0===a&&(a=""),void 0===t&&(t={}),a instanceof e)return a;"number"==typeof a&&(a={r:(D=a)>>16,g:(65280&D)>>8,b:255&D}),this.originalInput=a;var r,o,n,i,c,d,u,p,v,A,m,C,w,y,E,_,B,M,S,L,D,F,H=(y={r:0,g:0,b:0},E=1,_=null,B=null,M=null,S=!1,L=!1,"string"==typeof(r=a)&&(r=function(e){if(0===(e=e.trim().toLowerCase()).length)return!1;var a=!1;if(b[e])e=b[e],a=!0;else if("transparent"===e)return{r:0,g:0,b:0,a:0,format:"name"};var t=x.rgb.exec(e);return t?{r:t[1],g:t[2],b:t[3]}:(t=x.rgba.exec(e))?{r:t[1],g:t[2],b:t[3],a:t[4]}:(t=x.hsl.exec(e))?{h:t[1],s:t[2],l:t[3]}:(t=x.hsla.exec(e))?{h:t[1],s:t[2],l:t[3],a:t[4]}:(t=x.hsv.exec(e))?{h:t[1],s:t[2],v:t[3]}:(t=x.hsva.exec(e))?{h:t[1],s:t[2],v:t[3],a:t[4]}:(t=x.hex8.exec(e))?{r:g(t[1]),g:g(t[2]),b:g(t[3]),a:g(t[4])/255,format:a?"name":"hex8"}:(t=x.hex6.exec(e))?{r:g(t[1]),g:g(t[2]),b:g(t[3]),format:a?"name":"hex"}:(t=x.hex4.exec(e))?{r:g(t[1]+t[1]),g:g(t[2]+t[2]),b:g(t[3]+t[3]),a:g(t[4]+t[4])/255,format:a?"name":"hex8"}:!!(t=x.hex3.exec(e))&&{r:g(t[1]+t[1]),g:g(t[2]+t[2]),b:g(t[3]+t[3]),format:a?"name":"hex"}}(r)),"object"==typeof r&&(k(r.r)&&k(r.g)&&k(r.b)?(o=r.r,n=r.g,i=r.b,y={r:255*l(o,255),g:255*l(n,255),b:255*l(i,255)},S=!0,L="%"===String(r.r).substr(-1)?"prgb":"rgb"):k(r.h)&&k(r.s)&&k(r.v)?(_=h(r.s),B=h(r.v),c=r.h,d=_,u=B,c=6*l(c,360),d=l(d,100),u=l(u,100),p=Math.floor(c),v=c-p,A=u*(1-d),m=u*(1-v*d),C=u*(1-(1-v)*d),y={r:255*[u,m,A,A,C,u][w=p%6],g:255*[C,u,u,m,A,A][w],b:255*[A,A,C,u,u,m][w]},S=!0,L="hsv"):k(r.h)&&k(r.s)&&k(r.l)&&(_=h(r.s),M=h(r.l),y=function(e,a,t){if(e=l(e,360),a=l(a,100),t=l(t,100),0===a)o=t,n=t,r=t;else{var r,o,n,i=t<.5?t*(1+a):t+a-t*a,c=2*t-i;r=f(c,i,e+1/3),o=f(c,i,e),n=f(c,i,e-1/3)}return{r:255*r,g:255*o,b:255*n}}(r.h,_,M),S=!0,L="hsl"),Object.prototype.hasOwnProperty.call(r,"a")&&(E=r.a)),E=s(E),{ok:S,format:r.format||L,r:Math.min(255,Math.max(y.r,0)),g:Math.min(255,Math.max(y.g,0)),b:Math.min(255,Math.max(y.b,0)),a:E});this.originalInput=a,this.r=H.r,this.g=H.g,this.b=H.b,this.a=H.a,this.roundA=Math.round(100*this.a)/100,this.format=null!=(F=t.format)?F:H.format,this.gradientType=t.gradientType,this.r<1&&(this.r=Math.round(this.r)),this.g<1&&(this.g=Math.round(this.g)),this.b<1&&(this.b=Math.round(this.b)),this.isValid=H.ok}return e.prototype.isDark=function(){return 128>this.getBrightness()},e.prototype.isLight=function(){return!this.isDark()},e.prototype.getBrightness=function(){var e=this.toRgb();return(299*e.r+587*e.g+114*e.b)/1e3},e.prototype.getLuminance=function(){var e=this.toRgb(),a=e.r/255,t=e.g/255,r=e.b/255;return .2126*(a<=.03928?a/12.92:Math.pow((a+.055)/1.055,2.4))+.7152*(t<=.03928?t/12.92:Math.pow((t+.055)/1.055,2.4))+.0722*(r<=.03928?r/12.92:Math.pow((r+.055)/1.055,2.4))},e.prototype.getAlpha=function(){return this.a},e.prototype.setAlpha=function(e){return this.a=s(e),this.roundA=Math.round(100*this.a)/100,this},e.prototype.isMonochrome=function(){return 0===this.toHsl().s},e.prototype.toHsv=function(){var e=p(this.r,this.g,this.b);return{h:360*e.h,s:e.s,v:e.v,a:this.a}},e.prototype.toHsvString=function(){var e=p(this.r,this.g,this.b),a=Math.round(360*e.h),t=Math.round(100*e.s),r=Math.round(100*e.v);return 1===this.a?"hsv(".concat(a,", ").concat(t,"%, ").concat(r,"%)"):"hsva(".concat(a,", ").concat(t,"%, ").concat(r,"%, ").concat(this.roundA,")")},e.prototype.toHsl=function(){var e=u(this.r,this.g,this.b);return{h:360*e.h,s:e.s,l:e.l,a:this.a}},e.prototype.toHslString=function(){var e=u(this.r,this.g,this.b),a=Math.round(360*e.h),t=Math.round(100*e.s),r=Math.round(100*e.l);return 1===this.a?"hsl(".concat(a,", ").concat(t,"%, ").concat(r,"%)"):"hsla(".concat(a,", ").concat(t,"%, ").concat(r,"%, ").concat(this.roundA,")")},e.prototype.toHex=function(e){return void 0===e&&(e=!1),v(this.r,this.g,this.b,e)},e.prototype.toHexString=function(e){return void 0===e&&(e=!1),"#"+this.toHex(e)},e.prototype.toHex8=function(e){var a,t,r,o,n,i;return void 0===e&&(e=!1),a=this.r,t=this.g,r=this.b,o=this.a,n=e,i=[d(Math.round(a).toString(16)),d(Math.round(t).toString(16)),d(Math.round(r).toString(16)),d(Math.round(255*parseFloat(o)).toString(16))],n&&i[0].startsWith(i[0].charAt(1))&&i[1].startsWith(i[1].charAt(1))&&i[2].startsWith(i[2].charAt(1))&&i[3].startsWith(i[3].charAt(1))?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0)+i[3].charAt(0):i.join("")},e.prototype.toHex8String=function(e){return void 0===e&&(e=!1),"#"+this.toHex8(e)},e.prototype.toHexShortString=function(e){return void 0===e&&(e=!1),1===this.a?this.toHexString(e):this.toHex8String(e)},e.prototype.toRgb=function(){return{r:Math.round(this.r),g:Math.round(this.g),b:Math.round(this.b),a:this.a}},e.prototype.toRgbString=function(){var e=Math.round(this.r),a=Math.round(this.g),t=Math.round(this.b);return 1===this.a?"rgb(".concat(e,", ").concat(a,", ").concat(t,")"):"rgba(".concat(e,", ").concat(a,", ").concat(t,", ").concat(this.roundA,")")},e.prototype.toPercentageRgb=function(){var e=function(e){return"".concat(Math.round(100*l(e,255)),"%")};return{r:e(this.r),g:e(this.g),b:e(this.b),a:this.a}},e.prototype.toPercentageRgbString=function(){var e=function(e){return Math.round(100*l(e,255))};return 1===this.a?"rgb(".concat(e(this.r),"%, ").concat(e(this.g),"%, ").concat(e(this.b),"%)"):"rgba(".concat(e(this.r),"%, ").concat(e(this.g),"%, ").concat(e(this.b),"%, ").concat(this.roundA,")")},e.prototype.toName=function(){if(0===this.a)return"transparent";if(this.a<1)return!1;for(var e="#"+v(this.r,this.g,this.b,!1),a=0,t=Object.entries(b);a<t.length;a++){var r=t[a],o=r[0];if(e===r[1])return o}return!1},e.prototype.toString=function(e){var a=!!e;e=null!=e?e:this.format;var t=!1,r=this.a<1&&this.a>=0;return!a&&r&&(e.startsWith("hex")||"name"===e)?"name"===e&&0===this.a?this.toName():this.toRgbString():("rgb"===e&&(t=this.toRgbString()),"prgb"===e&&(t=this.toPercentageRgbString()),("hex"===e||"hex6"===e)&&(t=this.toHexString()),"hex3"===e&&(t=this.toHexString(!0)),"hex4"===e&&(t=this.toHex8String(!0)),"hex8"===e&&(t=this.toHex8String()),"name"===e&&(t=this.toName()),"hsl"===e&&(t=this.toHslString()),"hsv"===e&&(t=this.toHsvString()),t||this.toHexString())},e.prototype.toNumber=function(){return(Math.round(this.r)<<16)+(Math.round(this.g)<<8)+Math.round(this.b)},e.prototype.clone=function(){return new e(this.toString())},e.prototype.lighten=function(a){void 0===a&&(a=10);var t=this.toHsl();return t.l+=a/100,t.l=c(t.l),new e(t)},e.prototype.brighten=function(a){void 0===a&&(a=10);var t=this.toRgb();return t.r=Math.max(0,Math.min(255,t.r-Math.round(-(a/100*255)))),t.g=Math.max(0,Math.min(255,t.g-Math.round(-(a/100*255)))),t.b=Math.max(0,Math.min(255,t.b-Math.round(-(a/100*255)))),new e(t)},e.prototype.darken=function(a){void 0===a&&(a=10);var t=this.toHsl();return t.l-=a/100,t.l=c(t.l),new e(t)},e.prototype.tint=function(e){return void 0===e&&(e=10),this.mix("white",e)},e.prototype.shade=function(e){return void 0===e&&(e=10),this.mix("black",e)},e.prototype.desaturate=function(a){void 0===a&&(a=10);var t=this.toHsl();return t.s-=a/100,t.s=c(t.s),new e(t)},e.prototype.saturate=function(a){void 0===a&&(a=10);var t=this.toHsl();return t.s+=a/100,t.s=c(t.s),new e(t)},e.prototype.greyscale=function(){return this.desaturate(100)},e.prototype.spin=function(a){var t=this.toHsl(),r=(t.h+a)%360;return t.h=r<0?360+r:r,new e(t)},e.prototype.mix=function(a,t){void 0===t&&(t=50);var r=this.toRgb(),o=new e(a).toRgb(),n=t/100;return new e({r:(o.r-r.r)*n+r.r,g:(o.g-r.g)*n+r.g,b:(o.b-r.b)*n+r.b,a:(o.a-r.a)*n+r.a})},e.prototype.analogous=function(a,t){void 0===a&&(a=6),void 0===t&&(t=30);var r=this.toHsl(),o=360/t,n=[this];for(r.h=(r.h-(o*a>>1)+720)%360;--a;)r.h=(r.h+o)%360,n.push(new e(r));return n},e.prototype.complement=function(){var a=this.toHsl();return a.h=(a.h+180)%360,new e(a)},e.prototype.monochromatic=function(a){void 0===a&&(a=6);for(var t=this.toHsv(),r=t.h,o=t.s,n=t.v,i=[],l=1/a;a--;)i.push(new e({h:r,s:o,v:n})),n=(n+l)%1;return i},e.prototype.splitcomplement=function(){var a=this.toHsl(),t=a.h;return[this,new e({h:(t+72)%360,s:a.s,l:a.l}),new e({h:(t+216)%360,s:a.s,l:a.l})]},e.prototype.onBackground=function(a){var t=this.toRgb(),r=new e(a).toRgb(),o=t.a+r.a*(1-t.a);return new e({r:(t.r*t.a+r.r*r.a*(1-t.a))/o,g:(t.g*t.a+r.g*r.a*(1-t.a))/o,b:(t.b*t.a+r.b*r.a*(1-t.a))/o,a:o})},e.prototype.triad=function(){return this.polyad(3)},e.prototype.tetrad=function(){return this.polyad(4)},e.prototype.polyad=function(a){for(var t=this.toHsl(),r=t.h,o=[this],n=360/a,i=1;i<a;i++)o.push(new e({h:(r+i*n)%360,s:t.s,l:t.l}));return o},e.prototype.equals=function(a){return this.toRgbString()===new e(a).toRgbString()},e}();function y(...e){return new w(...e)}function E(e,a){let t,r=e&&e.a;(t=e&&e.hsl?y(e.hsl):e&&e.hex&&e.hex.length>0?y(e.hex):e&&e.hsv?y(e.hsv):e&&e.rgba?y(e.rgba):e&&e.rgb?y(e.rgb):y(e))&&(void 0===t._a||null===t._a)&&t.setAlpha(r||t.getAlpha());let o=t.toHsl(),n=t.toHsv();return 0===o.s&&(n.h=o.h=e.h||e.hsl&&e.hsl.h||a||0),n.v<.0164&&(n.h=e.h||e.hsv&&e.hsv.h||0,n.s=e.s||e.hsv&&e.hsv.s||0),o.l<.01&&(o.h=e.h||e.hsl&&e.hsl.h||0,o.s=e.s||e.hsl&&e.hsl.s||0),{hsl:o,hex:t.toHexString().toUpperCase(),hex8:t.toHex8String().toUpperCase(),rgba:t.toRgb(),hsv:n,oldHue:e.h||a||o.h,source:e.source,a:t.getAlpha()}}function _(e,a){void 0===a&&(a={});var t=a.insertAt;if(e&&"u">typeof document){var r=document.head||document.getElementsByTagName("head")[0],o=document.createElement("style");o.type="text/css","top"===t&&r.firstChild?r.insertBefore(o,r.firstChild):r.appendChild(o),o.styleSheet?o.styleSheet.cssText=e:o.appendChild(document.createTextNode(e))}}let B=function(e,a){let{componentPrefix:t=""}=a||{};e.component(`${t}${this.name}`,this)};var M={name:"EditableInput",props:{label:String,labelText:String,desc:String,value:[String,Number],max:Number,min:Number,arrowOffset:{type:Number,default:1}},computed:{val:{get(){return this.value},set(e){if(void 0===this.max||!(+e>this.max))return e;this.$refs.input.value=this.max}},labelId(){return`input__label__${this.label}__${Math.random().toString().slice(2,5)}`},labelSpanText(){return this.labelText||this.label}},methods:{update(e){this.handleChange(e.target.value)},handleChange(e){let a={};a[this.label]=e,void 0===a.hex&&void 0===a["#"]?this.$emit("change",a):e.length>5&&this.$emit("change",a)},handleKeyDown(e){let{val:a}=this,t=Number(a);if(t){let r=this.arrowOffset||1;38===e.keyCode&&(a=t+r,this.handleChange(a),e.preventDefault()),40===e.keyCode&&(a=t-r,this.handleChange(a),e.preventDefault())}}}};let S={class:"vc-editable-input"},L=["aria-labelledby"],D=["id","for"],F={class:"vc-input__desc"};function H(e,a,t){return a<t?e<a?a:e>t?t:e:e<t?t:e>a?a:e}_(".vc-editable-input{position:relative}.vc-input__input{border:0;outline:none;padding:0}.vc-input__label{text-transform:capitalize}"),M.render=function(e,a,t,o,l,c){return(0,r.uX)(),(0,r.CE)("div",S,[(0,r.bo)((0,r.Lk)("input",{ref:"input","onUpdate:modelValue":a[0]||(a[0]=e=>c.val=e),"aria-labelledby":c.labelId,class:"vc-input__input",onKeydown:a[1]||(a[1]=(...e)=>c.handleKeyDown&&c.handleKeyDown(...e)),onInput:a[2]||(a[2]=(...e)=>c.update&&c.update(...e))},null,40,L),[[i.vModelText,c.val]]),(0,r.Lk)("span",{id:c.labelId,for:t.label,class:"vc-input__label"},(0,n.toDisplayString)(c.labelSpanText),9,D),(0,r.Lk)("span",F,(0,n.toDisplayString)(t.desc),1)])},M.__file="src/components/editable-input/editable-input.vue",M.install=B;var R={name:"Saturation",props:{value:Object},computed:{colors(){return this.value},bgColor(){return`hsl(${this.colors.hsv.h}, 100%, 50%)`},pointerTop(){return`${-(100*this.colors.hsv.v)+1+100}%`},pointerLeft(){return`${100*this.colors.hsv.s}%`}},methods:{handleChange(e,a){a||e.preventDefault();let{container:t}=this.$refs;if(!t)return;let r=t.clientWidth,o=t.clientHeight,n=t.getBoundingClientRect().left+window.pageXOffset,i=t.getBoundingClientRect().top+window.pageYOffset,l=e.pageX||(e.touches?e.touches[0].pageX:0),c=e.pageY||(e.touches?e.touches[0].pageY:0),s=H(l-n,0,r),h=H(c-i,0,o),d=H(-(h/o)+1,0,1);this.onChange({h:this.colors.hsv.h,s:s/r,v:d,a:this.colors.hsv.a,source:"hsva"})},onChange(e){this.$emit("change",e)},handleMouseDown(e){window.addEventListener("mousemove",this.handleChange),window.addEventListener("mouseup",this.handleChange),window.addEventListener("mouseup",this.handleMouseUp)},handleMouseUp(e){this.unbindEventListeners()},unbindEventListeners(){window.removeEventListener("mousemove",this.handleChange),window.removeEventListener("mouseup",this.handleChange),window.removeEventListener("mouseup",this.handleMouseUp)}}};let X=(0,r.Lk)("div",{class:"vc-saturation--white"},null,-1),z=(0,r.Lk)("div",{class:"vc-saturation--black"},null,-1),N=[(0,r.Lk)("div",{class:"vc-saturation-circle"},null,-1)];_(".vc-saturation,.vc-saturation--black,.vc-saturation--white{bottom:0;cursor:pointer;left:0;position:absolute;right:0;top:0}.vc-saturation--white{background:linear-gradient(90deg,#fff,hsla(0,0%,100%,0))}.vc-saturation--black{background:linear-gradient(0deg,#000,transparent)}.vc-saturation-pointer{cursor:pointer;position:absolute}.vc-saturation-circle{border-radius:50%;box-shadow:0 0 0 1.5px #fff,inset 0 0 1px 1px rgba(0,0,0,.3),0 0 1px 2px rgba(0,0,0,.4);cursor:head;height:4px;transform:translate(-2px,-2px);width:4px}"),R.render=function(e,a,t,o,i,l){return(0,r.uX)(),(0,r.CE)("div",{ref:"container",class:"vc-saturation",style:(0,n.normalizeStyle)({background:l.bgColor}),onMousedown:a[0]||(a[0]=(...e)=>l.handleMouseDown&&l.handleMouseDown(...e)),onTouchmove:a[1]||(a[1]=(...e)=>l.handleChange&&l.handleChange(...e)),onTouchstart:a[2]||(a[2]=(...e)=>l.handleChange&&l.handleChange(...e))},[X,z,(0,r.Lk)("div",{class:"vc-saturation-pointer",style:(0,n.normalizeStyle)({top:l.pointerTop,left:l.pointerLeft})},N,4)],36)},R.__file="src/components/saturation/saturation.vue",R.install=B;var $={name:"Hue",props:{value:Object,direction:{type:String,default:"horizontal"}},data:()=>({oldHue:0,pullDirection:""}),computed:{colors(){return this.value},directionClass(){return{"vc-hue--horizontal":"horizontal"===this.direction,"vc-hue--vertical":"vertical"===this.direction}},pointerTop(){return"vertical"===this.direction?0===this.colors.hsl.h&&"right"===this.pullDirection?0:`${-(100*this.colors.hsl.h/360)+100}%`:0},pointerLeft(){return"vertical"===this.direction?0:0===this.colors.hsl.h&&"right"===this.pullDirection?"100%":`${100*this.colors.hsl.h/360}%`}},watch:{value:{handler(e,a){let{h:t}=e.hsl;0!==t&&t-this.oldHue>0&&(this.pullDirection="right"),0!==t&&t-this.oldHue<0&&(this.pullDirection="left"),this.oldHue=t},deep:!0,immediate:!0}},methods:{handleChange(e,a){let t;a||e.preventDefault();let{container:r}=this.$refs;if(!r)return;let o=r.clientWidth,n=r.clientHeight,i=r.getBoundingClientRect().left+window.pageXOffset,l=r.getBoundingClientRect().top+window.pageYOffset,c=e.pageX||(e.touches?e.touches[0].pageX:0),s=e.pageY||(e.touches?e.touches[0].pageY:0),h=c-i,d=s-l;t="vertical"===this.direction?d<0?360:d>n?0:360*(-(100*d/n)+100)/100:h<0?0:h>o?360:100*h/o*360/100,this.colors.hsl.h!==t&&this.$emit("change",{h:t,s:this.colors.hsl.s,l:this.colors.hsl.l,a:this.colors.hsl.a,source:"hsl"})},handleMouseDown(e){this.handleChange(e,!0),window.addEventListener("mousemove",this.handleChange),window.addEventListener("mouseup",this.handleChange),window.addEventListener("mouseup",this.handleMouseUp)},handleMouseUp(e){this.unbindEventListeners()},unbindEventListeners(){window.removeEventListener("mousemove",this.handleChange),window.removeEventListener("mouseup",this.handleChange),window.removeEventListener("mouseup",this.handleMouseUp)}}};let I=["aria-valuenow"],j=[(0,r.Lk)("div",{class:"vc-hue-picker"},null,-1)];_(".vc-hue{border-radius:2px;bottom:0;left:0;position:absolute;right:0;top:0}.vc-hue--horizontal{background:linear-gradient(90deg,red 0,#ff0 17%,#0f0 33%,#0ff 50%,#00f 67%,#f0f 83%,red)}.vc-hue--vertical{background:linear-gradient(0deg,red 0,#ff0 17%,#0f0 33%,#0ff 50%,#00f 67%,#f0f 83%,red)}.vc-hue-container{cursor:pointer;height:100%;margin:0 2px;position:relative}.vc-hue-pointer{position:absolute;z-index:2}.vc-hue-picker{background:#fff;border-radius:1px;box-shadow:0 0 2px rgba(0,0,0,.6);cursor:pointer;height:8px;margin-top:1px;transform:translateX(-2px);width:4px}"),$.render=function(e,a,t,o,i,l){return(0,r.uX)(),(0,r.CE)("div",{class:(0,n.normalizeClass)(["vc-hue",[l.directionClass]])},[(0,r.Lk)("div",{ref:"container",class:"vc-hue-container",role:"slider","aria-valuenow":l.colors.hsl.h,"aria-valuemin":"0","aria-valuemax":"360",onMousedown:a[0]||(a[0]=(...e)=>l.handleMouseDown&&l.handleMouseDown(...e)),onTouchmove:a[1]||(a[1]=(...e)=>l.handleChange&&l.handleChange(...e)),onTouchstart:a[2]||(a[2]=(...e)=>l.handleChange&&l.handleChange(...e))},[(0,r.Lk)("div",{class:"vc-hue-pointer",style:(0,n.normalizeStyle)({top:l.pointerTop,left:l.pointerLeft}),role:"presentation"},j,4)],40,I)],2)},$.__file="src/components/hue/hue.vue",$.install=B;let q={};var T={name:"Checkboard",props:{size:{type:[Number,String],default:8},white:{type:String,default:"#fff"},grey:{type:String,default:"#e6e6e6"}},computed:{bgStyle(){return{"background-image":`url(${function(e,a,t){let r=`${e},${a},${t}`;if(q[r])return q[r];let o=function(e,a,t){if("u"<typeof document)return null;let r=document.createElement("canvas");r.width=r.height=2*t;let o=r.getContext("2d");return o?(o.fillStyle=e,o.fillRect(0,0,r.width,r.height),o.fillStyle=a,o.fillRect(0,0,t,t),o.translate(t,t),o.fillRect(0,0,t,t),r.toDataURL()):null}(e,a,t);return q[r]=o,o}(this.white,this.grey,this.size)})`}}}};_(".vc-checkerboard{background-size:contain;bottom:0;left:0;position:absolute;right:0;top:0}"),T.render=function(e,a,t,o,i,l){return(0,r.uX)(),(0,r.CE)("div",{class:"vc-checkerboard",style:(0,n.normalizeStyle)(l.bgStyle)},null,4)},T.__file="src/components/checkboard/checkboard.vue",T.install=B;var U={name:"Alpha",components:{Checkboard:T},props:{value:Object,onChange:Function},computed:{colors(){return this.value},gradientColor(){let{rgba:e}=this.colors,a=[e.r,e.g,e.b].join(",");return`linear-gradient(to right, rgba(${a}, 0) 0%, rgba(${a}, 1) 100%)`}},methods:{handleChange(e,a){let t;a||e.preventDefault();let{container:r}=this.$refs;if(!r)return;let o=r.clientWidth,n=r.getBoundingClientRect().left+window.pageXOffset,i=(e.pageX||(e.touches?e.touches[0].pageX:0))-n;t=i<0?0:i>o?1:Math.round(100*i/o)/100,this.colors.a!==t&&this.$emit("change",{h:this.colors.hsl.h,s:this.colors.hsl.s,l:this.colors.hsl.l,a:t,source:"rgba"})},handleMouseDown(e){this.handleChange(e,!0),window.addEventListener("mousemove",this.handleChange),window.addEventListener("mouseup",this.handleMouseUp)},handleMouseUp(){this.unbindEventListeners()},unbindEventListeners(){window.removeEventListener("mousemove",this.handleChange),window.removeEventListener("mouseup",this.handleMouseUp)}}};let W={class:"vc-alpha"},V={class:"vc-alpha-checkboard-wrap"},P=[(0,r.Lk)("div",{class:"vc-alpha-picker"},null,-1)];_(".vc-alpha,.vc-alpha-checkboard-wrap{bottom:0;left:0;position:absolute;right:0;top:0}.vc-alpha-checkboard-wrap{overflow:hidden}.vc-alpha-gradient{bottom:0;left:0;position:absolute;right:0;top:0}.vc-alpha-container{cursor:pointer;height:100%;margin:0 3px;position:relative;z-index:2}.vc-alpha-pointer{position:absolute;z-index:2}.vc-alpha-picker{background:#fff;border-radius:1px;box-shadow:0 0 2px rgba(0,0,0,.6);cursor:pointer;height:8px;margin-top:1px;transform:translateX(-2px);width:4px}"),U.render=function(e,a,t,o,i,l){let c=(0,r.g2)("Checkboard");return(0,r.uX)(),(0,r.CE)("div",W,[(0,r.Lk)("div",V,[(0,r.bF)(c)]),(0,r.Lk)("div",{class:"vc-alpha-gradient",style:(0,n.normalizeStyle)({background:l.gradientColor})},null,4),(0,r.Lk)("div",{ref:"container",class:"vc-alpha-container",onMousedown:a[0]||(a[0]=(...e)=>l.handleMouseDown&&l.handleMouseDown(...e)),onTouchmove:a[1]||(a[1]=(...e)=>l.handleChange&&l.handleChange(...e)),onTouchstart:a[2]||(a[2]=(...e)=>l.handleChange&&l.handleChange(...e))},[(0,r.Lk)("div",{class:"vc-alpha-pointer",style:(0,n.normalizeStyle)({left:`${100*l.colors.a}%`})},P,4)],544)])},U.__file="src/components/alpha/alpha.vue",U.install=B;var Y={name:"Chrome",components:{Saturation:R,Hue:$,Alpha:U,EdIn:M,Checkboard:T},mixins:[{model:{prop:"modelValue",event:"update:modelValue"},props:["modelValue"],data(){return{val:E(this.modelValue)}},computed:{colors:{get(){return this.val},set(e){this.val=e,this.$emit("update:modelValue",e)}}},watch:{modelValue(e){this.val=E(e)}},methods:{colorChange(e,a){this.oldHue=this.colors.hsl.h,this.colors=E(e,a||this.oldHue)},isValidHex:e=>y(e).isValid,simpleCheckForValidColor(e){let a=["r","g","b","a","h","s","l","v"],t=0,r=0;for(let o=0;o<a.length;o++){let n=a[o];e[n]&&(t++,!isNaN(e[n])&&r++)}if(t===r)return e},paletteUpperCase:e=>e.map(e=>e.toUpperCase()),isTransparent:e=>0===y(e).getAlpha()}}],props:{disableAlpha:{type:Boolean,default:!1},disableFields:{type:Boolean,default:!1},format:{type:String,default:"hex"}},data:()=>({fieldsIndex:"hex",highlight:!1}),computed:{hsl(){let{h:e,s:a,l:t}=this.colors.hsl;return{h:e.toFixed(),s:`${(100*a).toFixed()}%`,l:`${(100*t).toFixed()}%`}},activeColor(){let{rgba:e}=this.colors;return`rgba(${[e.r,e.g,e.b,e.a].join(",")})`},hasAlpha(){return this.colors.a<1}},watch:{format:{handler(e){this.fieldsIndex=e},immediate:!0}},methods:{childChange(e){this.colorChange(e)},inputChange(e){if(e){if(e.hex)this.isValidHex(e.hex)&&this.colorChange({hex:e.hex,source:"hex"});else if(e.r||e.g||e.b||e.a)this.colorChange({r:e.r||this.colors.rgba.r,g:e.g||this.colors.rgba.g,b:e.b||this.colors.rgba.b,a:e.a||this.colors.rgba.a,source:"rgba"});else if(e.h||e.s||e.l){let a=e.s?e.s.replace("%","")/100:this.colors.hsl.s,t=e.l?e.l.replace("%","")/100:this.colors.hsl.l;this.colorChange({h:e.h||this.colors.hsl.h,s:a,l:t,source:"hsl"})}}},toggleViews(){switch(this.fieldsIndex){case"hex":this.fieldsIndex=`rgb${this.disableAlpha?"":"a"}`;break;case"rgb":case"rgba":this.fieldsIndex=`hsl${this.disableAlpha?"":"a"}`;break;default:this.fieldsIndex="hex"}this.$emit("update:format",this.fieldsIndex)},showHighlight(){this.highlight=!0},hideHighlight(){this.highlight=!1}}};let O={class:"vc-chrome-saturation-wrap"},Q={class:"vc-chrome-body"},G={class:"vc-chrome-controls"},Z={class:"vc-chrome-color-wrap"},K=["aria-label"],J={class:"vc-chrome-sliders"},ee={class:"vc-chrome-hue-wrap"},ea={key:0,class:"vc-chrome-alpha-wrap"},et={key:0,class:"vc-chrome-fields-wrap"},er={class:"vc-chrome-fields"},eo={class:"vc-chrome-field"},en={class:"vc-chrome-fields"},ei={class:"vc-chrome-field"},el={class:"vc-chrome-field"},ec={class:"vc-chrome-field"},es={key:0,class:"vc-chrome-field"},eh={class:"vc-chrome-fields"},ed={class:"vc-chrome-field"},eu={class:"vc-chrome-field"},ef={class:"vc-chrome-field"},ep={key:0,class:"vc-chrome-field"},ev={class:"vc-chrome-toggle-icon"},eg=[(0,r.Lk)("path",{fill:"#333",d:"M12,18.17L8.83,15L7.42,16.41L12,21L16.59,16.41L15.17,15M12,5.83L15.17,9L16.58,7.59L12,3L7.41,7.59L8.83,9L12,5.83Z"},null,-1)],eb={class:"vc-chrome-toggle-icon-highlight"};_(".vc-chrome{background:#fff;background-color:#fff;border-radius:2px;box-shadow:0 0 2px rgba(0,0,0,.3),0 4px 8px rgba(0,0,0,.3);box-sizing:initial;font-family:Menlo;width:225px}.vc-chrome-controls{display:flex}.vc-chrome-color-wrap{position:relative;width:36px}.vc-chrome-active-color{border-radius:15px;height:30px;overflow:hidden;position:relative;width:30px;z-index:1}.vc-chrome-color-wrap .vc-checkerboard{background-size:auto;border-radius:15px;height:30px;width:30px}.vc-chrome-sliders{flex:1}.vc-chrome-fields-wrap{display:flex;padding-top:16px}.vc-chrome-fields{display:flex;flex:1;margin-left:-6px}.vc-chrome-field{padding-left:6px;width:100%}.vc-chrome-toggle-btn{position:relative;text-align:right;width:32px}.vc-chrome-toggle-icon{cursor:pointer;margin-right:-4px;margin-top:12px;position:relative;z-index:2}.vc-chrome-toggle-icon-highlight{background:#eee;border-radius:4px;height:28px;left:12px;position:absolute;top:10px;width:24px}.vc-chrome-hue-wrap{margin-bottom:8px}.vc-chrome-alpha-wrap,.vc-chrome-hue-wrap{height:10px;position:relative}.vc-chrome-alpha-wrap .vc-alpha-gradient,.vc-chrome-hue-wrap .vc-hue{border-radius:2px}.vc-chrome-alpha-wrap .vc-alpha-picker,.vc-chrome-hue-wrap .vc-hue-picker{background-color:#f8f8f8;border-radius:6px;box-shadow:0 1px 4px 0 rgba(0,0,0,.37);height:12px;transform:translate(-6px,-2px);width:12px}.vc-chrome-body{background-color:#fff;padding:16px 16px 12px}.vc-chrome-saturation-wrap{border-radius:2px 2px 0 0;overflow:hidden;padding-bottom:55%;position:relative;width:100%}.vc-chrome-saturation-wrap .vc-saturation-circle{height:12px;width:12px}.vc-chrome-fields .vc-input__input{border:none;border-radius:2px;box-shadow:inset 0 0 0 1px #dadada;color:#333;font-size:11px;height:21px;text-align:center;width:100%}.vc-chrome-fields .vc-input__label{color:#969696;display:block;font-size:11px;line-height:11px;margin-top:12px;text-align:center;text-transform:uppercase}.vc-chrome__disable-alpha .vc-chrome-active-color{height:18px;width:18px}.vc-chrome__disable-alpha .vc-chrome-color-wrap{width:30px}.vc-chrome__disable-alpha .vc-chrome-hue-wrap{margin-bottom:4px;margin-top:4px}"),Y.render=function(e,a,t,o,l,c){let s=(0,r.g2)("Saturation"),h=(0,r.g2)("Checkboard"),d=(0,r.g2)("Hue"),u=(0,r.g2)("Alpha"),f=(0,r.g2)("EdIn");return(0,r.uX)(),(0,r.CE)("div",{role:"application","aria-label":"Chrome color picker",class:(0,n.normalizeClass)(["vc-chrome",[t.disableAlpha?"vc-chrome__disable-alpha":""]])},[(0,r.Lk)("div",O,[(0,r.bF)(s,{value:e.colors,onChange:c.childChange},null,8,["value","onChange"])]),(0,r.Lk)("div",Q,[(0,r.Lk)("div",G,[(0,r.Lk)("div",Z,[(0,r.Lk)("div",{"aria-label":`current color is ${e.colors.hex}`,class:"vc-chrome-active-color",style:(0,n.normalizeStyle)({background:c.activeColor})},null,12,K),t.disableAlpha?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.Wv)(h,{key:0}))]),(0,r.Lk)("div",J,[(0,r.Lk)("div",ee,[(0,r.bF)(d,{value:e.colors,onChange:c.childChange},null,8,["value","onChange"])]),t.disableAlpha?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.CE)("div",ea,[(0,r.bF)(u,{value:e.colors,onChange:c.childChange},null,8,["value","onChange"])]))])]),t.disableFields?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.CE)("div",et,[(0,r.bo)((0,r.Lk)("div",er,[(0,r.Q3)(" hex "),(0,r.Lk)("div",eo,[c.hasAlpha?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.Wv)(f,{key:0,label:"hex",value:e.colors.hex,onChange:c.inputChange},null,8,["value","onChange"])),c.hasAlpha?((0,r.uX)(),(0,r.Wv)(f,{key:1,label:"hex",value:e.colors.hex8,onChange:c.inputChange},null,8,["value","onChange"])):(0,r.Q3)("v-if",!0)])],512),[[i.vShow,"hex"===l.fieldsIndex]]),(0,r.bo)((0,r.Lk)("div",en,[(0,r.Q3)(" rgba "),(0,r.Lk)("div",ei,[(0,r.bF)(f,{label:"r",value:e.colors.rgba.r,onChange:c.inputChange},null,8,["value","onChange"])]),(0,r.Lk)("div",el,[(0,r.bF)(f,{label:"g",value:e.colors.rgba.g,onChange:c.inputChange},null,8,["value","onChange"])]),(0,r.Lk)("div",ec,[(0,r.bF)(f,{label:"b",value:e.colors.rgba.b,onChange:c.inputChange},null,8,["value","onChange"])]),t.disableAlpha?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.CE)("div",es,[(0,r.bF)(f,{label:"a",value:e.colors.a,"arrow-offset":.01,max:1,onChange:c.inputChange},null,8,["value","arrow-offset","onChange"])]))],512),[[i.vShow,["rgb","rgba"].includes(l.fieldsIndex)]]),(0,r.bo)((0,r.Lk)("div",eh,[(0,r.Q3)(" hsla "),(0,r.Lk)("div",ed,[(0,r.bF)(f,{label:"h",value:c.hsl.h,onChange:c.inputChange},null,8,["value","onChange"])]),(0,r.Lk)("div",eu,[(0,r.bF)(f,{label:"s",value:c.hsl.s,onChange:c.inputChange},null,8,["value","onChange"])]),(0,r.Lk)("div",ef,[(0,r.bF)(f,{label:"l",value:c.hsl.l,onChange:c.inputChange},null,8,["value","onChange"])]),t.disableAlpha?(0,r.Q3)("v-if",!0):((0,r.uX)(),(0,r.CE)("div",ep,[(0,r.bF)(f,{label:"a",value:e.colors.a,"arrow-offset":.01,max:1,onChange:c.inputChange},null,8,["value","arrow-offset","onChange"])]))],512),[[i.vShow,["hsl","hsla"].includes(l.fieldsIndex)]]),(0,r.Q3)(" btn "),(0,r.Lk)("div",{class:"vc-chrome-toggle-btn",role:"button","aria-label":"Change another color definition",onClick:a[3]||(a[3]=(...e)=>c.toggleViews&&c.toggleViews(...e))},[(0,r.Lk)("div",ev,[((0,r.uX)(),(0,r.CE)("svg",{style:{width:"24px",height:"24px"},viewBox:"0 0 24 24",onMouseover:a[0]||(a[0]=(...e)=>c.showHighlight&&c.showHighlight(...e)),onMouseenter:a[1]||(a[1]=(...e)=>c.showHighlight&&c.showHighlight(...e)),onMouseout:a[2]||(a[2]=(...e)=>c.hideHighlight&&c.hideHighlight(...e))},eg,32))]),(0,r.bo)((0,r.Lk)("div",eb,null,512),[[i.vShow,l.highlight]])]),(0,r.Q3)(" btn ")]))])],2)},Y.__file="src/components/chrome/chrome.vue",Y.install=B;var eA=t(98190),em=t(22436),eC=t(62839),ex=t(34163),ek=t(3168),ew=t(42221),ey=t(51012),eE=t(99143),e_=t(52697);(0,em.r)(em.w);let eB=["aria-label"],eM={key:0,class:"color-picker__simple"},eS=["aria-label","name","checked","onClick"],eL=["title"],eD=["aria-label","name","checked"],eF={key:0,class:"color-picker__navigation"},eH=(0,r.pM)({__name:"NcColorPicker",props:(0,r.zz)({advancedFields:{type:Boolean},clearable:{type:Boolean},container:{default:"body"},palette:{default:()=>[]},paletteOnly:{type:Boolean}},{modelValue:{required:!0},modelModifiers:{},open:{type:Boolean},openModifiers:{}}),emits:(0,r.zz)(["submit","closed"],["update:modelValue","update:open"]),setup(e,{emit:a}){let t=(0,r.fn)(e,"modelValue"),l=(0,r.fn)(e,"open"),c=/^#([a-f0-9]{3}|[a-f0-9]{6})$/i,s=(0,ex.c)(),h=(0,o.KR)(!1),d=(0,r.EW)(()=>{let a=e.palette;for(let e of a)if("string"==typeof e&&!e.match(c)||"object"==typeof e&&!e.color?.match(c)){ek.l.error("[NcColorPicker] Invalid palette passed",{color:e}),a=[];break}return 0===a.length&&(a=e.clearable?[...eC.d,eC.a,eC.b]:[...eC.d]),a.map(e=>({color:"object"==typeof e?e.color:e,name:"object"==typeof e&&e.name?e.name:(0,em.a)("A color with a HEX value {hex}",{hex:"string"==typeof e?e:e.color})}))});function u(e){t.value=e.hex}return(c,f)=>((0,r.uX)(),(0,r.Wv)((0,o.R1)(eE.N),{shown:l.value,"onUpdate:shown":f[3]||(f[3]=e=>l.value=e),container:e.container,popupRole:"dialog",onApplyHide:f[4]||(f[4]=e=>a("closed"))},{trigger:(0,r.k6)(e=>[(0,r.RG)(c.$slots,"default",(0,n.normalizeProps)((0,r.Ng)(e)),void 0,!0)]),default:(0,r.k6)(l=>[(0,r.Lk)("div",{role:"dialog",class:(0,n.normalizeClass)(["color-picker",{"color-picker--advanced-fields":h.value&&e.advancedFields,"color-picker--clearable":e.clearable}]),"aria-modal":"true","aria-label":(0,o.R1)(em.a)("Color picker")},[(0,r.bF)(i.Transition,{name:"slide",mode:"out-in"},{default:(0,r.k6)(()=>[h.value?((0,r.uX)(),(0,r.Wv)((0,o.R1)(Y),{key:1,class:"color-picker__advanced",disableAlpha:"",disableFields:!e.advancedFields,modelValue:t.value??"#000000","onUpdate:modelValue":u},null,8,["disableFields","modelValue"])):((0,r.uX)(),(0,r.CE)("div",eM,[((0,r.uX)(!0),(0,r.CE)(r.FK,null,(0,r.pI)(d.value,({color:a,name:i},l)=>((0,r.uX)(),(0,r.CE)("label",{key:l,class:(0,n.normalizeClass)(["color-picker__simple-color-circle",{"color-picker__simple-color-circle--active":a===t.value}]),style:(0,n.normalizeStyle)({backgroundColor:a,color:function(e){var a;let t,[r,o,n]=(a=e,(t=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(a))?[parseInt(t[1],16),parseInt(t[2],16),parseInt(t[3],16)]:[0,0,0]);return(.2126*r+.7152*o+.0722*n)/255}(a)>.5?eC.a.color:eC.b.color})},[a===t.value?((0,r.uX)(),(0,r.Wv)((0,o.R1)(ey.N),{key:0,path:(0,o.R1)(eA.d)},null,8,["path"])):(0,r.Q3)("",!0),(0,r.Lk)("input",{type:"radio",class:"hidden-visually","aria-label":i,name:`color-picker-${(0,o.R1)(s)}`,checked:a===t.value,onClick:r=>{var o;o="string"==typeof(o=a)?o:o.color,e.clearable&&t.value===o?t.value=void 0:t.value=o}},null,8,eS)],6))),128)),e.clearable?((0,r.uX)(),(0,r.CE)("label",{key:0,class:"color-picker__clear",title:(0,o.R1)(em.a)("No color")},[(0,r.bF)((0,o.R1)(ey.N),{size:t.value?28:34,path:(0,o.R1)(eA.u)},null,8,["size","path"]),(0,r.Lk)("input",{type:"radio",class:"hidden-visually","aria-label":(0,o.R1)(em.a)("No color"),name:`color-picker-${(0,o.R1)(s)}`,checked:!t.value,onClick:f[0]||(f[0]=e=>t.value=void 0)},null,8,eD)],8,eL)):(0,r.Q3)("",!0)]))]),_:1}),e.paletteOnly?(0,r.Q3)("",!0):((0,r.uX)(),(0,r.CE)("div",eF,[h.value?((0,r.uX)(),(0,r.Wv)((0,o.R1)(ew.N),{key:0,"aria-label":(0,o.R1)(em.a)("Back"),title:(0,o.R1)(em.a)("Back"),variant:"tertiary",onClick:f[1]||(f[1]=e=>h.value=!1)},{icon:(0,r.k6)(()=>[(0,r.bF)((0,o.R1)(ey.N),{directional:"",path:(0,o.R1)(eA.v)},null,8,["path"])]),_:1},8,["aria-label","title"])):((0,r.uX)(),(0,r.Wv)((0,o.R1)(ew.N),{key:1,"aria-label":(0,o.R1)(em.a)("More options"),title:(0,o.R1)(em.a)("More options"),variant:"tertiary",onClick:f[2]||(f[2]=e=>h.value=!0)},{icon:(0,r.k6)(()=>[(0,r.bF)((0,o.R1)(ey.N),{path:(0,o.R1)(eA.w)},null,8,["path"])]),_:1},8,["aria-label","title"])),(0,r.bF)((0,o.R1)(ew.N),{variant:"primary",onClick:e=>{var r;return r=l.hide,void(a("submit",t.value),r(),h.value=!1)}},{default:(0,r.k6)(()=>[(0,r.eW)((0,n.toDisplayString)((0,o.R1)(em.a)("Choose")),1)]),_:1},8,["onClick"])]))],10,eB)]),_:3},8,["shown","container"]))}}),eR=(0,e_._)(eH,[["__scopeId","data-v-fab7cffe"]])}}]);
//# sourceMappingURL=calendar-defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcColorPicker-CGE4Kei4_mjs.js.map?v=d53dba8d158d9ae6