(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcDateTimePicker-CK4rhfEB_mjs"],{91838(e,a,t){"use strict";t.r(a);var r=t(71354),n=t.n(r),o=t(76314),i=t.n(o)()(n());i.push([e.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-e6654786] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786] {
  --dp-common-transition: all var(--animation-quick) ease-in;
  --dp-menu-padding: 6px 8px;
  --dp-animation-duration: var(--animation-quick);
  --dp-menu-appear-transition-timing: cubic-bezier(.4, 0, 1, 1);
  --dp-transition-timing: ease-out;
  --dp-action-row-transtion: all 0.2s ease-in;
  --dp-font-family: var(--font-face);
  --dp-border-radius: var(--border-radius-element);
  --dp-cell-border-radius: var(--border-radius-small);
  --dp-transition-length: 22px;
  --dp-transition-timing-general: var(--animation-quick);
  --dp-button-height: var(--default-clickable-area);
  --dp-month-year-row-height: var(--default-clickable-area);
  --dp-month-year-row-button-size: var(--clickable-area-small);
  --dp-button-icon-height: 20px;
  --dp-calendar-wrap-padding: 0 5px;
  --dp-cell-size: var(--default-clickable-area);
  --dp-cell-padding: 5px;
  --dp-common-padding: 10px;
  --dp-input-icon-padding: var(--default-clickable-area);
  --dp-input-padding: 6px 12px;
  --dp-menu-min-width: 260px;
  --dp-action-buttons-padding: 1px 6px;
  --dp-row-margin: 5px 0;
  --dp-calendar-header-cell-padding: 0.5rem;
  --dp-multi-calendars-spacing: 10px;
  --dp-overlay-col-padding: 3px;
  --dp-time-inc-dec-button-size: var(--default-clickable-area);
  --dp-font-size: 1rem;
  --dp-preview-font-size: var(--font-size-small);
  --dp-time-font-size: 2rem;
  --dp-action-button-height: var(--clickable-area-small);
  --dp-action-row-padding: 8px;
  --dp-direction: ltr;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_wrap {
  position: relative;
  width: 100%;
  box-sizing: unset;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_wrap:focus {
  border-color: var(--dp-border-color-hover);
  outline: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_valid {
  box-shadow: 0 0 var(--dp-border-radius) var(--dp-success-color);
  border-color: var(--dp-success-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_valid:hover {
  border-color: var(--dp-success-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_invalid {
  box-shadow: 0 0 var(--dp-border-radius) var(--dp-danger-color);
  border-color: var(--dp-danger-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_invalid:hover {
  border-color: var(--dp-danger-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input {
  background-color: var(--dp-background-color);
  border-radius: var(--dp-border-radius);
  font-family: var(--dp-font-family);
  border: 1px solid var(--dp-border-color);
  outline: none;
  transition: border-color 0.2s cubic-bezier(0.645, 0.045, 0.355, 1);
  width: 100%;
  font-size: var(--dp-font-size);
  line-height: calc(var(--dp-font-size) * 1.5);
  padding: var(--dp-input-padding);
  color: var(--dp-text-color);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input::placeholder {
  opacity: 0.7;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input:hover:not(.dp__input_focus) {
  border-color: var(--dp-border-color-hover);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_not_clearable {
  padding-inline-end: var(--dp-input-not-clearable-padding) !important;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_reg {
  caret-color: rgba(0, 0, 0, 0);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_focus {
  border-color: var(--dp-border-color-focus);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__disabled {
  background: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__disabled::placeholder {
  color: var(--dp-disabled-color-text);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icons {
  display: inline-block;
  width: var(--dp-font-size);
  height: var(--dp-font-size);
  stroke-width: 0;
  font-size: var(--dp-font-size);
  line-height: calc(var(--dp-font-size) * 1.5);
  padding: 6px 12px;
  color: var(--dp-icon-color);
  box-sizing: content-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icon {
  cursor: pointer;
  position: absolute;
  top: 50%;
  inset-inline-start: 0;
  transform: translateY(-50%);
  color: var(--dp-icon-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--clear-btn {
  position: absolute;
  top: 50%;
  inset-inline-end: 0;
  transform: translateY(-50%);
  cursor: pointer;
  color: var(--dp-icon-color);
  background: rgba(0, 0, 0, 0);
  border: none;
  display: inline-flex;
  align-items: center;
  padding: 0;
  margin: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icon_pad {
  padding-inline-start: var(--dp-input-icon-padding);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu {
  background: var(--dp-background-color);
  border-radius: var(--dp-border-radius);
  min-width: var(--dp-menu-min-width);
  font-family: var(--dp-font-family);
  font-size: var(--dp-font-size);
  user-select: none;
  border: 1px solid var(--dp-menu-border-color);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu::after {
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu::before {
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu:focus {
  border: 1px solid var(--dp-menu-border-color);
  outline: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-wrapper {
  position: absolute;
  z-index: 99999;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_inner {
  padding: var(--dp-menu-padding);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu--inner-stretched {
  padding: 6px 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_index {
  z-index: 99999;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-loading, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_readonly, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_disabled {
  position: absolute;
  inset: 0;
  z-index: 999999;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_disabled {
  background: hsla(0, 0%, 100%, 0.5);
  cursor: not-allowed;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_readonly {
  background: rgba(0, 0, 0, 0);
  cursor: default;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-loading {
  background: hsla(0, 0%, 100%, 0.5);
  cursor: default;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-load-container {
  display: flex;
  height: 100%;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-loader {
  width: 48px;
  height: 48px;
  border: var(--dp-loader);
  border-bottom-color: rgba(0, 0, 0, 0);
  border-radius: 50%;
  display: inline-block;
  box-sizing: border-box;
  animation: dp-load-rotation-e6654786 1s linear infinite;
  position: absolute;
}
@keyframes dp-load-rotation-e6654786 {
0% {
    transform: rotate(0deg);
}
100% {
    transform: rotate(360deg);
}
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_top {
  left: var(--dp-arrow-left);
  top: 0;
  height: 12px;
  width: 12px;
  background-color: var(--dp-background-color);
  position: absolute;
  border-inline-end: 1px solid var(--dp-menu-border-color);
  border-top: 1px solid var(--dp-menu-border-color);
  transform: translate(-50%, -50%) rotate(-45deg);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_bottom {
  left: var(--dp-arrow-left);
  bottom: 0;
  height: 12px;
  width: 12px;
  background-color: var(--dp-background-color);
  position: absolute;
  border-inline-end: 1px solid var(--dp-menu-border-color);
  border-bottom: 1px solid var(--dp-menu-border-color);
  transform: translate(-50%, 50%) rotate(45deg);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_extra {
  text-align: center;
  padding: 2px 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates {
  padding: 5px;
  border-inline-end: 1px solid var(--dp-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates[data-dp-mobile] {
  display: flex;
  align-self: center;
  border: none;
  overflow-x: auto;
  max-width: calc(var(--dp-menu-width) - var(--dp-action-row-padding) * 2);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates-collapsed {
  display: flex;
  align-self: center;
  border: none;
  overflow-x: auto;
  max-width: calc(var(--dp-menu-width) - var(--dp-action-row-padding) * 2);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__sidebar_left {
  padding: 5px;
  border-inline-end: 1px solid var(--dp-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__sidebar_right {
  padding: 5px;
  margin-inline-end: 1px solid var(--dp-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range {
  display: block;
  width: 100%;
  padding: 5px;
  text-align: left;
  white-space: nowrap;
  color: var(--dp-text-color);
  border-radius: var(--dp-border-radius);
  transition: var(--dp-common-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range:hover {
  background-color: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
  cursor: pointer;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile] {
  border: 1px solid var(--dp-border-color);
  margin: 0 3px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile]:first-child {
  margin-left: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile]:last-child {
  margin-right: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed {
  border: 1px solid var(--dp-border-color);
  margin: 0 3px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed:first-child {
  margin-left: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed:last-child {
  margin-right: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_content_wrapper {
  display: flex;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_content_wrapper[data-dp-mobile] {
  flex-direction: column-reverse;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-content-wrapper-collapsed {
  flex-direction: column-reverse;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header {
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  color: var(--dp-text-color);
  white-space: nowrap;
  font-weight: bold;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_item {
  text-align: center;
  flex-grow: 1;
  height: var(--dp-cell-size);
  padding: var(--dp-cell-padding);
  width: var(--dp-cell-size);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_row {
  display: flex;
  justify-content: center;
  align-items: center;
  margin: var(--dp-row-margin);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_item {
  text-align: center;
  flex-grow: 1;
  box-sizing: border-box;
  color: var(--dp-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar {
  position: relative;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_cell {
  border-bottom: thin solid var(--dp-border-color);
  padding: var(--dp-calendar-header-cell-padding);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_inner {
  display: flex;
  align-items: center;
  text-align: center;
  justify-content: center;
  border-radius: var(--dp-cell-border-radius);
  height: var(--dp-cell-size);
  padding: var(--dp-cell-padding);
  width: var(--dp-cell-size);
  border: 1px solid rgba(0, 0, 0, 0);
  box-sizing: border-box;
  position: relative;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_inner:hover {
  transition: all 0.2s;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_start, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_start:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_start {
  border-end-end-radius: 0;
  border-start-end-radius: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_end, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_end:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_end {
  border-end-start-radius: 0;
  border-start-start-radius: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_end, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_start, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__active_date {
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_end:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_start:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_offset {
  color: var(--dp-secondary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_disabled {
  color: var(--dp-secondary-color);
  cursor: not-allowed;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_between {
  background: var(--dp-range-between-dates-background-color);
  color: var(--dp-range-between-dates-text-color);
  border-radius: 0;
  border: 1px solid var(--dp-range-between-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_between_week {
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
  border-radius: 0;
  border-top: 1px solid var(--dp-primary-color);
  border-bottom: 1px solid var(--dp-primary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__today {
  border: 1px solid var(--dp-primary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__week_num {
  color: var(--dp-secondary-color);
  text-align: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range {
  border-radius: 0;
  border-top: 1px dashed var(--dp-primary-color);
  border-bottom: 1px dashed var(--dp-primary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_start {
  border-start-start-radius: var(--dp-cell-border-radius);
  border-end-start-radius: var(--dp-cell-border-radius);
  border-inline-start: 1px dashed var(--dp-primary-color);
  border-top: 1px dashed var(--dp-primary-color);
  border-bottom: 1px dashed var(--dp-primary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_end {
  border-start-end-radius: var(--dp-cell-border-radius);
  border-end-end-radius: var(--dp-cell-border-radius);
  border-top: 1px dashed var(--dp-primary-color);
  border-bottom: 1px dashed var(--dp-primary-color);
  border-inline-end: 1px dashed var(--dp-primary-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_separator {
  width: 100%;
  height: 1px;
  background: var(--dp-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_next {
  margin-inline-start: var(--dp-multi-calendars-spacing);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_line, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_dot {
  height: 5px;
  background-color: var(--dp-marker-color);
  position: absolute;
  bottom: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_dot {
  width: 5px;
  border-radius: 50%;
  left: 50%;
  transform: translateX(-50%);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_line {
  width: 100%;
  left: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_tooltip {
  position: absolute;
  border-radius: var(--dp-border-radius);
  background-color: var(--dp-tooltip-color);
  padding: 5px;
  border: 1px solid var(--dp-border-color);
  z-index: 99999;
  box-sizing: border-box;
  cursor: default;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_content {
  white-space: nowrap;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_text {
  display: flex;
  align-items: center;
  flex-flow: row nowrap;
  color: var(--dp-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_mark {
  height: 5px;
  width: 5px;
  border-radius: 50%;
  background-color: var(--dp-text-color);
  color: var(--dp-text-color);
  margin-inline-end: 5px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_bottom_tp {
  bottom: 0;
  height: 8px;
  width: 8px;
  background-color: var(--dp-tooltip-color);
  position: absolute;
  border-inline-end: 1px solid var(--dp-border-color);
  border-bottom: 1px solid var(--dp-border-color);
  transform: translate(-50%, 50%) rotate(45deg);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__instance_calendar {
  position: relative;
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display[data-dp-mobile] {
  flex-direction: column;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--flex-display-collapsed {
  flex-direction: column;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_highlight {
  background-color: var(--dp-highlight-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_row {
  display: flex;
  align-items: center;
  height: var(--dp-month-year-row-height);
  color: var(--dp-text-color);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav {
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  height: var(--dp-month-year-row-button-size);
  width: var(--dp-month-year-row-button-size);
  color: var(--dp-icon-color);
  text-align: center;
  border-radius: 50%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav svg {
  height: var(--dp-button-icon-height);
  width: var(--dp-button-icon-height);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-icon-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  [dir=rtl] .dp__inner_nav {
  transform: rotate(180deg);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav_disabled:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav_disabled {
  background: var(--dp-disabled-color);
  color: var(--dp-disabled-color-text);
  cursor: not-allowed;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select {
  text-align: center;
  cursor: pointer;
  height: var(--dp-month-year-row-height);
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: var(--dp-border-radius);
  box-sizing: border-box;
  color: var(--dp-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
  transition: var(--dp-common-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select {
  width: 50%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select {
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_wrap {
  display: flex;
  flex-direction: row;
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__year_disable_select {
  justify-content: space-around;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--header-wrap {
  display: flex;
  width: 100%;
  flex-direction: column;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay {
  width: 100%;
  background: var(--dp-background-color);
  transition: opacity 1s ease-out;
  z-index: 99999;
  font-family: var(--dp-font-family);
  color: var(--dp-text-color);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--overlay-absolute {
  position: absolute;
  height: 100%;
  top: 0;
  left: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--overlay-relative {
  position: relative;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar-track {
  box-shadow: var(--dp-scroll-bar-background);
  background-color: var(--dp-scroll-bar-background);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar {
  width: 5px;
  background-color: var(--dp-scroll-bar-background);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar-thumb {
  background-color: var(--dp-scroll-bar-color);
  border-radius: 10px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay:focus {
  border: none;
  outline: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__container_flex {
  display: flex;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__container_block {
  display: block;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container {
  flex-direction: column;
  overflow-y: auto;
  height: var(--dp-overlay-height);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_picker_overlay_container {
  height: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_row {
  padding: 0;
  box-sizing: border-box;
  display: flex;
  margin-inline: auto;
  flex-wrap: wrap;
  max-width: 100%;
  width: 100%;
  align-items: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_row {
  flex: 1;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_col {
  box-sizing: border-box;
  width: 33%;
  padding: var(--dp-overlay-col-padding);
  white-space: nowrap;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_pad {
  padding: var(--dp-common-padding) 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active {
  cursor: pointer;
  border-radius: var(--dp-border-radius);
  text-align: center;
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell {
  cursor: pointer;
  border-radius: var(--dp-border-radius);
  text-align: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
  transition: var(--dp-common-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_in_between {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__over_action_scroll {
  right: 5px;
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_disabled {
  cursor: not-allowed;
  background: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_disabled:hover {
  background: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active_disabled {
  cursor: not-allowed;
  background: var(--dp-primary-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active_disabled:hover {
  background: var(--dp-primary-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-overlay-btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-invalid {
  border: none;
  font: inherit;
  transition: var(--dp-common-transition);
  line-height: normal;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-mode-picker {
  display: flex;
  width: 100%;
  align-items: center;
  justify-content: space-between;
  height: var(--dp-cell-size);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--tp-wrap {
  max-width: var(--dp-menu-min-width);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--tp-wrap[data-dp-mobile] {
  max-width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_input {
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  user-select: none;
  font-family: var(--dp-font-family);
  color: var(--dp-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_block {
  padding: 0 20px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_inline {
  padding: 0 10px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_with_button {
  padding: 0 15px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_with_button[data-compact~=true] {
  padding: 0 5px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec {
  padding: 0 10px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec_with_button {
  padding: 0 5px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec_with_button[data-collapsed~=true] {
  padding: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col {
  text-align: center;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-direction: column;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_block {
  font-size: var(--dp-time-font-size);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display_block {
  padding: 0 3px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display_inline {
  padding: 5px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_picker_inline_container {
  display: flex;
  width: 100%;
  justify-content: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button {
  padding: 5px;
  margin: 0;
  height: var(--dp-time-inc-dec-button-size);
  width: var(--dp-time-inc-dec-button-size);
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  border-radius: 50%;
  color: var(--dp-icon-color);
  box-sizing: border-box;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button svg {
  height: var(--dp-time-inc-dec-button-size);
  width: var(--dp-time-inc-dec-button-size);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-icon-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display {
  cursor: pointer;
  color: var(--dp-text-color);
  border-radius: var(--dp-border-radius);
  display: flex;
  align-items: center;
  justify-content: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display:hover:enabled {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_inline {
  width: 100%;
  padding: 0;
  height: 8px;
  cursor: pointer;
  display: flex;
  align-items: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_disabled, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_disabled:hover {
  background: var(--dp-disabled-color);
  color: var(--dp-disabled-color-text);
  cursor: not-allowed;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pm_am_button {
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
  border: none;
  padding: var(--dp-common-padding);
  border-radius: var(--dp-border-radius);
  cursor: pointer;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pm_am_button[data-compact~=true] {
  padding: 7px;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bar {
  width: 100%;
  height: 4px;
  background-color: var(--dp-secondary-color);
  transition: var(--dp-common-transition);
  border-collapse: collapse;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_top:hover .dp__tp_btn_in_r {
  background-color: var(--dp-primary-color);
  transform: rotate(12deg) scale(1.15) translateY(-2px);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_top:hover .dp__tp_btn_in_l {
  background-color: var(--dp-primary-color);
  transform: rotate(-12deg) scale(1.15) translateY(-2px);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bottom:hover .dp__tp_btn_in_r {
  background-color: var(--dp-primary-color);
  transform: rotate(-12deg) scale(1.15) translateY(-2px);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bottom:hover .dp__tp_btn_in_l {
  background-color: var(--dp-primary-color);
  transform: rotate(12deg) scale(1.15) translateY(-2px);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-overlay-btn {
  background: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-invalid {
  background-color: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_row {
  display: flex;
  align-items: center;
  width: 100%;
  padding: var(--dp-action-row-padding);
  box-sizing: border-box;
  color: var(--dp-text-color);
  flex-flow: row nowrap;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_row svg {
  height: var(--dp-button-icon-height);
  width: auto;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__selection_preview {
  display: block;
  color: var(--dp-text-color);
  font-size: var(--dp-preview-font-size);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons {
  display: flex;
  flex: 0;
  white-space: nowrap;
  align-items: center;
  justify-content: flex-end;
  margin-inline-start: auto;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_button {
  display: inline-flex;
  align-items: center;
  background: rgba(0, 0, 0, 0);
  border: 1px solid rgba(0, 0, 0, 0);
  padding: var(--dp-action-buttons-padding);
  line-height: var(--dp-action-button-height);
  margin-inline-start: 3px;
  height: var(--dp-action-button-height);
  cursor: pointer;
  border-radius: var(--dp-border-radius);
  font-size: var(--dp-preview-font-size);
  font-family: var(--dp-font-family);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_cancel {
  color: var(--dp-text-color);
  border: 1px solid var(--dp-border-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_cancel:hover {
  border-color: var(--dp-primary-color);
  transition: var(--dp-action-row-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select {
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select:hover {
  background: var(--dp-primary-color);
  transition: var(--dp-action-row-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select:disabled {
  background: var(--dp-primary-disabled-color);
  cursor: not-allowed;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-quarter-picker-wrap {
  display: flex;
  flex-direction: column;
  height: 100%;
  min-width: var(--dp-menu-min-width);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-disabled {
  cursor: not-allowed;
  background: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-disabled:hover {
  background: var(--dp-disabled-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn {
  width: 100%;
  padding: var(--dp-common-padding);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn:not(.dp--highlighted, .dp--qr-btn-active, .dp--qr-btn-disabled, .dp--qr-btn-between) {
  background: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn:hover:not(.dp--qr-btn-active, .dp--qr-btn-disabled) {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
  transition: var(--dp-common-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--quarter-items {
  display: flex;
  flex-direction: column;
  flex: 1;
  width: 100%;
  height: 100%;
  justify-content: space-evenly;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-active {
  background: var(--dp-primary-color);
  color: var(--dp-primary-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-between {
  background: var(--dp-hover-color);
  color: var(--dp-hover-text-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  :root {
  --dp-common-transition: all 0.1s ease-in;
  --dp-menu-padding: 6px 8px;
  --dp-animation-duration: 0.1s;
  --dp-menu-appear-transition-timing: cubic-bezier(.4, 0, 1, 1);
  --dp-transition-timing: ease-out;
  --dp-action-row-transition: all 0.2s ease-in;
  --dp-font-family: -apple-system, blinkmacsystemfont, "Segoe UI", roboto, oxygen, ubuntu, cantarell, "Open Sans", "Helvetica Neue", sans-serif;
  --dp-border-radius: 4px;
  --dp-cell-border-radius: 4px;
  --dp-transition-length: 22px;
  --dp-transition-timing-general: 0.1s;
  --dp-button-height: 35px;
  --dp-month-year-row-height: 35px;
  --dp-month-year-row-button-size: 25px;
  --dp-button-icon-height: 20px;
  --dp-calendar-wrap-padding: 0 5px;
  --dp-cell-size: 35px;
  --dp-cell-padding: 5px;
  --dp-common-padding: 10px;
  --dp-input-icon-padding: 35px;
  --dp-input-padding: 6px 30px 6px 12px;
  --dp-input-not-clearable-padding: 12px;
  --dp-menu-min-width: 260px;
  --dp-action-buttons-padding: 1px 6px;
  --dp-row-margin: 5px 0;
  --dp-calendar-header-cell-padding: 0.5rem;
  --dp-multi-calendars-spacing: 10px;
  --dp-overlay-col-padding: 3px;
  --dp-time-inc-dec-button-size: 32px;
  --dp-font-size: 1rem;
  --dp-preview-font-size: 0.8rem;
  --dp-time-font-size: 2rem;
  --dp-action-button-height: 22px;
  --dp-action-row-padding: 8px;
  --dp-direction: ltr;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__theme_dark {
  --dp-background-color: #212121;
  --dp-text-color: #fff;
  --dp-hover-color: #484848;
  --dp-hover-text-color: #fff;
  --dp-hover-icon-color: #959595;
  --dp-primary-color: #005cb2;
  --dp-primary-disabled-color: #61a8ea;
  --dp-primary-text-color: #fff;
  --dp-secondary-color: #a9a9a9;
  --dp-border-color: #2d2d2d;
  --dp-menu-border-color: #2d2d2d;
  --dp-border-color-hover: #aaaeb7;
  --dp-border-color-focus: #aaaeb7;
  --dp-disabled-color: #737373;
  --dp-disabled-color-text: #d0d0d0;
  --dp-scroll-bar-background: #212121;
  --dp-scroll-bar-color: #484848;
  --dp-success-color: #00701a;
  --dp-success-color-disabled: #428f59;
  --dp-icon-color: #959595;
  --dp-danger-color: #e53935;
  --dp-marker-color: #e53935;
  --dp-tooltip-color: #3e3e3e;
  --dp-highlight-color: rgb(0 92 178 / 20%);
  --dp-range-between-dates-background-color: var(--dp-hover-color, #484848);
  --dp-range-between-dates-text-color: var(--dp-hover-text-color, #fff);
  --dp-range-between-border-color: var(--dp-hover-color, #fff);
  --dp-loader: 5px solid #005cb2;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__theme_light {
  --dp-background-color: #fff;
  --dp-text-color: #212121;
  --dp-hover-color: #f3f3f3;
  --dp-hover-text-color: #212121;
  --dp-hover-icon-color: #959595;
  --dp-primary-color: #1976d2;
  --dp-primary-disabled-color: #6bacea;
  --dp-primary-text-color: #fff;
  --dp-secondary-color: #c0c4cc;
  --dp-border-color: #ddd;
  --dp-menu-border-color: #ddd;
  --dp-border-color-hover: #aaaeb7;
  --dp-border-color-focus: #aaaeb7;
  --dp-disabled-color: #f6f6f6;
  --dp-scroll-bar-background: #f3f3f3;
  --dp-scroll-bar-color: #959595;
  --dp-success-color: #76d275;
  --dp-success-color-disabled: #a3d9b1;
  --dp-icon-color: #959595;
  --dp-danger-color: #ff6f60;
  --dp-marker-color: #ff6f60;
  --dp-tooltip-color: #fafafa;
  --dp-disabled-color-text: #8e8e8e;
  --dp-highlight-color: rgb(25 118 210 / 10%);
  --dp-range-between-dates-background-color: var(--dp-hover-color, #f3f3f3);
  --dp-range-between-dates-text-color: var(--dp-hover-text-color, #212121);
  --dp-range-between-border-color: var(--dp-hover-color, #f3f3f3);
  --dp-loader: 5px solid #1976d2;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex {
  display: flex;
  align-items: center;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__btn {
  background: none;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__main {
  font-family: var(--dp-font-family);
  user-select: none;
  box-sizing: border-box;
  position: relative;
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__main * {
  direction: var(--dp-direction, ltr);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pointer {
  cursor: pointer;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__icon {
  stroke: currentcolor;
  fill: currentcolor;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button {
  width: 100%;
  text-align: center;
  color: var(--dp-icon-color);
  cursor: pointer;
  display: flex;
  align-items: center;
  place-content: center center;
  padding: var(--dp-common-padding);
  box-sizing: border-box;
  height: var(--dp-button-height);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button.dp__overlay_action {
  position: absolute;
  bottom: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-icon-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button svg {
  height: var(--dp-button-icon-height);
  width: auto;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button_bottom {
  border-bottom-left-radius: var(--dp-border-radius);
  border-bottom-right-radius: var(--dp-border-radius);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display {
  display: flex;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display_with_input {
  flex-direction: column;
  align-items: flex-start;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__relative {
  position: relative;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-leave-active {
  transition: all var(--dp-transition-timing-general) ease-out;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-enter-from {
  opacity: 0;
  transform: translateX(var(--dp-transition-length));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-leave-to {
  opacity: 0;
  transform: translateX(calc(var(--dp-transition-length) * -1));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-enter-from {
  opacity: 0;
  transform: translateX(calc(var(--dp-transition-length) * -1));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-leave-to {
  opacity: 0;
  transform: translateX(var(--dp-transition-length));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-leave-active {
  transition: all var(--dp-animation-duration) var(--dp-transition-timing);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-enter-from {
  opacity: 0;
  transform: translateY(var(--dp-transition-length));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-leave-to {
  opacity: 0;
  transform: translateY(calc(var(--dp-transition-length) * -1));
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--arrow-btn-nav {
  transition: var(--dp-common-transition);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--highlighted {
  background-color: var(--dp-highlight-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--hidden-el {
  visibility: hidden;
}
.vue-date-time-picker__wrapper[data-v-e6654786]  {
}
.vue-date-time-picker__wrapper.vue-date-time-picker__wrapper--teleport[data-v-e6654786] .dp--menu-wrapper {
  z-index: 100001;
}
.vue-date-time-picker__wrapper .vue-date-time-picker--clearable[data-v-e6654786] .dp__input {
  padding-inline-end: var(--default-clickable-area);
}
.vue-date-time-picker__wrapper .vue-date-time-picker__timezone[data-v-e6654786] {
  min-width: unset;
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .icon-vue {
  opacity: 1 !important;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp--tp-wrap,
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__action_extra {
  padding: var(--dp-menu-padding);
  padding-top: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__overlay.dp--overlay-absolute {
  padding: var(--dp-menu-padding);
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__overlay.dp--overlay-absolute .dp__btn.dp__button.dp__button_bottom {
  inset-block-end: 6px;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__button_bottom,
.vue-date-time-picker__wrapper[data-v-e6654786] .dp--tp-wrap .dp__button {
  width: 100%;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__overlay_action {
  width: calc(100% - 16px);
}
.vue-date-time-picker__wrapper[data-v-e6654786] input {
  padding-inline-start: var(--dp-input-icon-padding) !important;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn {
  margin: 0;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__inner_nav {
  height: fit-content;
  width: fit-content;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__button_bottom {
  color: var(--color-primary-element-light);
  background-color: var(--color-primary-element-light);
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp--header-wrap .dp__btn:not(.dp__button_bottom),
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_col .dp__btn {
  background-color: var(--color-main-background);
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp--header-wrap .dp__btn:not(.dp__button_bottom):hover,
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_col .dp__btn:hover {
  background: var(--dp-hover-color);
  color: var(--dp-hover-icon-color);
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__month_year_select {
  flex: 1;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp--time-overlay-btn {
  font-size: calc(2 * var(--default-font-size)) !important;
}
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_input .dp__time_col_reg_block {
  padding: 0 calc(4 * var(--default-grid-baseline));
}
.vue-date-time-picker__wrapper .vue-date-time-picker.dp__theme_dark[data-v-e6654786],
.vue-date-time-picker__wrapper .vue-date-time-picker.dp__theme_light[data-v-e6654786],
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__theme_dark,
.vue-date-time-picker__wrapper[data-v-e6654786] .dp__theme_light {
  --dp-background-color: var(--color-main-background);
  --dp-text-color: var(--color-main-text);
  --dp-hover-color: var(--color-primary-element-light-hover);
  --dp-hover-text-color: var(--color-primary-element-light-text);
  --dp-hover-icon-color: var(--color-primary-element-light-text);
  --dp-primary-color: var(--color-primary-element);
  --dp-primary-disabled-color: var(--color-primary-element-hover);
  --dp-primary-text-color: var(--color-primary-element-text);
  --dp-secondary-color: var(--color-text-maxcontrast);
  --dp-border-color: var(--color-border);
  --dp-menu-border-color: var(--color-border-dark);
  --dp-border-color-hover: var(--color-border-maxcontrast);
  --dp-border-color-focus: var(--color-border-maxcontrast);
  --dp-disabled-color: var(--color-background-dark);
  --dp-disabled-color-text: var(--color-text-maxcontrast);
  --dp-scroll-bar-background: var(--color-scrollbar);
  --dp-scroll-bar-color: var(--color-scrollbar);
  --dp-success-color: var(--color-success);
  --dp-success-color-disabled: var(--color-success-hover);
  --dp-icon-color: var(--color-main-text);
  --dp-danger-color: var(--color-error);
  --dp-marker-color: var(--color-text-error, var(--color-error));
  --dp-tooltip-color: var(--color-main-text);
  --dp-highlight-color: var(--color-main-text);
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcDateTimePicker-HT1ZTE-Z.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,0DAA0D;EAC1D,0BAA0B;EAC1B,+CAA+C;EAC/C,6DAA6D;EAC7D,gCAAgC;EAChC,2CAA2C;EAC3C,kCAAkC;EAClC,gDAAgD;EAChD,mDAAmD;EACnD,4BAA4B;EAC5B,sDAAsD;EACtD,iDAAiD;EACjD,yDAAyD;EACzD,4DAA4D;EAC5D,6BAA6B;EAC7B,iCAAiC;EACjC,6CAA6C;EAC7C,sBAAsB;EACtB,yBAAyB;EACzB,sDAAsD;EACtD,4BAA4B;EAC5B,0BAA0B;EAC1B,oCAAoC;EACpC,sBAAsB;EACtB,yCAAyC;EACzC,kCAAkC;EAClC,6BAA6B;EAC7B,4DAA4D;EAC5D,oBAAoB;EACpB,8CAA8C;EAC9C,yBAAyB;EACzB,sDAAsD;EACtD,4BAA4B;EAC5B,mBAAmB;AACrB;AACA;EACE,kBAAkB;EAClB,WAAW;EACX,iBAAiB;AACnB;AACA;EACE,0CAA0C;EAC1C,aAAa;AACf;AACA;EACE,+DAA+D;EAC/D,qCAAqC;AACvC;AACA;EACE,qCAAqC;AACvC;AACA;EACE,8DAA8D;EAC9D,oCAAoC;AACtC;AACA;EACE,oCAAoC;AACtC;AACA;EACE,4CAA4C;EAC5C,sCAAsC;EACtC,kCAAkC;EAClC,wCAAwC;EACxC,aAAa;EACb,kEAAkE;EAClE,WAAW;EACX,8BAA8B;EAC9B,4CAA4C;EAC5C,gCAAgC;EAChC,2BAA2B;EAC3B,sBAAsB;AACxB;AACA;EACE,YAAY;AACd;AACA;EACE,0CAA0C;AAC5C;AACA;EACE,oEAAoE;AACtE;AACA;EACE,6BAA6B;AAC/B;AACA;EACE,0CAA0C;AAC5C;AACA;EACE,oCAAoC;AACtC;AACA;EACE,oCAAoC;AACtC;AACA;EACE,qBAAqB;EACrB,0BAA0B;EAC1B,2BAA2B;EAC3B,eAAe;EACf,8BAA8B;EAC9B,4CAA4C;EAC5C,iBAAiB;EACjB,2BAA2B;EAC3B,uBAAuB;AACzB;AACA;EACE,eAAe;EACf,kBAAkB;EAClB,QAAQ;EACR,qBAAqB;EACrB,2BAA2B;EAC3B,2BAA2B;AAC7B;AACA;EACE,kBAAkB;EAClB,QAAQ;EACR,mBAAmB;EACnB,2BAA2B;EAC3B,eAAe;EACf,2BAA2B;EAC3B,4BAA4B;EAC5B,YAAY;EACZ,oBAAoB;EACpB,mBAAmB;EACnB,UAAU;EACV,SAAS;AACX;AACA;EACE,kDAAkD;AACpD;AACA;EACE,sCAAsC;EACtC,sCAAsC;EACtC,mCAAmC;EACnC,kCAAkC;EAClC,8BAA8B;EAC9B,iBAAiB;EACjB,6CAA6C;EAC7C,sBAAsB;AACxB;AACA;EACE,sBAAsB;AACxB;AACA;EACE,sBAAsB;AACxB;AACA;EACE,6CAA6C;EAC7C,aAAa;AACf;AACA;EACE,kBAAkB;EAClB,cAAc;AAChB;AACA;EACE,+BAA+B;AACjC;AACA;EACE,cAAc;AAChB;AACA;EACE,cAAc;AAChB;AACA;EACE,kBAAkB;EAClB,QAAQ;EACR,eAAe;AACjB;AACA;EACE,kCAAkC;EAClC,mBAAmB;AACrB;AACA;EACE,4BAA4B;EAC5B,eAAe;AACjB;AACA;EACE,kCAAkC;EAClC,eAAe;AACjB;AACA;EACE,aAAa;EACb,YAAY;EACZ,WAAW;EACX,uBAAuB;EACvB,mBAAmB;AACrB;AACA;EACE,WAAW;EACX,YAAY;EACZ,wBAAwB;EACxB,qCAAqC;EACrC,kBAAkB;EAClB,qBAAqB;EACrB,sBAAsB;EACtB,uDAAuD;EACvD,kBAAkB;AACpB;AACA;AACA;IACI,uBAAuB;AAC3B;AACA;IACI,yBAAyB;AAC7B;AACA;AACA;EACE,0BAA0B;EAC1B,MAAM;EACN,YAAY;EACZ,WAAW;EACX,4CAA4C;EAC5C,kBAAkB;EAClB,wDAAwD;EACxD,iDAAiD;EACjD,+CAA+C;AACjD;AACA;EACE,0BAA0B;EAC1B,SAAS;EACT,YAAY;EACZ,WAAW;EACX,4CAA4C;EAC5C,kBAAkB;EAClB,wDAAwD;EACxD,oDAAoD;EACpD,6CAA6C;AAC/C;AACA;EACE,kBAAkB;EAClB,cAAc;AAChB;AACA;EACE,YAAY;EACZ,mDAAmD;AACrD;AACA;EACE,aAAa;EACb,kBAAkB;EAClB,YAAY;EACZ,gBAAgB;EAChB,wEAAwE;AAC1E;AACA;EACE,aAAa;EACb,kBAAkB;EAClB,YAAY;EACZ,gBAAgB;EAChB,wEAAwE;AAC1E;AACA;EACE,YAAY;EACZ,mDAAmD;AACrD;AACA;EACE,YAAY;EACZ,mDAAmD;AACrD;AACA;EACE,cAAc;EACd,WAAW;EACX,YAAY;EACZ,gBAAgB;EAChB,mBAAmB;EACnB,2BAA2B;EAC3B,sCAAsC;EACtC,uCAAuC;AACzC;AACA;EACE,uCAAuC;EACvC,iCAAiC;EACjC,eAAe;AACjB;AACA;EACE,wCAAwC;EACxC,aAAa;AACf;AACA;EACE,cAAc;AAChB;AACA;EACE,eAAe;AACjB;AACA;EACE,wCAAwC;EACxC,aAAa;AACf;AACA;EACE,cAAc;AAChB;AACA;EACE,eAAe;AACjB;AACA;EACE,aAAa;AACf;AACA;EACE,8BAA8B;AAChC;AACA;EACE,8BAA8B;AAChC;AACA;EACE,kBAAkB;EAClB,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,2BAA2B;EAC3B,mBAAmB;EACnB,iBAAiB;AACnB;AACA;EACE,kBAAkB;EAClB,YAAY;EACZ,2BAA2B;EAC3B,+BAA+B;EAC/B,0BAA0B;EAC1B,sBAAsB;AACxB;AACA;EACE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,4BAA4B;AAC9B;AACA;EACE,kBAAkB;EAClB,YAAY;EACZ,sBAAsB;EACtB,2BAA2B;AAC7B;AACA;EACE,kBAAkB;AACpB;AACA;EACE,gDAAgD;EAChD,+CAA+C;AACjD;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,kBAAkB;EAClB,uBAAuB;EACvB,2CAA2C;EAC3C,2BAA2B;EAC3B,+BAA+B;EAC/B,0BAA0B;EAC1B,kCAAkC;EAClC,sBAAsB;EACtB,kBAAkB;AACpB;AACA;EACE,oBAAoB;AACtB;AACA;EACE,wBAAwB;EACxB,0BAA0B;AAC5B;AACA;EACE,0BAA0B;EAC1B,4BAA4B;AAC9B;AACA;EACE,mCAAmC;EACnC,mCAAmC;AACrC;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,gCAAgC;AAClC;AACA;EACE,gCAAgC;EAChC,mBAAmB;AACrB;AACA;EACE,0DAA0D;EAC1D,+CAA+C;EAC/C,gBAAgB;EAChB,sDAAsD;AACxD;AACA;EACE,mCAAmC;EACnC,mCAAmC;EACnC,gBAAgB;EAChB,6CAA6C;EAC7C,gDAAgD;AAClD;AACA;EACE,yCAAyC;AAC3C;AACA;EACE,gCAAgC;EAChC,kBAAkB;AACpB;AACA;EACE,gBAAgB;EAChB,8CAA8C;EAC9C,iDAAiD;AACnD;AACA;EACE,uDAAuD;EACvD,qDAAqD;EACrD,uDAAuD;EACvD,8CAA8C;EAC9C,iDAAiD;AACnD;AACA;EACE,qDAAqD;EACrD,mDAAmD;EACnD,8CAA8C;EAC9C,iDAAiD;EACjD,qDAAqD;AACvD;AACA;EACE,WAAW;EACX,WAAW;EACX,kCAAkC;AACpC;AACA;EACE,sDAAsD;AACxD;AACA;EACE,WAAW;EACX,wCAAwC;EACxC,kBAAkB;EAClB,SAAS;AACX;AACA;EACE,UAAU;EACV,kBAAkB;EAClB,SAAS;EACT,2BAA2B;AAC7B;AACA;EACE,WAAW;EACX,OAAO;AACT;AACA;EACE,kBAAkB;EAClB,sCAAsC;EACtC,yCAAyC;EACzC,YAAY;EACZ,wCAAwC;EACxC,cAAc;EACd,sBAAsB;EACtB,eAAe;AACjB;AACA;EACE,mBAAmB;AACrB;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,qBAAqB;EACrB,2BAA2B;AAC7B;AACA;EACE,WAAW;EACX,UAAU;EACV,kBAAkB;EAClB,sCAAsC;EACtC,2BAA2B;EAC3B,sBAAsB;AACxB;AACA;EACE,SAAS;EACT,WAAW;EACX,UAAU;EACV,yCAAyC;EACzC,kBAAkB;EAClB,mDAAmD;EACnD,+CAA+C;EAC/C,6CAA6C;AAC/C;AACA;EACE,kBAAkB;EAClB,WAAW;AACb;AACA;EACE,sBAAsB;AACxB;AACA;EACE,sBAAsB;AACxB;AACA;EACE,2CAA2C;AAC7C;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,uCAAuC;EACvC,2BAA2B;EAC3B,sBAAsB;AACxB;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,eAAe;EACf,4CAA4C;EAC5C,2CAA2C;EAC3C,2BAA2B;EAC3B,kBAAkB;EAClB,kBAAkB;AACpB;AACA;EACE,oCAAoC;EACpC,mCAAmC;AACrC;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,yBAAyB;AAC3B;AACA;EACE,oCAAoC;EACpC,oCAAoC;EACpC,mBAAmB;AACrB;AACA;EACE,kBAAkB;EAClB,eAAe;EACf,uCAAuC;EACvC,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,sCAAsC;EACtC,sBAAsB;EACtB,2BAA2B;AAC7B;AACA;EACE,iCAAiC;EACjC,iCAAiC;EACjC,uCAAuC;AACzC;AACA;EACE,UAAU;AACZ;AACA;EACE,WAAW;AACb;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,WAAW;AACb;AACA;EACE,6BAA6B;AAC/B;AACA;EACE,aAAa;EACb,WAAW;EACX,sBAAsB;AACxB;AACA;EACE,WAAW;EACX,sCAAsC;EACtC,+BAA+B;EAC/B,cAAc;EACd,kCAAkC;EAClC,2BAA2B;EAC3B,sBAAsB;AACxB;AACA;EACE,kBAAkB;EAClB,YAAY;EACZ,MAAM;EACN,OAAO;AACT;AACA;EACE,kBAAkB;AACpB;AACA;EACE,2CAA2C;EAC3C,iDAAiD;AACnD;AACA;EACE,UAAU;EACV,iDAAiD;AACnD;AACA;EACE,4CAA4C;EAC5C,mBAAmB;AACrB;AACA;EACE,YAAY;EACZ,aAAa;AACf;AACA;EACE,aAAa;AACf;AACA;EACE,cAAc;AAChB;AACA;EACE,sBAAsB;EACtB,gBAAgB;EAChB,gCAAgC;AAClC;AACA;EACE,YAAY;AACd;AACA;EACE,UAAU;EACV,sBAAsB;EACtB,aAAa;EACb,mBAAmB;EACnB,eAAe;EACf,eAAe;EACf,WAAW;EACX,mBAAmB;AACrB;AACA;EACE,OAAO;AACT;AACA;EACE,sBAAsB;EACtB,UAAU;EACV,sCAAsC;EACtC,mBAAmB;AACrB;AACA;EACE,mCAAmC;AACrC;AACA;EACE,eAAe;EACf,sCAAsC;EACtC,kBAAkB;EAClB,mCAAmC;EACnC,mCAAmC;AACrC;AACA;EACE,eAAe;EACf,sCAAsC;EACtC,kBAAkB;AACpB;AACA;EACE,iCAAiC;EACjC,iCAAiC;EACjC,uCAAuC;AACzC;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,UAAU;EACV,sBAAsB;AACxB;AACA;EACE,mBAAmB;EACnB,oCAAoC;AACtC;AACA;EACE,oCAAoC;AACtC;AACA;EACE,mBAAmB;EACnB,4CAA4C;AAC9C;AACA;EACE,4CAA4C;AAC9C;AACA;EACE,YAAY;EACZ,aAAa;EACb,uCAAuC;EACvC,mBAAmB;AACrB;AACA;EACE,aAAa;EACb,WAAW;EACX,mBAAmB;EACnB,8BAA8B;EAC9B,2BAA2B;AAC7B;AACA;EACE,mCAAmC;AACrC;AACA;EACE,eAAe;AACjB;AACA;EACE,WAAW;EACX,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,iBAAiB;EACjB,kCAAkC;EAClC,2BAA2B;AAC7B;AACA;EACE,eAAe;AACjB;AACA;EACE,eAAe;AACjB;AACA;EACE,eAAe;AACjB;AACA;EACE,cAAc;AAChB;AACA;EACE,eAAe;AACjB;AACA;EACE,cAAc;AAChB;AACA;EACE,UAAU;AACZ;AACA;EACE,kBAAkB;EAClB,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,sBAAsB;AACxB;AACA;EACE,mCAAmC;AACrC;AACA;EACE,cAAc;AAChB;AACA;EACE,YAAY;AACd;AACA;EACE,aAAa;EACb,WAAW;EACX,uBAAuB;AACzB;AACA;EACE,YAAY;EACZ,SAAS;EACT,0CAA0C;EAC1C,yCAAyC;EACzC,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,eAAe;EACf,kBAAkB;EAClB,2BAA2B;EAC3B,sBAAsB;AACxB;AACA;EACE,0CAA0C;EAC1C,yCAAyC;AAC3C;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,eAAe;EACf,2BAA2B;EAC3B,sCAAsC;EACtC,aAAa;EACb,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,WAAW;EACX,UAAU;EACV,WAAW;EACX,eAAe;EACf,aAAa;EACb,mBAAmB;AACrB;AACA;EACE,oCAAoC;EACpC,oCAAoC;EACpC,mBAAmB;AACrB;AACA;EACE,mCAAmC;EACnC,mCAAmC;EACnC,YAAY;EACZ,iCAAiC;EACjC,sCAAsC;EACtC,eAAe;AACjB;AACA;EACE,YAAY;AACd;AACA;EACE,WAAW;EACX,WAAW;EACX,2CAA2C;EAC3C,uCAAuC;EACvC,yBAAyB;AAC3B;AACA;EACE,yCAAyC;EACzC,qDAAqD;AACvD;AACA;EACE,yCAAyC;EACzC,sDAAsD;AACxD;AACA;EACE,yCAAyC;EACzC,sDAAsD;AACxD;AACA;EACE,yCAAyC;EACzC,qDAAqD;AACvD;AACA;EACE,gBAAgB;AAClB;AACA;EACE,0CAA0C;AAC5C;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,WAAW;EACX,qCAAqC;EACrC,sBAAsB;EACtB,2BAA2B;EAC3B,qBAAqB;AACvB;AACA;EACE,oCAAoC;EACpC,WAAW;AACb;AACA;EACE,cAAc;EACd,2BAA2B;EAC3B,sCAAsC;EACtC,gBAAgB;EAChB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,aAAa;EACb,OAAO;EACP,mBAAmB;EACnB,mBAAmB;EACnB,yBAAyB;EACzB,yBAAyB;AAC3B;AACA;EACE,oBAAoB;EACpB,mBAAmB;EACnB,4BAA4B;EAC5B,kCAAkC;EAClC,yCAAyC;EACzC,2CAA2C;EAC3C,wBAAwB;EACxB,sCAAsC;EACtC,eAAe;EACf,sCAAsC;EACtC,sCAAsC;EACtC,kCAAkC;AACpC;AACA;EACE,2BAA2B;EAC3B,wCAAwC;AAC1C;AACA;EACE,qCAAqC;EACrC,2CAA2C;AAC7C;AACA;EACE,mCAAmC;EACnC,mCAAmC;AACrC;AACA;EACE,mCAAmC;EACnC,2CAA2C;AAC7C;AACA;EACE,4CAA4C;EAC5C,mBAAmB;AACrB;AACA;EACE,aAAa;EACb,sBAAsB;EACtB,YAAY;EACZ,mCAAmC;AACrC;AACA;EACE,mBAAmB;EACnB,oCAAoC;AACtC;AACA;EACE,oCAAoC;AACtC;AACA;EACE,WAAW;EACX,iCAAiC;AACnC;AACA;EACE,gBAAgB;AAClB;AACA;EACE,iCAAiC;EACjC,iCAAiC;EACjC,uCAAuC;AACzC;AACA;EACE,aAAa;EACb,sBAAsB;EACtB,OAAO;EACP,WAAW;EACX,YAAY;EACZ,6BAA6B;AAC/B;AACA;EACE,mCAAmC;EACnC,mCAAmC;AACrC;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,wCAAwC;EACxC,0BAA0B;EAC1B,6BAA6B;EAC7B,6DAA6D;EAC7D,gCAAgC;EAChC,4CAA4C;EAC5C,6IAA6I;EAC7I,uBAAuB;EACvB,4BAA4B;EAC5B,4BAA4B;EAC5B,oCAAoC;EACpC,wBAAwB;EACxB,gCAAgC;EAChC,qCAAqC;EACrC,6BAA6B;EAC7B,iCAAiC;EACjC,oBAAoB;EACpB,sBAAsB;EACtB,yBAAyB;EACzB,6BAA6B;EAC7B,qCAAqC;EACrC,sCAAsC;EACtC,0BAA0B;EAC1B,oCAAoC;EACpC,sBAAsB;EACtB,yCAAyC;EACzC,kCAAkC;EAClC,6BAA6B;EAC7B,mCAAmC;EACnC,oBAAoB;EACpB,8BAA8B;EAC9B,yBAAyB;EACzB,+BAA+B;EAC/B,4BAA4B;EAC5B,mBAAmB;AACrB;AACA;EACE,8BAA8B;EAC9B,qBAAqB;EACrB,yBAAyB;EACzB,2BAA2B;EAC3B,8BAA8B;EAC9B,2BAA2B;EAC3B,oCAAoC;EACpC,6BAA6B;EAC7B,6BAA6B;EAC7B,0BAA0B;EAC1B,+BAA+B;EAC/B,gCAAgC;EAChC,gCAAgC;EAChC,4BAA4B;EAC5B,iCAAiC;EACjC,mCAAmC;EACnC,8BAA8B;EAC9B,2BAA2B;EAC3B,oCAAoC;EACpC,wBAAwB;EACxB,0BAA0B;EAC1B,0BAA0B;EAC1B,2BAA2B;EAC3B,yCAAyC;EACzC,yEAAyE;EACzE,qEAAqE;EACrE,4DAA4D;EAC5D,8BAA8B;AAChC;AACA;EACE,2BAA2B;EAC3B,wBAAwB;EACxB,yBAAyB;EACzB,8BAA8B;EAC9B,8BAA8B;EAC9B,2BAA2B;EAC3B,oCAAoC;EACpC,6BAA6B;EAC7B,6BAA6B;EAC7B,uBAAuB;EACvB,4BAA4B;EAC5B,gCAAgC;EAChC,gCAAgC;EAChC,4BAA4B;EAC5B,mCAAmC;EACnC,8BAA8B;EAC9B,2BAA2B;EAC3B,oCAAoC;EACpC,wBAAwB;EACxB,0BAA0B;EAC1B,0BAA0B;EAC1B,2BAA2B;EAC3B,iCAAiC;EACjC,2CAA2C;EAC3C,yEAAyE;EACzE,wEAAwE;EACxE,+DAA+D;EAC/D,8BAA8B;AAChC;AACA;EACE,aAAa;EACb,mBAAmB;AACrB;AACA;EACE,gBAAgB;AAClB;AACA;EACE,kCAAkC;EAClC,iBAAiB;EACjB,sBAAsB;EACtB,kBAAkB;EAClB,WAAW;AACb;AACA;EACE,mCAAmC;AACrC;AACA;EACE,eAAe;AACjB;AACA;EACE,oBAAoB;EACpB,kBAAkB;AACpB;AACA;EACE,WAAW;EACX,kBAAkB;EAClB,2BAA2B;EAC3B,eAAe;EACf,aAAa;EACb,mBAAmB;EACnB,4BAA4B;EAC5B,iCAAiC;EACjC,sBAAsB;EACtB,+BAA+B;AACjC;AACA;EACE,kBAAkB;EAClB,SAAS;AACX;AACA;EACE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,oCAAoC;EACpC,WAAW;AACb;AACA;EACE,kDAAkD;EAClD,mDAAmD;AACrD;AACA;EACE,aAAa;AACf;AACA;EACE,sBAAsB;EACtB,uBAAuB;AACzB;AACA;EACE,kBAAkB;AACpB;AACA;EACE,4DAA4D;AAC9D;AACA;EACE,UAAU;EACV,kDAAkD;AACpD;AACA;EACE,UAAU;EACV,6DAA6D;AAC/D;AACA;EACE,UAAU;EACV,6DAA6D;AAC/D;AACA;EACE,UAAU;EACV,kDAAkD;AACpD;AACA;EACE,wEAAwE;AAC1E;AACA;EACE,UAAU;EACV,kDAAkD;AACpD;AACA;EACE,UAAU;EACV,6DAA6D;AAC/D;AACA;EACE,uCAAuC;AACzC;AACA;EACE,2CAA2C;AAC7C;AACA;EACE,kBAAkB;AACpB;AACA;AACA;AACA;EACE,eAAe;AACjB;AACA;EACE,iDAAiD;AACnD;AACA;EACE,gBAAgB;EAChB,WAAW;AACb;AACA;EACE,qBAAqB;AACvB;AACA;;EAEE,+BAA+B;EAC/B,cAAc;AAChB;AACA;EACE,+BAA+B;AACjC;AACA;EACE,oBAAoB;AACtB;AACA;;EAEE,WAAW;AACb;AACA;EACE,wBAAwB;AAC1B;AACA;EACE,6DAA6D;AAC/D;AACA;EACE,SAAS;AACX;AACA;EACE,mBAAmB;EACnB,kBAAkB;AACpB;AACA;EACE,yCAAyC;EACzC,oDAAoD;AACtD;AACA;;EAEE,8CAA8C;AAChD;AACA;;EAEE,iCAAiC;EACjC,iCAAiC;AACnC;AACA;EACE,OAAO;AACT;AACA;EACE,wDAAwD;AAC1D;AACA;EACE,iDAAiD;AACnD;AACA;;;;EAIE,mDAAmD;EACnD,uCAAuC;EACvC,0DAA0D;EAC1D,8DAA8D;EAC9D,8DAA8D;EAC9D,gDAAgD;EAChD,+DAA+D;EAC/D,0DAA0D;EAC1D,mDAAmD;EACnD,sCAAsC;EACtC,gDAAgD;EAChD,wDAAwD;EACxD,wDAAwD;EACxD,iDAAiD;EACjD,uDAAuD;EACvD,kDAAkD;EAClD,6CAA6C;EAC7C,wCAAwC;EACxC,uDAAuD;EACvD,uCAAuC;EACvC,qCAAqC;EACrC,8DAA8D;EAC9D,0CAA0C;EAC1C,4CAA4C;AAC9C",sourcesContent:['/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-e6654786] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] {\n  --dp-common-transition: all var(--animation-quick) ease-in;\n  --dp-menu-padding: 6px 8px;\n  --dp-animation-duration: var(--animation-quick);\n  --dp-menu-appear-transition-timing: cubic-bezier(.4, 0, 1, 1);\n  --dp-transition-timing: ease-out;\n  --dp-action-row-transtion: all 0.2s ease-in;\n  --dp-font-family: var(--font-face);\n  --dp-border-radius: var(--border-radius-element);\n  --dp-cell-border-radius: var(--border-radius-small);\n  --dp-transition-length: 22px;\n  --dp-transition-timing-general: var(--animation-quick);\n  --dp-button-height: var(--default-clickable-area);\n  --dp-month-year-row-height: var(--default-clickable-area);\n  --dp-month-year-row-button-size: var(--clickable-area-small);\n  --dp-button-icon-height: 20px;\n  --dp-calendar-wrap-padding: 0 5px;\n  --dp-cell-size: var(--default-clickable-area);\n  --dp-cell-padding: 5px;\n  --dp-common-padding: 10px;\n  --dp-input-icon-padding: var(--default-clickable-area);\n  --dp-input-padding: 6px 12px;\n  --dp-menu-min-width: 260px;\n  --dp-action-buttons-padding: 1px 6px;\n  --dp-row-margin: 5px 0;\n  --dp-calendar-header-cell-padding: 0.5rem;\n  --dp-multi-calendars-spacing: 10px;\n  --dp-overlay-col-padding: 3px;\n  --dp-time-inc-dec-button-size: var(--default-clickable-area);\n  --dp-font-size: 1rem;\n  --dp-preview-font-size: var(--font-size-small);\n  --dp-time-font-size: 2rem;\n  --dp-action-button-height: var(--clickable-area-small);\n  --dp-action-row-padding: 8px;\n  --dp-direction: ltr;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_wrap {\n  position: relative;\n  width: 100%;\n  box-sizing: unset;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_wrap:focus {\n  border-color: var(--dp-border-color-hover);\n  outline: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_valid {\n  box-shadow: 0 0 var(--dp-border-radius) var(--dp-success-color);\n  border-color: var(--dp-success-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_valid:hover {\n  border-color: var(--dp-success-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_invalid {\n  box-shadow: 0 0 var(--dp-border-radius) var(--dp-danger-color);\n  border-color: var(--dp-danger-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_invalid:hover {\n  border-color: var(--dp-danger-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input {\n  background-color: var(--dp-background-color);\n  border-radius: var(--dp-border-radius);\n  font-family: var(--dp-font-family);\n  border: 1px solid var(--dp-border-color);\n  outline: none;\n  transition: border-color 0.2s cubic-bezier(0.645, 0.045, 0.355, 1);\n  width: 100%;\n  font-size: var(--dp-font-size);\n  line-height: calc(var(--dp-font-size) * 1.5);\n  padding: var(--dp-input-padding);\n  color: var(--dp-text-color);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input::placeholder {\n  opacity: 0.7;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input:hover:not(.dp__input_focus) {\n  border-color: var(--dp-border-color-hover);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_not_clearable {\n  padding-inline-end: var(--dp-input-not-clearable-padding) !important;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_reg {\n  caret-color: rgba(0, 0, 0, 0);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_focus {\n  border-color: var(--dp-border-color-focus);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__disabled {\n  background: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__disabled::placeholder {\n  color: var(--dp-disabled-color-text);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icons {\n  display: inline-block;\n  width: var(--dp-font-size);\n  height: var(--dp-font-size);\n  stroke-width: 0;\n  font-size: var(--dp-font-size);\n  line-height: calc(var(--dp-font-size) * 1.5);\n  padding: 6px 12px;\n  color: var(--dp-icon-color);\n  box-sizing: content-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icon {\n  cursor: pointer;\n  position: absolute;\n  top: 50%;\n  inset-inline-start: 0;\n  transform: translateY(-50%);\n  color: var(--dp-icon-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--clear-btn {\n  position: absolute;\n  top: 50%;\n  inset-inline-end: 0;\n  transform: translateY(-50%);\n  cursor: pointer;\n  color: var(--dp-icon-color);\n  background: rgba(0, 0, 0, 0);\n  border: none;\n  display: inline-flex;\n  align-items: center;\n  padding: 0;\n  margin: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__input_icon_pad {\n  padding-inline-start: var(--dp-input-icon-padding);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu {\n  background: var(--dp-background-color);\n  border-radius: var(--dp-border-radius);\n  min-width: var(--dp-menu-min-width);\n  font-family: var(--dp-font-family);\n  font-size: var(--dp-font-size);\n  user-select: none;\n  border: 1px solid var(--dp-menu-border-color);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu::after {\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu::before {\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu:focus {\n  border: 1px solid var(--dp-menu-border-color);\n  outline: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-wrapper {\n  position: absolute;\n  z-index: 99999;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_inner {\n  padding: var(--dp-menu-padding);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu--inner-stretched {\n  padding: 6px 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_index {\n  z-index: 99999;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-loading, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_readonly, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_disabled {\n  position: absolute;\n  inset: 0;\n  z-index: 999999;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_disabled {\n  background: hsla(0, 0%, 100%, 0.5);\n  cursor: not-allowed;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_readonly {\n  background: rgba(0, 0, 0, 0);\n  cursor: default;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-loading {\n  background: hsla(0, 0%, 100%, 0.5);\n  cursor: default;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-load-container {\n  display: flex;\n  height: 100%;\n  width: 100%;\n  justify-content: center;\n  align-items: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-loader {\n  width: 48px;\n  height: 48px;\n  border: var(--dp-loader);\n  border-bottom-color: rgba(0, 0, 0, 0);\n  border-radius: 50%;\n  display: inline-block;\n  box-sizing: border-box;\n  animation: dp-load-rotation-e6654786 1s linear infinite;\n  position: absolute;\n}\n@keyframes dp-load-rotation-e6654786 {\n0% {\n    transform: rotate(0deg);\n}\n100% {\n    transform: rotate(360deg);\n}\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_top {\n  left: var(--dp-arrow-left);\n  top: 0;\n  height: 12px;\n  width: 12px;\n  background-color: var(--dp-background-color);\n  position: absolute;\n  border-inline-end: 1px solid var(--dp-menu-border-color);\n  border-top: 1px solid var(--dp-menu-border-color);\n  transform: translate(-50%, -50%) rotate(-45deg);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_bottom {\n  left: var(--dp-arrow-left);\n  bottom: 0;\n  height: 12px;\n  width: 12px;\n  background-color: var(--dp-background-color);\n  position: absolute;\n  border-inline-end: 1px solid var(--dp-menu-border-color);\n  border-bottom: 1px solid var(--dp-menu-border-color);\n  transform: translate(-50%, 50%) rotate(45deg);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_extra {\n  text-align: center;\n  padding: 2px 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates {\n  padding: 5px;\n  border-inline-end: 1px solid var(--dp-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates[data-dp-mobile] {\n  display: flex;\n  align-self: center;\n  border: none;\n  overflow-x: auto;\n  max-width: calc(var(--dp-menu-width) - var(--dp-action-row-padding) * 2);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-dates-collapsed {\n  display: flex;\n  align-self: center;\n  border: none;\n  overflow-x: auto;\n  max-width: calc(var(--dp-menu-width) - var(--dp-action-row-padding) * 2);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__sidebar_left {\n  padding: 5px;\n  border-inline-end: 1px solid var(--dp-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__sidebar_right {\n  padding: 5px;\n  margin-inline-end: 1px solid var(--dp-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range {\n  display: block;\n  width: 100%;\n  padding: 5px;\n  text-align: left;\n  white-space: nowrap;\n  color: var(--dp-text-color);\n  border-radius: var(--dp-border-radius);\n  transition: var(--dp-common-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range:hover {\n  background-color: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n  cursor: pointer;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile] {\n  border: 1px solid var(--dp-border-color);\n  margin: 0 3px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile]:first-child {\n  margin-left: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range[data-dp-mobile]:last-child {\n  margin-right: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed {\n  border: 1px solid var(--dp-border-color);\n  margin: 0 3px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed:first-child {\n  margin-left: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--preset-range-collapsed:last-child {\n  margin-right: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_content_wrapper {\n  display: flex;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__menu_content_wrapper[data-dp-mobile] {\n  flex-direction: column-reverse;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--menu-content-wrapper-collapsed {\n  flex-direction: column-reverse;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header {\n  position: relative;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  color: var(--dp-text-color);\n  white-space: nowrap;\n  font-weight: bold;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_item {\n  text-align: center;\n  flex-grow: 1;\n  height: var(--dp-cell-size);\n  padding: var(--dp-cell-padding);\n  width: var(--dp-cell-size);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_row {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  margin: var(--dp-row-margin);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_item {\n  text-align: center;\n  flex-grow: 1;\n  box-sizing: border-box;\n  color: var(--dp-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar {\n  position: relative;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_cell {\n  border-bottom: thin solid var(--dp-border-color);\n  padding: var(--dp-calendar-header-cell-padding);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_inner {\n  display: flex;\n  align-items: center;\n  text-align: center;\n  justify-content: center;\n  border-radius: var(--dp-cell-border-radius);\n  height: var(--dp-cell-size);\n  padding: var(--dp-cell-padding);\n  width: var(--dp-cell-size);\n  border: 1px solid rgba(0, 0, 0, 0);\n  box-sizing: border-box;\n  position: relative;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_inner:hover {\n  transition: all 0.2s;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_start, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_start:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_start {\n  border-end-end-radius: 0;\n  border-start-end-radius: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_end, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_end:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_end {\n  border-end-start-radius: 0;\n  border-start-start-radius: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_end, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_start, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__active_date {\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_end:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover_start:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__date_hover:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_offset {\n  color: var(--dp-secondary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_disabled {\n  color: var(--dp-secondary-color);\n  cursor: not-allowed;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_between {\n  background: var(--dp-range-between-dates-background-color);\n  color: var(--dp-range-between-dates-text-color);\n  border-radius: 0;\n  border: 1px solid var(--dp-range-between-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__range_between_week {\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n  border-radius: 0;\n  border-top: 1px solid var(--dp-primary-color);\n  border-bottom: 1px solid var(--dp-primary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__today {\n  border: 1px solid var(--dp-primary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__week_num {\n  color: var(--dp-secondary-color);\n  text-align: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range {\n  border-radius: 0;\n  border-top: 1px dashed var(--dp-primary-color);\n  border-bottom: 1px dashed var(--dp-primary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_start {\n  border-start-start-radius: var(--dp-cell-border-radius);\n  border-end-start-radius: var(--dp-cell-border-radius);\n  border-inline-start: 1px dashed var(--dp-primary-color);\n  border-top: 1px dashed var(--dp-primary-color);\n  border-bottom: 1px dashed var(--dp-primary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_auto_range_end {\n  border-start-end-radius: var(--dp-cell-border-radius);\n  border-end-end-radius: var(--dp-cell-border-radius);\n  border-top: 1px dashed var(--dp-primary-color);\n  border-bottom: 1px dashed var(--dp-primary-color);\n  border-inline-end: 1px dashed var(--dp-primary-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_header_separator {\n  width: 100%;\n  height: 1px;\n  background: var(--dp-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__calendar_next {\n  margin-inline-start: var(--dp-multi-calendars-spacing);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_line, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_dot {\n  height: 5px;\n  background-color: var(--dp-marker-color);\n  position: absolute;\n  bottom: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_dot {\n  width: 5px;\n  border-radius: 50%;\n  left: 50%;\n  transform: translateX(-50%);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_line {\n  width: 100%;\n  left: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__marker_tooltip {\n  position: absolute;\n  border-radius: var(--dp-border-radius);\n  background-color: var(--dp-tooltip-color);\n  padding: 5px;\n  border: 1px solid var(--dp-border-color);\n  z-index: 99999;\n  box-sizing: border-box;\n  cursor: default;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_content {\n  white-space: nowrap;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_text {\n  display: flex;\n  align-items: center;\n  flex-flow: row nowrap;\n  color: var(--dp-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tooltip_mark {\n  height: 5px;\n  width: 5px;\n  border-radius: 50%;\n  background-color: var(--dp-text-color);\n  color: var(--dp-text-color);\n  margin-inline-end: 5px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__arrow_bottom_tp {\n  bottom: 0;\n  height: 8px;\n  width: 8px;\n  background-color: var(--dp-tooltip-color);\n  position: absolute;\n  border-inline-end: 1px solid var(--dp-border-color);\n  border-bottom: 1px solid var(--dp-border-color);\n  transform: translate(-50%, 50%) rotate(45deg);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__instance_calendar {\n  position: relative;\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display[data-dp-mobile] {\n  flex-direction: column;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--flex-display-collapsed {\n  flex-direction: column;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_highlight {\n  background-color: var(--dp-highlight-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_row {\n  display: flex;\n  align-items: center;\n  height: var(--dp-month-year-row-height);\n  color: var(--dp-text-color);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  cursor: pointer;\n  height: var(--dp-month-year-row-button-size);\n  width: var(--dp-month-year-row-button-size);\n  color: var(--dp-icon-color);\n  text-align: center;\n  border-radius: 50%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav svg {\n  height: var(--dp-button-icon-height);\n  width: var(--dp-button-icon-height);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-icon-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  [dir=rtl] .dp__inner_nav {\n  transform: rotate(180deg);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav_disabled:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inner_nav_disabled {\n  background: var(--dp-disabled-color);\n  color: var(--dp-disabled-color-text);\n  cursor: not-allowed;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select {\n  text-align: center;\n  cursor: pointer;\n  height: var(--dp-month-year-row-height);\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  border-radius: var(--dp-border-radius);\n  box-sizing: border-box;\n  color: var(--dp-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select:hover, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n  transition: var(--dp-common-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_select {\n  width: 50%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-select {\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__month_year_wrap {\n  display: flex;\n  flex-direction: row;\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__year_disable_select {\n  justify-content: space-around;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--header-wrap {\n  display: flex;\n  width: 100%;\n  flex-direction: column;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay {\n  width: 100%;\n  background: var(--dp-background-color);\n  transition: opacity 1s ease-out;\n  z-index: 99999;\n  font-family: var(--dp-font-family);\n  color: var(--dp-text-color);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--overlay-absolute {\n  position: absolute;\n  height: 100%;\n  top: 0;\n  left: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--overlay-relative {\n  position: relative;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar-track {\n  box-shadow: var(--dp-scroll-bar-background);\n  background-color: var(--dp-scroll-bar-background);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar {\n  width: 5px;\n  background-color: var(--dp-scroll-bar-background);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container::-webkit-scrollbar-thumb {\n  background-color: var(--dp-scroll-bar-color);\n  border-radius: 10px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay:focus {\n  border: none;\n  outline: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__container_flex {\n  display: flex;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__container_block {\n  display: block;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_container {\n  flex-direction: column;\n  overflow-y: auto;\n  height: var(--dp-overlay-height);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_picker_overlay_container {\n  height: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_row {\n  padding: 0;\n  box-sizing: border-box;\n  display: flex;\n  margin-inline: auto;\n  flex-wrap: wrap;\n  max-width: 100%;\n  width: 100%;\n  align-items: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_row {\n  flex: 1;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_col {\n  box-sizing: border-box;\n  width: 33%;\n  padding: var(--dp-overlay-col-padding);\n  white-space: nowrap;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_pad {\n  padding: var(--dp-common-padding) 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active {\n  cursor: pointer;\n  border-radius: var(--dp-border-radius);\n  text-align: center;\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell {\n  cursor: pointer;\n  border-radius: var(--dp-border-radius);\n  text-align: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n  transition: var(--dp-common-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__cell_in_between {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__over_action_scroll {\n  right: 5px;\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_disabled {\n  cursor: not-allowed;\n  background: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_disabled:hover {\n  background: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active_disabled {\n  cursor: not-allowed;\n  background: var(--dp-primary-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__overlay_cell_active_disabled:hover {\n  background: var(--dp-primary-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-overlay-btn, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-invalid {\n  border: none;\n  font: inherit;\n  transition: var(--dp-common-transition);\n  line-height: normal;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--year-mode-picker {\n  display: flex;\n  width: 100%;\n  align-items: center;\n  justify-content: space-between;\n  height: var(--dp-cell-size);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--tp-wrap {\n  max-width: var(--dp-menu-min-width);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--tp-wrap[data-dp-mobile] {\n  max-width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_input {\n  width: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  user-select: none;\n  font-family: var(--dp-font-family);\n  color: var(--dp-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_block {\n  padding: 0 20px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_inline {\n  padding: 0 10px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_with_button {\n  padding: 0 15px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_reg_with_button[data-compact~=true] {\n  padding: 0 5px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec {\n  padding: 0 10px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec_with_button {\n  padding: 0 5px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_sec_with_button[data-collapsed~=true] {\n  padding: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col {\n  text-align: center;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_col_block {\n  font-size: var(--dp-time-font-size);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display_block {\n  padding: 0 3px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display_inline {\n  padding: 5px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_picker_inline_container {\n  display: flex;\n  width: 100%;\n  justify-content: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button {\n  padding: 5px;\n  margin: 0;\n  height: var(--dp-time-inc-dec-button-size);\n  width: var(--dp-time-inc-dec-button-size);\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  cursor: pointer;\n  border-radius: 50%;\n  color: var(--dp-icon-color);\n  box-sizing: border-box;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button svg {\n  height: var(--dp-time-inc-dec-button-size);\n  width: var(--dp-time-inc-dec-button-size);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-icon-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display {\n  cursor: pointer;\n  color: var(--dp-text-color);\n  border-radius: var(--dp-border-radius);\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__time_display:hover:enabled {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_inline {\n  width: 100%;\n  padding: 0;\n  height: 8px;\n  cursor: pointer;\n  display: flex;\n  align-items: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_disabled, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp__inc_dec_button_disabled:hover {\n  background: var(--dp-disabled-color);\n  color: var(--dp-disabled-color-text);\n  cursor: not-allowed;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pm_am_button {\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n  border: none;\n  padding: var(--dp-common-padding);\n  border-radius: var(--dp-border-radius);\n  cursor: pointer;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pm_am_button[data-compact~=true] {\n  padding: 7px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bar {\n  width: 100%;\n  height: 4px;\n  background-color: var(--dp-secondary-color);\n  transition: var(--dp-common-transition);\n  border-collapse: collapse;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_top:hover .dp__tp_btn_in_r {\n  background-color: var(--dp-primary-color);\n  transform: rotate(12deg) scale(1.15) translateY(-2px);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_top:hover .dp__tp_btn_in_l {\n  background-color: var(--dp-primary-color);\n  transform: rotate(-12deg) scale(1.15) translateY(-2px);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bottom:hover .dp__tp_btn_in_r {\n  background-color: var(--dp-primary-color);\n  transform: rotate(-12deg) scale(1.15) translateY(-2px);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__tp_inline_btn_bottom:hover .dp__tp_btn_in_l {\n  background-color: var(--dp-primary-color);\n  transform: rotate(12deg) scale(1.15) translateY(-2px);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-overlay-btn {\n  background: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--time-invalid {\n  background-color: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_row {\n  display: flex;\n  align-items: center;\n  width: 100%;\n  padding: var(--dp-action-row-padding);\n  box-sizing: border-box;\n  color: var(--dp-text-color);\n  flex-flow: row nowrap;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_row svg {\n  height: var(--dp-button-icon-height);\n  width: auto;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__selection_preview {\n  display: block;\n  color: var(--dp-text-color);\n  font-size: var(--dp-preview-font-size);\n  overflow: hidden;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons {\n  display: flex;\n  flex: 0;\n  white-space: nowrap;\n  align-items: center;\n  justify-content: flex-end;\n  margin-inline-start: auto;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_button {\n  display: inline-flex;\n  align-items: center;\n  background: rgba(0, 0, 0, 0);\n  border: 1px solid rgba(0, 0, 0, 0);\n  padding: var(--dp-action-buttons-padding);\n  line-height: var(--dp-action-button-height);\n  margin-inline-start: 3px;\n  height: var(--dp-action-button-height);\n  cursor: pointer;\n  border-radius: var(--dp-border-radius);\n  font-size: var(--dp-preview-font-size);\n  font-family: var(--dp-font-family);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_cancel {\n  color: var(--dp-text-color);\n  border: 1px solid var(--dp-border-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_cancel:hover {\n  border-color: var(--dp-primary-color);\n  transition: var(--dp-action-row-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select {\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select:hover {\n  background: var(--dp-primary-color);\n  transition: var(--dp-action-row-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__action_buttons .dp__action_select:disabled {\n  background: var(--dp-primary-disabled-color);\n  cursor: not-allowed;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-quarter-picker-wrap {\n  display: flex;\n  flex-direction: column;\n  height: 100%;\n  min-width: var(--dp-menu-min-width);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-disabled {\n  cursor: not-allowed;\n  background: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-disabled:hover {\n  background: var(--dp-disabled-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn {\n  width: 100%;\n  padding: var(--dp-common-padding);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn:not(.dp--highlighted, .dp--qr-btn-active, .dp--qr-btn-disabled, .dp--qr-btn-between) {\n  background: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn:hover:not(.dp--qr-btn-active, .dp--qr-btn-disabled) {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n  transition: var(--dp-common-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--quarter-items {\n  display: flex;\n  flex-direction: column;\n  flex: 1;\n  width: 100%;\n  height: 100%;\n  justify-content: space-evenly;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-active {\n  background: var(--dp-primary-color);\n  color: var(--dp-primary-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--qr-btn-between {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-text-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  :root {\n  --dp-common-transition: all 0.1s ease-in;\n  --dp-menu-padding: 6px 8px;\n  --dp-animation-duration: 0.1s;\n  --dp-menu-appear-transition-timing: cubic-bezier(.4, 0, 1, 1);\n  --dp-transition-timing: ease-out;\n  --dp-action-row-transition: all 0.2s ease-in;\n  --dp-font-family: -apple-system, blinkmacsystemfont, "Segoe UI", roboto, oxygen, ubuntu, cantarell, "Open Sans", "Helvetica Neue", sans-serif;\n  --dp-border-radius: 4px;\n  --dp-cell-border-radius: 4px;\n  --dp-transition-length: 22px;\n  --dp-transition-timing-general: 0.1s;\n  --dp-button-height: 35px;\n  --dp-month-year-row-height: 35px;\n  --dp-month-year-row-button-size: 25px;\n  --dp-button-icon-height: 20px;\n  --dp-calendar-wrap-padding: 0 5px;\n  --dp-cell-size: 35px;\n  --dp-cell-padding: 5px;\n  --dp-common-padding: 10px;\n  --dp-input-icon-padding: 35px;\n  --dp-input-padding: 6px 30px 6px 12px;\n  --dp-input-not-clearable-padding: 12px;\n  --dp-menu-min-width: 260px;\n  --dp-action-buttons-padding: 1px 6px;\n  --dp-row-margin: 5px 0;\n  --dp-calendar-header-cell-padding: 0.5rem;\n  --dp-multi-calendars-spacing: 10px;\n  --dp-overlay-col-padding: 3px;\n  --dp-time-inc-dec-button-size: 32px;\n  --dp-font-size: 1rem;\n  --dp-preview-font-size: 0.8rem;\n  --dp-time-font-size: 2rem;\n  --dp-action-button-height: 22px;\n  --dp-action-row-padding: 8px;\n  --dp-direction: ltr;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__theme_dark {\n  --dp-background-color: #212121;\n  --dp-text-color: #fff;\n  --dp-hover-color: #484848;\n  --dp-hover-text-color: #fff;\n  --dp-hover-icon-color: #959595;\n  --dp-primary-color: #005cb2;\n  --dp-primary-disabled-color: #61a8ea;\n  --dp-primary-text-color: #fff;\n  --dp-secondary-color: #a9a9a9;\n  --dp-border-color: #2d2d2d;\n  --dp-menu-border-color: #2d2d2d;\n  --dp-border-color-hover: #aaaeb7;\n  --dp-border-color-focus: #aaaeb7;\n  --dp-disabled-color: #737373;\n  --dp-disabled-color-text: #d0d0d0;\n  --dp-scroll-bar-background: #212121;\n  --dp-scroll-bar-color: #484848;\n  --dp-success-color: #00701a;\n  --dp-success-color-disabled: #428f59;\n  --dp-icon-color: #959595;\n  --dp-danger-color: #e53935;\n  --dp-marker-color: #e53935;\n  --dp-tooltip-color: #3e3e3e;\n  --dp-highlight-color: rgb(0 92 178 / 20%);\n  --dp-range-between-dates-background-color: var(--dp-hover-color, #484848);\n  --dp-range-between-dates-text-color: var(--dp-hover-text-color, #fff);\n  --dp-range-between-border-color: var(--dp-hover-color, #fff);\n  --dp-loader: 5px solid #005cb2;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__theme_light {\n  --dp-background-color: #fff;\n  --dp-text-color: #212121;\n  --dp-hover-color: #f3f3f3;\n  --dp-hover-text-color: #212121;\n  --dp-hover-icon-color: #959595;\n  --dp-primary-color: #1976d2;\n  --dp-primary-disabled-color: #6bacea;\n  --dp-primary-text-color: #fff;\n  --dp-secondary-color: #c0c4cc;\n  --dp-border-color: #ddd;\n  --dp-menu-border-color: #ddd;\n  --dp-border-color-hover: #aaaeb7;\n  --dp-border-color-focus: #aaaeb7;\n  --dp-disabled-color: #f6f6f6;\n  --dp-scroll-bar-background: #f3f3f3;\n  --dp-scroll-bar-color: #959595;\n  --dp-success-color: #76d275;\n  --dp-success-color-disabled: #a3d9b1;\n  --dp-icon-color: #959595;\n  --dp-danger-color: #ff6f60;\n  --dp-marker-color: #ff6f60;\n  --dp-tooltip-color: #fafafa;\n  --dp-disabled-color-text: #8e8e8e;\n  --dp-highlight-color: rgb(25 118 210 / 10%);\n  --dp-range-between-dates-background-color: var(--dp-hover-color, #f3f3f3);\n  --dp-range-between-dates-text-color: var(--dp-hover-text-color, #212121);\n  --dp-range-between-border-color: var(--dp-hover-color, #f3f3f3);\n  --dp-loader: 5px solid #1976d2;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex {\n  display: flex;\n  align-items: center;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__btn {\n  background: none;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__main {\n  font-family: var(--dp-font-family);\n  user-select: none;\n  box-sizing: border-box;\n  position: relative;\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__main * {\n  direction: var(--dp-direction, ltr);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__pointer {\n  cursor: pointer;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__icon {\n  stroke: currentcolor;\n  fill: currentcolor;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button {\n  width: 100%;\n  text-align: center;\n  color: var(--dp-icon-color);\n  cursor: pointer;\n  display: flex;\n  align-items: center;\n  place-content: center center;\n  padding: var(--dp-common-padding);\n  box-sizing: border-box;\n  height: var(--dp-button-height);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button.dp__overlay_action {\n  position: absolute;\n  bottom: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-icon-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button svg {\n  height: var(--dp-button-icon-height);\n  width: auto;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__button_bottom {\n  border-bottom-left-radius: var(--dp-border-radius);\n  border-bottom-right-radius: var(--dp-border-radius);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display {\n  display: flex;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__flex_display_with_input {\n  flex-direction: column;\n  align-items: flex-start;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp__relative {\n  position: relative;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-leave-active {\n  transition: all var(--dp-transition-timing-general) ease-out;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-enter-from {\n  opacity: 0;\n  transform: translateX(var(--dp-transition-length));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-next-leave-to {\n  opacity: 0;\n  transform: translateX(calc(var(--dp-transition-length) * -1));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-enter-from {\n  opacity: 0;\n  transform: translateX(calc(var(--dp-transition-length) * -1));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .calendar-prev-leave-to {\n  opacity: 0;\n  transform: translateX(var(--dp-transition-length));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-leave-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-enter-active, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-leave-active {\n  transition: all var(--dp-animation-duration) var(--dp-transition-timing);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-top-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-enter-from {\n  opacity: 0;\n  transform: translateY(var(--dp-transition-length));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-menu-appear-bottom-leave-to, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-down-enter-from, .vue-date-time-picker__wrapper[data-v-e6654786]  .dp-slide-up-leave-to {\n  opacity: 0;\n  transform: translateY(calc(var(--dp-transition-length) * -1));\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--arrow-btn-nav {\n  transition: var(--dp-common-transition);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--highlighted {\n  background-color: var(--dp-highlight-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  .dp--hidden-el {\n  visibility: hidden;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786]  {\n}\n.vue-date-time-picker__wrapper.vue-date-time-picker__wrapper--teleport[data-v-e6654786] .dp--menu-wrapper {\n  z-index: 100001;\n}\n.vue-date-time-picker__wrapper .vue-date-time-picker--clearable[data-v-e6654786] .dp__input {\n  padding-inline-end: var(--default-clickable-area);\n}\n.vue-date-time-picker__wrapper .vue-date-time-picker__timezone[data-v-e6654786] {\n  min-width: unset;\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .icon-vue {\n  opacity: 1 !important;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp--tp-wrap,\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__action_extra {\n  padding: var(--dp-menu-padding);\n  padding-top: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__overlay.dp--overlay-absolute {\n  padding: var(--dp-menu-padding);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__overlay.dp--overlay-absolute .dp__btn.dp__button.dp__button_bottom {\n  inset-block-end: 6px;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__button_bottom,\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp--tp-wrap .dp__button {\n  width: 100%;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__overlay_action {\n  width: calc(100% - 16px);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] input {\n  padding-inline-start: var(--dp-input-icon-padding) !important;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn {\n  margin: 0;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__inner_nav {\n  height: fit-content;\n  width: fit-content;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__btn.dp__button.dp__button_bottom {\n  color: var(--color-primary-element-light);\n  background-color: var(--color-primary-element-light);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp--header-wrap .dp__btn:not(.dp__button_bottom),\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_col .dp__btn {\n  background-color: var(--color-main-background);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp--header-wrap .dp__btn:not(.dp__button_bottom):hover,\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_col .dp__btn:hover {\n  background: var(--dp-hover-color);\n  color: var(--dp-hover-icon-color);\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__month_year_select {\n  flex: 1;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp--time-overlay-btn {\n  font-size: calc(2 * var(--default-font-size)) !important;\n}\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__time_input .dp__time_col_reg_block {\n  padding: 0 calc(4 * var(--default-grid-baseline));\n}\n.vue-date-time-picker__wrapper .vue-date-time-picker.dp__theme_dark[data-v-e6654786],\n.vue-date-time-picker__wrapper .vue-date-time-picker.dp__theme_light[data-v-e6654786],\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__theme_dark,\n.vue-date-time-picker__wrapper[data-v-e6654786] .dp__theme_light {\n  --dp-background-color: var(--color-main-background);\n  --dp-text-color: var(--color-main-text);\n  --dp-hover-color: var(--color-primary-element-light-hover);\n  --dp-hover-text-color: var(--color-primary-element-light-text);\n  --dp-hover-icon-color: var(--color-primary-element-light-text);\n  --dp-primary-color: var(--color-primary-element);\n  --dp-primary-disabled-color: var(--color-primary-element-hover);\n  --dp-primary-text-color: var(--color-primary-element-text);\n  --dp-secondary-color: var(--color-text-maxcontrast);\n  --dp-border-color: var(--color-border);\n  --dp-menu-border-color: var(--color-border-dark);\n  --dp-border-color-hover: var(--color-border-maxcontrast);\n  --dp-border-color-focus: var(--color-border-maxcontrast);\n  --dp-disabled-color: var(--color-background-dark);\n  --dp-disabled-color-text: var(--color-text-maxcontrast);\n  --dp-scroll-bar-background: var(--color-scrollbar);\n  --dp-scroll-bar-color: var(--color-scrollbar);\n  --dp-success-color: var(--color-success);\n  --dp-success-color-disabled: var(--color-success-hover);\n  --dp-icon-color: var(--color-main-text);\n  --dp-danger-color: var(--color-error);\n  --dp-marker-color: var(--color-text-error, var(--color-error));\n  --dp-tooltip-color: var(--color-main-text);\n  --dp-highlight-color: var(--color-main-text);\n}'],sourceRoot:""}]),t.d(a,{},{default:i})},21025(e,a,t){var r=t(91838);r.__esModule&&(r=r.default),"string"==typeof r&&(r=[[e.id,r,""]]),r.locals&&(e.exports=r.locals),(0,t(15739).A)("6413304e",r,!0,{})},74638(e,a,t){"use strict";let r,n,o,i,l,d,u,p;t.d(a,{N:()=>nl}),t(21025);var s,c=t(20641),v=t(50953),m=t(90033),A=t(98190),_=t(53334),h=t(53751);let g={lessThanXSeconds:{one:"less than a second",other:"less than {{count}} seconds"},xSeconds:{one:"1 second",other:"{{count}} seconds"},halfAMinute:"half a minute",lessThanXMinutes:{one:"less than a minute",other:"less than {{count}} minutes"},xMinutes:{one:"1 minute",other:"{{count}} minutes"},aboutXHours:{one:"about 1 hour",other:"about {{count}} hours"},xHours:{one:"1 hour",other:"{{count}} hours"},xDays:{one:"1 day",other:"{{count}} days"},aboutXWeeks:{one:"about 1 week",other:"about {{count}} weeks"},xWeeks:{one:"1 week",other:"{{count}} weeks"},aboutXMonths:{one:"about 1 month",other:"about {{count}} months"},xMonths:{one:"1 month",other:"{{count}} months"},aboutXYears:{one:"about 1 year",other:"about {{count}} years"},xYears:{one:"1 year",other:"{{count}} years"},overXYears:{one:"over 1 year",other:"over {{count}} years"},almostXYears:{one:"almost 1 year",other:"almost {{count}} years"}};function C(e){return (a={})=>{let t=a.width?String(a.width):e.defaultWidth;return e.formats[t]||e.formats[e.defaultWidth]}}let b={date:C({formats:{full:"EEEE, MMMM do, y",long:"MMMM do, y",medium:"MMM d, y",short:"MM/dd/yyyy"},defaultWidth:"full"}),time:C({formats:{full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},defaultWidth:"full"}),dateTime:C({formats:{full:"{{date}} 'at' {{time}}",long:"{{date}} 'at' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})},y={lastWeek:"'last' eeee 'at' p",yesterday:"'yesterday at' p",today:"'today at' p",tomorrow:"'tomorrow at' p",nextWeek:"eeee 'at' p",other:"P"};function f(e){return(a,t)=>{let r;if("formatting"===(t?.context?String(t.context):"standalone")&&e.formattingValues){let a=e.defaultFormattingWidth||e.defaultWidth,n=t?.width?String(t.width):a;r=e.formattingValues[n]||e.formattingValues[a]}else{let a=e.defaultWidth,n=t?.width?String(t.width):e.defaultWidth;r=e.values[n]||e.values[a]}return r[e.argumentCallback?e.argumentCallback(a):a]}}function w(e){return(a,t={})=>{let r,n=t.width,o=n&&e.matchPatterns[n]||e.matchPatterns[e.defaultMatchWidth],i=a.match(o);if(!i)return null;let l=i[0],d=n&&e.parsePatterns[n]||e.parsePatterns[e.defaultParseWidth],u=Array.isArray(d)?function(e,a){for(let t=0;t<e.length;t++)if(a(e[t]))return t}(d,e=>e.test(l)):function(e,a){for(let t in e)if(Object.prototype.hasOwnProperty.call(e,t)&&a(e[t]))return t}(d,e=>e.test(l));return r=e.valueCallback?e.valueCallback(u):u,{value:r=t.valueCallback?t.valueCallback(r):r,rest:a.slice(l.length)}}}let k={code:"en-US",formatDistance:(e,a,t)=>{let r,n=g[e];if(r="string"==typeof n?n:1===a?n.one:n.other.replace("{{count}}",a.toString()),t?.addSuffix)if(t.comparison&&t.comparison>0)return"in "+r;else return r+" ago";return r},formatLong:b,formatRelative:(e,a,t,r)=>y[e],localize:{ordinalNumber:(e,a)=>{let t=Number(e),r=t%100;if(r>20||r<10)switch(r%10){case 1:return t+"st";case 2:return t+"nd";case 3:return t+"rd"}return t+"th"},era:f({values:{narrow:["B","A"],abbreviated:["BC","AD"],wide:["Before Christ","Anno Domini"]},defaultWidth:"wide"}),quarter:f({values:{narrow:["1","2","3","4"],abbreviated:["Q1","Q2","Q3","Q4"],wide:["1st quarter","2nd quarter","3rd quarter","4th quarter"]},defaultWidth:"wide",argumentCallback:e=>e-1}),month:f({values:{narrow:["J","F","M","A","M","J","J","A","S","O","N","D"],abbreviated:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],wide:["January","February","March","April","May","June","July","August","September","October","November","December"]},defaultWidth:"wide"}),day:f({values:{narrow:["S","M","T","W","T","F","S"],short:["Su","Mo","Tu","We","Th","Fr","Sa"],abbreviated:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],wide:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},defaultWidth:"wide"}),dayPeriod:f({values:{narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"}},defaultWidth:"wide",formattingValues:{narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"}},defaultFormattingWidth:"wide"})},match:{ordinalNumber:(s={matchPattern:/^(\d+)(th|st|nd|rd)?/i,parsePattern:/\d+/i,valueCallback:e=>parseInt(e,10)},(e,a={})=>{let t=e.match(s.matchPattern);if(!t)return null;let r=t[0],n=e.match(s.parsePattern);if(!n)return null;let o=s.valueCallback?s.valueCallback(n[0]):n[0];return{value:o=a.valueCallback?a.valueCallback(o):o,rest:e.slice(r.length)}}),era:w({matchPatterns:{narrow:/^(b|a)/i,abbreviated:/^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,wide:/^(before christ|before common era|anno domini|common era)/i},defaultMatchWidth:"wide",parsePatterns:{any:[/^b/i,/^(a|c)/i]},defaultParseWidth:"any"}),quarter:w({matchPatterns:{narrow:/^[1234]/i,abbreviated:/^q[1234]/i,wide:/^[1234](th|st|nd|rd)? quarter/i},defaultMatchWidth:"wide",parsePatterns:{any:[/1/i,/2/i,/3/i,/4/i]},defaultParseWidth:"any",valueCallback:e=>e+1}),month:w({matchPatterns:{narrow:/^[jfmasond]/i,abbreviated:/^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,wide:/^(january|february|march|april|may|june|july|august|september|october|november|december)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^j/i,/^f/i,/^m/i,/^a/i,/^m/i,/^j/i,/^j/i,/^a/i,/^s/i,/^o/i,/^n/i,/^d/i],any:[/^ja/i,/^f/i,/^mar/i,/^ap/i,/^may/i,/^jun/i,/^jul/i,/^au/i,/^s/i,/^o/i,/^n/i,/^d/i]},defaultParseWidth:"any"}),day:w({matchPatterns:{narrow:/^[smtwf]/i,short:/^(su|mo|tu|we|th|fr|sa)/i,abbreviated:/^(sun|mon|tue|wed|thu|fri|sat)/i,wide:/^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^s/i,/^m/i,/^t/i,/^w/i,/^t/i,/^f/i,/^s/i],any:[/^su/i,/^m/i,/^tu/i,/^w/i,/^th/i,/^f/i,/^sa/i]},defaultParseWidth:"any"}),dayPeriod:w({matchPatterns:{narrow:/^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,any:/^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i},defaultMatchWidth:"any",parsePatterns:{any:{am:/^a/i,pm:/^p/i,midnight:/^mi/i,noon:/^no/i,morning:/morning/i,afternoon:/afternoon/i,evening:/evening/i,night:/night/i}},defaultParseWidth:"any"})},options:{weekStartsOn:0,firstWeekContainsDate:1}},E={},x=Symbol.for("constructDateFrom");function B(e,a){return"function"==typeof e?e(a):e&&"object"==typeof e&&x in e?e[x](a):e instanceof Date?new e.constructor(a):new Date(a)}function D(e,a){return B(a||e,e)}function R(e){let a=D(e),t=new Date(Date.UTC(a.getFullYear(),a.getMonth(),a.getDate(),a.getHours(),a.getMinutes(),a.getSeconds(),a.getMilliseconds()));return t.setUTCFullYear(a.getFullYear()),e-t}function M(e,...a){let t=B.bind(null,e||a.find(e=>"object"==typeof e));return a.map(t)}function T(e,a){let t=D(e,a?.in);return t.setHours(0,0,0,0),t}function S(e,a,t){let[r,n]=M(t?.in,e,a),o=T(r),i=T(n);return Math.round((o-R(o)-(i-R(i)))/864e5)}function P(e,a){let t=D(e,a?.in);return t.setFullYear(t.getFullYear(),0,1),t.setHours(0,0,0,0),t}function z(e,a){let t=a?.weekStartsOn??a?.locale?.options?.weekStartsOn??E.weekStartsOn??E.locale?.options?.weekStartsOn??0,r=D(e,a?.in),n=r.getDay();return r.setDate(r.getDate()-(7*(n<t)+n-t)),r.setHours(0,0,0,0),r}function $(e,a){return z(e,{...a,weekStartsOn:1})}function Y(e,a){let t=D(e,a?.in),r=t.getFullYear(),n=B(t,0);n.setFullYear(r+1,0,4),n.setHours(0,0,0,0);let o=$(n),i=B(t,0);i.setFullYear(r,0,4),i.setHours(0,0,0,0);let l=$(i);return t.getTime()>=o.getTime()?r+1:t.getTime()>=l.getTime()?r:r-1}function W(e,a){let t,r,n=D(e,a?.in);return Math.round(($(n)-(t=Y(n,void 0),(r=B(n,0)).setFullYear(t,0,4),r.setHours(0,0,0,0),$(r)))/6048e5)+1}function O(e,a){let t=D(e,a?.in),r=t.getFullYear(),n=a?.firstWeekContainsDate??a?.locale?.options?.firstWeekContainsDate??E.firstWeekContainsDate??E.locale?.options?.firstWeekContainsDate??1,o=B(a?.in||e,0);o.setFullYear(r+1,0,n),o.setHours(0,0,0,0);let i=z(o,a),l=B(a?.in||e,0);l.setFullYear(r,0,n),l.setHours(0,0,0,0);let d=z(l,a);return+t>=+i?r+1:+t>=+d?r:r-1}function N(e,a){let t,r,n,o=D(e,a?.in);return Math.round((z(o,a)-(t=a?.firstWeekContainsDate??a?.locale?.options?.firstWeekContainsDate??E.firstWeekContainsDate??E.locale?.options?.firstWeekContainsDate??1,r=O(o,a),(n=B(a?.in||o,0)).setFullYear(r,0,t),n.setHours(0,0,0,0),z(n,a)))/6048e5)+1}function I(e,a){let t=Math.abs(e).toString().padStart(a,"0");return(e<0?"-":"")+t}let X={y(e,a){let t=e.getFullYear(),r=t>0?t:1-t;return I("yy"===a?r%100:r,a.length)},M(e,a){let t=e.getMonth();return"M"===a?String(t+1):I(t+1,2)},d:(e,a)=>I(e.getDate(),a.length),a(e,a){let t=e.getHours()/12>=1?"pm":"am";switch(a){case"a":case"aa":return t.toUpperCase();case"aaa":return t;case"aaaaa":return t[0];default:return"am"===t?"a.m.":"p.m."}},h:(e,a)=>I(e.getHours()%12||12,a.length),H:(e,a)=>I(e.getHours(),a.length),m:(e,a)=>I(e.getMinutes(),a.length),s:(e,a)=>I(e.getSeconds(),a.length),S(e,a){let t=a.length;return I(Math.trunc(e.getMilliseconds()*Math.pow(10,t-3)),a.length)}},F={G:function(e,a,t){let r=+(e.getFullYear()>0);switch(a){case"G":case"GG":case"GGG":return t.era(r,{width:"abbreviated"});case"GGGGG":return t.era(r,{width:"narrow"});default:return t.era(r,{width:"wide"})}},y:function(e,a,t){if("yo"===a){let a=e.getFullYear();return t.ordinalNumber(a>0?a:1-a,{unit:"year"})}return X.y(e,a)},Y:function(e,a,t,r){let n=O(e,r),o=n>0?n:1-n;return"YY"===a?I(o%100,2):"Yo"===a?t.ordinalNumber(o,{unit:"year"}):I(o,a.length)},R:function(e,a){return I(Y(e),a.length)},u:function(e,a){return I(e.getFullYear(),a.length)},Q:function(e,a,t){let r=Math.ceil((e.getMonth()+1)/3);switch(a){case"Q":return String(r);case"QQ":return I(r,2);case"Qo":return t.ordinalNumber(r,{unit:"quarter"});case"QQQ":return t.quarter(r,{width:"abbreviated",context:"formatting"});case"QQQQQ":return t.quarter(r,{width:"narrow",context:"formatting"});default:return t.quarter(r,{width:"wide",context:"formatting"})}},q:function(e,a,t){let r=Math.ceil((e.getMonth()+1)/3);switch(a){case"q":return String(r);case"qq":return I(r,2);case"qo":return t.ordinalNumber(r,{unit:"quarter"});case"qqq":return t.quarter(r,{width:"abbreviated",context:"standalone"});case"qqqqq":return t.quarter(r,{width:"narrow",context:"standalone"});default:return t.quarter(r,{width:"wide",context:"standalone"})}},M:function(e,a,t){let r=e.getMonth();switch(a){case"M":case"MM":return X.M(e,a);case"Mo":return t.ordinalNumber(r+1,{unit:"month"});case"MMM":return t.month(r,{width:"abbreviated",context:"formatting"});case"MMMMM":return t.month(r,{width:"narrow",context:"formatting"});default:return t.month(r,{width:"wide",context:"formatting"})}},L:function(e,a,t){let r=e.getMonth();switch(a){case"L":return String(r+1);case"LL":return I(r+1,2);case"Lo":return t.ordinalNumber(r+1,{unit:"month"});case"LLL":return t.month(r,{width:"abbreviated",context:"standalone"});case"LLLLL":return t.month(r,{width:"narrow",context:"standalone"});default:return t.month(r,{width:"wide",context:"standalone"})}},w:function(e,a,t,r){let n=N(e,r);return"wo"===a?t.ordinalNumber(n,{unit:"week"}):I(n,a.length)},I:function(e,a,t){let r=W(e);return"Io"===a?t.ordinalNumber(r,{unit:"week"}):I(r,a.length)},d:function(e,a,t){return"do"===a?t.ordinalNumber(e.getDate(),{unit:"date"}):X.d(e,a)},D:function(e,a,t){let r,n=S(r=D(e,void 0),P(r))+1;return"Do"===a?t.ordinalNumber(n,{unit:"dayOfYear"}):I(n,a.length)},E:function(e,a,t){let r=e.getDay();switch(a){case"E":case"EE":case"EEE":return t.day(r,{width:"abbreviated",context:"formatting"});case"EEEEE":return t.day(r,{width:"narrow",context:"formatting"});case"EEEEEE":return t.day(r,{width:"short",context:"formatting"});default:return t.day(r,{width:"wide",context:"formatting"})}},e:function(e,a,t,r){let n=e.getDay(),o=(n-r.weekStartsOn+8)%7||7;switch(a){case"e":return String(o);case"ee":return I(o,2);case"eo":return t.ordinalNumber(o,{unit:"day"});case"eee":return t.day(n,{width:"abbreviated",context:"formatting"});case"eeeee":return t.day(n,{width:"narrow",context:"formatting"});case"eeeeee":return t.day(n,{width:"short",context:"formatting"});default:return t.day(n,{width:"wide",context:"formatting"})}},c:function(e,a,t,r){let n=e.getDay(),o=(n-r.weekStartsOn+8)%7||7;switch(a){case"c":return String(o);case"cc":return I(o,a.length);case"co":return t.ordinalNumber(o,{unit:"day"});case"ccc":return t.day(n,{width:"abbreviated",context:"standalone"});case"ccccc":return t.day(n,{width:"narrow",context:"standalone"});case"cccccc":return t.day(n,{width:"short",context:"standalone"});default:return t.day(n,{width:"wide",context:"standalone"})}},i:function(e,a,t){let r=e.getDay(),n=0===r?7:r;switch(a){case"i":return String(n);case"ii":return I(n,a.length);case"io":return t.ordinalNumber(n,{unit:"day"});case"iii":return t.day(r,{width:"abbreviated",context:"formatting"});case"iiiii":return t.day(r,{width:"narrow",context:"formatting"});case"iiiiii":return t.day(r,{width:"short",context:"formatting"});default:return t.day(r,{width:"wide",context:"formatting"})}},a:function(e,a,t){let r=e.getHours()/12>=1?"pm":"am";switch(a){case"a":case"aa":return t.dayPeriod(r,{width:"abbreviated",context:"formatting"});case"aaa":return t.dayPeriod(r,{width:"abbreviated",context:"formatting"}).toLowerCase();case"aaaaa":return t.dayPeriod(r,{width:"narrow",context:"formatting"});default:return t.dayPeriod(r,{width:"wide",context:"formatting"})}},b:function(e,a,t){let r,n=e.getHours();switch(r=12===n?"noon":0===n?"midnight":n/12>=1?"pm":"am",a){case"b":case"bb":return t.dayPeriod(r,{width:"abbreviated",context:"formatting"});case"bbb":return t.dayPeriod(r,{width:"abbreviated",context:"formatting"}).toLowerCase();case"bbbbb":return t.dayPeriod(r,{width:"narrow",context:"formatting"});default:return t.dayPeriod(r,{width:"wide",context:"formatting"})}},B:function(e,a,t){let r,n=e.getHours();switch(r=n>=17?"evening":n>=12?"afternoon":n>=4?"morning":"night",a){case"B":case"BB":case"BBB":return t.dayPeriod(r,{width:"abbreviated",context:"formatting"});case"BBBBB":return t.dayPeriod(r,{width:"narrow",context:"formatting"});default:return t.dayPeriod(r,{width:"wide",context:"formatting"})}},h:function(e,a,t){if("ho"===a){let a=e.getHours()%12;return 0===a&&(a=12),t.ordinalNumber(a,{unit:"hour"})}return X.h(e,a)},H:function(e,a,t){return"Ho"===a?t.ordinalNumber(e.getHours(),{unit:"hour"}):X.H(e,a)},K:function(e,a,t){let r=e.getHours()%12;return"Ko"===a?t.ordinalNumber(r,{unit:"hour"}):I(r,a.length)},k:function(e,a,t){let r=e.getHours();return(0===r&&(r=24),"ko"===a)?t.ordinalNumber(r,{unit:"hour"}):I(r,a.length)},m:function(e,a,t){return"mo"===a?t.ordinalNumber(e.getMinutes(),{unit:"minute"}):X.m(e,a)},s:function(e,a,t){return"so"===a?t.ordinalNumber(e.getSeconds(),{unit:"second"}):X.s(e,a)},S:function(e,a){return X.S(e,a)},X:function(e,a,t){let r=e.getTimezoneOffset();if(0===r)return"Z";switch(a){case"X":return L(r);case"XXXX":case"XX":return K(r);default:return K(r,":")}},x:function(e,a,t){let r=e.getTimezoneOffset();switch(a){case"x":return L(r);case"xxxx":case"xx":return K(r);default:return K(r,":")}},O:function(e,a,t){let r=e.getTimezoneOffset();switch(a){case"O":case"OO":case"OOO":return"GMT"+V(r,":");default:return"GMT"+K(r,":")}},z:function(e,a,t){let r=e.getTimezoneOffset();switch(a){case"z":case"zz":case"zzz":return"GMT"+V(r,":");default:return"GMT"+K(r,":")}},t:function(e,a,t){return I(Math.trunc(e/1e3),a.length)},T:function(e,a,t){return I(+e,a.length)}};function V(e,a=""){let t=e>0?"-":"+",r=Math.abs(e),n=Math.trunc(r/60),o=r%60;return 0===o?t+String(n):t+String(n)+a+I(o,2)}function L(e,a){return e%60==0?(e>0?"-":"+")+I(Math.abs(e)/60,2):K(e,a)}function K(e,a=""){let t=Math.abs(e);return(e>0?"-":"+")+I(Math.trunc(t/60),2)+a+I(t%60,2)}let q=(e,a)=>{switch(e){case"P":return a.date({width:"short"});case"PP":return a.date({width:"medium"});case"PPP":return a.date({width:"long"});default:return a.date({width:"full"})}},H=(e,a)=>{switch(e){case"p":return a.time({width:"short"});case"pp":return a.time({width:"medium"});case"ppp":return a.time({width:"long"});default:return a.time({width:"full"})}},j={p:H,P:(e,a)=>{let t,r=e.match(/(P+)(p+)?/)||[],n=r[1],o=r[2];if(!o)return q(e,a);switch(n){case"P":t=a.dateTime({width:"short"});break;case"PP":t=a.dateTime({width:"medium"});break;case"PPP":t=a.dateTime({width:"long"});break;default:t=a.dateTime({width:"full"})}return t.replace("{{date}}",q(n,a)).replace("{{time}}",H(o,a))}},Q=/^D+$/,G=/^Y+$/,U=["D","DD","YY","YYYY"];function Z(e,a,t){var r,n,o;let i,l=(r=e,n=a,o=t,i="Y"===r[0]?"years":"days of the month",`Use \`${r.toLowerCase()}\` instead of \`${r}\` (in \`${n}\`) for formatting ${i} to the input \`${o}\`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md`);if(console.warn(l),U.includes(e))throw RangeError(l)}function J(e){return e instanceof Date||"object"==typeof e&&"[object Date]"===Object.prototype.toString.call(e)}function ee(e){return!(!J(e)&&"number"!=typeof e||isNaN(+D(e)))}let ea=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g,et=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g,er=/^'([^]*?)'?$/,en=/''/g,eo=/[a-zA-Z]/;function ei(e,a,t){let r=t?.locale??E.locale??k,n=t?.firstWeekContainsDate??t?.locale?.options?.firstWeekContainsDate??E.firstWeekContainsDate??E.locale?.options?.firstWeekContainsDate??1,o=t?.weekStartsOn??t?.locale?.options?.weekStartsOn??E.weekStartsOn??E.locale?.options?.weekStartsOn??0,i=D(e,t?.in);if(!ee(i))throw RangeError("Invalid time value");let l=a.match(et).map(e=>{let a=e[0];return"p"===a||"P"===a?(0,j[a])(e,r.formatLong):e}).join("").match(ea).map(e=>{if("''"===e)return{isToken:!1,value:"'"};let a=e[0];if("'"===a){var t;let a;return{isToken:!1,value:(a=(t=e).match(er))?a[1].replace(en,"'"):t}}if(F[a])return{isToken:!0,value:e};if(a.match(eo))throw RangeError("Format string contains an unescaped latin alphabet character `"+a+"`");return{isToken:!1,value:e}});r.localize.preprocessor&&(l=r.localize.preprocessor(i,l));let d={firstWeekContainsDate:n,weekStartsOn:o,locale:r};return l.map(n=>{if(!n.isToken)return n.value;let o=n.value;return(!t?.useAdditionalWeekYearTokens&&G.test(o)||!t?.useAdditionalDayOfYearTokens&&Q.test(o))&&Z(o,a,String(e)),(0,F[o[0]])(i,o,r.localize,d)}).join("")}class el{subPriority=0;validate(e,a){return!0}}class ed extends el{constructor(e,a,t,r,n){super(),this.value=e,this.validateValue=a,this.setValue=t,this.priority=r,n&&(this.subPriority=n)}validate(e,a){return this.validateValue(e,this.value,a)}set(e,a,t){return this.setValue(e,a,this.value,t)}}class eu extends el{priority=10;subPriority=-1;constructor(e,a){super(),this.context=e||(e=>B(a,e))}set(e,a){var t,r;let n;if(a.timestampIsSet)return e;return B(e,((n="function"==typeof(r=t=this.context)&&r.prototype?.constructor===r?new t(0):B(t,0)).setFullYear(e.getFullYear(),e.getMonth(),e.getDate()),n.setHours(e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()),n))}}class ep{run(e,a,t,r){let n=this.parse(e,a,t,r);return n?{setter:new ed(n.value,this.validate,this.set,this.priority,this.subPriority),rest:n.rest}:null}validate(e,a,t){return!0}}let es=/^(1[0-2]|0?\d)/,ec=/^(3[0-1]|[0-2]?\d)/,ev=/^(36[0-6]|3[0-5]\d|[0-2]?\d?\d)/,em=/^(5[0-3]|[0-4]?\d)/,eA=/^(2[0-3]|[0-1]?\d)/,e_=/^(2[0-4]|[0-1]?\d)/,eh=/^(1[0-1]|0?\d)/,eg=/^(1[0-2]|0?\d)/,eC=/^[0-5]?\d/,eb=/^[0-5]?\d/,ey=/^\d/,ef=/^\d{1,2}/,ew=/^\d{1,3}/,ek=/^\d{1,4}/,eE=/^-?\d+/,ex=/^-?\d/,eB=/^-?\d{1,2}/,eD=/^-?\d{1,3}/,eR=/^-?\d{1,4}/,eM=/^([+-])(\d{2})(\d{2})?|Z/,eT=/^([+-])(\d{2})(\d{2})|Z/,eS=/^([+-])(\d{2})(\d{2})((\d{2}))?|Z/,eP=/^([+-])(\d{2}):(\d{2})|Z/,ez=/^([+-])(\d{2}):(\d{2})(:(\d{2}))?|Z/;function e$(e,a){return e?{value:a(e.value),rest:e.rest}:e}function eY(e,a){let t=a.match(e);return t?{value:parseInt(t[0],10),rest:a.slice(t[0].length)}:null}function eW(e,a){let t=a.match(e);return t?"Z"===t[0]?{value:0,rest:a.slice(1)}:{value:("+"===t[1]?1:-1)*(36e5*(t[2]?parseInt(t[2],10):0)+6e4*(t[3]?parseInt(t[3],10):0)+1e3*(t[5]?parseInt(t[5],10):0)),rest:a.slice(t[0].length)}:null}function eO(e,a){switch(e){case 1:return eY(ey,a);case 2:return eY(ef,a);case 3:return eY(ew,a);case 4:return eY(ek,a);default:return eY(RegExp("^\\d{1,"+e+"}"),a)}}function eN(e,a){switch(e){case 1:return eY(ex,a);case 2:return eY(eB,a);case 3:return eY(eD,a);case 4:return eY(eR,a);default:return eY(RegExp("^-?\\d{1,"+e+"}"),a)}}function eI(e){switch(e){case"morning":return 4;case"evening":return 17;case"pm":case"noon":case"afternoon":return 12;default:return 0}}function eX(e,a){let t,r=a>0,n=r?a:1-a;if(n<=50)t=e||100;else{let a=n+50;t=e+100*Math.trunc(a/100)-100*(e>=a%100)}return r?t:1-t}function eF(e){return e%400==0||e%4==0&&e%100!=0}let eV=[31,28,31,30,31,30,31,31,30,31,30,31],eL=[31,29,31,30,31,30,31,31,30,31,30,31];function eK(e,a,t){let r=D(e,t?.in);return isNaN(a)?B(t?.in||e,NaN):(a&&r.setDate(r.getDate()+a),r)}function eq(e,a,t){let r=t?.weekStartsOn??t?.locale?.options?.weekStartsOn??E.weekStartsOn??E.locale?.options?.weekStartsOn??0,n=D(e,t?.in),o=n.getDay(),i=7-r;return eK(n,a<0||a>6?a-(o+i)%7:((a%7+7)%7+i)%7-(o+i)%7,t)}let eH={G:new class extends ep{priority=140;parse(e,a,t){switch(a){case"G":case"GG":case"GGG":return t.era(e,{width:"abbreviated"})||t.era(e,{width:"narrow"});case"GGGGG":return t.era(e,{width:"narrow"});default:return t.era(e,{width:"wide"})||t.era(e,{width:"abbreviated"})||t.era(e,{width:"narrow"})}}set(e,a,t){return a.era=t,e.setFullYear(t,0,1),e.setHours(0,0,0,0),e}incompatibleTokens=["R","u","t","T"]},y:new class extends ep{priority=130;incompatibleTokens=["Y","R","u","w","I","i","e","c","t","T"];parse(e,a,t){let r=e=>({year:e,isTwoDigitYear:"yy"===a});switch(a){case"y":return e$(eO(4,e),r);case"yo":return e$(t.ordinalNumber(e,{unit:"year"}),r);default:return e$(eO(a.length,e),r)}}validate(e,a){return a.isTwoDigitYear||a.year>0}set(e,a,t){let r=e.getFullYear();if(t.isTwoDigitYear){let a=eX(t.year,r);return e.setFullYear(a,0,1),e.setHours(0,0,0,0),e}let n="era"in a&&1!==a.era?1-t.year:t.year;return e.setFullYear(n,0,1),e.setHours(0,0,0,0),e}},Y:new class extends ep{priority=130;parse(e,a,t){let r=e=>({year:e,isTwoDigitYear:"YY"===a});switch(a){case"Y":return e$(eO(4,e),r);case"Yo":return e$(t.ordinalNumber(e,{unit:"year"}),r);default:return e$(eO(a.length,e),r)}}validate(e,a){return a.isTwoDigitYear||a.year>0}set(e,a,t,r){let n=O(e,r);if(t.isTwoDigitYear){let a=eX(t.year,n);return e.setFullYear(a,0,r.firstWeekContainsDate),e.setHours(0,0,0,0),z(e,r)}let o="era"in a&&1!==a.era?1-t.year:t.year;return e.setFullYear(o,0,r.firstWeekContainsDate),e.setHours(0,0,0,0),z(e,r)}incompatibleTokens=["y","R","u","Q","q","M","L","I","d","D","i","t","T"]},R:new class extends ep{priority=130;parse(e,a){return"R"===a?eN(4,e):eN(a.length,e)}set(e,a,t){let r=B(e,0);return r.setFullYear(t,0,4),r.setHours(0,0,0,0),$(r)}incompatibleTokens=["G","y","Y","u","Q","q","M","L","w","d","D","e","c","t","T"]},u:new class extends ep{priority=130;parse(e,a){return"u"===a?eN(4,e):eN(a.length,e)}set(e,a,t){return e.setFullYear(t,0,1),e.setHours(0,0,0,0),e}incompatibleTokens=["G","y","Y","R","w","I","i","e","c","t","T"]},Q:new class extends ep{priority=120;parse(e,a,t){switch(a){case"Q":case"QQ":return eO(a.length,e);case"Qo":return t.ordinalNumber(e,{unit:"quarter"});case"QQQ":return t.quarter(e,{width:"abbreviated",context:"formatting"})||t.quarter(e,{width:"narrow",context:"formatting"});case"QQQQQ":return t.quarter(e,{width:"narrow",context:"formatting"});default:return t.quarter(e,{width:"wide",context:"formatting"})||t.quarter(e,{width:"abbreviated",context:"formatting"})||t.quarter(e,{width:"narrow",context:"formatting"})}}validate(e,a){return a>=1&&a<=4}set(e,a,t){return e.setMonth((t-1)*3,1),e.setHours(0,0,0,0),e}incompatibleTokens=["Y","R","q","M","L","w","I","d","D","i","e","c","t","T"]},q:new class extends ep{priority=120;parse(e,a,t){switch(a){case"q":case"qq":return eO(a.length,e);case"qo":return t.ordinalNumber(e,{unit:"quarter"});case"qqq":return t.quarter(e,{width:"abbreviated",context:"standalone"})||t.quarter(e,{width:"narrow",context:"standalone"});case"qqqqq":return t.quarter(e,{width:"narrow",context:"standalone"});default:return t.quarter(e,{width:"wide",context:"standalone"})||t.quarter(e,{width:"abbreviated",context:"standalone"})||t.quarter(e,{width:"narrow",context:"standalone"})}}validate(e,a){return a>=1&&a<=4}set(e,a,t){return e.setMonth((t-1)*3,1),e.setHours(0,0,0,0),e}incompatibleTokens=["Y","R","Q","M","L","w","I","d","D","i","e","c","t","T"]},M:new class extends ep{incompatibleTokens=["Y","R","q","Q","L","w","I","D","i","e","c","t","T"];priority=110;parse(e,a,t){let r=e=>e-1;switch(a){case"M":return e$(eY(es,e),r);case"MM":return e$(eO(2,e),r);case"Mo":return e$(t.ordinalNumber(e,{unit:"month"}),r);case"MMM":return t.month(e,{width:"abbreviated",context:"formatting"})||t.month(e,{width:"narrow",context:"formatting"});case"MMMMM":return t.month(e,{width:"narrow",context:"formatting"});default:return t.month(e,{width:"wide",context:"formatting"})||t.month(e,{width:"abbreviated",context:"formatting"})||t.month(e,{width:"narrow",context:"formatting"})}}validate(e,a){return a>=0&&a<=11}set(e,a,t){return e.setMonth(t,1),e.setHours(0,0,0,0),e}},L:new class extends ep{priority=110;parse(e,a,t){let r=e=>e-1;switch(a){case"L":return e$(eY(es,e),r);case"LL":return e$(eO(2,e),r);case"Lo":return e$(t.ordinalNumber(e,{unit:"month"}),r);case"LLL":return t.month(e,{width:"abbreviated",context:"standalone"})||t.month(e,{width:"narrow",context:"standalone"});case"LLLLL":return t.month(e,{width:"narrow",context:"standalone"});default:return t.month(e,{width:"wide",context:"standalone"})||t.month(e,{width:"abbreviated",context:"standalone"})||t.month(e,{width:"narrow",context:"standalone"})}}validate(e,a){return a>=0&&a<=11}set(e,a,t){return e.setMonth(t,1),e.setHours(0,0,0,0),e}incompatibleTokens=["Y","R","q","Q","M","w","I","D","i","e","c","t","T"]},w:new class extends ep{priority=100;parse(e,a,t){switch(a){case"w":return eY(em,e);case"wo":return t.ordinalNumber(e,{unit:"week"});default:return eO(a.length,e)}}validate(e,a){return a>=1&&a<=53}set(e,a,t,r){let n,o;return z((o=N(n=D(e,r?.in),r)-t,n.setDate(n.getDate()-7*o),D(n,r?.in)),r)}incompatibleTokens=["y","R","u","q","Q","M","L","I","d","D","i","t","T"]},I:new class extends ep{priority=100;parse(e,a,t){switch(a){case"I":return eY(em,e);case"Io":return t.ordinalNumber(e,{unit:"week"});default:return eO(a.length,e)}}validate(e,a){return a>=1&&a<=53}set(e,a,t){let r,n;return $((n=W(r=D(e,void 0),void 0)-t,r.setDate(r.getDate()-7*n),r))}incompatibleTokens=["y","Y","u","q","Q","M","L","w","d","D","e","c","t","T"]},d:new class extends ep{priority=90;subPriority=1;parse(e,a,t){switch(a){case"d":return eY(ec,e);case"do":return t.ordinalNumber(e,{unit:"date"});default:return eO(a.length,e)}}validate(e,a){let t=eF(e.getFullYear()),r=e.getMonth();return t?a>=1&&a<=eL[r]:a>=1&&a<=eV[r]}set(e,a,t){return e.setDate(t),e.setHours(0,0,0,0),e}incompatibleTokens=["Y","R","q","Q","w","I","D","i","e","c","t","T"]},D:new class extends ep{priority=90;subpriority=1;parse(e,a,t){switch(a){case"D":case"DD":return eY(ev,e);case"Do":return t.ordinalNumber(e,{unit:"date"});default:return eO(a.length,e)}}validate(e,a){return eF(e.getFullYear())?a>=1&&a<=366:a>=1&&a<=365}set(e,a,t){return e.setMonth(0,t),e.setHours(0,0,0,0),e}incompatibleTokens=["Y","R","q","Q","M","L","w","I","d","E","i","e","c","t","T"]},E:new class extends ep{priority=90;parse(e,a,t){switch(a){case"E":case"EE":case"EEE":return t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"});case"EEEEE":return t.day(e,{width:"narrow",context:"formatting"});case"EEEEEE":return t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"});default:return t.day(e,{width:"wide",context:"formatting"})||t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"})}}validate(e,a){return a>=0&&a<=6}set(e,a,t,r){return(e=eq(e,t,r)).setHours(0,0,0,0),e}incompatibleTokens=["D","i","e","c","t","T"]},e:new class extends ep{priority=90;parse(e,a,t,r){let n=e=>{let a=7*Math.floor((e-1)/7);return(e+r.weekStartsOn+6)%7+a};switch(a){case"e":case"ee":return e$(eO(a.length,e),n);case"eo":return e$(t.ordinalNumber(e,{unit:"day"}),n);case"eee":return t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"});case"eeeee":return t.day(e,{width:"narrow",context:"formatting"});case"eeeeee":return t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"});default:return t.day(e,{width:"wide",context:"formatting"})||t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"})}}validate(e,a){return a>=0&&a<=6}set(e,a,t,r){return(e=eq(e,t,r)).setHours(0,0,0,0),e}incompatibleTokens=["y","R","u","q","Q","M","L","I","d","D","E","i","c","t","T"]},c:new class extends ep{priority=90;parse(e,a,t,r){let n=e=>{let a=7*Math.floor((e-1)/7);return(e+r.weekStartsOn+6)%7+a};switch(a){case"c":case"cc":return e$(eO(a.length,e),n);case"co":return e$(t.ordinalNumber(e,{unit:"day"}),n);case"ccc":return t.day(e,{width:"abbreviated",context:"standalone"})||t.day(e,{width:"short",context:"standalone"})||t.day(e,{width:"narrow",context:"standalone"});case"ccccc":return t.day(e,{width:"narrow",context:"standalone"});case"cccccc":return t.day(e,{width:"short",context:"standalone"})||t.day(e,{width:"narrow",context:"standalone"});default:return t.day(e,{width:"wide",context:"standalone"})||t.day(e,{width:"abbreviated",context:"standalone"})||t.day(e,{width:"short",context:"standalone"})||t.day(e,{width:"narrow",context:"standalone"})}}validate(e,a){return a>=0&&a<=6}set(e,a,t,r){return(e=eq(e,t,r)).setHours(0,0,0,0),e}incompatibleTokens=["y","R","u","q","Q","M","L","I","d","D","E","i","e","t","T"]},i:new class extends ep{priority=90;parse(e,a,t){let r=e=>0===e?7:e;switch(a){case"i":case"ii":return eO(a.length,e);case"io":return t.ordinalNumber(e,{unit:"day"});case"iii":return e$(t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"}),r);case"iiiii":return e$(t.day(e,{width:"narrow",context:"formatting"}),r);case"iiiiii":return e$(t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"}),r);default:return e$(t.day(e,{width:"wide",context:"formatting"})||t.day(e,{width:"abbreviated",context:"formatting"})||t.day(e,{width:"short",context:"formatting"})||t.day(e,{width:"narrow",context:"formatting"}),r)}}validate(e,a){return a>=1&&a<=7}set(e,a,t){var r;let n,o,i;return n=D(e,void 0),r=void 0,i=0===(o=D(n,r?.in).getDay())?7:o,(e=eK(n,t-i,void 0)).setHours(0,0,0,0),e}incompatibleTokens=["y","Y","u","q","Q","M","L","w","d","D","E","e","c","t","T"]},a:new class extends ep{priority=80;parse(e,a,t){switch(a){case"a":case"aa":case"aaa":return t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"});case"aaaaa":return t.dayPeriod(e,{width:"narrow",context:"formatting"});default:return t.dayPeriod(e,{width:"wide",context:"formatting"})||t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"})}}set(e,a,t){return e.setHours(eI(t),0,0,0),e}incompatibleTokens=["b","B","H","k","t","T"]},b:new class extends ep{priority=80;parse(e,a,t){switch(a){case"b":case"bb":case"bbb":return t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"});case"bbbbb":return t.dayPeriod(e,{width:"narrow",context:"formatting"});default:return t.dayPeriod(e,{width:"wide",context:"formatting"})||t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"})}}set(e,a,t){return e.setHours(eI(t),0,0,0),e}incompatibleTokens=["a","B","H","k","t","T"]},B:new class extends ep{priority=80;parse(e,a,t){switch(a){case"B":case"BB":case"BBB":return t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"});case"BBBBB":return t.dayPeriod(e,{width:"narrow",context:"formatting"});default:return t.dayPeriod(e,{width:"wide",context:"formatting"})||t.dayPeriod(e,{width:"abbreviated",context:"formatting"})||t.dayPeriod(e,{width:"narrow",context:"formatting"})}}set(e,a,t){return e.setHours(eI(t),0,0,0),e}incompatibleTokens=["a","b","t","T"]},h:new class extends ep{priority=70;parse(e,a,t){switch(a){case"h":return eY(eg,e);case"ho":return t.ordinalNumber(e,{unit:"hour"});default:return eO(a.length,e)}}validate(e,a){return a>=1&&a<=12}set(e,a,t){let r=e.getHours()>=12;return r&&t<12?e.setHours(t+12,0,0,0):r||12!==t?e.setHours(t,0,0,0):e.setHours(0,0,0,0),e}incompatibleTokens=["H","K","k","t","T"]},H:new class extends ep{priority=70;parse(e,a,t){switch(a){case"H":return eY(eA,e);case"Ho":return t.ordinalNumber(e,{unit:"hour"});default:return eO(a.length,e)}}validate(e,a){return a>=0&&a<=23}set(e,a,t){return e.setHours(t,0,0,0),e}incompatibleTokens=["a","b","h","K","k","t","T"]},K:new class extends ep{priority=70;parse(e,a,t){switch(a){case"K":return eY(eh,e);case"Ko":return t.ordinalNumber(e,{unit:"hour"});default:return eO(a.length,e)}}validate(e,a){return a>=0&&a<=11}set(e,a,t){return e.getHours()>=12&&t<12?e.setHours(t+12,0,0,0):e.setHours(t,0,0,0),e}incompatibleTokens=["h","H","k","t","T"]},k:new class extends ep{priority=70;parse(e,a,t){switch(a){case"k":return eY(e_,e);case"ko":return t.ordinalNumber(e,{unit:"hour"});default:return eO(a.length,e)}}validate(e,a){return a>=1&&a<=24}set(e,a,t){return e.setHours(t<=24?t%24:t,0,0,0),e}incompatibleTokens=["a","b","h","H","K","t","T"]},m:new class extends ep{priority=60;parse(e,a,t){switch(a){case"m":return eY(eC,e);case"mo":return t.ordinalNumber(e,{unit:"minute"});default:return eO(a.length,e)}}validate(e,a){return a>=0&&a<=59}set(e,a,t){return e.setMinutes(t,0,0),e}incompatibleTokens=["t","T"]},s:new class extends ep{priority=50;parse(e,a,t){switch(a){case"s":return eY(eb,e);case"so":return t.ordinalNumber(e,{unit:"second"});default:return eO(a.length,e)}}validate(e,a){return a>=0&&a<=59}set(e,a,t){return e.setSeconds(t,0),e}incompatibleTokens=["t","T"]},S:new class extends ep{priority=30;parse(e,a){return e$(eO(a.length,e),e=>Math.trunc(e*Math.pow(10,-a.length+3)))}set(e,a,t){return e.setMilliseconds(t),e}incompatibleTokens=["t","T"]},X:new class extends ep{priority=10;parse(e,a){switch(a){case"X":return eW(eM,e);case"XX":return eW(eT,e);case"XXXX":return eW(eS,e);case"XXXXX":return eW(ez,e);default:return eW(eP,e)}}set(e,a,t){return a.timestampIsSet?e:B(e,e.getTime()-R(e)-t)}incompatibleTokens=["t","T","x"]},x:new class extends ep{priority=10;parse(e,a){switch(a){case"x":return eW(eM,e);case"xx":return eW(eT,e);case"xxxx":return eW(eS,e);case"xxxxx":return eW(ez,e);default:return eW(eP,e)}}set(e,a,t){return a.timestampIsSet?e:B(e,e.getTime()-R(e)-t)}incompatibleTokens=["t","T","X"]},t:new class extends ep{priority=40;parse(e){return eY(eE,e)}set(e,a,t){return[B(e,1e3*t),{timestampIsSet:!0}]}incompatibleTokens="*"},T:new class extends ep{priority=20;parse(e){return eY(eE,e)}set(e,a,t){return[B(e,t),{timestampIsSet:!0}]}incompatibleTokens="*"}},ej=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g,eQ=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g,eG=/^'([^]*?)'?$/,eU=/''/g,eZ=/\S/,eJ=/[a-zA-Z]/;function e0(e,a,t,r){let n=()=>B(r?.in||t,NaN),o=Object.assign({},E),i=r?.locale??o.locale??k,l=r?.firstWeekContainsDate??r?.locale?.options?.firstWeekContainsDate??o.firstWeekContainsDate??o.locale?.options?.firstWeekContainsDate??1,d=r?.weekStartsOn??r?.locale?.options?.weekStartsOn??o.weekStartsOn??o.locale?.options?.weekStartsOn??0;if(!a)return e?n():D(t,r?.in);let u={firstWeekContainsDate:l,weekStartsOn:d,locale:i},p=[new eu(r?.in,t)],s=a.match(eQ).map(e=>{let a=e[0];return a in j?(0,j[a])(e,i.formatLong):e}).join("").match(ej),c=[];for(let t of s){var v,m;!r?.useAdditionalWeekYearTokens&&(v=t,G.test(v))&&Z(t,a,e),!r?.useAdditionalDayOfYearTokens&&(m=t,Q.test(m))&&Z(t,a,e);let o=t[0],l=eH[o];if(l){let{incompatibleTokens:a}=l;if(Array.isArray(a)){let e=c.find(e=>a.includes(e.token)||e.token===o);if(e)throw RangeError(`The format string mustn't contain \`${e.fullToken}\` and \`${t}\` at the same time`)}else if("*"===l.incompatibleTokens&&c.length>0)throw RangeError(`The format string mustn't contain \`${t}\` and any other token at the same time`);c.push({token:o,fullToken:t});let r=l.run(e,t,i.match,u);if(!r)return n();p.push(r.setter),e=r.rest}else{if(o.match(eJ))throw RangeError("Format string contains an unescaped latin alphabet character `"+o+"`");if("''"===t?t="'":"'"===o&&(t=t.match(eG)[1].replace(eU,"'")),0!==e.indexOf(t))return n();e=e.slice(t.length)}}if(e.length>0&&eZ.test(e))return n();let A=p.map(e=>e.priority).sort((e,a)=>a-e).filter((e,a,t)=>t.indexOf(e)===a).map(e=>p.filter(a=>a.priority===e).sort((e,a)=>a.subPriority-e.subPriority)).map(e=>e[0]),_=D(t,r?.in);if(isNaN(+_))return n();let h={};for(let e of A){if(!e.validate(_,u))return n();let a=e.set(_,h,u);Array.isArray(a)?(_=a[0],Object.assign(h,a[1])):_=a}return _}function e6(e,a,t){let r,n,o,i,l=D(e,t?.in),d=l.getFullYear(),u=l.getDate(),p=B(t?.in||e,0);p.setFullYear(d,a,15),p.setHours(0,0,0,0);let s=(n=(r=D(p,void 0)).getFullYear(),o=r.getMonth(),(i=B(r,0)).setFullYear(n,o+1,0),i.setHours(0,0,0,0),i.getDate());return l.setMonth(a,Math.min(u,s)),l}function e1(e,a,t){let r=D(e,t?.in);return isNaN(+r)?B(t?.in||e,NaN):(null!=a.year&&r.setFullYear(a.year),null!=a.month&&(r=e6(r,a.month)),null!=a.date&&r.setDate(a.date),null!=a.hours&&r.setHours(a.hours),null!=a.minutes&&r.setMinutes(a.minutes),null!=a.seconds&&r.setSeconds(a.seconds),null!=a.milliseconds&&r.setMilliseconds(a.milliseconds),r)}function e5(e,a,t){let r=D(e,t?.in);return r.setSeconds(a),r}function e4(e,a,t){let r=D(e,t?.in);return r.setMilliseconds(a),r}function e8(e,a){return+D(e)<+D(a)}function e7(e,a){return+D(e)==+D(a)}function e2(e,a){return+D(e)>+D(a)}function e3(e,a){return D(e,a?.in).getHours()}function e9(e,a){return D(e,a?.in).getMinutes()}function ae(e){return D(e).getSeconds()}function aa(e,a){return D(e,a?.in).getFullYear()}function at(e,a){return D(e,a?.in).getMonth()}function ar(e,a){let[t,r]=M(e,a.start,a.end);return{start:t,end:r}}function an(e,a){let{start:t,end:r}=ar(a?.in,e),n=+t>+r,o=n?+t:+r,i=n?r:t;i.setHours(0,0,0,0);let l=a?.step??1;if(!l)return[];l<0&&(l=-l,n=!n);let d=[];for(;+i<=o;)d.push(B(t,i)),i.setDate(i.getDate()+l),i.setHours(0,0,0,0);return n?d.reverse():d}function ao(e,a,t){let r=D(e,t?.in);if(isNaN(a))return B(t?.in||e,NaN);if(!a)return r;let n=r.getDate(),o=B(t?.in||e,r.getTime());return(o.setMonth(r.getMonth()+a+1,0),n>=o.getDate())?o:(r.setFullYear(o.getFullYear(),o.getMonth(),n),r)}function ai(e,a){let t=a?.weekStartsOn??a?.locale?.options?.weekStartsOn??E.weekStartsOn??E.locale?.options?.weekStartsOn??0,r=D(e,a?.in),n=r.getDay();return r.setDate(r.getDate()+((n<t?-7:0)+6-(n-t))),r.setHours(23,59,59,999),r}function al(e,a,t){let r=D(e,t?.in);return isNaN(+r)?B(t?.in||e,NaN):(r.setFullYear(a),r)}function ad(e,a){let t=D(e,a?.in),r=t.getFullYear();return t.setFullYear(r+1,0,0),t.setHours(23,59,59,999),t}function au(e,a){let t=D(e)-D(a);return t<0?-1:t>0?1:t}function ap(e,a,t){let{years:r=0,months:n=0,weeks:o=0,days:i=0,hours:l=0,minutes:d=0,seconds:u=0}=a,p=D(e,t?.in),s=n||r?ao(p,n+12*r):p,c=i||o?eK(s,i+7*o):s;return B(t?.in||e,+c+1e3*(u+60*(d+60*l)))}function as(e,a){let t=D(e,a?.in),r=t.getMonth();return t.setMonth(r-r%3,1),t.setHours(0,0,0,0),t}function ac(e,a,t){let[r,n]=M(t?.in,e,a);return+as(r)==+as(n)}function av(e,a){return Math.trunc(D(e,a?.in).getMonth()/3)+1}function am(e,a){let t=D(e,a?.in),r=t.getMonth();return t.setMonth(r-r%3+3,0),t.setHours(23,59,59,999),t}function aA(){let e=(0,c.OA)();return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img",...e},[(0,c.Lk)("path",{d:"M29.333 8c0-2.208-1.792-4-4-4h-18.667c-2.208 0-4 1.792-4 4v18.667c0 2.208 1.792 4 4 4h18.667c2.208 0 4-1.792 4-4v-18.667zM26.667 8v18.667c0 0.736-0.597 1.333-1.333 1.333 0 0-18.667 0-18.667 0-0.736 0-1.333-0.597-1.333-1.333 0 0 0-18.667 0-18.667 0-0.736 0.597-1.333 1.333-1.333 0 0 18.667 0 18.667 0 0.736 0 1.333 0.597 1.333 1.333z"}),(0,c.Lk)("path",{d:"M20 2.667v5.333c0 0.736 0.597 1.333 1.333 1.333s1.333-0.597 1.333-1.333v-5.333c0-0.736-0.597-1.333-1.333-1.333s-1.333 0.597-1.333 1.333z"}),(0,c.Lk)("path",{d:"M9.333 2.667v5.333c0 0.736 0.597 1.333 1.333 1.333s1.333-0.597 1.333-1.333v-5.333c0-0.736-0.597-1.333-1.333-1.333s-1.333 0.597-1.333 1.333z"}),(0,c.Lk)("path",{d:"M4 14.667h24c0.736 0 1.333-0.597 1.333-1.333s-0.597-1.333-1.333-1.333h-24c-0.736 0-1.333 0.597-1.333 1.333s0.597 1.333 1.333 1.333z"})])}function a_(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M23.057 7.057l-16 16c-0.52 0.52-0.52 1.365 0 1.885s1.365 0.52 1.885 0l16-16c0.52-0.52 0.52-1.365 0-1.885s-1.365-0.52-1.885 0z"}),(0,c.Lk)("path",{d:"M7.057 8.943l16 16c0.52 0.52 1.365 0.52 1.885 0s0.52-1.365 0-1.885l-16-16c-0.52-0.52-1.365-0.52-1.885 0s-0.52 1.365 0 1.885z"})])}function ah(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M20.943 23.057l-7.057-7.057c0 0 7.057-7.057 7.057-7.057 0.52-0.52 0.52-1.365 0-1.885s-1.365-0.52-1.885 0l-8 8c-0.521 0.521-0.521 1.365 0 1.885l8 8c0.52 0.52 1.365 0.52 1.885 0s0.52-1.365 0-1.885z"})])}function ag(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M12.943 24.943l8-8c0.521-0.521 0.521-1.365 0-1.885l-8-8c-0.52-0.52-1.365-0.52-1.885 0s-0.52 1.365 0 1.885l7.057 7.057c0 0-7.057 7.057-7.057 7.057-0.52 0.52-0.52 1.365 0 1.885s1.365 0.52 1.885 0z"})])}function aC(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M16 1.333c-8.095 0-14.667 6.572-14.667 14.667s6.572 14.667 14.667 14.667c8.095 0 14.667-6.572 14.667-14.667s-6.572-14.667-14.667-14.667zM16 4c6.623 0 12 5.377 12 12s-5.377 12-12 12c-6.623 0-12-5.377-12-12s5.377-12 12-12z"}),(0,c.Lk)("path",{d:"M14.667 8v8c0 0.505 0.285 0.967 0.737 1.193l5.333 2.667c0.658 0.329 1.46 0.062 1.789-0.596s0.062-1.46-0.596-1.789l-4.596-2.298c0 0 0-7.176 0-7.176 0-0.736-0.597-1.333-1.333-1.333s-1.333 0.597-1.333 1.333z"})])}function ab(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M24.943 19.057l-8-8c-0.521-0.521-1.365-0.521-1.885 0l-8 8c-0.52 0.52-0.52 1.365 0 1.885s1.365 0.52 1.885 0l7.057-7.057c0 0 7.057 7.057 7.057 7.057 0.52 0.52 1.365 0.52 1.885 0s0.52-1.365 0-1.885z"})])}function ay(){return(0,c.uX)(),(0,c.CE)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",fill:"currentColor","aria-hidden":"true",class:"dp__icon",role:"img"},[(0,c.Lk)("path",{d:"M7.057 12.943l8 8c0.521 0.521 1.365 0.521 1.885 0l8-8c0.52-0.52 0.52-1.365 0-1.885s-1.365-0.52-1.885 0l-7.057 7.057c0 0-7.057-7.057-7.057-7.057-0.52-0.52-1.365-0.52-1.885 0s-0.52 1.365 0 1.885z"})])}aA.compatConfig={MODE:3},a_.compatConfig={MODE:3},ah.compatConfig={MODE:3},ag.compatConfig={MODE:3},aC.compatConfig={MODE:3},ab.compatConfig={MODE:3},ay.compatConfig={MODE:3};let af=(e,a)=>new Date(a?e.toLocaleString("en-US",{timeZone:a}):e),aw=(e,a,t)=>ak(e,a,t)||aZ(),ak=(e,a,t)=>{let r;if(!e)return null;let n=t?aJ(aZ(e),!0):aZ(e);return a?a.exactMatch?(r=a.dateInTz?af(new Date(e),a.dateInTz):aZ(e),t?aJ(r,!0):r):af(n,a.timezone):n};var aE=((r=aE||{}).month="month",r.year="year",r),ax=((n=ax||{}).top="top",n.bottom="bottom",n),aB=((o=aB||{}).header="header",o.calendar="calendar",o.timePicker="timePicker",o),aD=((i=aD||{}).month="month",i.year="year",i.calendar="calendar",i.time="time",i.minutes="minutes",i.hours="hours",i.seconds="seconds",i);let aR=["timestamp","date","iso"];var aM=((l=aM||{}).up="up",l.down="down",l.left="left",l.right="right",l),aT=((d=aT||{}).arrowUp="ArrowUp",d.arrowDown="ArrowDown",d.arrowLeft="ArrowLeft",d.arrowRight="ArrowRight",d.enter="Enter",d.space=" ",d.esc="Escape",d.tab="Tab",d.home="Home",d.end="End",d.pageUp="PageUp",d.pageDown="PageDown",d),aS=((u=aS||{}).MONTH_AND_YEAR="MM-yyyy",u.YEAR="yyyy",u.DATE="dd-MM-yyyy",u);function aP(e){return a=>{let t=new Intl.DateTimeFormat(e,{weekday:"short",timeZone:"UTC"}).format(new Date(`2017-01-0${a}T00:00:00+00:00`));return"ar"===e?t.slice(2,5):t.slice(0,2)}}let az=(e,a,t)=>{let r=[];for(let t=+e[0];t<=+e[1];t++)r.push({value:+t,text:aK(t,a)});return t?r.reverse():r},a$=(e,a,t)=>{let r=[1,2,3,4,5,6,7,8,9,10,11,12].map(e=>{let a=e<10?`0${e}`:e;return new Date(`2017-${a}-01T00:00:00+00:00`)});if(null!==e)try{let a="long"===t?"LLLL":"LLL";return r.map((t,r)=>{let n=ei(af(t,"UTC"),a,{locale:e});return{text:n.charAt(0).toUpperCase()+n.substring(1),value:r}})}catch{}let n=new Intl.DateTimeFormat(a,{month:t,timeZone:"UTC"});return r.map((e,a)=>{let t=n.format(e);return{text:t.charAt(0).toUpperCase()+t.substring(1),value:a}})},aY=e=>{let a=(0,v.R1)(e);return a?.$el?a?.$el:a},aW=e=>!!Array.isArray(e)&&!!e[0]&&!!e[1],aO=e=>`"${e}" prop must be enabled!`,aN=e=>0===e?e:!e||isNaN(+e)?null:+e,aI=e=>{if(e)return[...e.querySelectorAll("input, button, select, textarea, a[href]")][0]},aX=(e,a,t)=>{let r=null!=t,n=null!=a;if(!r&&!n)return!1;let o=+t,i=+a;return r&&n?+e>o||+e<i:r?+e>o:!!n&&+e<i},aF=(e,a)=>(e=>{let a=[],t=e=>e.filter(e=>e);for(let r=0;r<e.length;r+=3){let n=[e[r],e[r+1],e[r+2]];a.push(t(n))}return a})(e).map(e=>e.map(e=>{let{active:t,disabled:r,isBetween:n,highlighted:o}=a(e);return{...e,active:t,disabled:r,className:{dp__overlay_cell_active:t,dp__overlay_cell:!t,dp__overlay_cell_disabled:r,dp__overlay_cell_pad:!0,dp__overlay_cell_active_disabled:r&&t,dp__cell_in_between:n,"dp--highlighted":o}}})),aV=(e,a,t=!1)=>{e&&a.allowStopPropagation&&(t&&e.stopImmediatePropagation(),e.stopPropagation())},aL=(e,a)=>e?.querySelector(`[data-dp-element="${a}"]`),aK=(e,a)=>new Intl.NumberFormat(a,{useGrouping:!1,style:"decimal"}).format(e),aq=(e,a)=>ei(e,a??aS.DATE),aH=(e,a,t)=>a.get(aq(e,t)),aj=(e,a,t=!1,r)=>e.key===aT.enter||e.key===aT.space?(t&&e.preventDefault(),a()):r?r(e):void 0,aQ=(e,a)=>e?aS.MONTH_AND_YEAR:a?aS.YEAR:aS.DATE,aG=e=>e<10?`0${e}`:e,aU=(e,a,t,r,n,o)=>{let i=e0(e,a.slice(0,e.length),new Date,{locale:o});return ee(i)&&J(i)?r||n?i:e1(i,{hours:+t.hours,minutes:+t?.minutes,seconds:+t?.seconds,milliseconds:0}):null},aZ=e=>e?new Date(e):new Date,aJ=(e,a)=>{let t,r=e1(aZ(JSON.parse(JSON.stringify(e))),{hours:0,minutes:0,seconds:0,milliseconds:0});return a?((t=D(r,void 0)).setDate(1),t.setHours(0,0,0,0),t):r},a0=(e,a,t,r)=>{var n,o,i,l;let d,u,p=e?aZ(e):aZ();return(a||0===a)&&(n=p,o=+a,(d=D(n,void 0)).setHours(o),p=d),(t||0===t)&&(i=p,l=+t,(u=D(i,void 0)).setMinutes(l),p=u),(r||0===r)&&(p=e5(p,+r)),e4(p,0)},a6=(e,a)=>!!e&&!!a&&e8(aJ(e),aJ(a)),a1=(e,a)=>!!e&&!!a&&e7(aJ(e),aJ(a)),a5=(e,a)=>!!e&&!!a&&e2(aJ(e),aJ(a)),a4=(e,a,t)=>e?.[0]&&e?.[1]?a5(t,e[0])&&a6(t,e[1]):!!e?.[0]&&!!a&&(a5(t,e[0])&&a6(t,a)||a6(t,e[0])&&a5(t,a)),a8=e=>aJ(e1(new Date(e),{date:1})),a7=(e,a,t)=>a&&(t||0===t)?Object.fromEntries(["hours","minutes","seconds"].map(r=>r===a?[r,t]:[r,isNaN(+e[r])?void 0:+e[r]])):{hours:isNaN(+e.hours)?void 0:+e.hours,minutes:isNaN(+e.minutes)?void 0:+e.minutes,seconds:isNaN(+e.seconds)?void 0:+e.seconds},a2=e=>({hours:e3(e),minutes:e9(e),seconds:ae(e)}),a3=(e,a)=>{if(a){let t=aa(aZ(a));if(t>e)return 12;if(t===e)return at(aZ(a))}},a9=(e,a)=>{if(a){let t=aa(aZ(a));return t<e?-1:t===e?at(aZ(a)):void 0}},te=e=>{if(e)return aa(aZ(e))},ta=(e,a)=>an({start:a5(e,a)?a:e,end:a5(a,e)?a:e}),tt=e=>{let a=ao(e,1);return{month:at(a),year:aa(a)}},tr=(e,a)=>[z(e,{weekStartsOn:+a}),ai(e,{weekStartsOn:+a})],tn=(e,a)=>Object.assign({hours:e3(aZ()),minutes:e9(aZ()),seconds:a?ae(aZ()):0},e),to=(e,a,t)=>[e1(aZ(e),{date:1}),e1(aZ(),{month:a,year:t,date:1})],ti=(e,a,t)=>{let r=e?aZ(e):aZ();return(a||0===a)&&(r=e6(r,a)),t&&(r=al(r,t)),r},tl=(e,a,t,r,n)=>{if(!r||n&&!a||!n&&!t)return!1;let o=n?ao(e,1):ao(e,-1,void 0),i=[at(o),aa(o)];return n?!tu(...i,a):!td(...i,t)},td=(e,a,t)=>a6(...to(t,e,a))||a1(...to(t,e,a)),tu=(e,a,t)=>a5(...to(t,e,a))||a1(...to(t,e,a)),tp=(e,a,t,r,n,o,i)=>{if("function"==typeof a&&!i)return a(e);let l=t?{locale:t}:void 0;return Array.isArray(e)?`${ei(e[0],o,l)}${n&&!e[1]?"":r}${e[1]?ei(e[1],o,l):""}`:ei(e,o,l)},ts=e=>{if(e)return null;throw Error(aO("partial-range"))},tc=(e,a)=>{if(a)return e();throw Error(aO("range"))},tv=e=>Array.isArray(e)?ee(e[0])&&(!e[1]||ee(e[1])):!!e&&ee(e),tm=(e,a,t,r)=>{if(!e)return!0;if(r){let r="max"===t?e8(e,a):e2(e,a),n={seconds:0,milliseconds:0};return r||e7(e1(e,n),e1(a,n))}return"max"===t?e.getTime()<=a.getTime():e.getTime()>=a.getTime()},tA=(e,a,t)=>e?e1(a??aZ(),{hours:+e.hours||0,minutes:+e.minutes||0,seconds:+e.seconds||0}):aZ(t??a),t_=(e,a,t,r,n)=>{if(Array.isArray(r)){let o=tA(e,r[0],a),i=tA(e,r[1],a);return tm(r[0],o,t,!!a)&&tm(r[1],i,t,!!a)&&n}let o=tA(e,r,a);return tm(r,o,t,!!a)&&n},th=e=>e1(aZ(),a2(e)),tg=(e,a,t)=>"function"==typeof e?e({month:a,year:t}):!!e.months.find(e=>e.month===a&&e.year===t),tC=(e,a)=>"function"==typeof e?e(a):e.years.includes(a),tb=e=>`dp-${ei(e,"yyyy-MM-dd")}`,ty=(e,a)=>({before:eK(aJ(a),-e,void 0),after:eK(aJ(a),e)}),tf=(e,a)=>a<+e[0]||a>+e[1],tw=(0,v.Kh)({menuFocused:!1,shiftKeyInMenu:!1}),tk=()=>({control:(0,c.EW)(()=>({shiftKeyInMenu:tw.shiftKeyInMenu,menuFocused:tw.menuFocused})),setMenuFocused:e=>{tw.menuFocused=e},setShiftKey:e=>{tw.shiftKeyInMenu!==e&&(tw.shiftKeyInMenu=e)}}),tE=(0,v.Kh)({monthYear:[],calendar:[],time:[],actionRow:[],selectionGrid:[],timePicker:{0:[],1:[]},monthPicker:[]}),tx=(0,v.KR)(null),tB=(0,v.KR)(!1),tD=(0,v.KR)(!1),tR=(0,v.KR)(!1),tM=(0,v.KR)(!1),tT=(0,v.KR)(0),tS=(0,v.KR)(0),tP=()=>{let e=(0,c.EW)(()=>tB.value?[...tE.selectionGrid,tE.actionRow].filter(e=>e.length):tD.value?[...tE.timePicker[0],...tE.timePicker[1],tM.value?[]:[tx.value],tE.actionRow].filter(e=>e.length):tR.value?[...tE.monthPicker,tE.actionRow]:[tE.monthYear,...tE.calendar,tE.time,tE.actionRow].filter(e=>e.length)),a=a=>{tT.value=a?tT.value+1:tT.value-1;let t=null;e.value[tS.value]&&(t=e.value[tS.value][tT.value]),!t&&e.value[tS.value+(a?1:-1)]?(tS.value=tS.value+(a?1:-1),tT.value=a?0:e.value[tS.value].length-1):t||(tT.value=a?tT.value-1:tT.value+1)},t=a=>{(0!==tS.value||a)&&(tS.value!==e.value.length||!a)&&(tS.value=a?tS.value+1:tS.value-1,e.value[tS.value]?e.value[tS.value]&&!e.value[tS.value][tT.value]&&0!==tT.value&&(tT.value=e.value[tS.value].length-1):tS.value=a?tS.value-1:tS.value+1)},r=a=>{let t=null;e.value[tS.value]&&(t=e.value[tS.value][tT.value]),t?t.focus({preventScroll:!tB.value}):tT.value=a?tT.value-1:tT.value+1},n=()=>{tT.value=0,tS.value=0};return{buildMatrix:(e,a)=>{tE[a]=e},buildMultiLevelMatrix:(e,a)=>{tE[a]=e},setTimePickerBackRef:e=>{tx.value=e},setSelectionGrid:e=>{tB.value=e,n(),e||(tE.selectionGrid=[])},setTimePicker:(e,a=!1)=>{tD.value=e,tM.value=a,n(),e||(tE.timePicker[0]=[],tE.timePicker[1]=[])},setTimePickerElements:(e,a=0)=>{tE.timePicker[a]=e},arrowRight:()=>{a(!0),r(!0)},arrowLeft:()=>{a(!1),r(!1)},arrowUp:()=>{t(!1),r(!0)},arrowDown:()=>{t(!0),r(!0)},clearArrowNav:()=>{tE.monthYear=[],tE.calendar=[],tE.time=[],tE.actionRow=[],tE.selectionGrid=[],tE.timePicker[0]=[],tE.timePicker[1]=[],tB.value=!1,tD.value=!1,tM.value=!1,tR.value=!1,n(),tx.value=null},setMonthPicker:e=>{tR.value=e,n()},refSets:tE}},tz=e=>({menuAppearTop:"dp-menu-appear-top",menuAppearBottom:"dp-menu-appear-bottom",open:"dp-slide-down",close:"dp-slide-up",next:"calendar-next",previous:"calendar-prev",vNext:"dp-slide-up",vPrevious:"dp-slide-down",...e??{}}),t$=e=>e?"boolean"==typeof e?2*!!e:+e>=2?+e:2:0,tY=(e,a,t,r)=>new Map(e.map(e=>{let n=aw(e,a,r);return[aq(n,t),n]})),tW=e=>{let a=()=>{let a=e.enableSeconds?":ss":"",t=e.enableMinutes?":mm":"";return e.is24?`HH${t}${a}`:`hh${t}${a} aa`},t=()=>e.format?e.format:e.monthPicker?"MM/yyyy":e.timePicker?a():e.weekPicker?`${_.value?.type==="iso"?"II":"ww"}-RR`:e.yearPicker?"yyyy":e.quarterPicker?"QQQ/yyyy":e.enableTimePicker?`MM/dd/yyyy, ${a()}`:"MM/dd/yyyy",r=()=>b.value.enabled?e.startTime&&Array.isArray(e.startTime)?[tn(e.startTime[0],e.enableSeconds),tn(e.startTime[1],e.enableSeconds)]:null:e.startTime&&!Array.isArray(e.startTime)?tn(e.startTime,e.enableSeconds):null,n=(0,c.EW)(()=>(e=>{let a="object"==typeof e&&e,t={static:!0,solo:!1};if(!e)return{...t,count:t$(!1)};let r=a?e:{},n=t$(a?r.count??!0:e);return Object.assign(t,r,{count:n})})(e.multiCalendars)),o=(0,c.EW)(()=>r()),i=(0,c.EW)(()=>({toggleOverlay:"Toggle overlay",menu:"Datepicker menu",input:"Datepicker input",openTimePicker:"Open time picker",closeTimePicker:"Close time Picker",incrementValue:e=>`Increment ${e}`,decrementValue:e=>`Decrement ${e}`,openTpOverlay:e=>`Open ${e} overlay`,amPmButton:"Switch AM/PM mode",openYearsOverlay:"Open years overlay",openMonthsOverlay:"Open months overlay",nextMonth:"Next month",prevMonth:"Previous month",nextYear:"Next year",prevYear:"Previous year",day:void 0,weekDay:void 0,clearInput:"Clear value",calendarIcon:"Calendar icon",timePicker:"Time picker",monthPicker:e=>`Month picker${e?" overlay":""}`,yearPicker:e=>`Year picker${e?" overlay":""}`,timeOverlay:e=>`${e} overlay`,...e.ariaLabels??{}})),l=(0,c.EW)(()=>({months:[],years:[],times:{hours:[],minutes:[],seconds:[]},...e.filters??{}})),d=(0,c.EW)(()=>{let a;return"boolean"==typeof(a=e.transitions)?!!a&&tz({}):tz(a)}),u=(0,c.EW)(()=>({showSelect:!0,showCancel:!0,showNow:!1,showPreview:!0,...e.actionRow??{}})),p=(0,c.EW)(()=>{let a,r,n;return a=e.previewFormat,r=e.format,n=t(),a||("string"==typeof n?n:r)}),s=(0,c.EW)(()=>{var a;let t;return a=e.textInput,t={enterSubmit:!0,tabSubmit:!0,openMenu:"open",selectOnFocus:!1,rangeSeparator:" - ",escClose:!0},"object"==typeof a?{...t,...a??{},enabled:!0}:{...t,enabled:a}}),v=(0,c.EW)(()=>{var a;let t;return a=e.inline,t={input:!1},"object"==typeof a?{...t,...a??{},enabled:!0}:{enabled:a,...t}}),m=(0,c.EW)(()=>({allowStopPropagation:!0,closeOnScroll:!1,modeHeight:255,allowPreventDefault:!1,closeOnClearValue:!0,closeOnAutoApply:!0,noSwipe:!1,keepActionRow:!1,onClickOutside:void 0,tabOutClosesMenu:!0,arrowLeft:void 0,keepViewOnOffsetClick:!1,timeArrowHoldThreshold:0,shadowDom:!1,mobileBreakpoint:600,setDateOnMenuClose:!1,...e.config??{}})),A=(0,c.EW)(()=>{var a;let t;return t={dates:Array.isArray(a=e.highlight)?a.map(e=>aZ(e)):[],years:[],months:[],quarters:[],weeks:[],weekdays:[],options:{highlightDisabled:!1}},"function"==typeof a?a:{...t,...a??{}}}),_=(0,c.EW)(()=>{let a;return"object"==typeof(a=e.weekNumbers)?{type:a?.type??"local",hideOnOffsetDates:a?.hideOnOffsetDates??!1}:{type:a,hideOnOffsetDates:!1}}),h=(0,c.EW)(()=>{let a;return(a=e.timezone)?"string"==typeof a?{timezone:a,exactMatch:!1,dateInTz:void 0,emitTimezone:void 0,convertModel:!0}:{timezone:a.timezone,exactMatch:a.exactMatch??!1,dateInTz:a.dateInTz??void 0,emitTimezone:a.emitTimezone??void 0,convertModel:a.convertModel??!0}:{timezone:void 0,exactMatch:!1,emitTimezone:void 0}}),g=(0,c.EW)(()=>{let a;return"boolean"==typeof(a=e.multiDates)?{enabled:a,dragSelect:!0,limit:null}:{enabled:!!a,limit:a.limit?+a.limit:null,dragSelect:a.dragSelect??!0}}),C=(0,c.EW)(()=>{var a;let t,r,n;return n=aQ((a={minDate:e.minDate,maxDate:e.maxDate,disabledDates:e.disabledDates,allowedDates:e.allowedDates,highlight:A.value,markers:e.markers,timezone:h.value,isSpecific:e.monthPicker||e.yearPicker||e.quarterPicker,isMonthPicker:e.monthPicker,isYearPicker:e.yearPicker}).isMonthPicker,a.isYearPicker),{minDate:ak(a.minDate,a.timezone,a.isSpecific),maxDate:ak(a.maxDate,a.timezone,a.isSpecific),disabledDates:Array.isArray(a.disabledDates)?tY(a.disabledDates,a.timezone,n,a.isSpecific):a.disabledDates,allowedDates:Array.isArray(a.allowedDates)?tY(a.allowedDates,a.timezone,n,a.isSpecific):null,highlight:"object"==typeof a.highlight&&Array.isArray(a.highlight?.dates)?tY(a.highlight.dates,a.timezone,n):a.highlight,markers:(t=a.markers,r=a.timezone,t.length?new Map(t.map(e=>[aq(aw(e.date,r),aS.DATE),e])):null)}}),b=(0,c.EW)(()=>{var a;let t;return a=e.range,t={noDisabledRange:!1,showLastInRange:!0,minMaxRawRange:!1,partialRange:!0,disableTimeRangeValidation:!1,maxRange:void 0,minRange:void 0,autoRange:void 0,fixedStart:!1,fixedEnd:!1},"object"==typeof a?{enabled:!0,...t,...a}:{enabled:a,...t}});return{defaultedTransitions:d,defaultedMultiCalendars:n,defaultedStartTime:o,defaultedAriaLabels:i,defaultedFilters:l,defaultedActionRow:u,defaultedPreviewFormat:p,defaultedTextInput:s,defaultedInline:v,defaultedConfig:m,defaultedHighlight:A,defaultedWeekNumbers:_,defaultedRange:b,propDates:C,defaultedTz:h,defaultedMultiDates:g,defaultedUI:(0,c.EW)(()=>{let a;return{...Object.fromEntries(Object.keys(a=e.ui).map(e=>{let t=a[e],r="string"==typeof a[e]?{[t]:!0}:Object.fromEntries(t.map(e=>[e,!0]));return[e,r]}))}}),getDefaultPattern:t,getDefaultStartTime:r,handleEventPropagation:e=>{m.value.allowStopPropagation&&e.stopPropagation(),m.value.allowPreventDefault&&e.preventDefault()}}},tO={multiCalendars:{type:[Boolean,Number,String,Object],default:void 0},modelValue:{type:[String,Date,Array,Object,Number],default:null},modelType:{type:String,default:null},position:{type:String,default:"center"},dark:{type:Boolean,default:!1},format:{type:[String,Function],default:()=>null},autoPosition:{type:[Boolean,String],default:!0},altPosition:{type:Function,default:null},transitions:{type:[Boolean,Object],default:!0},formatLocale:{type:Object,default:null},utc:{type:[Boolean,String],default:!1},ariaLabels:{type:Object,default:()=>({})},offset:{type:[Number,String],default:10},hideNavigation:{type:Array,default:()=>[]},timezone:{type:[String,Object],default:null},vertical:{type:Boolean,default:!1},disableMonthYearSelect:{type:Boolean,default:!1},disableYearSelect:{type:Boolean,default:!1},dayClass:{type:Function,default:null},yearRange:{type:Array,default:()=>[1900,2100]},enableTimePicker:{type:Boolean,default:!0},autoApply:{type:Boolean,default:!1},disabledDates:{type:[Array,Function],default:()=>[]},monthNameFormat:{type:String,default:"short"},startDate:{type:[Date,String],default:null},startTime:{type:[Object,Array],default:null},hideOffsetDates:{type:Boolean,default:!1},noToday:{type:Boolean,default:!1},disabledWeekDays:{type:Array,default:()=>[]},allowedDates:{type:Array,default:null},nowButtonLabel:{type:String,default:"Now"},markers:{type:Array,default:()=>[]},escClose:{type:Boolean,default:!0},spaceConfirm:{type:Boolean,default:!0},monthChangeOnArrows:{type:Boolean,default:!0},presetDates:{type:Array,default:()=>[]},flow:{type:Array,default:()=>[]},partialFlow:{type:Boolean,default:!1},preventMinMaxNavigation:{type:Boolean,default:!1},reverseYears:{type:Boolean,default:!1},weekPicker:{type:Boolean,default:!1},filters:{type:Object,default:()=>({})},arrowNavigation:{type:Boolean,default:!1},highlight:{type:[Function,Object],default:null},teleport:{type:[Boolean,String,Object],default:null},teleportCenter:{type:Boolean,default:!1},locale:{type:String,default:"en-Us"},weekNumName:{type:String,default:"W"},weekStart:{type:[Number,String],default:1},weekNumbers:{type:[String,Function,Object],default:null},monthChangeOnScroll:{type:[Boolean,String],default:!0},dayNames:{type:[Function,Array],default:null},monthPicker:{type:Boolean,default:!1},customProps:{type:Object,default:null},yearPicker:{type:Boolean,default:!1},modelAuto:{type:Boolean,default:!1},selectText:{type:String,default:"Select"},cancelText:{type:String,default:"Cancel"},previewFormat:{type:[String,Function],default:()=>""},multiDates:{type:[Object,Boolean],default:!1},ignoreTimeValidation:{type:Boolean,default:!1},minDate:{type:[Date,String],default:null},maxDate:{type:[Date,String],default:null},minTime:{type:Object,default:null},maxTime:{type:Object,default:null},name:{type:String,default:null},placeholder:{type:String,default:""},hideInputIcon:{type:Boolean,default:!1},clearable:{type:Boolean,default:!0},alwaysClearable:{type:Boolean,default:!1},state:{type:Boolean,default:null},required:{type:Boolean,default:!1},autocomplete:{type:String,default:"off"},timePicker:{type:Boolean,default:!1},enableSeconds:{type:Boolean,default:!1},is24:{type:Boolean,default:!0},noHoursOverlay:{type:Boolean,default:!1},noMinutesOverlay:{type:Boolean,default:!1},noSecondsOverlay:{type:Boolean,default:!1},hoursGridIncrement:{type:[String,Number],default:1},minutesGridIncrement:{type:[String,Number],default:5},secondsGridIncrement:{type:[String,Number],default:5},hoursIncrement:{type:[Number,String],default:1},minutesIncrement:{type:[Number,String],default:1},secondsIncrement:{type:[Number,String],default:1},range:{type:[Boolean,Object],default:!1},uid:{type:String,default:null},disabled:{type:Boolean,default:!1},readonly:{type:Boolean,default:!1},inline:{type:[Boolean,Object],default:!1},textInput:{type:[Boolean,Object],default:!1},sixWeeks:{type:[Boolean,String],default:!1},actionRow:{type:Object,default:()=>({})},focusStartDate:{type:Boolean,default:!1},disabledTimes:{type:[Function,Array],default:void 0},timePickerInline:{type:Boolean,default:!1},calendar:{type:Function,default:null},config:{type:Object,default:void 0},quarterPicker:{type:Boolean,default:!1},yearFirst:{type:Boolean,default:!1},loading:{type:Boolean,default:!1},onInternalModelChange:{type:[Function,Object],default:null},enableMinutes:{type:Boolean,default:!0},ui:{type:Object,default:()=>({})}},tN={...tO,shadow:{type:Boolean,default:!1},flowStep:{type:Number,default:0},internalModelValue:{type:[Date,Array],default:null},noOverlayFocus:{type:Boolean,default:!1},collapse:{type:Boolean,default:!1},menuWrapRef:{type:Object,default:null},getInputRect:{type:Function,default:()=>({})},isTextInputDate:{type:Boolean,default:!1},isMobile:{type:Boolean,default:void 0}},tI=["title"],tX=["disabled"],tF=(0,c.pM)({compatConfig:{MODE:3},__name:"ActionRow",props:{menuMount:{type:Boolean,default:!1},calendarWidth:{type:Number,default:0},...tN},emits:["close-picker","select-date","select-now","invalid-select"],setup(e,{emit:a}){let{defaultedActionRow:t,defaultedPreviewFormat:r,defaultedMultiCalendars:n,defaultedTextInput:o,defaultedInline:i,defaultedRange:l,defaultedMultiDates:d}=tW(e),{isTimeValid:u,isMonthValid:p}=rG(e),{buildMatrix:s}=tP(),A=(0,v.KR)(null),_=(0,v.KR)(null),h=(0,v.KR)(!1),g=(0,v.KR)({}),C=(0,v.KR)(null),b=(0,v.KR)(null);(0,c.sV)(()=>{e.arrowNavigation&&s([aY(A),aY(_)],"actionRow"),y(),window.addEventListener("resize",y)}),(0,c.hi)(()=>{window.removeEventListener("resize",y)});let y=()=>{h.value=!1,setTimeout(()=>{let e=C.value?.getBoundingClientRect(),a=b.value?.getBoundingClientRect();e&&a&&(g.value.maxWidth=`${a.width-e.width-20}px`),h.value=!0},0)},f=(0,c.EW)(()=>!l.value.enabled||!!l.value.partialRange||!e.internalModelValue||2===e.internalModelValue.length),w=(0,c.EW)(()=>!u.value(e.internalModelValue)||!p.value(e.internalModelValue)||!f.value),k=a=>tp(a,r.value,e.formatLocale,o.value.rangeSeparator,e.modelAuto,r.value),E=(0,c.EW)(()=>{let a,t;return e.internalModelValue&&e.menuMount?"string"==typeof r.value?Array.isArray(e.internalModelValue)?2===e.internalModelValue.length&&e.internalModelValue[1]?(a=e.internalModelValue,n.value.count>0?`${k(a[0])} - ${k(a[1])}`:[k(a[0]),k(a[1])]):d.value.enabled?e.internalModelValue.map(e=>`${k(e)}`):e.modelAuto?`${k(e.internalModelValue[0])}`:`${k(e.internalModelValue[0])} -`:k(e.internalModelValue):(t=r.value,e.timePicker||e.monthPicker,t(e.internalModelValue)):""}),x=(0,c.EW)(()=>Array.isArray(E.value)?E.value.join(d.value.enabled?"; ":" - "):E.value),B=()=>{u.value(e.internalModelValue)&&p.value(e.internalModelValue)&&f.value?a("select-date"):a("invalid-select")};return(e,a)=>((0,c.uX)(),(0,c.CE)("div",{ref_key:"actionRowRef",ref:b,class:"dp__action_row"},[e.$slots["action-row"]?(0,c.RG)(e.$slots,"action-row",(0,m.normalizeProps)((0,c.v6)({key:0},{internalModelValue:e.internalModelValue,disabled:w.value,selectDate:()=>e.$emit("select-date"),closePicker:()=>e.$emit("close-picker")}))):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,v.R1)(t).showPreview?((0,c.uX)(),(0,c.CE)("div",{key:0,class:"dp__selection_preview",title:x.value,style:(0,m.normalizeStyle)(g.value)},[e.$slots["action-preview"]&&h.value?(0,c.RG)(e.$slots,"action-preview",{key:0,value:e.internalModelValue}):(0,c.Q3)("",!0),!e.$slots["action-preview"]&&h.value?((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(x.value),1)],64)):(0,c.Q3)("",!0)],12,tI)):(0,c.Q3)("",!0),(0,c.Lk)("div",{ref_key:"actionBtnContainer",ref:C,class:"dp__action_buttons","data-dp-element":"action-row"},[e.$slots["action-buttons"]?(0,c.RG)(e.$slots,"action-buttons",{key:0,value:e.internalModelValue}):(0,c.Q3)("",!0),e.$slots["action-buttons"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[!(0,v.R1)(i).enabled&&(0,v.R1)(t).showCancel?((0,c.uX)(),(0,c.CE)("button",{key:0,ref_key:"cancelButtonRef",ref:A,type:"button",class:"dp__action_button dp__action_cancel",onClick:a[0]||(a[0]=a=>e.$emit("close-picker")),onKeydown:a[1]||(a[1]=a=>(0,v.R1)(aj)(a,()=>e.$emit("close-picker")))},(0,m.toDisplayString)(e.cancelText),545)):(0,c.Q3)("",!0),(0,v.R1)(t).showNow?((0,c.uX)(),(0,c.CE)("button",{key:1,type:"button",class:"dp__action_button dp__action_cancel",onClick:a[2]||(a[2]=a=>e.$emit("select-now")),onKeydown:a[3]||(a[3]=a=>(0,v.R1)(aj)(a,()=>e.$emit("select-now")))},(0,m.toDisplayString)(e.nowButtonLabel),33)):(0,c.Q3)("",!0),(0,v.R1)(t).showSelect?((0,c.uX)(),(0,c.CE)("button",{key:2,ref_key:"selectButtonRef",ref:_,type:"button",class:"dp__action_button dp__action_select",disabled:w.value,"data-test-id":"select-button",onKeydown:a[4]||(a[4]=e=>(0,v.R1)(aj)(e,()=>B())),onClick:B},(0,m.toDisplayString)(e.selectText),41,tX)):(0,c.Q3)("",!0)],64))],512)],64))],512))}}),tV=["role","aria-label","tabindex"],tL={class:"dp__selection_grid_header"},tK=["aria-selected","aria-disabled","data-test-id","onClick","onKeydown","onMouseover"],tq=["aria-label"],tH=(0,c.pM)({__name:"SelectionOverlay",props:{items:{},type:{},isLast:{type:Boolean},arrowNavigation:{type:Boolean},skipButtonRef:{type:Boolean},headerRefs:{},hideNavigation:{},escClose:{type:Boolean},useRelative:{type:Boolean},height:{},textInput:{type:[Boolean,Object]},config:{},noOverlayFocus:{type:Boolean},focusValue:{},menuWrapRef:{},ariaLabels:{},overlayLabel:{}},emits:["selected","toggle","reset-flow","hover-value"],setup(e,{expose:a,emit:t}){let{setSelectionGrid:r,buildMultiLevelMatrix:n,setMonthPicker:o}=tP(),{defaultedAriaLabels:i,defaultedTextInput:l,defaultedConfig:d,handleEventPropagation:u}=tW(e),{hideNavigationButtons:p}=rU(),s=(0,v.KR)(!1),A=(0,v.KR)(null),_=(0,v.KR)(null),g=(0,v.KR)([]),C=(0,v.KR)(),b=(0,v.KR)(null),y=(0,v.KR)(0),f=(0,v.KR)(null);(0,c.Ic)(()=>{A.value=null}),(0,c.sV)(()=>{(0,c.dY)().then(()=>M()),e.noOverlayFocus||k(),w(!0)}),(0,c.hi)(()=>w(!1));let w=a=>{e.arrowNavigation&&(e.headerRefs?.length?o(a):r(a))},k=()=>{let e=aY(_);e&&(l.value.enabled||(A.value?A.value?.focus({preventScroll:!0}):e.focus({preventScroll:!0})),s.value=e.clientHeight<e.scrollHeight)},E=(0,c.EW)(()=>({dp__overlay:!0,"dp--overlay-absolute":!e.useRelative,"dp--overlay-relative":e.useRelative})),x=(0,c.EW)(()=>e.useRelative?{height:`${e.height}px`,width:"var(--dp-menu-min-width)"}:void 0),B=(0,c.EW)(()=>({dp__overlay_col:!0})),D=(0,c.EW)(()=>({dp__btn:!0,dp__button:!0,dp__overlay_action:!0,dp__over_action_scroll:s.value,dp__button_bottom:e.isLast})),R=(0,c.EW)(()=>({dp__overlay_container:!0,dp__container_flex:e.items?.length<=6,dp__container_block:e.items?.length>6}));(0,c.wB)(()=>e.items,()=>M(!1),{deep:!0});let M=(e=!0)=>{(0,c.dY)().then(()=>{let a=aY(A),t=aY(_),r=aY(b),n=aY(f),o=r?r.getBoundingClientRect().height:0;t&&(t.getBoundingClientRect().height?y.value=t.getBoundingClientRect().height-o:y.value=d.value.modeHeight-o),a&&n&&e&&(n.scrollTop=a.offsetTop-n.offsetTop-(y.value/2-a.getBoundingClientRect().height)-o)})},T=e=>{e.disabled||t("selected",e.value)},S=()=>{t("toggle"),t("reset-flow")},P=a=>{switch(a.key){case aT.esc:return void(e.escClose&&(S(),u(a)));case aT.arrowLeft:case aT.arrowRight:case aT.arrowUp:case aT.arrowDown:return void(e.arrowNavigation||aV(a,d.value,!0));default:return}},z=a=>{if(a.key===aT.enter)return S();if(a.key===aT.tab){if(S(),!e.isLast){let a=aL(e.menuWrapRef??null,"action-row");a&&aI(a)?.focus()}return}};return a({focusGrid:k}),(a,r)=>((0,c.uX)(),(0,c.CE)("div",{ref_key:"gridWrapRef",ref:_,class:(0,m.normalizeClass)(E.value),style:(0,m.normalizeStyle)(x.value),role:e.useRelative?void 0:"dialog","aria-label":e.overlayLabel,tabindex:e.useRelative?void 0:"0",onKeydown:P,onClick:r[0]||(r[0]=(0,h.withModifiers)(()=>{},["prevent"]))},[(0,c.Lk)("div",{ref_key:"containerRef",ref:f,class:(0,m.normalizeClass)(R.value),style:(0,m.normalizeStyle)({"--dp-overlay-height":`${y.value}px`}),role:"grid"},[(0,c.Lk)("div",tL,[(0,c.RG)(a.$slots,"header")]),a.$slots.overlay?(0,c.RG)(a.$slots,"overlay",{key:0}):((0,c.uX)(!0),(0,c.CE)(c.FK,{key:1},(0,c.pI)(e.items,(r,o)=>((0,c.uX)(),(0,c.CE)("div",{key:o,class:(0,m.normalizeClass)(["dp__overlay_row",{dp__flex_row:e.items.length>=3}]),role:"row"},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(r,(r,i)=>((0,c.uX)(),(0,c.CE)("div",{key:r.value,ref_for:!0,ref:a=>{a&&((r.active||r.value===e.focusValue)&&(A.value=a),e.arrowNavigation&&(Array.isArray(g.value[o])?g.value[o][i]=a:g.value[o]=[a],n(e.headerRefs?.length?[e.headerRefs].concat(g.value):g.value.concat([e.skipButtonRef?[]:[b.value]]),e.headerRefs?.length?"monthPicker":"selectionGrid")))},role:"gridcell",class:(0,m.normalizeClass)(B.value),"aria-selected":r.active||void 0,"aria-disabled":r.disabled||void 0,tabindex:"0","data-test-id":r.text,onClick:(0,h.withModifiers)(e=>T(r),["prevent"]),onKeydown:e=>(0,v.R1)(aj)(e,()=>T(r),!0),onMouseover:e=>{var a;C.value=a=r.value,t("hover-value",a)}},[(0,c.Lk)("div",{class:(0,m.normalizeClass)(r.className)},[a.$slots.item?(0,c.RG)(a.$slots,"item",{key:0,item:r}):(0,c.Q3)("",!0),a.$slots.item?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(r.text),1)],64))],2)],42,tK))),128))],2))),128))],6),a.$slots["button-icon"]?(0,c.bo)(((0,c.uX)(),(0,c.CE)("button",{key:0,ref_key:"toggleButton",ref:b,type:"button","aria-label":(0,v.R1)(i)?.toggleOverlay,class:(0,m.normalizeClass)(D.value),tabindex:"0",onClick:S,onKeydown:z},[(0,c.RG)(a.$slots,"button-icon")],42,tq)),[[h.vShow,!(0,v.R1)(p)(e.hideNavigation,e.type)]]):(0,c.Q3)("",!0)],46,tV))}}),tj=["data-dp-mobile"],tQ=(0,c.pM)({__name:"InstanceWrap",props:{multiCalendars:{},stretch:{type:Boolean},collapse:{type:Boolean},isMobile:{type:Boolean}},setup(e){let a=(0,c.EW)(()=>e.multiCalendars>0?[...Array(e.multiCalendars).keys()]:[0]),t=(0,c.EW)(()=>({dp__instance_calendar:e.multiCalendars>0}));return(r,n)=>((0,c.uX)(),(0,c.CE)("div",{class:(0,m.normalizeClass)({dp__menu_inner:!e.stretch,"dp--menu--inner-stretched":e.stretch,dp__flex_display:e.multiCalendars>0,"dp--flex-display-collapsed":e.collapse}),"data-dp-mobile":e.isMobile},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(a.value,(e,a)=>((0,c.uX)(),(0,c.CE)("div",{key:e,class:(0,m.normalizeClass)(t.value)},[(0,c.RG)(r.$slots,"default",{instance:e,index:a})],2))),128))],10,tj))}}),tG=["data-dp-element","aria-label","aria-disabled"],tU=(0,c.pM)({compatConfig:{MODE:3},__name:"ArrowBtn",props:{ariaLabel:{},elName:{},disabled:{type:Boolean}},emits:["activate","set-ref"],setup(e,{emit:a}){let t=(0,v.KR)(null);return(0,c.sV)(()=>a("set-ref",t)),(r,n)=>((0,c.uX)(),(0,c.CE)("button",{ref_key:"elRef",ref:t,type:"button","data-dp-element":e.elName,class:"dp__btn dp--arrow-btn-nav",tabindex:"0","aria-label":e.ariaLabel,"aria-disabled":e.disabled||void 0,onClick:n[0]||(n[0]=e=>a("activate")),onKeydown:n[1]||(n[1]=e=>(0,v.R1)(aj)(e,()=>a("activate"),!0))},[(0,c.Lk)("span",{class:(0,m.normalizeClass)(["dp__inner_nav",{dp__inner_nav_disabled:e.disabled}])},[(0,c.RG)(r.$slots,"default")],2)],40,tG))}}),tZ=["aria-label","data-test-id"],tJ=(0,c.pM)({__name:"YearModePicker",props:{...tN,showYearPicker:{type:Boolean,default:!1},items:{type:Array,default:()=>[]},instance:{type:Number,default:0},year:{type:Number,default:0},isDisabled:{type:Function,default:()=>!1}},emits:["toggle-year-picker","year-select","handle-year"],setup(e,{emit:a}){let{showRightIcon:t,showLeftIcon:r}=rU(),{defaultedConfig:n,defaultedMultiCalendars:o,defaultedAriaLabels:i,defaultedTransitions:l,defaultedUI:d}=tW(e),{showTransition:u,transitionName:p}=rH(l),s=(0,v.KR)(!1),A=(0,c.EW)(()=>aK(e.year,e.locale)),_=(e=!1,t)=>{s.value=!s.value,a("toggle-year-picker",{flow:e,show:t})},g=(e=!1)=>{a("handle-year",e)};return(l,C)=>((0,c.uX)(),(0,c.CE)(c.FK,null,[(0,c.Lk)("div",{class:(0,m.normalizeClass)(["dp--year-mode-picker",{"dp--hidden-el":s.value}])},[(0,v.R1)(r)((0,v.R1)(o),e.instance)?((0,c.uX)(),(0,c.Wv)(tU,{key:0,ref:"mpPrevIconRef","aria-label":(0,v.R1)(i)?.prevYear,disabled:e.isDisabled(!1),class:(0,m.normalizeClass)((0,v.R1)(d)?.navBtnPrev),onActivate:C[0]||(C[0]=e=>g(!1))},{default:(0,c.k6)(()=>[l.$slots["arrow-left"]?(0,c.RG)(l.$slots,"arrow-left",{key:0}):(0,c.Q3)("",!0),l.$slots["arrow-left"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ah),{key:1}))]),_:3},8,["aria-label","disabled","class"])):(0,c.Q3)("",!0),(0,c.Lk)("button",{ref:"mpYearButtonRef",class:"dp__btn dp--year-select",type:"button","aria-label":`${e.year}-${(0,v.R1)(i)?.openYearsOverlay}`,"data-test-id":`year-mode-btn-${e.instance}`,onClick:C[1]||(C[1]=()=>_(!1)),onKeydown:C[2]||(C[2]=(0,h.withKeys)(()=>_(!1),["enter"]))},[l.$slots.year?(0,c.RG)(l.$slots,"year",{key:0,year:e.year,text:A.value,value:e.year}):(0,c.Q3)("",!0),l.$slots.year?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(A.value),1)],64))],40,tZ),(0,v.R1)(t)((0,v.R1)(o),e.instance)?((0,c.uX)(),(0,c.Wv)(tU,{key:1,ref:"mpNextIconRef","aria-label":(0,v.R1)(i)?.nextYear,disabled:e.isDisabled(!0),class:(0,m.normalizeClass)((0,v.R1)(d)?.navBtnNext),onActivate:C[3]||(C[3]=e=>g(!0))},{default:(0,c.k6)(()=>[l.$slots["arrow-right"]?(0,c.RG)(l.$slots,"arrow-right",{key:0}):(0,c.Q3)("",!0),l.$slots["arrow-right"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ag),{key:1}))]),_:3},8,["aria-label","disabled","class"])):(0,c.Q3)("",!0)],2),(0,c.bF)(h.Transition,{name:(0,v.R1)(p)(e.showYearPicker),css:(0,v.R1)(u)},{default:(0,c.k6)(()=>[e.showYearPicker?((0,c.uX)(),(0,c.Wv)(tH,{key:0,items:e.items,"text-input":l.textInput,"esc-close":l.escClose,config:l.config,"is-last":l.autoApply&&!(0,v.R1)(n).keepActionRow,"hide-navigation":l.hideNavigation,"aria-labels":l.ariaLabels,"overlay-label":(0,v.R1)(i)?.yearPicker?.(!0),type:"year",onToggle:_,onSelected:C[4]||(C[4]=e=>{s.value=!1,a("year-select",e)})},(0,c.eX)({"button-icon":(0,c.k6)(()=>[l.$slots["calendar-icon"]?(0,c.RG)(l.$slots,"calendar-icon",{key:0}):(0,c.Q3)("",!0),l.$slots["calendar-icon"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(aA),{key:1}))]),_:2},[l.$slots["year-overlay-value"]?{name:"item",fn:(0,c.k6)(({item:e})=>[(0,c.RG)(l.$slots,"year-overlay-value",{text:e.text,value:e.value})]),key:"0"}:void 0]),1032,["items","text-input","esc-close","config","is-last","hide-navigation","aria-labels","overlay-label"])):(0,c.Q3)("",!0)]),_:3},8,["name","css"])],64))}}),t0=(e,a,t)=>{if(a.value&&Array.isArray(a.value))if(a.value.some(a=>a1(e,a))){let t=a.value.filter(a=>!a1(a,e));a.value=t.length?t:null}else(t&&+t>a.value.length||!t)&&a.value.push(e);else a.value=[e]},t6=(e,a,t)=>{let r=e.value?e.value.slice():[];return 2===r.length&&null!==r[1]&&(r=[]),r.length?(a6(a,r[0])?r.unshift(a):r[1]=a,t("range-end",a)):(r=[a],t("range-start",a)),r},t1=(e,a,t,r)=>{e&&(e[0]&&e[1]&&t&&a("auto-apply"),e[0]&&!e[1]&&r&&t&&a("auto-apply"))},t5=e=>{Array.isArray(e.value)&&e.value.length<=2&&e.range?e.modelValue.value=e.value.map(a=>af(aZ(a),e.timezone)):Array.isArray(e.value)||(e.modelValue.value=af(aZ(e.value),e.timezone))},t4=(e,a,t,r)=>Array.isArray(a.value)&&(2===a.value.length||1===a.value.length&&r.value.partialRange)?r.value.fixedStart&&(a5(e,a.value[0])||a1(e,a.value[0]))?[a.value[0],e]:r.value.fixedEnd&&(a6(e,a.value[1])||a1(e,a.value[1]))?[e,a.value[1]]:(t("invalid-fixed-range",e),a.value):[],t8=({multiCalendars:e,range:a,highlight:t,propDates:r,calendars:n,modelValue:o,props:i,filters:l,year:d,month:u,emit:p})=>{let s=(0,c.EW)(()=>az(i.yearRange,i.locale,i.reverseYears)),m=(0,v.KR)([!1]),A=(0,c.EW)(()=>(e,a)=>{let t=e1(a8(new Date),{month:u.value(e),year:d.value(e)});return tl(a?ad(t):P(t),r.value.maxDate,r.value.minDate,i.preventMinMaxNavigation,a)}),_=()=>Array.isArray(o.value)&&e.value.solo&&o.value[1],h=()=>{for(let a=0;a<e.value.count;a++)if(0===a)n.value[a]=n.value[0];else if(a===e.value.count-1&&_())n.value[a]={month:at(o.value[1]),year:aa(o.value[1])};else{let e=e1(aZ(),n.value[a-1]);n.value[a]={month:at(e),year:aa(ao(e,12,void 0))}}},g=()=>{(()=>{if(o.value){var t,r,l;let d,u=Array.isArray(o.value)?(t=o.value,i.focusStartDate||e.value.solo?t[0]:t[1]?(r=t[0],d=function(e,a){let[t,r]=M(void 0,e,a),n=au(t,r),o=Math.abs(function(e,a){let[t,r]=M(void 0,e,a);return t.getFullYear()-r.getFullYear()}(t,r));t.setFullYear(1584),r.setFullYear(1584);let i=au(t,r)===-n,l=n*(o-i);return 0===l?0:l}(l=t[1],r),a.value.showLastInRange&&d>1?l:r):t[0]):o.value;n.value[0]={month:at(u),year:aa(u)}}})(),e.value.count&&h()};(0,c.wB)(o,(e,a)=>{i.isTextInputDate&&JSON.stringify(e??{})!==JSON.stringify(a??{})&&g()}),(0,c.sV)(()=>{g()});let C=(a,t)=>{n.value[t].year=a,p("update-month-year",{instance:t,year:a,month:n.value[t].month}),e.value.count&&!e.value.solo&&(a=>{if(!a)return h();let t=e1(aZ(),n.value[a]);return n.value[0].year=aa(ao(t,-(12*(e.value.count-1)),void 0)),h()})(t)},b=(0,c.EW)(()=>e=>aF(s.value,a=>({active:d.value(e)===a.value,disabled:aX(a.value,te(r.value.minDate),te(r.value.maxDate))||l.value.years?.includes(d.value(e)),highlighted:tC(t.value,a.value)}))),y=(e,a=!1,t)=>{a||p("reset-flow"),void 0!==t?m.value[e]=t:m.value[e]=!m.value[e],m.value[e]?p("overlay-toggle",{open:!0,overlay:aD.year}):(p("overlay-closed"),p("overlay-toggle",{open:!1,overlay:aD.year}))};return{isDisabled:A,groupedYears:b,showYearPicker:m,selectYear:C,toggleYearPicker:y,handleYearSelect:(e,a)=>{C(e,a),y(a)},handleYear:(e,a=!1)=>{A.value(e,a)||C(a?d.value(e)+1:d.value(e)-1,e)}}},t7=(0,c.pM)({compatConfig:{MODE:3},__name:"MonthPicker",props:{...tN},emits:["update:internal-model-value","overlay-closed","reset-flow","range-start","range-end","auto-apply","update-month-year","update-flow-step","mount","invalid-fixed-range","overlay-toggle"],setup(e,{expose:a,emit:t}){let r=rq((0,c.Ht)(),"yearMode");(0,c.sV)(()=>{e.shadow||t("mount",null)});let{groupedMonths:n,groupedYears:o,year:i,isDisabled:l,defaultedMultiCalendars:d,defaultedConfig:u,showYearPicker:p,modelValue:s,presetDate:A,setHoverDate:_,selectMonth:h,selectYear:g,toggleYearPicker:C,handleYearSelect:b,handleYear:y,getModelMonthYear:f}=((e,a)=>{let{defaultedMultiCalendars:t,defaultedAriaLabels:r,defaultedTransitions:n,defaultedConfig:o,defaultedRange:i,defaultedHighlight:l,propDates:d,defaultedTz:u,defaultedFilters:p,defaultedMultiDates:s}=tW(e),{modelValue:m,year:A,month:_,calendars:h}=rj(e,a,()=>{e.isTextInputDate&&y(aa(aZ(e.startDate)),0)}),g=(0,c.EW)(()=>a$(e.formatLocale,e.locale,e.monthNameFormat)),C=(0,v.KR)(null),{checkMinMaxRange:b}=rG(e),{selectYear:y,groupedYears:f,showYearPicker:w,toggleYearPicker:k,handleYearSelect:E,handleYear:x,isDisabled:B}=t8({modelValue:m,multiCalendars:t,range:i,highlight:l,calendars:h,year:A,propDates:d,month:_,filters:p,props:e,emit:a});(0,c.sV)(()=>{e.startDate&&(m.value&&e.focusStartDate||!m.value)&&y(aa(aZ(e.startDate)),0)});let D=e=>e?{month:at(e),year:aa(e)}:{month:null,year:null},R=()=>m.value?Array.isArray(m.value)?m.value.map(e=>D(e)):D(m.value):D(),M=(e,a,t)=>{let r=R();return!!Array.isArray(r)&&A.value(a)===r[t]?.year&&e===r[t]?.month},T=(0,c.EW)(()=>a=>aF(g.value,t=>{var r;let n,o;return{active:(r=t.value,n=h.value[a],Array.isArray(o=R())?o.some(e=>e.year===n?.year&&e.month===r):n?.year===o.year&&r===o.month),disabled:aX(t.value,a3(A.value(a),d.value.minDate),a9(A.value(a),d.value.maxDate))||((e,a,t)=>{if(e instanceof Map){let r=`${aG(t+1)}-${a}`;return!!e.size&&e.has(r)}return"function"==typeof e&&e(aJ(e1(aZ(),{month:t,year:a}),!0))})(d.value.disabledDates,A.value(a),t.value)||p.value.months?.includes(t.value)||!((e,a,t)=>{if(e instanceof Map){let r=`${aG(t+1)}-${a}`;return!e.size||e.has(r)}return!0})(d.value.allowedDates,A.value(a),t.value)||tf(e.yearRange,A.value(a)),isBetween:((e,a)=>{if(i.value.enabled){let t=R();if(Array.isArray(m.value)&&Array.isArray(t)){let t=M(e,a,0)||M(e,a,1),r=ti(a8(aZ()),e,A.value(a));return a4(m.value,C.value,r)&&!t}}return!1})(t.value,a),highlighted:tg(l.value,t.value,A.value(a))}})),S=(e,a)=>ti(a8(aZ()),e,A.value(a)),P=(e,t,r)=>{let n=r;if(!n&&0!==n){let a=R();n=Array.isArray(a)?a[e].month:a.month}a("update-month-year",{instance:e,year:t,month:n})};return{groupedMonths:T,groupedYears:f,year:A,isDisabled:B,defaultedMultiCalendars:t,defaultedAriaLabels:r,defaultedTransitions:n,defaultedConfig:o,showYearPicker:w,modelValue:m,presetDate:(e,t)=>{t5({value:e,modelValue:m,range:i.value.enabled,timezone:t?void 0:u.value.timezone}),a("auto-apply")},setHoverDate:(e,a)=>{C.value=S(e,a)},selectMonth:(t,r)=>{let n,o;return h.value[r].month=t,P(r,h.value[r].year,t),s.value.enabled?void(t0(S(t,r),m,s.value.limit),a("auto-apply",!0)):i.value.enabled?(n=S(t,r),void(i.value.fixedEnd||i.value.fixedStart?m.value=t4(n,m,a,i):m.value?b(n,m.value)&&(m.value=t6(m,S(t,r),a)):m.value=[S(t,r)],(0,c.dY)().then(()=>{t1(m.value,a,e.autoApply,e.modelAuto)}))):(o=m.value?m.value:a8(new Date),void(m.value=ti(o,t,A.value(r)),a("auto-apply"),a("update-flow-step")))},selectYear:(e,a)=>{y(e,a),P(a,e,null)},toggleYearPicker:k,handleYearSelect:E,handleYear:x,getModelMonthYear:R}})(e,t);return a({getSidebarProps:()=>({modelValue:s,year:i,getModelMonthYear:f,selectMonth:h,selectYear:g,handleYear:y}),presetDate:A,toggleYearPicker:e=>C(0,e)}),(e,a)=>((0,c.uX)(),(0,c.Wv)(tQ,{"multi-calendars":(0,v.R1)(d).count,collapse:e.collapse,stretch:"","is-mobile":e.isMobile},{default:(0,c.k6)(({instance:a})=>[e.$slots["top-extra"]?(0,c.RG)(e.$slots,"top-extra",{key:0,value:e.internalModelValue}):(0,c.Q3)("",!0),e.$slots["month-year"]?(0,c.RG)(e.$slots,"month-year",(0,m.normalizeProps)((0,c.v6)({key:1},{year:(0,v.R1)(i),months:(0,v.R1)(n)(a),years:(0,v.R1)(o)(a),selectMonth:(0,v.R1)(h),selectYear:(0,v.R1)(g),instance:a}))):((0,c.uX)(),(0,c.Wv)(tH,{key:2,items:(0,v.R1)(n)(a),"arrow-navigation":e.arrowNavigation,"is-last":e.autoApply&&!(0,v.R1)(u).keepActionRow,"esc-close":e.escClose,height:(0,v.R1)(u).modeHeight,config:e.config,"no-overlay-focus":!!(e.noOverlayFocus||e.textInput),"use-relative":"",type:"month",onSelected:e=>(0,v.R1)(h)(e,a),onHoverValue:e=>(0,v.R1)(_)(e,a)},(0,c.eX)({header:(0,c.k6)(()=>[(0,c.bF)(tJ,(0,c.v6)(e.$props,{items:(0,v.R1)(o)(a),instance:a,"show-year-picker":(0,v.R1)(p)[a],year:(0,v.R1)(i)(a),"is-disabled":e=>(0,v.R1)(l)(a,e),onHandleYear:e=>(0,v.R1)(y)(a,e),onYearSelect:e=>(0,v.R1)(b)(e,a),onToggleYearPicker:e=>(0,v.R1)(C)(a,e?.flow,e?.show)}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(r),(a,t)=>({name:a,fn:(0,c.k6)(t=>[(0,c.RG)(e.$slots,a,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["items","instance","show-year-picker","year","is-disabled","onHandleYear","onYearSelect","onToggleYearPicker"])]),_:2},[e.$slots["month-overlay-value"]?{name:"item",fn:(0,c.k6)(({item:a})=>[(0,c.RG)(e.$slots,"month-overlay-value",{text:a.text,value:a.value})]),key:"0"}:void 0]),1032,["items","arrow-navigation","is-last","esc-close","height","config","no-overlay-focus","onSelected","onHoverValue"]))]),_:3},8,["multi-calendars","collapse","is-mobile"]))}}),t2=(0,c.pM)({compatConfig:{MODE:3},__name:"YearPicker",props:{...tN},emits:["update:internal-model-value","reset-flow","range-start","range-end","auto-apply","update-month-year"],setup(e,{expose:a,emit:t}){let{groupedYears:r,modelValue:n,focusYear:o,selectYear:i,setHoverValue:l}=((e,a)=>{let{modelValue:t}=rj(e,a,()=>{e.isTextInputDate&&(u.value=aa(aZ(e.startDate)))}),r=(0,v.KR)(null),{defaultedHighlight:n,defaultedMultiDates:o,defaultedFilters:i,defaultedRange:l,propDates:d}=tW(e),u=(0,v.KR)();(0,c.sV)(()=>{e.startDate&&(t.value&&e.focusStartDate||!t.value)&&(u.value=aa(aZ(e.startDate)))});let p=(0,c.EW)(()=>aF(az(e.yearRange,e.locale,e.reverseYears),e=>{let a,o,u,p,c=(a=e.value,Array.isArray(t.value)?t.value.some(e=>aa(e)===a):!!t.value&&aa(t.value)===a),v=aX(e.value,te(d.value.minDate),te(d.value.maxDate))||i.value.years.includes(e.value)||(o=e.value,!(!(d.value.allowedDates instanceof Map)||d.value.allowedDates.size&&d.value.allowedDates.has(`${o}`)))||(u=e.value,d.value.disabledDates instanceof Map?!!d.value.disabledDates.size&&d.value.disabledDates.has(`${u}`):"function"!=typeof d.value.disabledDates||d.value.disabledDates(al(aJ(P(aZ())),u))),m=(p=e.value,!!(l.value.enabled&&Array.isArray(t.value))&&a4(t.value,r.value,s(p))&&!c);return{active:c,disabled:v,isBetween:m,highlighted:tC(n.value,e.value)}})),s=e=>al(a8(P(new Date)),e);return{groupedYears:p,modelValue:t,focusYear:u,setHoverValue:e=>{r.value=al(a8(new Date),e)},selectYear:r=>{if(a("update-month-year",{instance:0,year:r}),o.value.enabled)return t.value?Array.isArray(t.value)&&((t.value?.map(e=>aa(e))).includes(r)?t.value=t.value.filter(e=>aa(e)!==r):t.value.push(al(aJ(aZ()),r))):t.value=[al(aJ(P(aZ())),r)],a("auto-apply",!0);l.value.enabled?(t.value=t6(t,s(r),a),(0,c.dY)().then(()=>{t1(t.value,a,e.autoApply,e.modelAuto)})):(t.value=s(r),a("auto-apply"))}}})(e,t),{defaultedConfig:d}=tW(e);return a({getSidebarProps:()=>({modelValue:n,selectYear:i})}),(e,a)=>((0,c.uX)(),(0,c.CE)("div",null,[e.$slots["top-extra"]?(0,c.RG)(e.$slots,"top-extra",{key:0,value:e.internalModelValue}):(0,c.Q3)("",!0),e.$slots["month-year"]?(0,c.RG)(e.$slots,"month-year",(0,m.normalizeProps)((0,c.v6)({key:1},{years:(0,v.R1)(r),selectYear:(0,v.R1)(i)}))):((0,c.uX)(),(0,c.Wv)(tH,{key:2,items:(0,v.R1)(r),"is-last":e.autoApply&&!(0,v.R1)(d).keepActionRow,height:(0,v.R1)(d).modeHeight,config:e.config,"no-overlay-focus":!!(e.noOverlayFocus||e.textInput),"focus-value":(0,v.R1)(o),type:"year","use-relative":"",onSelected:(0,v.R1)(i),onHoverValue:(0,v.R1)(l)},(0,c.eX)({_:2},[e.$slots["year-overlay-value"]?{name:"item",fn:(0,c.k6)(({item:a})=>[(0,c.RG)(e.$slots,"year-overlay-value",{text:a.text,value:a.value})]),key:"0"}:void 0]),1032,["items","is-last","height","config","no-overlay-focus","focus-value","onSelected","onHoverValue"]))]))}}),t3={key:0,class:"dp__time_input"},t9=["data-compact","data-collapsed"],re=["data-test-id","aria-label","onKeydown","onClick","onMousedown"],ra=["aria-label","disabled","data-test-id","onKeydown","onClick"],rt=["data-test-id","aria-label","onKeydown","onClick","onMousedown"],rr={key:0},rn=["aria-label","data-compact"],ro=(0,c.pM)({compatConfig:{MODE:3},__name:"TimeInput",props:{hours:{type:Number,default:0},minutes:{type:Number,default:0},seconds:{type:Number,default:0},closeTimePickerBtn:{type:Object,default:null},order:{type:Number,default:0},disabledTimesConfig:{type:Function,default:null},validateTime:{type:Function,default:()=>!1},...tN},emits:["set-hours","set-minutes","update:hours","update:minutes","update:seconds","reset-flow","mounted","overlay-closed","overlay-opened","am-pm-change"],setup(e,{expose:a,emit:t}){let{setTimePickerElements:r,setTimePickerBackRef:n}=tP(),{defaultedAriaLabels:o,defaultedTransitions:i,defaultedFilters:l,defaultedConfig:d,defaultedRange:u,defaultedMultiCalendars:p}=tW(e),{transitionName:s,showTransition:A}=rH(i),_=(0,v.Kh)({hours:!1,minutes:!1,seconds:!1}),g=(0,v.KR)("AM"),C=(0,v.KR)(null),b=(0,v.KR)([]),y=(0,v.KR)(),f=(0,v.KR)(!1);(0,c.sV)(()=>{t("mounted")});let w=a=>e1(new Date,{hours:a.hours,minutes:a.minutes,seconds:e.enableSeconds?a.seconds:0,milliseconds:0}),k=(0,c.EW)(()=>a=>O(a,e[a])||x(a,e[a])),E=(0,c.EW)(()=>({hours:e.hours,minutes:e.minutes,seconds:e.seconds})),x=(a,t)=>!!u.value.enabled&&!u.value.disableTimeRangeValidation&&!e.validateTime(a,t),D=(a,t)=>{if(u.value.enabled&&!u.value.disableTimeRangeValidation){let r=t?+e[`${a}Increment`]:-e[`${a}Increment`],n=e[a]+r;return!e.validateTime(a,n)}return!1},R=(0,c.EW)(()=>a=>!I(+e[a]+ +e[`${a}Increment`],a)||D(a,!0)),M=(0,c.EW)(()=>a=>!I(e[a]-e[`${a}Increment`],a)||D(a,!1)),T=(e,a)=>ap(e1(aZ(),e),a),S=(e,a)=>(function(e,a){let{years:t=0,months:r=0,weeks:n=0,days:o=0,hours:i=0,minutes:l=0,seconds:d=0}=a,u=eK(ao(e,-(r+12*t),void 0),-(o+7*n),void 0);return B(e,u-1e3*(d+60*(l+60*i)))})(e1(aZ(),e),a),P=(0,c.EW)(()=>({dp__time_col:!0,dp__time_col_block:!e.timePickerInline,dp__time_col_reg_block:!e.enableSeconds&&e.is24&&!e.timePickerInline,dp__time_col_reg_inline:!e.enableSeconds&&e.is24&&e.timePickerInline,dp__time_col_reg_with_button:!e.enableSeconds&&!e.is24,dp__time_col_sec:e.enableSeconds&&e.is24,dp__time_col_sec_with_button:e.enableSeconds&&!e.is24})),z=(0,c.EW)(()=>e.timePickerInline&&u.value.enabled&&!p.value.count),$=(0,c.EW)(()=>{let a=[{type:"hours"}];return e.enableMinutes&&a.push({type:"",separator:!0},{type:"minutes"}),e.enableSeconds&&a.push({type:"",separator:!0},{type:"seconds"}),a}),Y=(0,c.EW)(()=>$.value.filter(e=>!e.separator)),W=(0,c.EW)(()=>a=>{if("hours"===a){let a=K(+e.hours);return{text:a<10?`0${a}`:`${a}`,value:a}}return{text:e[a]<10?`0${e[a]}`:`${e[a]}`,value:e[a]}}),O=(a,t)=>{if(!e.disabledTimesConfig)return!1;let r=e.disabledTimesConfig(e.order,"hours"===a?t:void 0);return!r[a]||!!r[a]?.includes(t)},N=(e,a)=>"hours"!==a||"AM"===g.value?e:e+12,I=(a,t)=>{let r=e.minTime?w(a7(e.minTime)):null,n=e.maxTime?w(a7(e.maxTime)):null,o=w(a7(E.value,t,"minutes"===t||"seconds"===t?a>=0?a:59:a>=0?a:23));return r&&n?(e8(o,n)||e7(o,n))&&(e2(o,r)||e7(o,r)):r?e2(o,r)||e7(o,r):!n||e8(o,n)||e7(o,n)},X=a=>e[`no${a[0].toUpperCase()+a.slice(1)}Overlay`],F=e=>{X(e)||(_[e]=!_[e],_[e]?(f.value=!0,t("overlay-opened",e)):(f.value=!1,t("overlay-closed",e)))},V=()=>{y.value&&clearTimeout(y.value)},L=(a,r=!0,n)=>{let o=r?T:S,i=r?+e[`${a}Increment`]:-e[`${a}Increment`];I(+e[a]+i,a)&&t(`update:${a}`,("hours"===a?e3:"minutes"===a?e9:ae)(o({[a]:+e[a]},{[a]:+e[`${a}Increment`]}))),!n?.keyboard&&d.value.timeArrowHoldThreshold&&(y.value=setTimeout(()=>{L(a,r)},d.value.timeArrowHoldThreshold))},K=a=>e.is24?a:(a>=12?g.value="PM":g.value="AM",[12,1,2,3,4,5,6,7,8,9,10,11,12,1,2,3,4,5,6,7,8,9,10,11][a]),q=()=>{"PM"===g.value?(g.value="AM",t("update:hours",e.hours-12)):(g.value="PM",t("update:hours",e.hours+12)),t("am-pm-change",g.value)},H=(a,t,o)=>{if(a&&e.arrowNavigation){Array.isArray(b.value[t])?b.value[t][o]=a:b.value[t]=[a];let i=b.value.reduce((e,a)=>a.map((t,r)=>[...e[r]||[],a[r]]),[]);n(e.closeTimePickerBtn),C.value&&(i[1]=i[1].concat(C.value)),r(i,e.order)}};return a({openChildCmp:e=>{_[e]=!0}}),(a,r)=>a.disabled?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("div",t3,[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)($.value,(t,n)=>((0,c.uX)(),(0,c.CE)("div",{key:n,class:(0,m.normalizeClass)(P.value),"data-compact":z.value&&!a.enableSeconds,"data-collapsed":z.value&&a.enableSeconds},[t.separator?((0,c.uX)(),(0,c.CE)(c.FK,{key:0},[f.value?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:0},[(0,c.eW)(":")],64))],64)):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.Lk)("button",{ref_for:!0,ref:e=>H(e,n,0),type:"button",class:(0,m.normalizeClass)({dp__btn:!0,dp__inc_dec_button:!a.timePickerInline,dp__inc_dec_button_inline:a.timePickerInline,dp__tp_inline_btn_top:a.timePickerInline,dp__inc_dec_button_disabled:R.value(t.type),"dp--hidden-el":f.value}),"data-test-id":`${t.type}-time-inc-btn-${e.order}`,"aria-label":(0,v.R1)(o)?.incrementValue(t.type),tabindex:"0",onKeydown:e=>(0,v.R1)(aj)(e,()=>L(t.type,!0,{keyboard:!0}),!0),onClick:e=>(0,v.R1)(d).timeArrowHoldThreshold?void 0:L(t.type,!0),onMousedown:e=>(0,v.R1)(d).timeArrowHoldThreshold?L(t.type,!0):void 0,onMouseup:V},[e.timePickerInline?((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[a.$slots["tp-inline-arrow-up"]?(0,c.RG)(a.$slots,"tp-inline-arrow-up",{key:0}):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[r[2]||(r[2]=(0,c.Lk)("span",{class:"dp__tp_inline_btn_bar dp__tp_btn_in_l"},null,-1)),r[3]||(r[3]=(0,c.Lk)("span",{class:"dp__tp_inline_btn_bar dp__tp_btn_in_r"},null,-1))],64))],64)):((0,c.uX)(),(0,c.CE)(c.FK,{key:0},[a.$slots["arrow-up"]?(0,c.RG)(a.$slots,"arrow-up",{key:0}):(0,c.Q3)("",!0),a.$slots["arrow-up"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ab),{key:1}))],64))],42,re),(0,c.Lk)("button",{ref_for:!0,ref:e=>H(e,n,1),type:"button","aria-label":`${W.value(t.type).text}-${(0,v.R1)(o)?.openTpOverlay(t.type)}`,class:(0,m.normalizeClass)({dp__time_display:!0,dp__time_display_block:!a.timePickerInline,dp__time_display_inline:a.timePickerInline,"dp--time-invalid":k.value(t.type),"dp--time-overlay-btn":!k.value(t.type),"dp--hidden-el":f.value}),disabled:X(t.type),tabindex:"0","data-test-id":`${t.type}-toggle-overlay-btn-${e.order}`,onKeydown:e=>(0,v.R1)(aj)(e,()=>F(t.type),!0),onClick:e=>F(t.type)},[a.$slots[t.type]?(0,c.RG)(a.$slots,t.type,{key:0,text:W.value(t.type).text,value:W.value(t.type).value}):(0,c.Q3)("",!0),a.$slots[t.type]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(W.value(t.type).text),1)],64))],42,ra),(0,c.Lk)("button",{ref_for:!0,ref:e=>H(e,n,2),type:"button",class:(0,m.normalizeClass)({dp__btn:!0,dp__inc_dec_button:!a.timePickerInline,dp__inc_dec_button_inline:a.timePickerInline,dp__tp_inline_btn_bottom:a.timePickerInline,dp__inc_dec_button_disabled:M.value(t.type),"dp--hidden-el":f.value}),"data-test-id":`${t.type}-time-dec-btn-${e.order}`,"aria-label":(0,v.R1)(o)?.decrementValue(t.type),tabindex:"0",onKeydown:e=>(0,v.R1)(aj)(e,()=>L(t.type,!1,{keyboard:!0}),!0),onClick:e=>(0,v.R1)(d).timeArrowHoldThreshold?void 0:L(t.type,!1),onMousedown:e=>(0,v.R1)(d).timeArrowHoldThreshold?L(t.type,!1):void 0,onMouseup:V},[e.timePickerInline?((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[a.$slots["tp-inline-arrow-down"]?(0,c.RG)(a.$slots,"tp-inline-arrow-down",{key:0}):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[r[4]||(r[4]=(0,c.Lk)("span",{class:"dp__tp_inline_btn_bar dp__tp_btn_in_l"},null,-1)),r[5]||(r[5]=(0,c.Lk)("span",{class:"dp__tp_inline_btn_bar dp__tp_btn_in_r"},null,-1))],64))],64)):((0,c.uX)(),(0,c.CE)(c.FK,{key:0},[a.$slots["arrow-down"]?(0,c.RG)(a.$slots,"arrow-down",{key:0}):(0,c.Q3)("",!0),a.$slots["arrow-down"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ay),{key:1}))],64))],42,rt)],64))],10,t9))),128)),a.is24?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("div",rr,[a.$slots["am-pm-button"]?(0,c.RG)(a.$slots,"am-pm-button",{key:0,toggle:q,value:g.value}):(0,c.Q3)("",!0),a.$slots["am-pm-button"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("button",{key:1,ref_key:"amPmButton",ref:C,type:"button",class:"dp__pm_am_button",role:"button","aria-label":(0,v.R1)(o)?.amPmButton,tabindex:"0","data-compact":z.value,onClick:q,onKeydown:r[0]||(r[0]=e=>(0,v.R1)(aj)(e,()=>q(),!0))},(0,m.toDisplayString)(g.value),41,rn))])),((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(Y.value,(n,i)=>((0,c.uX)(),(0,c.Wv)(h.Transition,{key:i,name:(0,v.R1)(s)(_[n.type]),css:(0,v.R1)(A)},{default:(0,c.k6)(()=>[_[n.type]?((0,c.uX)(),(0,c.Wv)(tH,{key:0,items:(a=>{let t=e.is24?24:12,r="hours"===a?t:60,n=+e[`${a}GridIncrement`],o="hours"!==a||e.is24?0:n,i=[];for(let t=o;t<r;t+=n)i.push({value:e.is24?t:N(t,a),text:t<10?`0${t}`:`${t}`});return"hours"!==a||e.is24||i.unshift({value:12*("PM"===g.value),text:"12"}),aF(i,e=>({active:!1,disabled:l.value.times[a].includes(e.value)||!I(e.value,a)||O(a,e.value)||x(a,e.value)}))})(n.type),"is-last":a.autoApply&&!(0,v.R1)(d).keepActionRow,"esc-close":a.escClose,type:n.type,"text-input":a.textInput,config:a.config,"arrow-navigation":a.arrowNavigation,"aria-labels":a.ariaLabels,"overlay-label":(0,v.R1)(o).timeOverlay?.(n.type),onSelected:e=>{let a;return a=n.type,F(a),t(`update:${a}`,e)},onToggle:e=>F(n.type),onResetFlow:r[1]||(r[1]=e=>a.$emit("reset-flow"))},(0,c.eX)({"button-icon":(0,c.k6)(()=>[a.$slots["clock-icon"]?(0,c.RG)(a.$slots,"clock-icon",{key:0}):(0,c.Q3)("",!0),a.$slots["clock-icon"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,c.$y)(a.timePickerInline?(0,v.R1)(aA):(0,v.R1)(aC)),{key:1}))]),_:2},[a.$slots[`${n.type}-overlay-value`]?{name:"item",fn:(0,c.k6)(({item:e})=>[(0,c.RG)(a.$slots,`${n.type}-overlay-value`,{text:e.text,value:e.value})]),key:"0"}:void 0,a.$slots[`${n.type}-overlay-header`]?{name:"header",fn:(0,c.k6)(()=>[(0,c.RG)(a.$slots,`${n.type}-overlay-header`,{toggle:()=>F(n.type)})]),key:"1"}:void 0]),1032,["items","is-last","esc-close","type","text-input","config","arrow-navigation","aria-labels","overlay-label","onSelected","onToggle"])):(0,c.Q3)("",!0)]),_:2},1032,["name","css"]))),128))]))}}),ri=["data-dp-mobile"],rl=["aria-label","tabindex"],rd=["role","aria-label","tabindex"],ru=["aria-label"],rp=(0,c.pM)({compatConfig:{MODE:3},__name:"TimePicker",props:{hours:{type:[Number,Array],default:0},minutes:{type:[Number,Array],default:0},seconds:{type:[Number,Array],default:0},disabledTimesConfig:{type:Function,default:null},validateTime:{type:Function,default:()=>!1},...tN},emits:["update:hours","update:minutes","update:seconds","mount","reset-flow","overlay-opened","overlay-closed","am-pm-change"],setup(e,{expose:a,emit:t}){let{buildMatrix:r,setTimePicker:n}=tP(),o=(0,c.Ht)(),{defaultedTransitions:i,defaultedAriaLabels:l,defaultedTextInput:d,defaultedConfig:u,defaultedRange:p}=tW(e),{transitionName:s,showTransition:A}=rH(i),{hideNavigationButtons:_}=rU(),g=(0,v.KR)(null),C=(0,v.KR)(null),b=(0,v.KR)([]),y=(0,v.KR)(null),f=(0,v.KR)(!1);(0,c.sV)(()=>{t("mount"),!e.timePicker&&e.arrowNavigation?r([aY(g.value)],"time"):n(!0,e.timePicker)});let w=(0,c.EW)(()=>!p.value.enabled||!e.modelAuto||aW(e.internalModelValue)),k=(0,v.KR)(!1),E=a=>({hours:Array.isArray(e.hours)?e.hours[a]:e.hours,minutes:Array.isArray(e.minutes)?e.minutes[a]:e.minutes,seconds:Array.isArray(e.seconds)?e.seconds[a]:e.seconds}),x=(0,c.EW)(()=>{let e=[];if(p.value.enabled)for(let a=0;a<2;a++)e.push(E(a));else e.push(E(0));return e}),B=(a,r=!1,o="")=>{r||t("reset-flow"),k.value=a,t(a?"overlay-opened":"overlay-closed",aD.time),e.arrowNavigation&&n(a),(0,c.dY)(()=>{""!==o&&b.value[0]&&b.value[0].openChildCmp(o)})},D=(0,c.EW)(()=>({dp__btn:!0,dp__button:!0,dp__button_bottom:e.autoApply&&!u.value.keepActionRow})),R=rq(o,"timePicker"),M=(e,a,t)=>p.value.enabled?0===a?[e,x.value[1][t]]:[x.value[0][t],e]:e,T=e=>{t("update:hours",e)},S=e=>{t("update:minutes",e)},P=e=>{t("update:seconds",e)},z=()=>{if(y.value&&!d.value.enabled&&!e.noOverlayFocus){let e=aI(y.value);e&&e.focus({preventScroll:!0})}},$=e=>{f.value=!1,t("overlay-closed",e)},Y=e=>{f.value=!0,t("overlay-opened",e)};return a({toggleTimePicker:B}),(a,t)=>((0,c.uX)(),(0,c.CE)("div",{class:"dp--tp-wrap","data-dp-mobile":a.isMobile},[a.timePicker||a.timePickerInline?(0,c.Q3)("",!0):(0,c.bo)(((0,c.uX)(),(0,c.CE)("button",{key:0,ref_key:"openTimePickerBtn",ref:g,type:"button",class:(0,m.normalizeClass)({...D.value,"dp--hidden-el":k.value}),"aria-label":(0,v.R1)(l)?.openTimePicker,tabindex:a.noOverlayFocus?void 0:0,"data-test-id":"open-time-picker-btn",onKeydown:t[0]||(t[0]=e=>(0,v.R1)(aj)(e,()=>B(!0))),onClick:t[1]||(t[1]=e=>B(!0))},[a.$slots["clock-icon"]?(0,c.RG)(a.$slots,"clock-icon",{key:0}):(0,c.Q3)("",!0),a.$slots["clock-icon"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(aC),{key:1}))],42,rl)),[[h.vShow,!(0,v.R1)(_)(a.hideNavigation,"time")]]),(0,c.bF)(h.Transition,{name:(0,v.R1)(s)(k.value),css:(0,v.R1)(A)&&!a.timePickerInline},{default:(0,c.k6)(()=>[k.value||a.timePicker||a.timePickerInline?((0,c.uX)(),(0,c.CE)("div",{key:0,ref_key:"overlayRef",ref:y,role:a.timePickerInline?void 0:"dialog",class:(0,m.normalizeClass)({dp__overlay:!a.timePickerInline,"dp--overlay-absolute":!e.timePicker&&!a.timePickerInline,"dp--overlay-relative":e.timePicker}),style:(0,m.normalizeStyle)(a.timePicker?{height:`${(0,v.R1)(u).modeHeight}px`}:void 0),"aria-label":(0,v.R1)(l)?.timePicker,tabindex:a.timePickerInline?void 0:0},[(0,c.Lk)("div",{class:(0,m.normalizeClass)(a.timePickerInline?"dp__time_picker_inline_container":"dp__overlay_container dp__container_flex dp__time_picker_overlay_container"),style:{display:"flex"}},[a.$slots["time-picker-overlay"]?(0,c.RG)(a.$slots,"time-picker-overlay",{key:0,hours:e.hours,minutes:e.minutes,seconds:e.seconds,setHours:T,setMinutes:S,setSeconds:P}):(0,c.Q3)("",!0),a.$slots["time-picker-overlay"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("div",{key:1,class:(0,m.normalizeClass)(a.timePickerInline?"dp__flex":"dp__overlay_row dp__flex_row")},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(x.value,(r,n)=>(0,c.bo)(((0,c.uX)(),(0,c.Wv)(ro,(0,c.v6)({key:n},{ref_for:!0},{...a.$props,order:n,hours:r.hours,minutes:r.minutes,seconds:r.seconds,closeTimePickerBtn:C.value,disabledTimesConfig:e.disabledTimesConfig,disabled:0===n?(0,v.R1)(p).fixedStart:(0,v.R1)(p).fixedEnd},{ref_for:!0,ref_key:"timeInputRefs",ref:b,"validate-time":(a,t)=>e.validateTime(a,M(t,n,a)),"onUpdate:hours":e=>T(M(e,n,"hours")),"onUpdate:minutes":e=>S(M(e,n,"minutes")),"onUpdate:seconds":e=>P(M(e,n,"seconds")),onMounted:z,onOverlayClosed:$,onOverlayOpened:Y,onAmPmChange:t[2]||(t[2]=e=>a.$emit("am-pm-change",e))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(R),(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,c.v6)({ref_for:!0},t))])}))]),1040,["validate-time","onUpdate:hours","onUpdate:minutes","onUpdate:seconds"])),[[h.vShow,0===n||w.value]])),128))],2)),a.timePicker||a.timePickerInline?(0,c.Q3)("",!0):(0,c.bo)(((0,c.uX)(),(0,c.CE)("button",{key:2,ref_key:"closeTimePickerBtn",ref:C,type:"button",class:(0,m.normalizeClass)({...D.value,"dp--hidden-el":f.value}),"aria-label":(0,v.R1)(l)?.closeTimePicker,tabindex:"0",onKeydown:t[3]||(t[3]=e=>(0,v.R1)(aj)(e,()=>B(!1))),onClick:t[4]||(t[4]=e=>B(!1))},[a.$slots["calendar-icon"]?(0,c.RG)(a.$slots,"calendar-icon",{key:0}):(0,c.Q3)("",!0),a.$slots["calendar-icon"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(aA),{key:1}))],42,ru)),[[h.vShow,!(0,v.R1)(_)(a.hideNavigation,"time")]])],2)],14,rd)):(0,c.Q3)("",!0)]),_:3},8,["name","css"])],8,ri))}}),rs=(e,a,t,r)=>{let{defaultedRange:n}=tW(e),o=(e,t)=>Array.isArray(a[e])?a[e][t]:a[e],i=t=>e.enableSeconds?Array.isArray(a.seconds)?a.seconds[t]:a.seconds:0,l=(e,t)=>{a[e]=t},d=(0,c.EW)(()=>e.modelAuto&&n.value.enabled?!!Array.isArray(t.value)&&t.value.length>1:n.value.enabled),u=(e,r)=>{let o=Object.fromEntries(Object.keys(a).map(t=>t===e?[t,r]:[t,a[t]].slice()));if(d.value&&!n.value.disableTimeRangeValidation){let e=e=>t.value?a0(t.value[e],o.hours[e],o.minutes[e],o.seconds[e]):null,a=e=>e4(t.value[e],0);return!(a1(e(0),e(1))&&(e2(e(0),a(1))||e8(e(1),a(0))))}return!0},p=(e,a)=>{u(e,a)&&(l(e,a),r&&r())},s=e=>{p("hours",e)},v=e=>{p("minutes",e)},m=e=>{p("seconds",e)};return{setTime:l,updateHours:s,updateMinutes:v,updateSeconds:m,getSetDateTime:(e,t)=>e?void 0!==t?a0(e,o("hours",t),o("minutes",t),i(t)):a0(e,a.hours,a.minutes,i()):e5(aZ(),i(t)),updateTimeValues:(e,a,r,n)=>{a&&s(e),a||r||v(e),r&&m(e),t.value&&n(t.value)},getSecondsValue:i,assignStartTime:a=>{if(a){let t=Array.isArray(a),r=t?[+a[0].hours,+a[1].hours]:+a.hours,n=t?[+a[0].minutes,+a[1].minutes]:+a.minutes,o=t?[+a[0].seconds,+a[1].seconds]:+a.seconds;l("hours",r),l("minutes",n),e.enableSeconds&&l("seconds",o)}},validateTime:u,disabledTimesConfig:(0,c.EW)(()=>(t,r)=>{if(Array.isArray(e.disabledTimes)){let o,{disabledArr:i,hours:l}=(o={hours:Array.isArray(a.hours)?a.hours[t]:a.hours,disabledArr:[]},(r||0===r)&&(o.hours=r),Array.isArray(e.disabledTimes)&&(o.disabledArr=n.value.enabled&&Array.isArray(e.disabledTimes[t])?e.disabledTimes[t]:e.disabledTimes),o),d=i.filter(e=>+e.hours===l);return d[0]?.minutes==="*"?{hours:[l],minutes:void 0,seconds:void 0}:{hours:[],minutes:d?.map(e=>+e.minutes)??[],seconds:d?.map(e=>e.seconds?+e.seconds:void 0)??[]}}return{hours:[],minutes:[],seconds:[]}})}},rc=(0,c.pM)({compatConfig:{MODE:3},__name:"TimePickerSolo",props:{...tN},emits:["update:internal-model-value","time-update","am-pm-change","mount","reset-flow","update-flow-step","overlay-toggle"],setup(e,{expose:a,emit:t}){let r=rq((0,c.Ht)(),"timePicker"),n=(0,v.KR)(null),{time:o,modelValue:i,disabledTimesConfig:l,updateTime:d,validateTime:u}=((e,a)=>{let{modelValue:t,time:r}=rj(e,a,()=>{e.isTextInputDate&&h()}),{defaultedStartTime:n,defaultedRange:o,defaultedTz:i}=tW(e),{updateTimeValues:l,getSetDateTime:d,setTime:u,assignStartTime:p,disabledTimesConfig:s,validateTime:v}=rs(e,r,t,function(){a("update-flow-step")}),m=e=>{let{hours:a,minutes:t,seconds:r}=e;return{hours:+a,minutes:+t,seconds:r?+r:0}},A=()=>{if(e.startTime){if(Array.isArray(e.startTime)){let a=m(e.startTime[0]),t=m(e.startTime[1]);return[e1(aZ(),a),e1(aZ(),t)]}let a=m(e.startTime);return e1(aZ(),a)}return o.value.enabled?[null,null]:null},_=(a,t,r)=>{u("hours",a),u("minutes",t),u("seconds",e.enableSeconds?r:0)},h=()=>{let e,[a,r]=Array.isArray(e=t.value)?[a2(aZ(e[0])),a2(aZ(e[1]))]:[a2(e??aZ())];return o.value.enabled?_([a.hours,r.hours],[a.minutes,r.minutes],[a.seconds,r.seconds]):_(a.hours,a.minutes,a.seconds)};(0,c.sV)(()=>{if(!e.shadow)return p(n.value),t.value?h():(()=>{if(o.value.enabled){let[e,a]=A();t.value=[af(d(e,0),i.value.timezone),af(d(a,1),i.value.timezone)]}else t.value=af(d(A()),i.value.timezone)})()});let g=()=>{Array.isArray(t.value)?t.value=t.value.map((e,a)=>e&&d(e,a)):t.value=d(t.value),a("time-update")};return{modelValue:t,time:r,disabledTimesConfig:s,updateTime:(e,a=!0,t=!1)=>{l(e,a,t,g)},validateTime:v}})(e,t);return(0,c.sV)(()=>{e.shadow||t("mount",null)}),a({getSidebarProps:()=>({modelValue:i,time:o,updateTime:d}),toggleTimePicker:(e,a=!1,t="")=>{n.value?.toggleTimePicker(e,a,t)}}),(e,a)=>((0,c.uX)(),(0,c.Wv)(tQ,{"multi-calendars":0,stretch:"","is-mobile":e.isMobile},{default:(0,c.k6)(()=>[(0,c.bF)(rp,(0,c.v6)({ref_key:"tpRef",ref:n},e.$props,{hours:(0,v.R1)(o).hours,minutes:(0,v.R1)(o).minutes,seconds:(0,v.R1)(o).seconds,"internal-model-value":e.internalModelValue,"disabled-times-config":(0,v.R1)(l),"validate-time":(0,v.R1)(u),"onUpdate:hours":a[0]||(a[0]=e=>(0,v.R1)(d)(e)),"onUpdate:minutes":a[1]||(a[1]=e=>(0,v.R1)(d)(e,!1)),"onUpdate:seconds":a[2]||(a[2]=e=>(0,v.R1)(d)(e,!1,!0)),onAmPmChange:a[3]||(a[3]=a=>e.$emit("am-pm-change",a)),onResetFlow:a[4]||(a[4]=a=>e.$emit("reset-flow")),onOverlayClosed:a[5]||(a[5]=a=>e.$emit("overlay-toggle",{open:!1,overlay:a})),onOverlayOpened:a[6]||(a[6]=a=>e.$emit("overlay-toggle",{open:!0,overlay:a}))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(r),(a,t)=>({name:a,fn:(0,c.k6)(t=>[(0,c.RG)(e.$slots,a,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["hours","minutes","seconds","internal-model-value","disabled-times-config","validate-time"])]),_:3},8,["is-mobile"]))}}),rv={class:"dp--header-wrap"},rm={key:0,class:"dp__month_year_wrap"},rA={key:0},r_={class:"dp__month_year_wrap"},rh=["data-dp-element","aria-label","data-test-id","onClick","onKeydown"],rg=(0,c.pM)({compatConfig:{MODE:3},__name:"DpHeader",props:{month:{type:Number,default:0},year:{type:Number,default:0},instance:{type:Number,default:0},years:{type:Array,default:()=>[]},months:{type:Array,default:()=>[]},...tN},emits:["update-month-year","mount","reset-flow","overlay-closed","overlay-opened"],setup(e,{expose:a,emit:t}){let{defaultedTransitions:r,defaultedAriaLabels:n,defaultedMultiCalendars:o,defaultedFilters:i,defaultedConfig:l,defaultedHighlight:d,propDates:u,defaultedUI:p}=tW(e),{transitionName:s,showTransition:A}=rH(r),{buildMatrix:_}=tP(),{handleMonthYearChange:g,isDisabled:C,updateMonthYear:b}=((e,a)=>{let{defaultedFilters:t,propDates:r}=tW(e),{validateMonthYearInRange:n}=rG(e),o=(e,a)=>{let r=e;return t.value.months.includes(at(r))?o(r=a?ao(e,1):ao(e,-1,void 0),a):r},i=(e,a)=>{let r=e;return t.value.years.includes(aa(r))?i(r=a?ao(e,12,void 0):ao(e,-12,void 0),a):r},l=(e,t,r)=>{a("update-month-year",{month:e,year:t,fromNav:r})};return{handleMonthYearChange:(a,r=!1)=>{let d=e1(aZ(),{month:e.month,year:e.year}),u=a?ao(d,1):ao(d,-1,void 0);e.disableYearSelect&&(u=al(u,e.year));let p=at(u),s=aa(u);t.value.months.includes(p)&&(p=at(u=o(u,a)),s=aa(u)),t.value.years.includes(s)&&(s=aa(u=i(u,a))),n(p,s,a,e.preventMinMaxNavigation)&&l(p,s,r)},isDisabled:(0,c.EW)(()=>a=>tl(e1(aZ(),{month:e.month,year:e.year}),r.value.maxDate,r.value.minDate,e.preventMinMaxNavigation,a)),updateMonthYear:l}})(e,t),{showLeftIcon:y,showRightIcon:f}=rU(),w=(0,v.KR)(!1),k=(0,v.KR)(!1),E=(0,v.KR)(!1),x=(0,v.KR)([null,null,null,null]);(0,c.sV)(()=>{t("mount")});let B=a=>({get:()=>e[a],set:r=>{let n=a===aE.month?aE.year:aE.month;t("update-month-year",{[a]:r,[n]:e[n]}),a===aE.month?$(!0):Y(!0)}}),D=(0,c.EW)(B(aE.month)),R=(0,c.EW)(B(aE.year)),M=(0,c.EW)(()=>a=>({month:e.month,year:e.year,items:a===aE.month?e.months:e.years,instance:e.instance,updateMonthYear:b,toggle:a===aE.month?$:Y})),T=(0,c.EW)(()=>e.months.find(a=>a.value===e.month)||{text:"",value:0}),S=(0,c.EW)(()=>aF(e.months,a=>({active:e.month===a.value,disabled:aX(a.value,a3(e.year,u.value.minDate),a9(e.year,u.value.maxDate))||i.value.months.includes(a.value),highlighted:tg(d.value,a.value,e.year)}))),P=(0,c.EW)(()=>aF(e.years,a=>({active:e.year===a.value,disabled:aX(a.value,te(u.value.minDate),te(u.value.maxDate))||i.value.years.includes(a.value),highlighted:tC(d.value,a.value)}))),z=(e,a,r)=>{void 0!==r?e.value=r:e.value=!e.value,e.value?(E.value=!0,t("overlay-opened",a)):(E.value=!1,t("overlay-closed",a))},$=(e=!1,a)=>{W(e),z(w,aD.month,a)},Y=(e=!1,a)=>{W(e),z(k,aD.year,a)},W=e=>{e||t("reset-flow")},O=(a,t)=>{e.arrowNavigation&&(x.value[t]=aY(a),_(x.value,"monthYear"))},N=(0,c.EW)(()=>[{type:aE.month,index:1,toggle:$,modelValue:D.value,updateModelValue:e=>D.value=e,text:T.value.text,showSelectionGrid:w.value,items:S.value,ariaLabel:n.value?.openMonthsOverlay,overlayLabel:n.value.monthPicker?.(!0)??void 0},{type:aE.year,index:2,toggle:Y,modelValue:R.value,updateModelValue:e=>R.value=e,text:aK(e.year,e.locale),showSelectionGrid:k.value,items:P.value,ariaLabel:n.value?.openYearsOverlay,overlayLabel:n.value.yearPicker?.(!0)??void 0}]),I=(0,c.EW)(()=>e.disableYearSelect?[N.value[0]]:e.yearFirst?[...N.value].reverse():N.value);return a({toggleMonthPicker:$,toggleYearPicker:Y,handleMonthYearChange:g}),(a,t)=>((0,c.uX)(),(0,c.CE)("div",rv,[a.$slots["month-year"]?((0,c.uX)(),(0,c.CE)("div",rm,[(0,c.RG)(a.$slots,"month-year",(0,m.normalizeProps)((0,c.Ng)({month:e.month,year:e.year,months:e.months,years:e.years,updateMonthYear:(0,v.R1)(b),handleMonthYearChange:(0,v.R1)(g),instance:e.instance,isDisabled:(0,v.R1)(C)})))])):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[a.$slots["top-extra"]?((0,c.uX)(),(0,c.CE)("div",rA,[(0,c.RG)(a.$slots,"top-extra",{value:a.internalModelValue})])):(0,c.Q3)("",!0),(0,c.Lk)("div",r_,[(0,v.R1)(y)((0,v.R1)(o),e.instance)&&!a.vertical?((0,c.uX)(),(0,c.Wv)(tU,{key:0,"aria-label":(0,v.R1)(n)?.prevMonth,disabled:(0,v.R1)(C)(!1),class:(0,m.normalizeClass)((0,v.R1)(p)?.navBtnPrev),"el-name":"action-prev",onActivate:t[0]||(t[0]=e=>(0,v.R1)(g)(!1,!0)),onSetRef:t[1]||(t[1]=e=>O(e,0))},{default:(0,c.k6)(()=>[a.$slots["arrow-left"]?(0,c.RG)(a.$slots,"arrow-left",{key:0}):(0,c.Q3)("",!0),a.$slots["arrow-left"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ah),{key:1}))]),_:3},8,["aria-label","disabled","class"])):(0,c.Q3)("",!0),(0,c.Lk)("div",{class:(0,m.normalizeClass)(["dp__month_year_wrap",{dp__year_disable_select:a.disableYearSelect}])},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(I.value,(t,r)=>((0,c.uX)(),(0,c.CE)(c.FK,{key:t.type},[(0,c.Lk)("button",{ref_for:!0,ref:e=>O(e,r+1),type:"button","data-dp-element":`overlay-${t.type}`,class:(0,m.normalizeClass)(["dp__btn dp__month_year_select",{"dp--hidden-el":E.value}]),"aria-label":`${t.text}-${t.ariaLabel}`,"data-test-id":`${t.type}-toggle-overlay-${e.instance}`,onClick:t.toggle,onKeydown:e=>(0,v.R1)(aj)(e,()=>t.toggle(),!0)},[a.$slots[t.type]?(0,c.RG)(a.$slots,t.type,{key:0,text:t.text,value:e[t.type]}):(0,c.Q3)("",!0),a.$slots[t.type]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(t.text),1)],64))],42,rh),(0,c.bF)(h.Transition,{name:(0,v.R1)(s)(t.showSelectionGrid),css:(0,v.R1)(A)},{default:(0,c.k6)(()=>[t.showSelectionGrid?((0,c.uX)(),(0,c.Wv)(tH,{key:0,items:t.items,"arrow-navigation":a.arrowNavigation,"hide-navigation":a.hideNavigation,"is-last":a.autoApply&&!(0,v.R1)(l).keepActionRow,"skip-button-ref":!1,config:a.config,type:t.type,"header-refs":[],"esc-close":a.escClose,"menu-wrap-ref":a.menuWrapRef,"text-input":a.textInput,"aria-labels":a.ariaLabels,"overlay-label":t.overlayLabel,onSelected:t.updateModelValue,onToggle:t.toggle},(0,c.eX)({"button-icon":(0,c.k6)(()=>[a.$slots["calendar-icon"]?(0,c.RG)(a.$slots,"calendar-icon",{key:0}):(0,c.Q3)("",!0),a.$slots["calendar-icon"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(aA),{key:1}))]),_:2},[a.$slots[`${t.type}-overlay-value`]?{name:"item",fn:(0,c.k6)(({item:e})=>[(0,c.RG)(a.$slots,`${t.type}-overlay-value`,{text:e.text,value:e.value})]),key:"0"}:void 0,a.$slots[`${t.type}-overlay`]?{name:"overlay",fn:(0,c.k6)(()=>[(0,c.RG)(a.$slots,`${t.type}-overlay`,(0,c.v6)({ref_for:!0},M.value(t.type)))]),key:"1"}:void 0,a.$slots[`${t.type}-overlay-header`]?{name:"header",fn:(0,c.k6)(()=>[(0,c.RG)(a.$slots,`${t.type}-overlay-header`,{toggle:t.toggle})]),key:"2"}:void 0]),1032,["items","arrow-navigation","hide-navigation","is-last","config","type","esc-close","menu-wrap-ref","text-input","aria-labels","overlay-label","onSelected","onToggle"])):(0,c.Q3)("",!0)]),_:2},1032,["name","css"])],64))),128))],2),(0,v.R1)(y)((0,v.R1)(o),e.instance)&&a.vertical?((0,c.uX)(),(0,c.Wv)(tU,{key:1,"aria-label":(0,v.R1)(n)?.prevMonth,"el-name":"action-prev",disabled:(0,v.R1)(C)(!1),class:(0,m.normalizeClass)((0,v.R1)(p)?.navBtnPrev),onActivate:t[2]||(t[2]=e=>(0,v.R1)(g)(!1,!0))},{default:(0,c.k6)(()=>[a.$slots["arrow-up"]?(0,c.RG)(a.$slots,"arrow-up",{key:0}):(0,c.Q3)("",!0),a.$slots["arrow-up"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(ab),{key:1}))]),_:3},8,["aria-label","disabled","class"])):(0,c.Q3)("",!0),(0,v.R1)(f)((0,v.R1)(o),e.instance)?((0,c.uX)(),(0,c.Wv)(tU,{key:2,ref:"rightIcon","el-name":"action-next",disabled:(0,v.R1)(C)(!0),"aria-label":(0,v.R1)(n)?.nextMonth,class:(0,m.normalizeClass)((0,v.R1)(p)?.navBtnNext),onActivate:t[3]||(t[3]=e=>(0,v.R1)(g)(!0,!0)),onSetRef:t[4]||(t[4]=e=>O(e,a.disableYearSelect?2:3))},{default:(0,c.k6)(()=>[a.$slots[a.vertical?"arrow-down":"arrow-right"]?(0,c.RG)(a.$slots,a.vertical?"arrow-down":"arrow-right",{key:0}):(0,c.Q3)("",!0),a.$slots[a.vertical?"arrow-down":"arrow-right"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,c.$y)(a.vertical?(0,v.R1)(ay):(0,v.R1)(ag)),{key:1}))]),_:3},8,["disabled","aria-label","class"])):(0,c.Q3)("",!0)])],64))]))}}),rC={class:"dp__calendar_header",role:"row"},rb={key:0,class:"dp__calendar_header_item",role:"gridcell"},ry=["aria-label"],rf={key:0,class:"dp__calendar_item dp__week_num",role:"gridcell"},rw={class:"dp__cell_inner"},rk=["id","aria-selected","aria-disabled","aria-label","tabindex","data-test-id","onClick","onTouchend","onKeydown","onMouseenter","onMouseleave","onMousedown"],rE=(0,c.pM)({compatConfig:{MODE:3},__name:"DpCalendar",props:{mappedDates:{type:Array,default:()=>[]},instance:{type:Number,default:0},month:{type:Number,default:0},year:{type:Number,default:0},...tN},emits:["select-date","set-hover-date","handle-scroll","mount","handle-swipe","handle-space","tooltip-open","tooltip-close"],setup(e,{expose:a,emit:t}){let{buildMultiLevelMatrix:r}=tP(),{defaultedTransitions:n,defaultedConfig:o,defaultedAriaLabels:i,defaultedMultiCalendars:l,defaultedWeekNumbers:d,defaultedMultiDates:u,defaultedUI:p}=tW(e),s=(0,v.KR)(null),A=(0,v.KR)({bottom:"",left:"",transform:""}),_=(0,v.KR)([]),g=(0,v.KR)(null),C=(0,v.KR)(!0),b=(0,v.KR)(""),y=(0,v.KR)({startX:0,endX:0,startY:0,endY:0}),f=(0,v.KR)([]),w=(0,v.KR)({left:"50%"}),k=(0,v.KR)(!1),E=(0,c.EW)(()=>e.calendar?e.calendar(e.mappedDates):e.mappedDates),x=(0,c.EW)(()=>e.dayNames?Array.isArray(e.dayNames)?e.dayNames:e.dayNames(e.locale,+e.weekStart):((e,a,t)=>{let r,n=[1,2,3,4,5,6,7];if(null!==e)try{r=n.map(a=>ei(af(new Date(`2017-01-0${a}T00:00:00+00:00`),"UTC"),"EEEEEE",{locale:e}))}catch{r=n.map(aP(a))}else r=n.map(aP(a));let o=r.slice(0,t),i=r.slice(t+1,r.length);return[r[t]].concat(...i).concat(...o)})(e.formatLocale,e.locale,+e.weekStart));(0,c.sV)(()=>{t("mount",{cmp:"calendar",refs:_}),o.value.noSwipe||g.value&&(g.value.addEventListener("touchstart",Y,{passive:!1}),g.value.addEventListener("touchend",O,{passive:!1}),g.value.addEventListener("touchmove",I,{passive:!1})),e.monthChangeOnScroll&&g.value&&g.value.addEventListener("wheel",F,{passive:!1})}),(0,c.hi)(()=>{o.value.noSwipe||g.value&&(g.value.removeEventListener("touchstart",Y),g.value.removeEventListener("touchend",O),g.value.removeEventListener("touchmove",I)),e.monthChangeOnScroll&&g.value&&g.value.removeEventListener("wheel",F)});let B=a=>a?e.vertical?"vNext":"next":e.vertical?"vPrevious":"previous",D=(0,c.EW)(()=>({...p.value.calendar??{}})),R=(0,c.EW)(()=>e=>{let a={type:"dot",...e??{}};return{dp__marker_dot:"dot"===a.type,dp__marker_line:"line"===a.type}}),M=(0,c.EW)(()=>e=>a1(e,s.value)),T=(0,c.EW)(()=>({dp__calendar:!0,dp__calendar_next:l.value.count>0&&0!==e.instance})),S=(0,c.EW)(()=>a=>!e.hideOffsetDates||a.current),P=async(e,a)=>{let{width:t,height:r}=e.getBoundingClientRect();s.value=a.value;let n={left:`${t/2}px`},o=-50;if(await (0,c.dY)(),f.value[0]){let{left:e,width:a}=f.value[0].getBoundingClientRect();e<0&&(n={left:"0"},o=0,w.value.left=`${t/2}px`),window.innerWidth<e+a&&(n={right:"0"},o=0,w.value.left=`${a-t/2}px`)}A.value={bottom:`${r}px`,...n,transform:`translateX(${o}%)`}},z=async(e,a,r)=>{let n=aY(_.value[a][r]);n&&(e.marker?.customPosition&&e.marker?.tooltip?.length?A.value=e.marker.customPosition(n):await P(n,e),t("tooltip-open",e.marker))},$=async(a,r,n)=>{if(k.value&&u.value.enabled&&u.value.dragSelect)return t("select-date",a);if(t("set-hover-date",a),a.marker?.tooltip?.length){if(e.hideOffsetDates&&!a.current)return;await z(a,r,n)}},Y=e=>{y.value.startX=e.changedTouches[0].screenX,y.value.startY=e.changedTouches[0].screenY},O=e=>{y.value.endX=e.changedTouches[0].screenX,y.value.endY=e.changedTouches[0].screenY,X()},I=a=>{e.vertical&&!e.inline&&a.preventDefault()},X=()=>{let a=e.vertical?"Y":"X";Math.abs(y.value[`start${a}`]-y.value[`end${a}`])>10&&t("handle-swipe",y.value[`start${a}`]>y.value[`end${a}`]?"right":"left")},F=a=>{e.monthChangeOnScroll&&(a.preventDefault(),t("handle-scroll",a))},V=a=>"local"===d.value.type?N(a.value,{weekStartsOn:+e.weekStart}):"iso"===d.value.type?W(a.value):"function"==typeof d.value.type?d.value.type(a.value):"",L=(e,a,r=!0)=>{!r&&("ontouchstart"in window||navigator.maxTouchPoints>0)||(!u.value.enabled||o.value.allowPreventDefault)&&(aV(e,o.value),t("select-date",a))},K=e=>{aV(e,o.value)};return a({triggerTransition:(a,t)=>{if(e.transitions){let r=aJ(ti(aZ(),e.month,e.year));b.value=a5(aJ(ti(aZ(),a,t)),r)?n.value[B(!0)]:n.value[B(!1)],C.value=!1,(0,c.dY)(()=>{C.value=!0})}}}),(a,n)=>((0,c.uX)(),(0,c.CE)("div",{class:(0,m.normalizeClass)(T.value)},[(0,c.Lk)("div",{ref_key:"calendarWrapRef",ref:g,class:(0,m.normalizeClass)(D.value),role:"grid"},[(0,c.Lk)("div",rC,[a.weekNumbers?((0,c.uX)(),(0,c.CE)("div",rb,(0,m.toDisplayString)(a.weekNumName),1)):(0,c.Q3)("",!0),((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(x.value,(e,t)=>((0,c.uX)(),(0,c.CE)("div",{key:t,class:"dp__calendar_header_item",role:"gridcell","data-test-id":"calendar-header","aria-label":(0,v.R1)(i)?.weekDay?.(t)},[a.$slots["calendar-header"]?(0,c.RG)(a.$slots,"calendar-header",{key:0,day:e,index:t}):(0,c.Q3)("",!0),a.$slots["calendar-header"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(e),1)],64))],8,ry))),128))]),n[2]||(n[2]=(0,c.Lk)("div",{class:"dp__calendar_header_separator"},null,-1)),(0,c.bF)(h.Transition,{name:b.value,css:!!a.transitions},{default:(0,c.k6)(()=>[C.value?((0,c.uX)(),(0,c.CE)("div",{key:0,class:"dp__calendar",role:"rowgroup",onMouseleave:n[1]||(n[1]=e=>k.value=!1)},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(E.value,(o,l)=>{var p;let g;return(0,c.uX)(),(0,c.CE)("div",{key:l,class:"dp__calendar_row",role:"row"},[a.weekNumbers?((0,c.uX)(),(0,c.CE)("div",rf,[(0,c.Lk)("div",rw,(0,m.toDisplayString)((g=(p=o.days)[0],d.value.hideOnOffsetDates?p.some(e=>e.current)?V(g):"":V(g))),1)])):(0,c.Q3)("",!0),((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(o.days,(o,d)=>((0,c.uX)(),(0,c.CE)("div",{id:(0,v.R1)(tb)(o.value),ref_for:!0,ref:a=>{a&&(Array.isArray(_.value[l])?_.value[l][d]=a:_.value[l]=[a]),e.arrowNavigation&&r(_.value,"calendar")},key:d+l,role:"gridcell",class:"dp__calendar_item","aria-selected":(o.classData.dp__active_date||o.classData.dp__range_start||o.classData.dp__range_end)??void 0,"aria-disabled":o.classData.dp__cell_disabled||void 0,"aria-label":(0,v.R1)(i)?.day?.(o),tabindex:!o.current&&a.hideOffsetDates?void 0:0,"data-test-id":(0,v.R1)(tb)(o.value),onClick:(0,h.withModifiers)(e=>L(e,o),["prevent"]),onTouchend:e=>L(e,o,!1),onKeydown:e=>(0,v.R1)(aj)(e,()=>a.$emit("select-date",o)),onMouseenter:e=>$(o,l,d),onMouseleave:e=>{s.value&&(s.value=null,A.value=JSON.parse(JSON.stringify({bottom:"",left:"",transform:""})),t("tooltip-close",o.marker))},onMousedown:e=>{u.value.enabled&&u.value.dragSelect?(k.value=!0,t("select-date",o)):u.value.enabled&&t("select-date",o)},onMouseup:n[0]||(n[0]=e=>k.value=!1)},[(0,c.Lk)("div",{class:(0,m.normalizeClass)(["dp__cell_inner",o.classData])},[a.$slots.day&&S.value(o)?(0,c.RG)(a.$slots,"day",{key:0,day:+o.text,date:o.value}):(0,c.Q3)("",!0),a.$slots.day?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(o.text),1)],64)),o.marker&&S.value(o)?((0,c.uX)(),(0,c.CE)(c.FK,{key:2},[a.$slots.marker?(0,c.RG)(a.$slots,"marker",{key:0,marker:o.marker,day:+o.text,date:o.value}):((0,c.uX)(),(0,c.CE)("div",{key:1,class:(0,m.normalizeClass)(R.value(o.marker)),style:(0,m.normalizeStyle)(o.marker.color?{backgroundColor:o.marker.color}:{})},null,6))],64)):(0,c.Q3)("",!0),M.value(o.value)?((0,c.uX)(),(0,c.CE)("div",{key:3,ref_for:!0,ref_key:"activeTooltip",ref:f,class:"dp__marker_tooltip",style:(0,m.normalizeStyle)(A.value)},[o.marker?.tooltip?((0,c.uX)(),(0,c.CE)("div",{key:0,class:"dp__tooltip_content",onClick:K},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(o.marker.tooltip,(e,t)=>((0,c.uX)(),(0,c.CE)("div",{key:t,class:"dp__tooltip_text"},[a.$slots["marker-tooltip"]?(0,c.RG)(a.$slots,"marker-tooltip",{key:0,tooltip:e,day:o.value}):(0,c.Q3)("",!0),a.$slots["marker-tooltip"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.Lk)("div",{class:"dp__tooltip_mark",style:(0,m.normalizeStyle)(e.color?{backgroundColor:e.color}:{})},null,4),(0,c.Lk)("div",null,(0,m.toDisplayString)(e.text),1)],64))]))),128)),(0,c.Lk)("div",{class:"dp__arrow_bottom_tp",style:(0,m.normalizeStyle)(w.value)},null,4)])):(0,c.Q3)("",!0)],4)):(0,c.Q3)("",!0)],2)],40,rk))),128))])}),128))],32)):(0,c.Q3)("",!0)]),_:3},8,["name","css"])],2)],2))}}),rx={key:0},rB=(0,c.pM)({__name:"DatePicker",props:{...tN},emits:["tooltip-open","tooltip-close","mount","update:internal-model-value","update-flow-step","reset-flow","auto-apply","focus-menu","select-date","range-start","range-end","invalid-fixed-range","time-update","am-pm-change","time-picker-open","time-picker-close","recalculate-position","update-month-year","auto-apply-invalid","date-update","invalid-date","overlay-toggle"],setup(e,{expose:a,emit:t}){let{calendars:r,month:n,year:o,modelValue:i,time:l,disabledTimesConfig:d,today:u,validateTime:p,getCalendarDays:s,getMarker:A,handleArrow:_,handleScroll:h,handleSwipe:g,selectDate:C,updateMonthYear:b,presetDate:y,selectCurrentDate:f,updateTime:w,assignMonthAndYear:k,setStartTime:E}=((e,a,t,r)=>{let n=(0,v.KR)([]),o=(0,v.KR)(new Date),i=(0,v.KR)(),{modelValue:l,calendars:d,time:u,today:p}=rj(e,a,()=>W(e.isTextInputDate)),{defaultedMultiCalendars:s,defaultedStartTime:m,defaultedRange:A,defaultedConfig:_,defaultedTz:h,propDates:g,defaultedMultiDates:C}=tW(e),{validateMonthYearInRange:b,isDisabled:y,isDateRangeAllowed:f,checkMinMaxRange:w}=rG(e),{updateTimeValues:k,getSetDateTime:E,setTime:x,assignStartTime:B,validateTime:D,disabledTimesConfig:R}=rs(e,u,l,r),M=(0,c.EW)(()=>e=>d.value[e]?d.value[e].month:0),T=(0,c.EW)(()=>e=>d.value[e]?d.value[e].year:0),S=(e,a,t,r=!1)=>{_.value.keepViewOnOffsetClick&&!r&&i.value||(d.value[e]||(d.value[e]={month:0,year:0}),d.value[e].month=null===a?d.value[e]?.month:a,d.value[e].year=null===t?d.value[e]?.year:t)},P=()=>{e.autoApply&&a("select-date")},$=()=>{m.value&&B(m.value)};(0,c.sV)(()=>{e.shadow||(l.value||(L(),$()),W(!0),e.focusStartDate&&e.startDate&&L())});let Y=(0,c.EW)(()=>!e.flow?.length||!!e.partialFlow||e.flowStep===e.flow.length),W=(a=!1)=>l.value?Array.isArray(l.value)?(n.value=l.value,I(a)):N(l.value,a):s.value.count&&a&&!e.startDate?O(aZ(),a):void 0,O=(e=new Date,a=!1)=>{if(s.value.count&&s.value.static&&!a||S(0,at(e),aa(e)),s.value.count&&(!l.value||Array.isArray(l.value)&&A.value.enabled&&at(l.value[0])===at(l.value[1]??l.value[0])||!s.value.solo)&&(!s.value.solo||a))for(let e=1;e<s.value.count;e++){let a=ap(e1(aZ(),{month:M.value(e-1),year:T.value(e-1)}),{months:1});d.value[e]={month:at(a),year:aa(a)}}},N=(e,a)=>{O(e),x("hours",e3(e)),x("minutes",e9(e)),x("seconds",ae(e)),s.value.count&&a&&V()},I=a=>{((a,t)=>{if((A.value.enabled||e.weekPicker)&&!C.value.enabled){let e;return a[1]&&A.value.showLastInRange?O(a[(e=>{if(s.value.count){if(s.value.solo)return 0;let a=at(e[0]);return Math.abs(at(e[1])-a)<s.value.count?0:1}return 1})(a)],t):O(a[0],t),x("hours",(e=(e,t)=>[e(a[0]),a[1]?e(a[1]):u[t][1]])(e3,"hours")),x("minutes",e(e9,"minutes")),x("seconds",e(ae,"seconds"))}if(C.value.enabled&&t)return N(a[a.length-1],t)})(l.value,a),s.value.count&&s.value.solo&&V()},X=(r,n)=>{let o=e1(aZ(),{month:M.value(n),year:T.value(n)}),i=r<0?ao(o,1):ao(o,-1,void 0);b(at(i),aa(i),r<0,e.preventMinMaxNavigation)&&(S(n,at(i),aa(i)),a("update-month-year",{instance:n,month:at(i),year:aa(i)}),s.value.count&&!s.value.solo&&F(n),t())},F=e=>{for(let a=e-1;a>=0;a--){let e=ao(e1(aZ(),{month:M.value(a+1),year:T.value(a+1)}),-1,void 0);S(a,at(e),aa(e))}for(let a=e+1;a<=s.value.count-1;a++){let e=ao(e1(aZ(),{month:M.value(a-1),year:T.value(a-1)}),1);S(a,at(e),aa(e))}},V=()=>{if(Array.isArray(l.value)&&2===l.value.length){let e=aZ(aZ(l.value[1]?l.value[1]:ao(l.value[0],1))),[a,t]=[at(l.value[0]),aa(l.value[0])],[r,n]=[at(l.value[1]),aa(l.value[1])];(a!==r||a===r&&t!==n)&&s.value.solo&&S(1,at(e),aa(e))}else l.value&&!Array.isArray(l.value)&&(S(0,at(l.value),aa(l.value)),O(aZ()))},L=()=>{e.startDate&&(S(0,at(aZ(e.startDate)),aa(aZ(e.startDate))),s.value.count&&F(0))},K=(e,a)=>{X("right"===e?-1:1,a)},q=(a,t)=>{let r=aZ(a),n=[];for(let a=0;a<7;a++){let o=eK(r,a),i=at(o)!==t;n.push({text:e.hideOffsetDates&&i?"":o.getDate(),value:o,current:!i,classData:{}})}return n},H=e=>!!A.value.noDisabledRange&&ta(n.value[0],e).some(e=>y(e)),j=(a=!0)=>e.enableSeconds?Array.isArray(u.seconds)?a?u.seconds[0]:u.seconds[1]:u.seconds:0,Q=e=>{n.value[e]=a0(n.value[e],u.hours[e],u.minutes[e],j(1!==e))},G=()=>{if(Array.isArray(l.value))if(C.value.enabled){let e=U();l.value[l.value.length-1]=E(e)}else l.value=l.value.map((e,a)=>e&&E(e,a));else l.value=E(l.value);a("time-update")},U=()=>Array.isArray(l.value)&&l.value.length?l.value[l.value.length-1]:null;return{calendars:d,modelValue:l,month:M,year:T,time:u,disabledTimesConfig:R,today:p,validateTime:D,getCalendarDays:(a,t)=>{let r=[],n=new Date(t,a),o=new Date(t,a+1,0),i=e.weekStart,l=z(n,{weekStartsOn:i}),d=e=>{let t=q(e,a);r.push({days:t}),r[r.length-1].days.some(e=>a1(aJ(e.value),aJ(o)))||d(eK(e,7))};return d(l),((a,t,r,n)=>{if(e.sixWeeks&&a.length<6){let o=6-a.length,[i,l]=((a,t)=>{switch(!0===e.sixWeeks?"append":e.sixWeeks){case"prepend":return[!0,!1];case"center":return[0==a,!0];case"fair":return[0==a||t>a,!0];default:return[!1,!1]}})((t.getDay()+7-n)%7,6-(r.getDay()+7-n)%7);for(let e=1;e<=o;e++)if(l?!!(e%2)==i:i){let e=q(eK(a[0].days[0].value,-7),at(t));a.unshift({days:e})}else{let e=a[a.length-1],r=q(eK(e.days[e.days.length-1].value,1),at(t));a.push({days:r})}}return a})(r,n,o,i)},getMarker:e=>{if(g.value.markers)return aH(e.value,g.value.markers)},handleScroll:(a,t)=>{if(e.monthChangeOnScroll){let r=new Date().getTime()-o.value.getTime(),n=Math.abs(a.deltaY),i=500;n>1&&(i=100),n>100&&(i=0),r>i&&(o.value=new Date,X("inverse"!==e.monthChangeOnScroll?-a.deltaY:a.deltaY,t))}},handleSwipe:K,handleArrow:(a,t,r=!1)=>{e.monthChangeOnArrows&&e.vertical===r&&K(a,t)},selectDate:(t,o=!1)=>{if(y(t.value)||!t.current&&e.hideOffsetDates)return a("invalid-date",t.value);if(i.value=JSON.parse(JSON.stringify(t)),!A.value.enabled){let n;return void(a("date-update",n=a0(aZ(t.value),u.hours,u.minutes,j())),C.value.enabled?t0(n,l,C.value.limit):l.value=n,r(),(0,c.dY)().then(()=>{e.autoApply&&Y.value&&a("auto-apply",!!e.partialFlow&&e.flowStep!==e.flow.length)}))}Array.isArray(u.hours)&&Array.isArray(u.minutes)&&!C.value.enabled&&(((t,r)=>{if(n.value=l.value?l.value.slice():[],2!==n.value.length||A.value.fixedStart||A.value.fixedEnd||(n.value=[]),A.value.autoRange){let e;return f(e=[aZ(t.value),eK(aZ(t.value),+A.value.autoRange)])?(r&&(e=>{if(S(0,at(aZ(e)),aa(aZ(e))),s.value.count>0)for(let a=1;a<s.value.count;a++){let t=tt(e1(aZ(e),{year:T.value(a-1),month:M.value(a-1)}));S(a,t.month,t.year)}})(t.value),n.value=e):a("invalid-date",t.value)}if(A.value.fixedStart||A.value.fixedEnd)return H(t.value)||!w(t.value,l.value,+!A.value.fixedStart)?a("invalid-date",t.value):n.value=t4(aZ(t.value),l,a,A);n.value[0]?w(aZ(t.value),l.value)&&!H(t.value)?a6(aZ(t.value),aZ(n.value[0]))?(n.value.unshift(aZ(t.value)),a("range-end",n.value[0])):(n.value[1]=aZ(t.value),a("range-end",n.value[1])):(e.autoApply&&a("auto-apply-invalid",t.value),a("invalid-date",t.value)):(n.value[0]=aZ(t.value),a("range-start",n.value[0]))})(t,o),n.value.length&&(n.value[0]&&!n.value[1]?Q(0):(Q(0),Q(1),r()),n.value[0]&&n.value[1]&&+n.value?.[0]>+n.value?.[1]&&(n.value.reverse(),a("range-start",n.value[0]),a("range-end",n.value[1])),l.value=n.value.slice(),t1(n.value,a,e.autoApply,e.modelAuto)))},updateMonthYear:(n,o)=>{S(n,o.month,o.year,!0),s.value.count&&!s.value.solo&&F(n),a("update-month-year",{instance:n,month:o.month,year:o.year}),t(s.value.solo?n:void 0);let i=e.flow?.length?e.flow[e.flowStep]:void 0;o.fromNav||i!==aD.month&&i!==aD.year||r()},presetDate:(a,t)=>{t5({value:a,modelValue:l,range:A.value.enabled,timezone:t?void 0:h.value.timezone}),P(),e.multiCalendars&&(0,c.dY)().then(()=>W(!0))},selectCurrentDate:()=>{let e=aw(aZ(),h.value);A.value.enabled||C.value.enabled?l.value&&Array.isArray(l.value)&&l.value[0]?C.value.enabled?l.value=[...l.value,e]:l.value=a6(e,l.value[0])?[e,l.value[0]]:[l.value[0],e]:l.value=[e]:l.value=e,P()},updateTime:(e,a=!0,t=!1)=>{k(e,a,t,G)},assignMonthAndYear:O,setStartTime:$}})(e,t,function(e){e||0===e?S.value[e]?.triggerTransition(n.value(e),o.value(e)):S.value.forEach((e,a)=>e.triggerTransition(n.value(a),o.value(a)))},function(){t("update-flow-step")}),x=(0,c.Ht)(),{setHoverDate:B,getDayClassData:D,clearHoverDate:R}=rQ(i,e),{defaultedMultiCalendars:M}=tW(e),T=(0,v.KR)([]),S=(0,v.KR)([]),P=(0,v.KR)(null),$=rq(x,"calendar"),Y=rq(x,"monthYear"),W=rq(x,"timePicker"),O=a=>{e.shadow||t("mount",a)};(0,c.wB)(r,()=>{e.shadow||setTimeout(()=>{t("recalculate-position")},0)},{deep:!0}),(0,c.wB)(M,(e,a)=>{e.count-a.count>0&&k()},{deep:!0});let N=(0,c.EW)(()=>e=>s(n.value(e),o.value(e)).map(e=>({...e,days:e.days.map(e=>(e.marker=A(e),e.classData=D(e),e))}))),I=(e,a)=>{e===aD.time&&t(`time-picker-${a?"open":"close"}`),t("overlay-toggle",{open:a,overlay:e})},X=e=>{t("overlay-toggle",{open:!1,overlay:e}),t("focus-menu")};return a({clearHoverDate:R,presetDate:y,selectCurrentDate:f,toggleMonthPicker:(e,a,t=0)=>{T.value[t]?.toggleMonthPicker(e,a)},toggleYearPicker:(e,a,t=0)=>{T.value[t]?.toggleYearPicker(e,a)},toggleTimePicker:(e,a,t)=>{P.value?.toggleTimePicker(e,a,t)},handleArrow:_,updateMonthYear:b,getSidebarProps:()=>({modelValue:i,month:n,year:o,time:l,updateTime:w,updateMonthYear:b,selectDate:C,presetDate:y}),changeMonth:e=>{T.value[0]?.handleMonthYearChange(e,!0)},changeYear:e=>{b(0,{month:n.value(0),year:o.value(0)+(e?1:-1),fromNav:!0})},selectWeekDate:(a,t)=>{if(!e.range){let e=i.value?i.value:u,r=t?new Date(t):e,o=a?z(r,{weekStartsOn:1}):ai(r,{weekStartsOn:1});C({value:o,current:at(r)===n.value(0),text:"",classData:{}}),document.getElementById(tb(o))?.focus()}},setStartTime:E}),(a,r)=>((0,c.uX)(),(0,c.CE)(c.FK,null,[(0,c.bF)(tQ,{"multi-calendars":(0,v.R1)(M).count,collapse:a.collapse,"is-mobile":a.isMobile},{default:(0,c.k6)(({instance:i,index:l})=>[a.disableMonthYearSelect?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)(rg,(0,c.v6)({key:0,ref:e=>{e&&(T.value[l]=e)},months:(0,v.R1)(a$)(a.formatLocale,a.locale,a.monthNameFormat),years:(0,v.R1)(az)(a.yearRange,a.locale,a.reverseYears),month:(0,v.R1)(n)(i),year:(0,v.R1)(o)(i),instance:i},a.$props,{onMount:r[0]||(r[0]=e=>O((0,v.R1)(aB).header)),onResetFlow:r[1]||(r[1]=e=>a.$emit("reset-flow")),onUpdateMonthYear:e=>(0,v.R1)(b)(i,e),onOverlayClosed:X,onOverlayOpened:r[2]||(r[2]=e=>a.$emit("overlay-toggle",{open:!0,overlay:e}))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(Y),(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["months","years","month","year","instance","onUpdateMonthYear"])),(0,c.bF)(rE,(0,c.v6)({ref:e=>{e&&(S.value[l]=e)},"mapped-dates":N.value(i),month:(0,v.R1)(n)(i),year:(0,v.R1)(o)(i),instance:i},a.$props,{onSelectDate:e=>(0,v.R1)(C)(e,1!==i),onHandleSpace:a=>((a,r=!1)=>{C(a,r),e.spaceConfirm&&t("select-date")})(a,1!==i),onSetHoverDate:r[3]||(r[3]=e=>(0,v.R1)(B)(e)),onHandleScroll:e=>(0,v.R1)(h)(e,i),onHandleSwipe:e=>(0,v.R1)(g)(e,i),onMount:r[4]||(r[4]=e=>O((0,v.R1)(aB).calendar)),onResetFlow:r[5]||(r[5]=e=>a.$emit("reset-flow")),onTooltipOpen:r[6]||(r[6]=e=>a.$emit("tooltip-open",e)),onTooltipClose:r[7]||(r[7]=e=>a.$emit("tooltip-close",e))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)($),(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,m.normalizeProps)((0,c.Ng)({...t})))])}))]),1040,["mapped-dates","month","year","instance","onSelectDate","onHandleSpace","onHandleScroll","onHandleSwipe"])]),_:3},8,["multi-calendars","collapse","is-mobile"]),a.enableTimePicker?((0,c.uX)(),(0,c.CE)("div",rx,[a.$slots["time-picker"]?(0,c.RG)(a.$slots,"time-picker",(0,m.normalizeProps)((0,c.v6)({key:0},{time:(0,v.R1)(l),updateTime:(0,v.R1)(w)}))):((0,c.uX)(),(0,c.Wv)(rp,(0,c.v6)({key:1,ref_key:"timePickerRef",ref:P},a.$props,{hours:(0,v.R1)(l).hours,minutes:(0,v.R1)(l).minutes,seconds:(0,v.R1)(l).seconds,"internal-model-value":a.internalModelValue,"disabled-times-config":(0,v.R1)(d),"validate-time":(0,v.R1)(p),onMount:r[8]||(r[8]=e=>O((0,v.R1)(aB).timePicker)),"onUpdate:hours":r[9]||(r[9]=e=>(0,v.R1)(w)(e)),"onUpdate:minutes":r[10]||(r[10]=e=>(0,v.R1)(w)(e,!1)),"onUpdate:seconds":r[11]||(r[11]=e=>(0,v.R1)(w)(e,!1,!0)),onResetFlow:r[12]||(r[12]=e=>a.$emit("reset-flow")),onOverlayClosed:r[13]||(r[13]=e=>I(e,!1)),onOverlayOpened:r[14]||(r[14]=e=>I(e,!0)),onAmPmChange:r[15]||(r[15]=e=>a.$emit("am-pm-change",e))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(W),(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["hours","minutes","seconds","internal-model-value","disabled-times-config","validate-time"]))])):(0,c.Q3)("",!0)],64))}}),rD={class:"dp--quarter-items"},rR=["data-test-id","disabled","onClick","onMouseover"],rM=(0,c.pM)({compatConfig:{MODE:3},__name:"QuarterPicker",props:{...tN},emits:["update:internal-model-value","reset-flow","overlay-closed","auto-apply","range-start","range-end","overlay-toggle","update-month-year"],setup(e,{expose:a,emit:t}){let r=rq((0,c.Ht)(),"yearMode"),{defaultedMultiCalendars:n,defaultedConfig:o,groupedYears:i,year:l,isDisabled:d,quarters:u,modelValue:p,showYearPicker:s,setHoverDate:A,selectQuarter:_,toggleYearPicker:h,handleYearSelect:g,handleYear:C}=((e,a)=>{let t=(0,v.KR)(),{defaultedMultiCalendars:r,defaultedConfig:n,defaultedHighlight:o,defaultedRange:i,propDates:l,defaultedFilters:d,defaultedMultiDates:u}=tW(e),{modelValue:p,year:s,month:m,calendars:A}=rj(e,a),{isDisabled:_}=rG(e),{selectYear:h,groupedYears:g,showYearPicker:C,isDisabled:b,toggleYearPicker:y,handleYearSelect:f,handleYear:w}=t8({modelValue:p,multiCalendars:r,range:i,highlight:o,calendars:A,propDates:l,month:m,year:s,filters:d,props:e,emit:a}),k=(0,c.EW)(()=>e=>!!p.value&&(Array.isArray(p.value)?p.value.some(a=>ac(e,a)):ac(p.value,e))),E=(0,c.EW)(()=>a=>{let r=e1(new Date,{year:s.value(a)});return(function(e){let{start:a,end:t}=ar(void 0,e),r=+a>+t,n=r?+as(a):+as(t),o=r?as(t):as(a),i=(void 0)??1;if(!i)return[];i<0&&(i=-i,r=!r);let l=[];for(;+o<=n;)l.push(B(a,o)),o=ao(o,3*i,void 0);return r?l.reverse():l})({start:P(r),end:ad(r)}).map(a=>{let r=as(a),n=am(a),l=_(a),d=(e=>{if(i.value.enabled&&Array.isArray(p.value)){let a=a1(e,p.value[0])||a1(e,p.value[1]);return a4(p.value,t.value,e)&&!a}return!1})(r),u="function"==typeof o.value?o.value({quarter:av(r),year:aa(r)}):!!o.value.quarters.find(e=>e.quarter===av(r)&&e.year===aa(r));return{text:[r,n].map(a=>ei(a,"MMMM",{locale:e.formatLocale})).join("-"),value:r,active:k.value(r),highlighted:u,disabled:l,isBetween:d}})});return{defaultedConfig:n,defaultedMultiCalendars:r,groupedYears:g,year:s,isDisabled:b,quarters:E,showYearPicker:C,modelValue:p,setHoverDate:e=>{t.value=e},selectYear:h,selectQuarter:(t,r,n)=>{if(!n)return A.value[r].month=at(am(t)),u.value.enabled?void(t0(t,p,u.value.limit),a("auto-apply",!0)):i.value.enabled?void(p.value=t6(p,t,a),t1(p.value,a,e.autoApply,e.modelAuto)):void(p.value=t,a("auto-apply"))},toggleYearPicker:y,handleYearSelect:f,handleYear:w}})(e,t);return a({getSidebarProps:()=>({modelValue:p,year:l,selectQuarter:_,handleYearSelect:g,handleYear:C})}),(e,a)=>((0,c.uX)(),(0,c.Wv)(tQ,{"multi-calendars":(0,v.R1)(n).count,collapse:e.collapse,stretch:"","is-mobile":e.isMobile},{default:(0,c.k6)(({instance:a})=>[(0,c.Lk)("div",{class:"dp-quarter-picker-wrap",style:(0,m.normalizeStyle)({minHeight:`${(0,v.R1)(o).modeHeight}px`})},[e.$slots["top-extra"]?(0,c.RG)(e.$slots,"top-extra",{key:0,value:e.internalModelValue}):(0,c.Q3)("",!0),(0,c.Lk)("div",null,[(0,c.bF)(tJ,(0,c.v6)(e.$props,{items:(0,v.R1)(i)(a),instance:a,"show-year-picker":(0,v.R1)(s)[a],year:(0,v.R1)(l)(a),"is-disabled":e=>(0,v.R1)(d)(a,e),onHandleYear:e=>(0,v.R1)(C)(a,e),onYearSelect:e=>(0,v.R1)(g)(e,a),onToggleYearPicker:e=>(0,v.R1)(h)(a,e?.flow,e?.show)}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(r),(a,t)=>({name:a,fn:(0,c.k6)(t=>[(0,c.RG)(e.$slots,a,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["items","instance","show-year-picker","year","is-disabled","onHandleYear","onYearSelect","onToggleYearPicker"])]),(0,c.Lk)("div",rD,[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)((0,v.R1)(u)(a),(t,r)=>((0,c.uX)(),(0,c.CE)("div",{key:r},[(0,c.Lk)("button",{type:"button",class:(0,m.normalizeClass)(["dp--qr-btn",{"dp--qr-btn-active":t.active,"dp--qr-btn-between":t.isBetween,"dp--qr-btn-disabled":t.disabled,"dp--highlighted":t.highlighted}]),"data-test-id":t.value,disabled:t.disabled,onClick:e=>(0,v.R1)(_)(t.value,a,t.disabled),onMouseover:e=>(0,v.R1)(A)(t.value)},[e.$slots.quarter?(0,c.RG)(e.$slots,"quarter",{key:0,value:t.value,text:t.text}):((0,c.uX)(),(0,c.CE)(c.FK,{key:1},[(0,c.eW)((0,m.toDisplayString)(t.text),1)],64))],42,rR)]))),128))])],4)]),_:3},8,["multi-calendars","collapse","is-mobile"]))}}),rT=(e,a)=>{let t=(0,v.KR)(0);(0,c.sV)(()=>{r(),window.addEventListener("resize",r,{passive:!0})}),(0,c.hi)(()=>{window.removeEventListener("resize",r)});let r=()=>{t.value=window.document.documentElement.clientWidth};return{isMobile:(0,c.EW)(()=>t.value<=e.value.mobileBreakpoint&&!a||void 0)}},rS=["id","tabindex","role","aria-label"],rP={key:0,class:"dp--menu-load-container"},rz={key:1,class:"dp--menu-header"},r$=["data-dp-mobile"],rY={key:0,class:"dp__sidebar_left"},rW=["data-dp-mobile"],rO=["data-test-id","data-dp-mobile","onClick","onKeydown"],rN={key:2,class:"dp__sidebar_right"},rI={key:3,class:"dp__action_extra"},rX=(0,c.pM)({compatConfig:{MODE:3},__name:"DatepickerMenu",props:{...tO,shadow:{type:Boolean,default:!1},openOnTop:{type:Boolean,default:!1},internalModelValue:{type:[Date,Array],default:null},noOverlayFocus:{type:Boolean,default:!1},collapse:{type:Boolean,default:!1},getInputRect:{type:Function,default:()=>({})},isTextInputDate:{type:Boolean,default:!1}},emits:["close-picker","select-date","auto-apply","time-update","flow-step","update-month-year","invalid-select","update:internal-model-value","recalculate-position","invalid-fixed-range","tooltip-open","tooltip-close","time-picker-open","time-picker-close","am-pm-change","range-start","range-end","auto-apply-invalid","date-update","invalid-date","overlay-toggle","menu-blur"],setup(e,{expose:a,emit:t}){let r=(0,v.KR)(null),n=(0,c.EW)(()=>{let{openOnTop:a,...t}=e;return{...t,isMobile:g.value,flowStep:T.value,menuWrapRef:r.value}}),{setMenuFocused:o,setShiftKey:i,control:l}=tk(),d=(0,c.Ht)(),{defaultedTextInput:u,defaultedInline:p,defaultedConfig:s,defaultedUI:A,handleEventPropagation:_}=tW(e),{isMobile:g}=rT(s,e.shadow),C=(0,v.KR)(null),b=(0,v.KR)(0),y=(0,v.KR)(null),f=(0,v.KR)(!1),w=(0,v.KR)(null),k=(0,v.KR)(!1),E=e=>{k.value=!0,s.value.allowPreventDefault&&e.preventDefault(),aV(e,s.value,!0)};(0,c.sV)(()=>{if(!e.shadow){f.value=!0,x(),window.addEventListener("resize",x);let e=aY(r);!e||u.value.enabled||p.value.enabled||(o(!0),O()),e&&(e.addEventListener("pointerdown",E),e.addEventListener("mousedown",E))}document.addEventListener("mousedown",ee)}),(0,c.hi)(()=>{window.removeEventListener("resize",x),document.removeEventListener("mousedown",ee);let e=aY(r);e&&(e.removeEventListener("pointerdown",E),e.removeEventListener("mousedown",E))});let x=()=>{let e=aY(y);e&&(b.value=e.getBoundingClientRect().width)},{arrowRight:B,arrowLeft:D,arrowDown:R,arrowUp:M}=tP(),{flowStep:T,updateFlowStep:S,childMount:P,resetFlow:z,handleFlow:$}=rZ(e,t,w),Y=(0,c.EW)(()=>e.monthPicker?t7:e.yearPicker?t2:e.timePicker?rc:e.quarterPicker?rM:rB),W=(0,c.EW)(()=>{if(s.value.arrowLeft)return s.value.arrowLeft;let a=r.value?.getBoundingClientRect(),t=e.getInputRect();return t?.width<b?.value&&t?.left<=(a?.left??0)?`${t?.width/2}px`:t?.right>=(a?.right??0)&&t?.width<b?.value?`${b?.value-t?.width/2}px`:"50%"}),O=()=>{let e=aY(r);e&&e.focus({preventScroll:!0})},N=(0,c.EW)(()=>w.value?.getSidebarProps()||{}),I=()=>{e.openOnTop&&t("recalculate-position")},X=rq(d,"action"),F=(0,c.EW)(()=>e.monthPicker||e.yearPicker?rq(d,"monthYear"):e.timePicker?rq(d,"timePicker"):rq(d,"shared")),V=(0,c.EW)(()=>e.openOnTop?"dp__arrow_bottom":"dp__arrow_top"),L=(0,c.EW)(()=>({dp__menu_disabled:e.disabled,dp__menu_readonly:e.readonly,"dp-menu-loading":e.loading})),K=(0,c.EW)(()=>({dp__menu:!0,dp__menu_index:!p.value.enabled,dp__relative:p.value.enabled,...A.value.menu??{}})),q=e=>{aV(e,s.value,!0)},H=()=>{O(),t("time-picker-close")},j=(e,...a)=>{w.value?.[e]&&w.value?.[e](...a)},Q=()=>{j("selectCurrentDate")},G=(e,a)=>{j("presetDate",(0,v.BA)(e),a)},U=()=>{j("clearHoverDate")},Z=(a,t)=>{a.preventDefault(),(a=>{if(e.arrowNavigation){if(a===aM.up)return M();if(a===aM.down)return R();if(a===aM.left)return D();if(a===aM.right)return B()}else a===aM.left||a===aM.up?j("handleArrow",aM.left,0,a===aM.up):j("handleArrow",aM.right,0,a===aM.down)})(t)},J=a=>{if(i(a.shiftKey),!e.disableMonthYearSelect&&a.code===aT.tab&&a.target.classList.contains("dp__menu")&&l.value.shiftKeyInMenu&&(a.preventDefault(),aV(a,s.value,!0),t("close-picker")),a.key===aT.home||a.key===aT.end)return j("selectWeekDate",a.key===aT.home,a.target.getAttribute("id"));switch((a.key===aT.pageUp||a.key===aT.pageDown)&&(a.shiftKey?(j("changeYear",a.key===aT.pageUp),aL(r.value,"overlay-year")?.focus()):(j("changeMonth",a.key===aT.pageUp),aL(r.value,a.key===aT.pageUp?"action-prev":"action-next")?.focus()),a.target.getAttribute("id")&&r.value?.focus({preventScroll:!0})),a.key){case aT.esc:return void(e.escClose&&(t("close-picker"),_(a)));case aT.arrowLeft:return Z(a,aM.left);case aT.arrowRight:return Z(a,aM.right);case aT.arrowUp:return Z(a,aM.up);case aT.arrowDown:return Z(a,aM.down);default:return}},ee=e=>{p.value.enabled&&!p.value.input&&!r.value?.contains(e.target)&&k.value&&(k.value=!1,t("menu-blur"))};return a({updateMonthYear:(e,a)=>{j("updateMonthYear",e,a)},switchView:(e,a=0)=>"month"===e?w.value?.toggleMonthPicker(!1,!0,a):"year"===e?w.value?.toggleYearPicker(!1,!0,a):"time"===e?w.value?.toggleTimePicker(!0,!1):void(w.value?.toggleTimePicker(!1,!1),w.value?.toggleMonthPicker(!1,!1,a),w.value?.toggleYearPicker(!1,!1,a)),handleFlow:$,onValueCleared:()=>{w.value?.setStartTime?.()}}),(a,t)=>((0,c.uX)(),(0,c.CE)("div",{id:a.uid?`dp-menu-${a.uid}`:void 0,ref_key:"dpMenuRef",ref:r,tabindex:(0,v.R1)(p).enabled?void 0:"0",role:(0,v.R1)(p).enabled?void 0:"dialog","aria-label":a.ariaLabels?.menu,class:(0,m.normalizeClass)(K.value),style:(0,m.normalizeStyle)({"--dp-arrow-left":W.value}),onMouseleave:U,onClick:q,onKeydown:J},[(a.disabled||a.readonly)&&(0,v.R1)(p).enabled||a.loading?((0,c.uX)(),(0,c.CE)("div",{key:0,class:(0,m.normalizeClass)(L.value)},[a.loading?((0,c.uX)(),(0,c.CE)("div",rP,[...t[19]||(t[19]=[(0,c.Lk)("span",{class:"dp--menu-loader"},null,-1)])])):(0,c.Q3)("",!0)],2)):(0,c.Q3)("",!0),a.$slots["menu-header"]?((0,c.uX)(),(0,c.CE)("div",rz,[(0,c.RG)(a.$slots,"menu-header")])):(0,c.Q3)("",!0),(0,v.R1)(p).enabled||a.teleportCenter?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("div",{key:2,class:(0,m.normalizeClass)(V.value)},null,2)),(0,c.Lk)("div",{ref_key:"innerMenuRef",ref:y,class:(0,m.normalizeClass)({dp__menu_content_wrapper:a.presetDates?.length||!!a.$slots["left-sidebar"]||!!a.$slots["right-sidebar"],"dp--menu-content-wrapper-collapsed":e.collapse&&(a.presetDates?.length||!!a.$slots["left-sidebar"]||!!a.$slots["right-sidebar"])}),"data-dp-mobile":(0,v.R1)(g),style:(0,m.normalizeStyle)({"--dp-menu-width":`${b.value}px`})},[a.$slots["left-sidebar"]?((0,c.uX)(),(0,c.CE)("div",rY,[(0,c.RG)(a.$slots,"left-sidebar",(0,m.normalizeProps)((0,c.Ng)(N.value)))])):(0,c.Q3)("",!0),a.presetDates.length?((0,c.uX)(),(0,c.CE)("div",{key:1,class:(0,m.normalizeClass)({"dp--preset-dates-collapsed":e.collapse,"dp--preset-dates":!0}),"data-dp-mobile":(0,v.R1)(g)},[((0,c.uX)(!0),(0,c.CE)(c.FK,null,(0,c.pI)(a.presetDates,(t,r)=>((0,c.uX)(),(0,c.CE)(c.FK,{key:r},[t.slot?(0,c.RG)(a.$slots,t.slot,{key:0,presetDate:G,label:t.label,value:t.value}):((0,c.uX)(),(0,c.CE)("button",{key:1,type:"button",style:(0,m.normalizeStyle)(t.style||{}),class:(0,m.normalizeClass)(["dp__btn dp--preset-range",{"dp--preset-range-collapsed":e.collapse}]),"data-test-id":t.testId??void 0,"data-dp-mobile":(0,v.R1)(g),onClick:(0,h.withModifiers)(e=>G(t.value,t.noTz),["prevent"]),onKeydown:e=>(0,v.R1)(aj)(e,()=>G(t.value,t.noTz),!0)},(0,m.toDisplayString)(t.label),47,rO))],64))),128))],10,rW)):(0,c.Q3)("",!0),(0,c.Lk)("div",{ref_key:"calendarWrapperRef",ref:C,class:"dp__instance_calendar",role:"document"},[((0,c.uX)(),(0,c.Wv)((0,c.$y)(Y.value),(0,c.v6)({ref_key:"dynCmpRef",ref:w},n.value,{"flow-step":(0,v.R1)(T),onMount:(0,v.R1)(P),onUpdateFlowStep:(0,v.R1)(S),onResetFlow:(0,v.R1)(z),onFocusMenu:O,onSelectDate:t[0]||(t[0]=e=>a.$emit("select-date")),onDateUpdate:t[1]||(t[1]=e=>a.$emit("date-update",e)),onTooltipOpen:t[2]||(t[2]=e=>a.$emit("tooltip-open",e)),onTooltipClose:t[3]||(t[3]=e=>a.$emit("tooltip-close",e)),onAutoApply:t[4]||(t[4]=e=>a.$emit("auto-apply",e)),onRangeStart:t[5]||(t[5]=e=>a.$emit("range-start",e)),onRangeEnd:t[6]||(t[6]=e=>a.$emit("range-end",e)),onInvalidFixedRange:t[7]||(t[7]=e=>a.$emit("invalid-fixed-range",e)),onTimeUpdate:t[8]||(t[8]=e=>a.$emit("time-update")),onAmPmChange:t[9]||(t[9]=e=>a.$emit("am-pm-change",e)),onTimePickerOpen:t[10]||(t[10]=e=>a.$emit("time-picker-open",e)),onTimePickerClose:H,onRecalculatePosition:I,onUpdateMonthYear:t[11]||(t[11]=e=>a.$emit("update-month-year",e)),onAutoApplyInvalid:t[12]||(t[12]=e=>a.$emit("auto-apply-invalid",e)),onInvalidDate:t[13]||(t[13]=e=>a.$emit("invalid-date",e)),onOverlayToggle:t[14]||(t[14]=e=>a.$emit("overlay-toggle",e)),"onUpdate:internalModelValue":t[15]||(t[15]=e=>a.$emit("update:internal-model-value",e))}),(0,c.eX)({_:2},[(0,c.pI)(F.value,(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,m.normalizeProps)((0,c.Ng)({...t})))])}))]),1040,["flow-step","onMount","onUpdateFlowStep","onResetFlow"]))],512),a.$slots["right-sidebar"]?((0,c.uX)(),(0,c.CE)("div",rN,[(0,c.RG)(a.$slots,"right-sidebar",(0,m.normalizeProps)((0,c.Ng)(N.value)))])):(0,c.Q3)("",!0),a.$slots["action-extra"]?((0,c.uX)(),(0,c.CE)("div",rI,[a.$slots["action-extra"]?(0,c.RG)(a.$slots,"action-extra",{key:0,selectCurrentDate:Q}):(0,c.Q3)("",!0)])):(0,c.Q3)("",!0)],14,r$),!a.autoApply||(0,v.R1)(s).keepActionRow?((0,c.uX)(),(0,c.Wv)(tF,(0,c.v6)({key:3,"menu-mount":f.value},n.value,{"calendar-width":b.value,onClosePicker:t[16]||(t[16]=e=>a.$emit("close-picker")),onSelectDate:t[17]||(t[17]=e=>a.$emit("select-date")),onInvalidSelect:t[18]||(t[18]=e=>a.$emit("invalid-select")),onSelectNow:Q}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(X),(e,t)=>({name:e,fn:(0,c.k6)(t=>[(0,c.RG)(a.$slots,e,(0,m.normalizeProps)((0,c.Ng)({...t})))])}))]),1040,["menu-mount","calendar-width"])):(0,c.Q3)("",!0)],46,rS))}});var rF=((p=rF||{}).center="center",p.left="left",p.right="right",p);let rV=[{name:"clock-icon",use:["time","calendar","shared"]},{name:"arrow-left",use:["month-year","calendar","shared","year-mode"]},{name:"arrow-right",use:["month-year","calendar","shared","year-mode"]},{name:"arrow-up",use:["time","calendar","month-year","shared"]},{name:"arrow-down",use:["time","calendar","month-year","shared"]},{name:"calendar-icon",use:["month-year","time","calendar","shared","year-mode"]},{name:"day",use:["calendar","shared"]},{name:"month-overlay-value",use:["calendar","month-year","shared"]},{name:"year-overlay-value",use:["calendar","month-year","shared","year-mode"]},{name:"year-overlay",use:["month-year","shared"]},{name:"month-overlay",use:["month-year","shared"]},{name:"month-overlay-header",use:["month-year","shared"]},{name:"year-overlay-header",use:["month-year","shared"]},{name:"hours-overlay-value",use:["calendar","time","shared"]},{name:"hours-overlay-header",use:["calendar","time","shared"]},{name:"minutes-overlay-value",use:["calendar","time","shared"]},{name:"minutes-overlay-header",use:["calendar","time","shared"]},{name:"seconds-overlay-value",use:["calendar","time","shared"]},{name:"seconds-overlay-header",use:["calendar","time","shared"]},{name:"hours",use:["calendar","time","shared"]},{name:"minutes",use:["calendar","time","shared"]},{name:"month",use:["calendar","month-year","shared"]},{name:"year",use:["calendar","month-year","shared","year-mode"]},{name:"action-buttons",use:["action"]},{name:"action-preview",use:["action"]},{name:"calendar-header",use:["calendar","shared"]},{name:"marker-tooltip",use:["calendar","shared"]},{name:"action-extra",use:["menu"]},{name:"time-picker-overlay",use:["calendar","time","shared"]},{name:"am-pm-button",use:["calendar","time","shared"]},{name:"left-sidebar",use:["menu"]},{name:"right-sidebar",use:["menu"]},{name:"month-year",use:["month-year","shared"]},{name:"time-picker",use:["menu","shared"]},{name:"action-row",use:["action"]},{name:"marker",use:["calendar","shared"]},{name:"quarter",use:["shared"]},{name:"top-extra",use:["shared","month-year"]},{name:"tp-inline-arrow-up",use:["shared","time"]},{name:"tp-inline-arrow-down",use:["shared","time"]},{name:"menu-header",use:["menu"]}],rL=[{name:"trigger"},{name:"input-icon"},{name:"clear-icon"},{name:"dp-input"}],rK={all:()=>rV,monthYear:()=>rV.filter(e=>e.use.includes("month-year")),input:()=>rL,timePicker:()=>rV.filter(e=>e.use.includes("time")),action:()=>rV.filter(e=>e.use.includes("action")),calendar:()=>rV.filter(e=>e.use.includes("calendar")),menu:()=>rV.filter(e=>e.use.includes("menu")),shared:()=>rV.filter(e=>e.use.includes("shared")),yearMode:()=>rV.filter(e=>e.use.includes("year-mode"))},rq=(e,a,t)=>{let r=[];return rK[a]().forEach(a=>{e[a.name]&&r.push(a.name)}),t?.length&&t.forEach(e=>{e.slot&&r.push(e.slot)}),r},rH=e=>{let a=(0,c.EW)(()=>a=>e.value?a?e.value.open:e.value.close:""),t=(0,c.EW)(()=>a=>e.value?a?e.value.menuAppearTop:e.value.menuAppearBottom:"");return{transitionName:a,showTransition:!!e.value,menuTransition:t}},rj=(e,a,t)=>{let{defaultedRange:r,defaultedTz:n}=tW(e),o=aZ(af(aZ(),n.value.timezone)),i=(0,v.KR)([{month:at(o),year:aa(o)}]),l=e=>{let a={hours:e3(o),minutes:e9(o),seconds:0};return r.value.enabled?[a[e],a[e]]:a[e]},d=(0,v.Kh)({hours:l("hours"),minutes:l("minutes"),seconds:l("seconds")});(0,c.wB)(r,(e,a)=>{e.enabled!==a.enabled&&(d.hours=l("hours"),d.minutes=l("minutes"),d.seconds=l("seconds"))},{deep:!0});let u=(0,c.EW)({get:()=>e.internalModelValue,set:t=>{e.readonly||e.disabled||a("update:internal-model-value",t)}}),p=(0,c.EW)(()=>e=>i.value[e]?i.value[e].month:0),s=(0,c.EW)(()=>e=>i.value[e]?i.value[e].year:0);return(0,c.wB)(u,(e,a)=>{t&&JSON.stringify(e??{})!==JSON.stringify(a??{})&&t()},{deep:!0}),{calendars:i,time:d,modelValue:u,month:p,year:s,today:o}},rQ=(e,a)=>{let{defaultedMultiCalendars:t,defaultedMultiDates:r,defaultedUI:n,defaultedHighlight:o,defaultedTz:i,propDates:l,defaultedRange:d}=tW(a),{isDisabled:u}=rG(a),p=(0,v.KR)(null),s=(0,v.KR)(af(new Date,i.value.timezone)),c=(t,r=!0)=>{let n,o;return(d.value.enabled||a.weekPicker)&&Array.isArray(e.value)&&2===e.value.length?(!a.hideOffsetDates||!!t.current)&&a1(aZ(t.value),e.value[+!r]):!!d.value.enabled&&(n=e.value&&Array.isArray(e.value)&&e.value?r?e.value[0]||null:e.value[1]:null,a1(aZ(t.value),n)&&(o=Array.isArray(e.value)?e.value[0]:null,!r||!a6(p.value??null,o))||a1(t.value,Array.isArray(e.value)?e.value[0]:null)&&(!Array.isArray(e.value)||!d.value.enabled||!e.value[0]||!p.value||(r?a5(p.value,e.value[0]):a6(p.value,e.value[0]))))},m=(a,t)=>{if(Array.isArray(e.value)&&e.value[0]&&1===e.value.length){let r=a1(a.value,p.value);return t?a5(e.value[0],a.value)&&r:a6(e.value[0],a.value)&&r}return!1},A=t=>!!e.value&&(!a.hideOffsetDates||!!t.current)&&(d.value.enabled?!!(a.modelAuto&&Array.isArray(e.value))&&a1(t.value,e.value[0]?e.value[0]:s.value):r.value.enabled&&Array.isArray(e.value)?e.value.some(e=>a1(e,t.value)):a1(t.value,e.value?e.value:s.value)),_=e=>{if((d.value.autoRange||a.weekPicker)&&p.value){if(a.hideOffsetDates&&!e.current)return!1;let t=tr(aZ(p.value),a.weekStart);return a.weekPicker?a1(t[0],e.value):a1(p.value,e.value)}return!1},h=()=>!a.modelAuto||aW(a.internalModelValue),g=e=>d.value.enabled?!!a.modelAuto&&!!(a.modelAuto&&Array.isArray(a.internalModelValue))&&!!a.internalModelValue[0]&&A(e):A(e),C=e=>{let a,t;return!!o.value&&(a=e.value,t=l.value.highlight,!a||!!t&&(t instanceof Map?!!aH(a,t):t(aZ(a))))},b=e=>{let a=u(e.value);return a&&("function"==typeof o.value?!o.value(e.value,a):!o.value.options.highlightDisabled)},y=e=>"function"==typeof o.value?o.value(e.value):o.value.weekdays?.includes(e.value.getDay()),f=r=>!(!((d.value.enabled||a.weekPicker)&&(!(t.value.count>0)||r.current)&&h())||!r.current&&a.hideOffsetDates||A(r))&&a4(e.value,p.value,r.value),w=a=>{if(Array.isArray(e.value)&&1===e.value.length){let{before:t,after:r}=ty(+d.value.maxRange,e.value[0]);return e8(a.value,t)||e2(a.value,r)}return!1},k=a=>{if(Array.isArray(e.value)&&1===e.value.length){let{before:t,after:r}=ty(+d.value.minRange,e.value[0]);return a4([t,r],e.value[0],a.value)}return!1},E=e=>!!d.value.enabled&&(!!d.value.maxRange||!!d.value.minRange)&&(d.value.maxRange&&d.value.minRange?w(e)||k(e):d.value.maxRange?w(e):k(e)),x=e=>({dp__active_date:g(e),dp__date_hover:(e=>{if(a.weekPicker)return!1;let t=!d.value.enabled||!c(e)&&!c(e,!1);return!u(e.value)&&!A(e)&&!(!e.current&&a.hideOffsetDates)&&t})(e)}),B=e=>({isRangeStart:t.value.count>0?e.current&&c(e)&&h():c(e)&&h(),isRangeEnd:t.value.count>0?e.current&&c(e,!1)&&h():c(e,!1)&&h()}),D=e=>{let{isRangeStart:t,isRangeEnd:r}=B(e);return{dp__range_start:t,dp__range_end:r,dp__range_between:f(e),dp__date_hover:a1(e.value,p.value)&&!t&&!r&&!a.weekPicker,dp__date_hover_start:m(e,!0),dp__date_hover_end:m(e,!1)}},R=e=>({...D(e),dp__cell_auto_range:(e=>{if((d.value.autoRange||a.weekPicker)&&p.value){let t=eK(p.value,+d.value.autoRange);if(a.hideOffsetDates&&!e.current)return!1;let r=tr(aZ(p.value),a.weekStart);return a.weekPicker?a5(e.value,r[0])&&a6(e.value,r[1]):a5(e.value,p.value)&&a6(e.value,t)}return!1})(e),dp__cell_auto_range_start:_(e),dp__cell_auto_range_end:(e=>{if((d.value.autoRange||a.weekPicker)&&p.value){if(a.hideOffsetDates&&!e.current)return!1;let t=eK(p.value,+d.value.autoRange),r=tr(aZ(p.value),a.weekStart);return a.weekPicker?a1(r[1],aZ(e.value)):a1(t,aZ(e.value))}return!1})(e)});return{setHoverDate:e=>{!e.current&&a.hideOffsetDates||(p.value=e.value)},clearHoverDate:()=>{p.value=null},getDayClassData:t=>a.hideOffsetDates&&!t.current?{}:{...(e=>{let{isRangeStart:t,isRangeEnd:r}=B(e),n=!!d.value.enabled&&(t||r);return{dp__cell_offset:!e.current,dp__pointer:!a.disabled&&!(!e.current&&a.hideOffsetDates)&&!u(e.value)&&!E(e),dp__cell_disabled:u(e.value)||E(e),dp__cell_highlight:!b(e)&&(C(e)||y(e))&&!g(e)&&!n&&!_(e)&&!(f(e)&&a.weekPicker)&&!r,dp__cell_highlight_active:!b(e)&&(C(e)||y(e))&&g(e),dp__today:!a.noToday&&a1(e.value,s.value)&&e.current,"dp--past":a6(e.value,s.value),"dp--future":a5(e.value,s.value)}})(t),...d.value.enabled?d.value.autoRange?R(t):a.modelAuto?{...x(t),...D(t)}:a.weekPicker?(t=>{if(e.value&&Array.isArray(e.value)){let r=tr(e.value[0],a.weekStart),n=e.value[1]?tr(e.value[1],a.weekStart):[];return{...R(t),dp__range_start:a1(r[0],t.value)||a1(n[0],t.value),dp__range_end:a1(r[1],t.value)||a1(n[1],t.value),dp__range_between_week:a5(t.value,r[0])&&a6(t.value,r[1])||a5(t.value,n[0])&&a6(t.value,n[1]),dp__range_between:a5(t.value,r[1])&&a6(t.value,n[0])}}return{...R(t)}})(t):D(t):a.weekPicker?(t=>{if(e.value&&!Array.isArray(e.value)){let r=tr(e.value,a.weekStart);return{...R(t),dp__range_start:a1(r[0],t.value),dp__range_end:a1(r[1],t.value),dp__range_between_week:a5(t.value,r[0])&&a6(t.value,r[1])}}return{...R(t)}})(t):x(t),[a.dayClass?a.dayClass(t.value,a.internalModelValue):""]:!0,...n.value.calendarCell??{}}}},rG=e=>{let{defaultedFilters:a,defaultedRange:t,propDates:r,defaultedMultiDates:n}=tW(e),o=t=>{let n=!!r.value.maxDate&&(e.yearPicker?aa(t)>aa(r.value.maxDate):a5(t,r.value.maxDate)),o=!!r.value.minDate&&(e.yearPicker?aa(t)<aa(r.value.minDate):a6(t,r.value.minDate)),i=!!r.value.disabledDates&&("function"==typeof r.value.disabledDates?r.value.disabledDates(aZ(t)):!!aH(t,r.value.disabledDates)),l=a.value.months.map(e=>+e).includes(at(t)),u=!!e.disabledWeekDays.length&&e.disabledWeekDays.some(e=>+e===D(t,void 0).getDay()),p=d(t),s=aa(t),c=tf(e.yearRange,s);return!(n||o||i||l||c||u||p)},i=(e,a)=>a6(...to(r.value.minDate,e,a))||a1(...to(r.value.minDate,e,a)),l=(e,a)=>a5(...to(r.value.maxDate,e,a))||a1(...to(r.value.maxDate,e,a)),d=a=>!!Array.isArray(r.value.allowedDates)&&!r.value.allowedDates.length||!!r.value.allowedDates&&!aH(a,r.value.allowedDates,aQ(e.monthPicker,e.yearPicker)),u=e=>!o(e),p=a=>{if(a){let t=aa(a);return t>=+e.yearRange[0]&&t<=e.yearRange[1]}return!0},s=(e,a,t)=>e.find(e=>+e.hours===e3(a)&&"*"===e.minutes||+e.minutes===e9(a)&&+e.hours===e3(a))&&t,v=a=>{var t;let n,o,i,l=!0;if(!a||!e.enableTimePicker||e.monthPicker||e.yearPicker||e.ignoreTimeValidation)return!0;let d=r.value.minDate||r.value.maxDate?a:Array.isArray(a)?[a[0]?th(a[0]):null,a[1]?th(a[1]):null]:th(a);return(e.maxTime||r.value.maxDate)&&(l=t_(e.maxTime,r.value.maxDate,"max",d,l)),(e.minTime||r.value.minDate)&&(l=t_(e.minTime,r.value.minDate,"min",d,l)),t=l,e.disabledTimes?Array.isArray(e.disabledTimes)?(n=Array.isArray(a)?a:[a],Array.isArray(e.disabledTimes)?Array.isArray(e.disabledTimes[0])?((e,a,t)=>{let[r,n]=e,[o,i]=a;return!s(r,o,t)&&!s(n,i,t)&&t})(e.disabledTimes,n,t):!n.some(a=>s(e.disabledTimes,a,t)):t):(o=Array.isArray(a)?[a2(a[0]),a[1]?a2(a[1]):void 0]:a2(a),i=!e.disabledTimes(o),t&&i):t},m=a=>{if(!e.monthPicker)return!0;let t=!0,n=aZ(a8(a));if(r.value.minDate&&r.value.maxDate){let e=aZ(a8(r.value.minDate)),a=aZ(a8(r.value.maxDate));return a5(n,e)&&a6(n,a)||a1(n,e)||a1(n,a)}if(r.value.minDate){let e=aZ(a8(r.value.minDate));t=a5(n,e)||a1(n,e)}if(r.value.maxDate){let e=aZ(a8(r.value.maxDate));t=a6(n,e)||a1(n,e)}return t},A=(0,c.EW)(()=>a=>!e.enableTimePicker||!!e.ignoreTimeValidation||v(a));return{isDisabled:u,validateDate:o,validateMonthYearInRange:(e,a,t,n)=>{let o,d=!1;return n&&(r.value.minDate||r.value.maxDate)?r.value.minDate&&r.value.maxDate?(o=!1,r.value.maxDate&&t&&l(e,a)&&(o=!0),r.value.minDate&&!t&&i(e,a)&&(o=!0),d=o):(r.value.minDate&&i(e,a)||r.value.maxDate&&l(e,a))&&(d=!0):d=!0,d},isDateRangeAllowed:e=>!t.value.noDisabledRange||!an({start:e[0],end:e[1]}).some(e=>u(e)),checkMinMaxRange:(e,a,r=0)=>{if(Array.isArray(a)&&a[r]&&(t.value.maxRange||t.value.minRange)&&p(a[r])&&p(e)){let n=S(e,a[r]),o=ta(a[r],e),i=1===o.length?0:o.filter(e=>u(e)).length,l=Math.abs(n)-(t.value.minMaxRawRange?0:i);if(t.value.minRange&&t.value.maxRange)return l>=+t.value.minRange&&l<=+t.value.maxRange;if(t.value.minRange)return l>=+t.value.minRange;if(t.value.maxRange)return l<=+t.value.maxRange}return!0},isValidTime:v,isTimeValid:A,isMonthValid:(0,c.EW)(()=>a=>!e.monthPicker||(Array.isArray(a)&&(t.value.enabled||n.value.enabled)?!a.filter(e=>!m(e)).length:m(a)))}},rU=()=>({hideNavigationButtons:(0,c.EW)(()=>(e,a)=>e?.includes(a)),showLeftIcon:(0,c.EW)(()=>(e,a)=>!e.count||!!e.solo||0===a),showRightIcon:(0,c.EW)(()=>(e,a)=>!e.count||!!e.solo||a===e.count-1)}),rZ=(e,a,t)=>{let r=(0,v.KR)(0),n=(0,v.Kh)({[aB.timePicker]:!e.enableTimePicker||e.timePicker||e.monthPicker,[aB.calendar]:!1,[aB.header]:!1}),o=(0,c.EW)(()=>e.monthPicker||e.timePicker),i=()=>{r.value=-1},l=(a,n,...o)=>{e.flow[r.value]===a&&t.value&&t.value[n]?.(...o)},d=(a=0)=>{a&&(r.value+=a),l(aD.month,"toggleMonthPicker",!0),l(aD.year,"toggleYearPicker",!0),l(aD.calendar,"toggleTimePicker",!1,!0),l(aD.time,"toggleTimePicker",!0,!0);let t=e.flow[r.value];(t===aD.hours||t===aD.minutes||t===aD.seconds)&&l(t,"toggleTimePicker",!0,!0,t)};return{childMount:a=>{if(e.flow?.length){if(!a&&o.value)return d();n[a]=!0,Object.keys(n).filter(e=>!n[e]).length||d()}},updateFlowStep:()=>{e.flow?.length&&-1!==r.value&&(r.value+=1,a("flow-step",r.value),d()),e.flow?.length===r.value&&(0,c.dY)().then(()=>i())},resetFlow:i,handleFlow:d,flowStep:r}},rJ={key:1,class:"dp__input_wrap"},r0=["id","name","inputmode","placeholder","disabled","readonly","required","value","autocomplete","aria-label","aria-disabled","aria-invalid"],r6={key:2,class:"dp--clear-btn"},r1=["aria-label"],r5=(0,c.pM)({compatConfig:{MODE:3},__name:"DatepickerInput",props:{isMenuOpen:{type:Boolean,default:!1},inputValue:{type:String,default:""},...tO},emits:["clear","open","update:input-value","set-input-date","close","select-date","set-empty-date","toggle","focus-prev","focus","blur","real-blur","text-input"],setup(e,{expose:a,emit:t}){let{defaultedTextInput:r,defaultedAriaLabels:n,defaultedInline:o,defaultedConfig:i,defaultedRange:l,defaultedMultiDates:d,defaultedUI:u,getDefaultPattern:p,getDefaultStartTime:s}=tW(e),{checkMinMaxRange:A}=rG(e),_=(0,v.KR)(),g=(0,v.KR)(null),C=(0,v.KR)(!1),b=(0,v.KR)(!1),y=(0,c.EW)(()=>({dp__pointer:!e.disabled&&!e.readonly&&!r.value.enabled,dp__disabled:e.disabled,dp__input_readonly:!r.value.enabled,dp__input:!0,dp__input_not_clearable:!e.clearable,dp__input_icon_pad:!e.hideInputIcon,dp__input_valid:"boolean"==typeof e.state&&e.state,dp__input_invalid:"boolean"==typeof e.state&&!e.state,dp__input_focus:C.value||e.isMenuOpen,dp__input_reg:!r.value.enabled,...u.value.input??{}})),f=a=>{let t=s();return((e,a,t,r,n,o)=>{let i=Array.isArray(t)?t[0]:t;if("string"==typeof a)return aU(e,a,i,r,n,o);if(Array.isArray(a)){let t=null;for(let l of a)if(t=aU(e,l,i,r,n,o))break;return t}return"function"==typeof a?a(e):null})(a,r.value.format??p(),t??tn({},e.enableSeconds),e.inputValue,b.value,e.formatLocale)},w=()=>{b.value=!0},k=e=>{l.value.enabled?(e=>{let{rangeSeparator:a}=r.value,[t,n]=e.split(`${a}`);if(t){let e=f(t.trim()),a=n?f(n.trim()):void 0;if(e2(e,a))return;let r=e&&a?[e,a]:[e];A(a,r,0)&&(_.value=e?r:null)}})(e):d.value.enabled?_.value=e.split(";").map(e=>f(e.trim())).filter(e=>e):_.value=f(e)},E=a=>{let n="string"==typeof a?a:a.target?.value;""!==n?(r.value.openMenu&&!e.isMenuOpen&&t("open"),k(n),t("set-input-date",_.value)):(t("set-input-date",null),e.clearable&&e.autoApply&&(t("set-empty-date"),_.value=null)),b.value=!1,t("update:input-value",n),t("text-input",a,_.value)},x=a=>{r.value.enabled?(k(a.target.value),r.value.enterSubmit&&tv(_.value)&&""!==e.inputValue?(t("set-input-date",_.value,!0),_.value=null):r.value.enterSubmit&&""===e.inputValue&&(_.value=null,t("clear"))):R(a)},B=(a,n)=>{r.value.enabled&&r.value.tabSubmit&&!n&&k(a.target.value),r.value.tabSubmit&&tv(_.value)&&""!==e.inputValue?(t("set-input-date",_.value,!0,!0),_.value=null):r.value.tabSubmit&&""===e.inputValue&&(_.value=null,t("clear",!0))},D=()=>{C.value=!0,t("focus"),(0,c.dY)().then(()=>{r.value.enabled&&r.value.selectOnFocus&&g.value?.select()})},R=a=>{if(aV(a,i.value,!0),r.value.enabled&&r.value.openMenu&&!o.value.input){if("open"===r.value.openMenu&&!e.isMenuOpen)return t("open");if("toggle"===r.value.openMenu)return t("toggle")}else r.value.enabled||t("toggle")},M=()=>{t("real-blur"),C.value=!1,(!e.isMenuOpen||o.value.enabled&&o.value.input)&&t("blur"),e.autoApply&&r.value.enabled&&_.value&&!e.isMenuOpen&&(t("set-input-date",_.value),t("select-date"),_.value=null)},T=e=>{aV(e,i.value,!0),t("clear")},S=e=>{"Tab"===e.key&&B(e),"Enter"===e.key&&x(e),"Escape"===e.key&&r.value.escClose&&t("close"),r.value.enabled||"Tab"!==e.code&&e.preventDefault()},P=e=>{e.key===aT.tab&&B(e,!0)};return a({focusInput:()=>{g.value?.focus({preventScroll:!0})},setParsedDate:e=>{_.value=e}}),(a,i)=>((0,c.uX)(),(0,c.CE)("div",{onClick:R},[!a.$slots.trigger||a.$slots["dp-input"]||(0,v.R1)(o).enabled?(0,c.Q3)("",!0):(0,c.RG)(a.$slots,"trigger",{key:0}),a.$slots.trigger||(0,v.R1)(o).enabled&&!(0,v.R1)(o).input?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("div",rJ,[a.$slots["dp-input"]&&!a.$slots.trigger&&(!(0,v.R1)(o).enabled||(0,v.R1)(o).enabled&&(0,v.R1)(o).input)?(0,c.RG)(a.$slots,"dp-input",{key:0,value:e.inputValue,isMenuOpen:e.isMenuOpen,onInput:E,onEnter:x,onTab:B,onClear:T,onBlur:M,onKeypress:S,onPaste:w,onFocus:D,openMenu:()=>a.$emit("open"),closeMenu:()=>a.$emit("close"),toggleMenu:()=>a.$emit("toggle")}):(0,c.Q3)("",!0),a.$slots["dp-input"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.CE)("input",{key:1,id:a.uid?`dp-input-${a.uid}`:void 0,ref_key:"inputRef",ref:g,"data-test-id":"dp-input",name:a.name,class:(0,m.normalizeClass)(y.value),inputmode:(0,v.R1)(r).enabled?"text":"none",placeholder:a.placeholder,disabled:a.disabled,readonly:a.readonly,required:a.required,value:e.inputValue,autocomplete:a.autocomplete,"aria-label":(0,v.R1)(n)?.input,"aria-disabled":a.disabled||void 0,"aria-invalid":!1===a.state||void 0,onInput:E,onBlur:M,onFocus:D,onKeypress:S,onKeydown:i[0]||(i[0]=e=>S(e)),onPaste:w},null,42,r0)),(0,c.Lk)("div",{onClick:i[3]||(i[3]=e=>t("toggle"))},[a.$slots["input-icon"]&&!a.hideInputIcon?((0,c.uX)(),(0,c.CE)("span",{key:0,class:"dp__input_icon",onClick:i[1]||(i[1]=e=>t("toggle"))},[(0,c.RG)(a.$slots,"input-icon")])):(0,c.Q3)("",!0),a.$slots["input-icon"]||a.hideInputIcon||a.$slots["dp-input"]?(0,c.Q3)("",!0):((0,c.uX)(),(0,c.Wv)((0,v.R1)(aA),{key:1,"aria-label":(0,v.R1)(n)?.calendarIcon,class:"dp__input_icon dp__input_icons",onClick:i[2]||(i[2]=e=>t("toggle"))},null,8,["aria-label"]))]),a.$slots["clear-icon"]&&(a.alwaysClearable||e.inputValue&&a.clearable&&!a.disabled&&!a.readonly)?((0,c.uX)(),(0,c.CE)("span",r6,[(0,c.RG)(a.$slots,"clear-icon",{clear:T})])):(0,c.Q3)("",!0),!a.$slots["clear-icon"]&&(a.alwaysClearable||a.clearable&&e.inputValue&&!a.disabled&&!a.readonly)?((0,c.uX)(),(0,c.CE)("button",{key:3,"aria-label":(0,v.R1)(n)?.clearInput,class:"dp--clear-btn",type:"button",onKeydown:i[4]||(i[4]=e=>(0,v.R1)(aj)(e,()=>T(e),!0,P)),onClick:i[5]||(i[5]=(0,h.withModifiers)(e=>T(e),["prevent"]))},[(0,c.bF)((0,v.R1)(a_),{class:"dp__input_icons","data-test-id":"clear-icon"})],40,r1)):(0,c.Q3)("",!0)]))]))}}),r4="u">typeof window?window:void 0,r8=()=>{},r7=["data-dp-mobile"],r2=(0,c.pM)({compatConfig:{MODE:3},__name:"VueDatePicker",props:{...tO},emits:["update:model-value","update:model-timezone-value","text-submit","closed","cleared","open","focus","blur","internal-model-change","recalculate-position","flow-step","update-month-year","invalid-select","invalid-fixed-range","tooltip-open","tooltip-close","time-picker-open","time-picker-close","am-pm-change","range-start","range-end","date-update","invalid-date","overlay-toggle","text-input"],setup(e,{expose:a,emit:t}){let r=(0,c.Ht)(),n=(0,v.KR)(!1),o=(0,v.lW)(e,"modelValue"),i=(0,v.lW)(e,"timezone"),l=(0,v.KR)(null),d=(0,v.KR)(null),u=(0,v.KR)(null),p=(0,v.KR)(!1),s=(0,v.KR)(null),A=(0,v.KR)(!1),_=(0,v.KR)(!1),g=(0,v.KR)(!1),C=(0,v.KR)(!1),{setMenuFocused:b,setShiftKey:y}=tk(),{clearArrowNav:f}=tP(),{validateDate:w,isValidTime:k}=rG(e),{defaultedTransitions:E,defaultedTextInput:x,defaultedInline:R,defaultedConfig:M,defaultedRange:T,defaultedMultiDates:S}=tW(e),{menuTransition:P,showTransition:z}=rH(E),{isMobile:$}=rT(M),Y=(0,c.nI)();(0,c.sV)(()=>{H(e.modelValue),(0,c.dY)().then(()=>{R.value.enabled||(V(s.value)?.addEventListener("scroll",er),window?.addEventListener("resize",en))}),R.value.enabled&&(n.value=!0),window?.addEventListener("keyup",eo),window?.addEventListener("keydown",el)}),(0,c.hi)(()=>{R.value.enabled||(V(s.value)?.removeEventListener("scroll",er),window?.removeEventListener("resize",en)),window?.removeEventListener("keyup",eo),window?.removeEventListener("keydown",el)});let W=rq(r,"all",e.presetDates),O=rq(r,"input");(0,c.wB)([o,i],()=>{H(o.value)},{deep:!0});let{openOnTop:N,menuStyle:I,xCorrect:X,setMenuPosition:F,getScrollableParent:V,shadowRender:L}=(({menuRef:e,menuRefInner:a,inputRef:t,pickerWrapperRef:r,inline:n,emit:o,props:i,slots:l})=>{let{defaultedConfig:d}=tW(i),u=(0,v.KR)({}),p=(0,v.KR)(!1),s=(0,v.KR)({top:"0",left:"0"}),m=(0,v.KR)(!1),A=(0,v.lW)(i,"teleportCenter");(0,c.wB)(A,()=>{s.value=JSON.parse(JSON.stringify({})),y()});let _=(e,a)=>{s.value.left=`${e+a-u.value.width}px`},g=e=>{s.value.left=`${e}px`},C=(e,a)=>{i.position===rF.left&&g(e),i.position===rF.right&&_(e,a),i.position===rF.center&&(s.value.left=`${e+a/2-u.value.width/2}px`)},b=e=>{let{width:a,height:t}=e.getBoundingClientRect(),{top:r,left:n}=(e=>{if(i.teleport){let a=e.getBoundingClientRect();return{left:a.left+window.scrollX,top:a.top+window.scrollY}}return{top:0,left:0}})(e);return{top:+r,left:+n,width:a,height:t}},y=(r=!0)=>{if(!n.value.enabled){if(A.value)return void(s.value.left="50%",s.value.top="50%",s.value.transform="translate(-50%, -50%)",s.value.position="fixed",delete s.value.opacity);if(null!==i.altPosition){let e;return e=aY(t),void(s.value=i.altPosition(e))}if(r){let t=i.teleport?a.value?.$el:e.value;t&&(u.value=t.getBoundingClientRect()),o("recalculate-position")}return E()}},f=({inputEl:e,left:a,width:t})=>{window.screen.width>768&&!p.value&&C(a,t),k(e)},w=e=>{let{top:a,left:t,height:r,width:n}=b(e);s.value.top=`${r+a+ +i.offset}px`,m.value=!1,p.value||(s.value.left=`${t+n/2-u.value.width/2}px`),f({inputEl:e,left:t,width:n})},k=e=>{if(i.autoPosition){let{left:a,width:t}=b(e),{left:r,right:n}=u.value;if(!p.value){if(Math.abs(r)!==Math.abs(n)){if(r<=0)return p.value=!0,g(a);if(n>=document.documentElement.clientWidth)return p.value=!0,_(a,t)}return C(a,t)}}},E=()=>{let e=aY(t);if(e)return i.autoPosition?(()=>{let e=aY(t);if(e){if(i.autoPosition===ax.top)return ax.top;if(i.autoPosition===ax.bottom)return ax.bottom;let{height:a}=u.value,{top:t,height:r}=e.getBoundingClientRect(),n=window.innerHeight-t-r;return a<=n?ax.bottom:a>n&&a<=t?ax.top:n>=t?ax.bottom:ax.top}return ax.bottom})()===ax.bottom?w(e):(e=>{let{top:a,left:t,width:r}=b(e);s.value.top=`${a-i.offset-u.value.height}px`,m.value=!0,f({inputEl:e,left:t,width:r})})(e):w(e)},x=function(e){if(e){let a=e.scrollHeight>e.clientHeight,t=-1!==window.getComputedStyle(e).overflowY.indexOf("hidden");return a&&!t}return!0},B=function(e){return e&&e!==document.body&&e.nodeType!==Node.DOCUMENT_FRAGMENT_NODE?x(e)?e:B(e.assignedSlot&&d.value.shadowDom?e.assignedSlot.parentNode:e.parentNode):window};return{openOnTop:m,menuStyle:s,xCorrect:p,setMenuPosition:y,getScrollableParent:B,shadowRender:(e,a,n)=>{let o=document.createElement("div"),p=aY(t)?.getBoundingClientRect();o.setAttribute("id","dp--temp-container");let s=r.value?.clientWidth?r.value:document.body;s.append(o);let v=(e=>{if(e)switch(i.position){case rF.left:return{left:0,transform:"translateX(0)"};case rF.right:return{left:`${e.width}px`,transform:"translateX(-100%)"};default:return{left:`${e.width/2}px`,transform:"translateX(-50%)"}}return{}})(p),m=d.value.shadowDom?Object.keys(l).filter(e=>["right-sidebar","left-sidebar","top-extra","action-extra"].includes(e)):Object.keys(l),A=(0,c.h)(a,{...n,shadow:!0,style:{opacity:0,position:"absolute",...v}},Object.fromEntries(m.map(e=>[e,l[e]])));null!=e&&(A.appContext=e.appContext),(0,h.render)(A,o),u.value=A.el?.getBoundingClientRect(),(0,h.render)(null,o),s.removeChild(o)}}})({menuRef:l,menuRefInner:d,inputRef:u,pickerWrapperRef:s,inline:R,emit:t,props:e,slots:r}),{inputValue:K,internalModelValue:q,parseExternalModelValue:H,emitModelValue:j,formatInputValue:Q,checkBeforeEmit:G}=((e,a,{isInputFocused:t,isTextInputDate:r})=>{let n=(0,v.KR)(),{defaultedTextInput:o,defaultedRange:i,defaultedTz:l,defaultedMultiDates:d,getDefaultPattern:u}=tW(a),p=(0,v.KR)(""),s=(0,v.lW)(a,"format"),m=(0,v.lW)(a,"formatLocale");(0,c.wB)(n,()=>{"function"==typeof a.onInternalModelChange&&e("internal-model-change",n.value,M(!0))},{deep:!0}),(0,c.wB)(i,(e,a)=>{e.enabled!==a.enabled&&(n.value=null)}),(0,c.wB)(s,()=>{f()});let A=e=>l.value.timezone&&l.value.convertModel?af(e,l.value.timezone):e,_=e=>{if(l.value.timezone&&l.value.convertModel){var a,t;let r=((e,a)=>{var t;let r;if(!e)return 0;let n=new Date,o=new Date(n.toLocaleString("en-US",{timeZone:"UTC"})),i=new Date(n.toLocaleString("en-US",{timeZone:e})),l=((r=new Date((t=a??i).getFullYear(),0,1).getTimezoneOffset(),t.getTimezoneOffset()<r)?i:a??i).getTimezoneOffset()/60;return(o-i)/36e5-l})(l.value.timezone,e);return a=36e5*r,t=void 0,B(t?.in||e,+D(e)+a)}return e},h=(e,t,r=!1)=>tp(e,a.format,a.formatLocale,o.value.rangeSeparator,a.modelAuto,t??u(),r),g=e=>e?a.modelType?k(e):{hours:e3(e),minutes:e9(e),seconds:a.enableSeconds?ae(e):0}:null,C=e=>a.modelType?k(e):{month:at(e),year:aa(e)},b=(e,t)=>("string"==typeof e||"number"==typeof e)&&a.modelType?w(e):t,y=()=>{let e=n.value;return[k(e[0]),e[1]?k(e[1]):ts(i.value.partialRange)]},f=()=>{let e;!a.format||"string"==typeof a.format||o.value.enabled&&"string"==typeof o.value.format?p.value=n.value?d.value.enabled?n.value.map(e=>h(e)).join("; "):o.value.enabled&&"string"==typeof o.value.format&&t.value&&n.value?Array.isArray(n.value)?(e=e=>ei(e,o.value.format),`${e(n.value[0])} ${o.value.rangeSeparator} ${n.value[1]?e(n.value[1]):""}`):ei(n.value,o.value.format):h(n.value):"":p.value=a.format(n.value)},w=e=>{if(a.utc){let t=new Date(e);return"preserve"===a.utc?new Date(t.getTime()+6e4*t.getTimezoneOffset()):t}return a.modelType?aR.includes(a.modelType)?A(new Date(e)):"format"!==a.modelType||"string"!=typeof a.format&&a.format?A(e0(e,a.modelType,new Date,{locale:m.value})):A(e0(e,u(),new Date,{locale:m.value})):A(new Date(e))},k=e=>e?a.utc?((e,a,t)=>{if(a){let a=(e.getMonth()+1).toString().padStart(2,"0"),r=e.getDate().toString().padStart(2,"0"),n=e.getHours().toString().padStart(2,"0"),o=e.getMinutes().toString().padStart(2,"0"),i=t?e.getSeconds().toString().padStart(2,"0"):"00";return`${e.getFullYear()}-${a}-${r}T${n}:${o}:${i}.000Z`}return new Date(Date.UTC(e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate(),e.getUTCHours(),e.getUTCMinutes(),e.getUTCSeconds())).toISOString()})(e,"preserve"===a.utc,a.enableSeconds):a.modelType?"timestamp"===a.modelType?+_(e):"iso"===a.modelType?_(e).toISOString():"format"!==a.modelType||"string"!=typeof a.format&&a.format?h(_(e),a.modelType,!0):h(_(e)):_(e):"",E=(a,t=!1,r=!1)=>{if(r)return a;e("update:model-value",a),l.value.emitTimezone&&t&&e("update:model-timezone-value",Array.isArray(a)?a.map(e=>af(e,l.value.emitTimezone)):af(a,l.value.emitTimezone))},x=()=>{if(Array.isArray(n.value)){let e=tr(n.value[0],a.weekStart),t=n.value[1]?tr(n.value[1],a.weekStart):[];return[e.map(e=>aZ(e)),t.map(e=>aZ(e))]}return tr(n.value,a.weekStart).map(e=>aZ(e))},R=(e,a)=>E(Array.isArray(n.value)?d.value.enabled?n.value.map(a=>e(a)):[e(n.value[0]),n.value[1]?e(n.value[1]):ts(i.value.partialRange)]:e(n.value),!1,a),M=(t=!1)=>{let r;return t||f(),a.monthPicker?R(C,t):a.timePicker?R(g,t):a.yearPicker?R(aa,t):a.weekPicker?(r=x(),t?r:e("update:model-value",x())):E(((e=!1)=>(e||Array.isArray(n.value)&&i.value.enabled&&1===n.value.length&&n.value.push(ts(i.value.partialRange)),a.modelAuto?Array.isArray(n.value)?n.value[1]?y():k(n.value[0]):[]:d.value.enabled?(n.value||[]).map(e=>k(e)):Array.isArray(n.value)?tc(()=>y(),i.value.enabled):k(n.value)))(t),!0,t)};return{inputValue:p,internalModelValue:n,checkBeforeEmit:()=>!!n.value&&(i.value.enabled?i.value.partialRange?n.value.length>=1:2===n.value.length:!!n.value),parseExternalModelValue:e=>{if(r.value)return;let t=(e=>{let t;return!e||Array.isArray(e)&&!e.length?null:a.timePicker?Array.isArray(e)?[b(e[0],a0(null,+e[0].hours,+e[0].minutes,e[0].seconds)),b(e[1],a0(null,+e[1].hours,+e[1].minutes,e[1].seconds))]:b(e,a0(null,e.hours,e.minutes,e.seconds)):a.monthPicker?(t=e1(aZ(),{date:1}),Array.isArray(e)?d.value.enabled?e.map(e=>b(e,ti(t,+e.month,+e.year))):tc(()=>[b(e[0],ti(t,+e[0].month,+e[0].year)),b(e[1],e[1]?ti(t,+e[1].month,+e[1].year):ts(i.value.partialRange))],i.value.enabled):b(e,ti(t,+e.month,+e.year))):a.yearPicker?Array.isArray(e)?d.value.enabled?e.map(e=>b(e,al(aZ(),e))):tc(()=>[al(aZ(),e[0]),e[1]?al(aZ(),e[1]):ts(i.value.partialRange)],i.value.enabled):al(aZ(),+e):d.value.enabled?(e=>{if(Array.isArray(e))return e.map(e=>w(e));throw Error('You need to use array as "model-value" binding in order to support "multi-dates"')})(e):a.weekPicker?(e=>{if(Array.isArray(e)&&i.value.enabled){let a=e[0],t=e[1];return[aZ(Array.isArray(a)?a[0]:null),Array.isArray(t)&&t.length?aZ(t[0]):null]}return aZ(e[0])})(e):a.modelAuto?Array.isArray(e)?[w(e[0]),w(e[1])]:a.autoApply?[w(e)]:[w(e),null]:Array.isArray(e)?tc(()=>e[1]?[w(e[0]),e[1]?w(e[1]):ts(i.value.partialRange)]:[w(e[0])],i.value.enabled):w(e)})(e);tv(t)?(n.value=t,f()):(n.value=null,p.value="")},formatInputValue:f,emitModelValue:M}})(t,e,{isInputFocused:p,isTextInputDate:C}),U=(0,c.EW)(()=>({dp__main:!0,dp__theme_dark:e.dark,dp__theme_light:!e.dark,dp__flex_display:R.value.enabled,"dp--flex-display-collapsed":g.value,dp__flex_display_with_input:R.value.input})),Z=(0,c.EW)(()=>e.dark?"dp__theme_dark":"dp__theme_light"),J=(0,c.EW)(()=>e.teleport?{to:"boolean"==typeof e.teleport?"body":e.teleport,disabled:!e.teleport||R.value.enabled}:{}),ee=(0,c.EW)(()=>({class:"dp__outer_menu_wrap"})),ea=(0,c.EW)(()=>R.value.enabled&&(e.timePicker||e.monthPicker||e.yearPicker||e.quarterPicker)),et=()=>u.value?.$el?.getBoundingClientRect()??{width:0,left:0,right:0},er=()=>{n.value&&(M.value.closeOnScroll?e_():F())},en=()=>{n.value&&F();let e=d.value?.$el.getBoundingClientRect().width??0;g.value=document.body.offsetWidth<=e},eo=a=>{"Tab"===a.key&&!R.value.enabled&&!e.teleport&&M.value.tabOutClosesMenu&&(s.value.contains(document.activeElement)||e_()),_.value=a.shiftKey},el=e=>{_.value=e.shiftKey},ed=()=>{e.disabled||e.readonly||(L(Y,rX,e),F(!1),n.value=!0,n.value&&t("open"),n.value||eA(),H(e.modelValue))},eu=()=>{K.value="",eA(),d.value?.onValueCleared(),u.value?.setParsedDate(null),t("update:model-value",null),t("update:model-timezone-value",null),t("cleared"),M.value.closeOnClearValue&&e_()},ep=()=>{let a=q.value;return!!(!a||!Array.isArray(a)&&w(a))||!!Array.isArray(a)&&(!!(S.value.enabled||2===a.length&&w(a[0])&&w(a[1]))||!!T.value.partialRange&&!e.timePicker&&w(a[0]))},es=()=>{G()&&ep()?(j(),e_()):t("invalid-select",q.value)},ec=e=>{ev(),j(),M.value.closeOnAutoApply&&!e&&e_()},ev=()=>{u.value&&x.value.enabled&&u.value.setParsedDate(q.value)},em=(a=!1)=>{e.autoApply&&k(q.value)&&ep()&&(T.value.enabled&&Array.isArray(q.value)?(T.value.partialRange||2===q.value.length)&&ec(a):ec(a))},eA=()=>{x.value.enabled||(q.value=null)},e_=(e=!1)=>{e&&q.value&&M.value.setDateOnMenuClose&&es(),R.value.enabled||(n.value&&(n.value=!1,X.value=!1,b(!1),y(!1),f(),t("closed"),K.value&&H(o.value)),eA(),t("blur"),d.value?.$el?.remove())},eh=(a,r,n=!1)=>{if(!a){q.value=null;return}let o=Array.isArray(a)?!a.some(e=>!w(e)):w(a),i=k(a);o&&i?(C.value=!0,q.value=a,r?(A.value=n,es(),t("text-submit")):e.autoApply&&em(!0),(0,c.dY)().then(()=>{C.value=!1})):t("invalid-date",a)},eg=()=>{e.autoApply&&k(q.value)&&j(),ev()},eC=()=>n.value?e_():ed(),eb=()=>{x.value.enabled&&(p.value=!0,Q()),t("focus")},ey=()=>{x.value.enabled&&(p.value=!1,H(e.modelValue),A.value&&(function(e,a){let t=[...document.querySelectorAll("a[href], area[href], input:not([disabled]):not([type='hidden']), select:not([disabled]), textarea:not([disabled]), button:not([disabled]), [tabindex]:not([tabindex='-1']), [data-datepicker-instance]")],r=(t=t.filter(a=>!e.contains(a)||a.hasAttribute("data-datepicker-instance"))).indexOf(e);if(r>=0&&(a?r-1>=0:r+1<=t.length))return t[r+(a?-1:1)]})(s.value,_.value)?.focus()),t("blur")};return((e,a,t,r={})=>{let{window:n=r4,event:o="pointerdown"}=r;return n&&((e,a,t,r)=>{let n;if(!e)return;let o=r8,i=(0,c.wB)(()=>(0,v.R1)(e),e=>{o(),e&&(e.removeEventListener(a,t),e.addEventListener(a,t,r),o=()=>{e.removeEventListener(a,t,r),o=r8})},{immediate:!0,flush:"post"});return n=()=>{i(),o()},(0,v.o5)()&&(0,v.jr)(n)})(n,o,r=>{let n=aY(e),o=aY(a);!n||!o||n===r.target||r.composedPath().includes(n)||r.composedPath().includes(o)||t(r)},{passive:!0})})(l,u,e=>M.value.onClickOutside?M.value.onClickOutside(ep,e):e_(!0)),a({closeMenu:e_,selectDate:es,clearValue:eu,openMenu:ed,onScroll:er,formatInputValue:Q,updateInternalModelValue:e=>{q.value=e},setMonthYear:e=>{d.value&&d.value.updateMonthYear(0,{month:aN(e.month),year:aN(e.year)})},parseModel:a=>{H(a??e.modelValue)},switchView:(e,a)=>{d.value?.switchView(e,a)},toggleMenu:eC,handleFlow:(e=0)=>{d.value?.handleFlow(e)},getDpWrapMenuRef:()=>l}),(e,a)=>((0,c.uX)(),(0,c.CE)("div",{ref_key:"pickerWrapperRef",ref:s,class:(0,m.normalizeClass)(U.value),"data-datepicker-instance":"","data-dp-mobile":(0,v.R1)($)},[(0,c.bF)(r5,(0,c.v6)({ref_key:"inputRef",ref:u,"input-value":(0,v.R1)(K),"onUpdate:inputValue":a[0]||(a[0]=e=>(0,v.i9)(K)?K.value=e:null),"is-menu-open":n.value},e.$props,{onClear:eu,onOpen:ed,onSetInputDate:eh,onSetEmptyDate:(0,v.R1)(j),onSelectDate:es,onToggle:eC,onClose:e_,onFocus:eb,onBlur:ey,onRealBlur:a[1]||(a[1]=e=>p.value=!1),onTextInput:a[2]||(a[2]=a=>e.$emit("text-input",a))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(O),(a,t)=>({name:a,fn:(0,c.k6)(t=>[(0,c.RG)(e.$slots,a,(0,m.normalizeProps)((0,c.Ng)(t)))])}))]),1040,["input-value","is-menu-open","onSetEmptyDate"]),((0,c.uX)(),(0,c.Wv)((0,c.$y)(e.teleport?c.Im:"div"),(0,m.normalizeProps)((0,c.Ng)(J.value)),{default:(0,c.k6)(()=>[(0,c.bF)(h.Transition,{name:(0,v.R1)(P)((0,v.R1)(N)),css:(0,v.R1)(z)&&!(0,v.R1)(R).enabled},{default:(0,c.k6)(()=>[n.value?((0,c.uX)(),(0,c.CE)("div",(0,c.v6)({key:0,ref_key:"dpWrapMenuRef",ref:l},ee.value,{class:{"dp--menu-wrapper":!(0,v.R1)(R).enabled},style:(0,v.R1)(R).enabled?void 0:(0,v.R1)(I)}),[(0,c.bF)(rX,(0,c.v6)({ref_key:"dpMenuRef",ref:d},e.$props,{"internal-model-value":(0,v.R1)(q),"onUpdate:internalModelValue":a[3]||(a[3]=e=>(0,v.i9)(q)?q.value=e:null),class:{[Z.value]:!0,"dp--menu-wrapper":e.teleport},"open-on-top":(0,v.R1)(N),"no-overlay-focus":ea.value,collapse:g.value,"get-input-rect":et,"is-text-input-date":C.value,onClosePicker:e_,onSelectDate:es,onAutoApply:em,onTimeUpdate:eg,onFlowStep:a[4]||(a[4]=a=>e.$emit("flow-step",a)),onUpdateMonthYear:a[5]||(a[5]=a=>e.$emit("update-month-year",a)),onInvalidSelect:a[6]||(a[6]=a=>e.$emit("invalid-select",(0,v.R1)(q))),onAutoApplyInvalid:a[7]||(a[7]=a=>e.$emit("invalid-select",a)),onInvalidFixedRange:a[8]||(a[8]=a=>e.$emit("invalid-fixed-range",a)),onRecalculatePosition:(0,v.R1)(F),onTooltipOpen:a[9]||(a[9]=a=>e.$emit("tooltip-open",a)),onTooltipClose:a[10]||(a[10]=a=>e.$emit("tooltip-close",a)),onTimePickerOpen:a[11]||(a[11]=a=>e.$emit("time-picker-open",a)),onTimePickerClose:a[12]||(a[12]=a=>e.$emit("time-picker-close",a)),onAmPmChange:a[13]||(a[13]=a=>e.$emit("am-pm-change",a)),onRangeStart:a[14]||(a[14]=a=>e.$emit("range-start",a)),onRangeEnd:a[15]||(a[15]=a=>e.$emit("range-end",a)),onDateUpdate:a[16]||(a[16]=a=>e.$emit("date-update",a)),onInvalidDate:a[17]||(a[17]=a=>e.$emit("invalid-date",a)),onOverlayToggle:a[18]||(a[18]=a=>e.$emit("overlay-toggle",a)),onMenuBlur:a[19]||(a[19]=a=>e.$emit("blur"))}),(0,c.eX)({_:2},[(0,c.pI)((0,v.R1)(W),(a,t)=>({name:a,fn:(0,c.k6)(t=>[(0,c.RG)(e.$slots,a,(0,m.normalizeProps)((0,c.Ng)({...t})))])}))]),1040,["internal-model-value","class","open-on-top","no-overlay-focus","collapse","is-text-input-date","onRecalculatePosition"])],16)):(0,c.Q3)("",!0)]),_:3},8,["name","css"])]),_:3},16))],10,r7))}}),r3=(r2.install=e=>{e.component("Vue3DatePicker",r2)},r2);Object.entries(Object.freeze(Object.defineProperty({__proto__:null,default:r3},Symbol.toStringTag,{value:"Module"}))).forEach(([e,a])=>{"default"!==e&&(r3[e]=a)});var r9=t(51012),ne=t(6446),na=t(22436),nt=t(42221),nr=t(52697);(0,na.r)(na.y);let nn={class:"vue-date-time-picker__wrapper"},no={ref:"target",class:"vue-date-time-picker__wrapper vue-date-time-picker__wrapper--teleport"},ni=(0,c.pM)({__name:"NcDateTimePicker",props:(0,c.zz)({appendToBody:{type:Boolean},ariaLabel:{default:(0,na.a)("Datepicker input")},ariaLabelMenu:{default:(0,na.a)("Datepicker menu")},clearable:{type:Boolean},confirm:{type:Boolean},format:{type:[String,Function],default:void 0},locale:{default:(0,_.lO)()},max:{default:void 0},min:{default:void 0},minuteStep:{default:10},modelValue:{default:null},placeholder:{default:void 0},showTimezoneSelect:{type:Boolean},showWeekNumber:{type:Boolean},type:{default:"date"},inline:{type:Boolean,default:!1}},{timezoneId:{default:"UTC"},timezoneIdModifiers:{}}),emits:(0,c.zz)(["update:modelValue","update:timezoneId","blur"],["update:timezoneId"]),setup(e,{emit:a}){let t=(0,c.fn)(e,"timezoneId"),r=(0,c.rk)("target"),n=(0,c.rk)("picker"),o=(0,c.EW)(()=>{if(null===e.modelValue&&e.clearable)return null;if("week"===e.type){let a=e.modelValue instanceof Date?e.modelValue:new Date,t=new Date(a);return t.setUTCDate(a.getUTCDate()+6),[a,t]}if("year"===e.type)return(e.modelValue instanceof Date?e.modelValue:new Date).getUTCFullYear();if("month"===e.type){let a=e.modelValue instanceof Date?e.modelValue:new Date;return{year:a.getUTCFullYear(),month:a.getUTCMonth()}}if("time"===e.type){let a=e.modelValue instanceof Date?e.modelValue:new Date;return{hours:a.getHours(),minutes:a.getMinutes(),seconds:a.getSeconds()}}if("time-range"===e.type){let a=[e.modelValue].flat();if(2!==a.length){let e=new Date,t=new Date(e);t.setHours(t.getHours()+1),a.splice(0,2,e,t)}return a.map(e=>({hours:e.getHours(),minutes:e.getMinutes(),seconds:e.getSeconds()}))}else if(e.type.endsWith("-range")){if(void 0===e.modelValue){let e=new Date,a=new Date(e);return a.setUTCDate(e.getUTCDate()+7),[e,a]}return e.modelValue}return e.modelValue??new Date}),i=(0,c.EW)(()=>{if("date"===e.type)return(0,na.a)("Select date");if("time"===e.type)return(0,na.a)("Select time");if("datetime"===e.type);else if("week"===e.type)return(0,na.a)("Select week");else if("month"===e.type)return(0,na.a)("Select month");else if("year"===e.type)return(0,na.a)("Select year");else if(e.type.endsWith("-range"))return(0,na.a)("Select time range");return(0,na.a)("Select date and time")}),l=(0,c.EW)(()=>{let a;return e.format?e.format:"week"===e.type?"RR-II":("date"===e.type||"date-range"===e.type?a=new Intl.DateTimeFormat((0,_.lO)(),{dateStyle:"medium"}):"time"===e.type||"time-range"===e.type?a=new Intl.DateTimeFormat((0,_.lO)(),{timeStyle:"short"}):"datetime"===e.type||"datetime-range"===e.type?a=new Intl.DateTimeFormat((0,_.lO)(),{dateStyle:"medium",timeStyle:"short"}):"month"===e.type?a=new Intl.DateTimeFormat((0,_.lO)(),{year:"numeric",month:"2-digit"}):"year"===e.type&&(a=new Intl.DateTimeFormat((0,_.lO)(),{year:"numeric"})),a)?e=>Array.isArray(e)?a.formatRange(e[0],e[1]):a.format(e):void 0}),d=(0,c.EW)(()=>({timePicker:"time"===e.type||"time-range"===e.type,yearPicker:"year"===e.type,monthPicker:"month"===e.type,weekPicker:"week"===e.type,range:e.type.endsWith("-range")&&{partialRange:!1},enableTimePicker:"date"!==e.type&&"date-range"!==e.type,flow:"datetime"===e.type?["calendar","time"]:void 0})),u=(0,c.EW)(()=>e.min&&{hours:e.min.getHours(),minutes:e.min.getMinutes(),seconds:e.min.getSeconds()}),p=(0,c.EW)(()=>e.max&&{hours:e.max.getHours(),minutes:e.max.getMinutes(),seconds:e.max.getSeconds()});function s(t){if(null===t)return a("update:modelValue",null);if("time"===e.type)a("update:modelValue",h(t));else if("time-range"===e.type){let e=h(t[0]),r=h(t[1]);r.getTime()<e.getTime()&&r.setDate(r.getDate()+1),a("update:modelValue",[e,r])}else"month"===e.type?a("update:modelValue",new Date(t.year,t.month,1)):"year"===e.type?a("update:modelValue",new Date(t,0)):"week"===e.type?a("update:modelValue",t[0]):a("update:modelValue",t)}function h(e){let a=new Date;return a.setHours(e.hours),a.setMinutes(e.minutes),a.setSeconds(e.seconds),a}let g=(0,_.JN)(),C=[...(0,_.Pe)()];for(let e=0;e<g;e++)C.push(C.shift());let b=(0,na.a)("W"),y=(0,c.EW)(()=>({toggleOverlay:(0,na.a)("Toggle overlay"),menu:e.ariaLabelMenu,input:e.ariaLabel,openTimePicker:(0,na.a)("Open time picker"),closeTimePicker:(0,na.a)("Close time Picker"),incrementValue:e=>"hours"===e?(0,na.a)("Increment hours"):"minutes"===e?(0,na.a)("Increment minutes"):(0,na.a)("Increment seconds"),decrementValue:e=>"hours"===e?(0,na.a)("Decrement hours"):"minutes"===e?(0,na.a)("Decrement minutes"):(0,na.a)("Decrement seconds"),openTpOverlay:e=>"hours"===e?(0,na.a)("Open hours overlay"):"minutes"===e?(0,na.a)("Open minutes overlay"):(0,na.a)("Open seconds overlay"),amPmButton:(0,na.a)("Switch AM/PM mode"),openYearsOverlay:(0,na.a)("Open years overlay"),openMonthsOverlay:(0,na.a)("Open months overlay"),nextMonth:(0,na.a)("Next month"),prevMonth:(0,na.a)("Previous month"),nextYear:(0,na.a)("Next year"),prevYear:(0,na.a)("Previous year"),weekDay:e=>(0,_.hY)()[e],clearInput:(0,na.a)("Clear value"),calendarIcon:(0,na.a)("Calendar icon"),timePicker:(0,na.a)("Time picker"),monthPicker:e=>e?(0,na.a)("Month picker overlay"):(0,na.a)("Month picker"),yearPicker:e=>e?(0,na.a)("Year picker overlay"):(0,na.a)("Year picker")}));function f(){n.value.selectDate()}function w(){n.value.closeMenu()}let k=(0,c.EW)(()=>"datetime"===e.type?{minDate:e.min,maxDate:e.max,minTime:e.min&&o.value&&E(e.min,o.value)?u.value:void 0,maxTime:e.max&&o.value&&E(e.max,o.value)?p.value:void 0}:"datetime-range"===e.type?{minDate:e.min,maxDate:e.max,minTime:e.min&&o.value&&E(e.min,o.value[0])?u.value:void 0,maxTime:e.max&&o.value&&E(e.max,o.value[1])?p.value:void 0}:"time"===e.type||"time-range"===e.type?{minTime:e.min?u.value:void 0,maxTime:e.max?p.value:void 0}:{minDate:e.min,maxDate:e.max});function E(e,a){return e.getFullYear()===a.getFullYear()&&e.getMonth()===a.getMonth()&&e.getDate()===a.getDate()}return(n,u)=>((0,c.uX)(),(0,c.CE)("div",nn,[(0,c.bF)((0,v.R1)(r3),(0,c.v6)({ref:"picker","aria-labels":y.value,autoApply:!e.confirm,class:["vue-date-time-picker",{"vue-date-time-picker--clearable":e.clearable}],cancelText:(0,v.R1)(na.a)("Cancel"),clearable:e.clearable,dayNames:C,placeholder:e.placeholder??i.value,format:l.value,locale:e.locale,minDate:k.value.minDate,maxDate:k.value.maxDate,minTime:k.value.minTime,maxTime:k.value.maxTime,minutesIncrement:e.minuteStep,modelValue:o.value,nowButtonLabel:(0,v.R1)(na.a)("Now"),selectText:(0,v.R1)(na.a)("Pick"),sixWeeks:"fair",inline:e.inline,teleport:!!e.appendToBody&&(r.value||void 0),textInput:"",weekNumName:(0,v.R1)(b),weekNumbers:e.showWeekNumber?{type:"iso"}:void 0,weekStart:(0,v.R1)(g)},d.value,{"onUpdate:modelValue":s,onBlur:u[1]||(u[1]=e=>a("blur"))}),(0,c.eX)({"action-buttons":(0,c.k6)(()=>[(0,c.bF)((0,v.R1)(nt.N),{size:"small",variant:"tertiary",onClick:w},{default:(0,c.k6)(()=>[(0,c.eW)((0,m.toDisplayString)((0,v.R1)(na.a)("Cancel")),1)]),_:1}),(0,c.bF)((0,v.R1)(nt.N),{size:"small",variant:"primary",onClick:f},{default:(0,c.k6)(()=>[(0,c.eW)((0,m.toDisplayString)((0,v.R1)(na.a)("Pick")),1)]),_:1})]),"clear-icon":(0,c.k6)(({clear:e})=>[(0,c.bF)((0,v.R1)(nt.N),{"aria-label":(0,v.R1)(na.a)("Clear value"),variant:"tertiary-no-background",onClick:e},{icon:(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.b),size:20},null,8,["path"])]),_:1},8,["aria-label","onClick"])]),"input-icon":(0,c.k6)(()=>[(0,c.bF)(r9.N,{path:(0,v.R1)(A.B),size:20},null,8,["path"])]),"clock-icon":(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.A),size:20},null,8,["path"])]),"arrow-left":(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.z),size:20},null,8,["path"])]),"arrow-right":(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.c),size:20},null,8,["path"])]),"arrow-down":(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.y),size:20},null,8,["path"])]),"arrow-up":(0,c.k6)(()=>[(0,c.bF)(r9.N,{inline:"",path:(0,v.R1)(A.x),size:20},null,8,["path"])]),_:2},[e.showTimezoneSelect?{name:"action-extra",fn:(0,c.k6)(()=>[(0,c.bF)(ne._,{modelValue:t.value,"onUpdate:modelValue":u[0]||(u[0]=e=>t.value=e),class:"vue-date-time-picker__timezone",appendToBody:!1,inputLabel:(0,v.R1)(na.a)("Time zone")},null,8,["modelValue","inputLabel"])]),key:"0"}:void 0]),1040,["aria-labels","autoApply","class","cancelText","clearable","placeholder","format","locale","minDate","maxDate","minTime","maxTime","minutesIncrement","modelValue","nowButtonLabel","selectText","inline","teleport","weekNumName","weekNumbers","weekStart"]),((0,c.uX)(),(0,c.Wv)(c.Im,{to:"body",disabled:!e.appendToBody},[(0,c.Lk)("div",no,null,512)],8,["disabled"]))]))}}),nl=(0,nr._)(ni,[["__scopeId","data-v-e6654786"]])}}]);
//# sourceMappingURL=calendar-defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcDateTimePicker-CK4rhfEB_mjs.js.map?v=4883fcea72061dfc